import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountAlertRequest } from '../model/accountAlertRequest';
import { AccountAlertResponse } from '../model/accountAlertResponse';
import { AccountAuditEnable } from '../model/accountAuditEnable';
import { AccountAuditSettingsRequest } from '../model/accountAuditSettingsRequest';
import { AccountAuditSettingsResponse } from '../model/accountAuditSettingsResponse';
import { AccountCodeHistoryRequest } from '../model/accountCodeHistoryRequest';
import { AccountCodeHistoryResponse } from '../model/accountCodeHistoryResponse';
import { AccountCreate } from '../model/accountCreate';
import { AccountEdit } from '../model/accountEdit';
import { AccountRateResponse } from '../model/accountRateResponse';
import { AccountResponse } from '../model/accountResponse';
import { AccountTemplateResponse } from '../model/accountTemplateResponse';
import { AccountUDFResponse } from '../model/accountUDFResponse';
import { SearchAccountMeterBillEntry } from '../model/searchAccountMeterBillEntry';
import { SingleValue } from '../model/singleValue';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WebhookCustomAction } from '../model/webhookCustomAction';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class AccountService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates an account
     *
     * @param body Data representing the account being created
     */
    createAccount(body?: AccountCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountResponse>;
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlert(accountId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAlertResponse>;
    /**
     * Deletes an account. Currently NO confirmation is required
     *
     * @param accountId The identifier for the account being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteAccount(accountId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlert(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFile(accountId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccount(accountId: number, body?: AccountEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountResponse>;
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersion(accountId: number, body?: AccountCodeHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountCodeHistoryResponse>;
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFs(accountId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccount(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountResponse>;
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlert(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAlertResponse>;
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlerts(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountAlertResponse>>;
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettings(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAuditSettingsResponse>;
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRates(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountRateResponse>>;
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplates(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountTemplateResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfs(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccounts(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountUDFResponse>>;
    /**
     * For a given accountId, startDate and endDates for a bill get a billing period recommendation  The billing period will be in YYYYMM format YYYY represents the 4 digit year and MM is the two digit month 01 for Jan to 12 for Dec
     *
     * @param accountId The identifier for the account for which bill is being created
     * @param startDate The start date of the bill
     * @param endDate The end date of the bill
     */
    getDefaultBillingPeriod(accountId: number, startDate?: Date, endDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleValue>;
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccount(parentCostCenterId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomAction(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccounts(query?: string, includeInactiveAccounts?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SearchAccountMeterBillEntry>>;
    /**
     * Enable or disable Accounts from audits
     *
     * @param body
     */
    setAccountAuditExclusion(body?: AccountAuditEnable, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlert(accountId: number, alertId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAlertResponse>;
    /**
     * Update audit settings for an account.   Every audit must be included but supplying null for its settings will remove them.
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param accountId The account identifier
     * @param body The new state of the audit settings
     */
    updateAccountAuditSettings(accountId: number, body?: AccountAuditSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAuditSettingsResponse>;
    /**
     * Creates an account
     *
     * @param body Data representing the account being created
     */
    createAccountWithHttpInfo(body?: AccountCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountResponse>>;
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlertWithHttpInfo(accountId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAlertResponse>>;
    /**
     * Deletes an account. Currently NO confirmation is required
     *
     * @param accountId The identifier for the account being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteAccountWithHttpInfo(accountId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlertWithHttpInfo(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFileWithHttpInfo(accountId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccountWithHttpInfo(accountId: number, body?: AccountEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountResponse>>;
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersionWithHttpInfo(accountId: number, body?: AccountCodeHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountCodeHistoryResponse>>;
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFsWithHttpInfo(accountId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccountWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountResponse>>;
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlertWithHttpInfo(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAlertResponse>>;
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlertsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountAlertResponse>>>;
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettingsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAuditSettingsResponse>>;
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRatesWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountRateResponse>>>;
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplatesWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountTemplateResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountUDFResponse>>>;
    /**
     * For a given accountId, startDate and endDates for a bill get a billing period recommendation  The billing period will be in YYYYMM format YYYY represents the 4 digit year and MM is the two digit month 01 for Jan to 12 for Dec
     *
     * @param accountId The identifier for the account for which bill is being created
     * @param startDate The start date of the bill
     * @param endDate The end date of the bill
     */
    getDefaultBillingPeriodWithHttpInfo(accountId: number, startDate?: Date, endDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleValue>>;
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccountWithHttpInfo(parentCostCenterId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomActionWithHttpInfo(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccountsWithHttpInfo(query?: string, includeInactiveAccounts?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SearchAccountMeterBillEntry>>>;
    /**
     * Enable or disable Accounts from audits
     *
     * @param body
     */
    setAccountAuditExclusionWithHttpInfo(body?: AccountAuditEnable, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlertWithHttpInfo(accountId: number, alertId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAlertResponse>>;
    /**
     * Update audit settings for an account.   Every audit must be included but supplying null for its settings will remove them.
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param accountId The account identifier
     * @param body The new state of the audit settings
     */
    updateAccountAuditSettingsWithHttpInfo(accountId: number, body?: AccountAuditSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAuditSettingsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AccountService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AccountService>;
}
