import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountDigestActualMonthlyResponse } from '../model/accountDigestActualMonthlyResponse';
import { AccountDigestActualYearlyResponse } from '../model/accountDigestActualYearlyResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class AccountDigestService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthly(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountDigestActualMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearly(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountDigestActualYearlyResponse>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountDigestActualYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthlyWithHttpInfo(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountDigestActualMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearlyWithHttpInfo(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountDigestActualYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountDigestActualYearlyResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AccountDigestService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AccountDigestService>;
}
