import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountMeterEdit } from '../model/accountMeterEdit';
import { AccountMeterRateResponse } from '../model/accountMeterRateResponse';
import { AccountMeterRequest } from '../model/accountMeterRequest';
import { AccountMeterResponse } from '../model/accountMeterResponse';
import { AccountRateRequest } from '../model/accountRateRequest';
import { FormTemplateRequest } from '../model/formTemplateRequest';
import { FormTemplateResponse } from '../model/formTemplateResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class AccountMeterService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeter(body?: Array<AccountMeterRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountMeterResponse>>;
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRate(accountMeterId: number, body?: AccountRateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountMeterRateResponse>;
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplate(accountMeterId: number, body?: FormTemplateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FormTemplateResponse>;
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeter(accountMeterId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignment(accountMeterId: number, formTemplateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeter(accountMeterId: number, deleteBills?: boolean, body?: AccountMeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountMeterResponse>;
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateList(accountMeterId: number, body?: Array<AccountRateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountMeterRateResponse>>;
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateList(accountMeterId: number, body?: Array<FormTemplateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FormTemplateResponse>>;
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeterWithHttpInfo(body?: Array<AccountMeterRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountMeterResponse>>>;
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRateWithHttpInfo(accountMeterId: number, body?: AccountRateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountMeterRateResponse>>;
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplateWithHttpInfo(accountMeterId: number, body?: FormTemplateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FormTemplateResponse>>;
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeterWithHttpInfo(accountMeterId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignmentWithHttpInfo(accountMeterId: number, formTemplateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeterWithHttpInfo(accountMeterId: number, deleteBills?: boolean, body?: AccountMeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountMeterResponse>>;
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateListWithHttpInfo(accountMeterId: number, body?: Array<AccountRateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountMeterRateResponse>>>;
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateListWithHttpInfo(accountMeterId: number, body?: Array<FormTemplateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FormTemplateResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AccountMeterService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AccountMeterService>;
}
