import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccrualProcessorRequest } from '../model/accrualProcessorRequest';
import { AccrualSettingsResponse } from '../model/accrualSettingsResponse';
import { GuidResponse } from '../model/guidResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class AccrualService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete all bills created by the Accrual task   If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the accrual task
     */
    deleteAccrualTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Get Accrual settings
     *
     */
    getAccrualSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccrualSettingsResponse>;
    /**
     * Run the accrual processor engine using the supplied settings to generate accrual bills
     *
     * @param filter Accrual data selection filters
     * @param body Accrual processor settings
     */
    processAccruals(filter?: string, body?: AccrualProcessorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     * Void all bills created by the Accrual task  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the accrual task
     */
    voidAccrualTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete all bills created by the Accrual task   If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the accrual task
     */
    deleteAccrualTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Get Accrual settings
     *
     */
    getAccrualSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccrualSettingsResponse>>;
    /**
     * Run the accrual processor engine using the supplied settings to generate accrual bills
     *
     * @param filter Accrual data selection filters
     * @param body Accrual processor settings
     */
    processAccrualsWithHttpInfo(filter?: string, body?: AccrualProcessorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     * Void all bills created by the Accrual task  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the accrual task
     */
    voidAccrualTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AccrualService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AccrualService>;
}
