import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountPeriodResponse } from '../model/accountPeriodResponse';
import { AccountingSettingsRequest } from '../model/accountingSettingsRequest';
import { AccountingSettingsResponse } from '../model/accountingSettingsResponse';
import { AdminSettingsRequest } from '../model/adminSettingsRequest';
import { AdminSettingsResponse } from '../model/adminSettingsResponse';
import { LicenseRequest } from '../model/licenseRequest';
import { LicenseResponse } from '../model/licenseResponse';
import { ReportingSettingRequest } from '../model/reportingSettingRequest';
import { ReportingSettingResponse } from '../model/reportingSettingResponse';
import { SingleValue } from '../model/singleValue';
import { SystemSettingsRequest } from '../model/systemSettingsRequest';
import { SystemSettingsResponse } from '../model/systemSettingsResponse';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class AdminService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Edit accounting settings
     *
     * @param body
     */
    editAccountingSettings(body?: AccountingSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountingSettingsResponse>;
    /**
     * Edit the license details.
     *
     * @param body
     */
    editLicenseDetails(body?: LicenseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<LicenseResponse>;
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettings(body?: SystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SystemSettingsResponse>;
    /**
     * Get the list of account periods
     *
     */
    getAccountPeriods(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountPeriodResponse>>;
    /**
     * Get accounting settings
     *
     */
    getAccountingSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountingSettingsResponse>;
    /**
     * Get license details.
     *
     */
    getLicenseDetails(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<LicenseResponse>;
    /**
     * Retrieve the organization logo, if configured. Only URLs or JPEG, PNG, and SVG images are acceptable organization logos. If the saved base64 image is of a different file type, it will return an error.
     *
     */
    getOrganizationLogo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleValue>;
    /**
     * Get the system reporting settings
     *
     */
    getReportingSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportingSettingResponse>;
    /**
     *
     *
     */
    getSystemSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AdminSettingsResponse>>;
    /**
     * Get system settings
     *
     */
    getSystemSettingsNew(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SystemSettingsResponse>;
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppAction(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettings(body?: ReportingSettingRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportingSettingResponse>;
    /**
     *
     *
     * @param body
     */
    updateSystemSettings(body?: Array<AdminSettingsRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AdminSettingsResponse>>;
    /**
     * Edit accounting settings
     *
     * @param body
     */
    editAccountingSettingsWithHttpInfo(body?: AccountingSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountingSettingsResponse>>;
    /**
     * Edit the license details.
     *
     * @param body
     */
    editLicenseDetailsWithHttpInfo(body?: LicenseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<LicenseResponse>>;
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettingsWithHttpInfo(body?: SystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SystemSettingsResponse>>;
    /**
     * Get the list of account periods
     *
     */
    getAccountPeriodsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountPeriodResponse>>>;
    /**
     * Get accounting settings
     *
     */
    getAccountingSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountingSettingsResponse>>;
    /**
     * Get license details.
     *
     */
    getLicenseDetailsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<LicenseResponse>>;
    /**
     * Retrieve the organization logo, if configured. Only URLs or JPEG, PNG, and SVG images are acceptable organization logos. If the saved base64 image is of a different file type, it will return an error.
     *
     */
    getOrganizationLogoWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleValue>>;
    /**
     * Get the system reporting settings
     *
     */
    getReportingSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportingSettingResponse>>;
    /**
     *
     *
     */
    getSystemSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AdminSettingsResponse>>>;
    /**
     * Get system settings
     *
     */
    getSystemSettingsNewWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SystemSettingsResponse>>;
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppActionWithHttpInfo(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettingsWithHttpInfo(body?: ReportingSettingRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportingSettingResponse>>;
    /**
     *
     *
     * @param body
     */
    updateSystemSettingsWithHttpInfo(body?: Array<AdminSettingsRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AdminSettingsResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AdminService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AdminService>;
}
