import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ApiKeyCreateRequest } from '../model/apiKeyCreateRequest';
import { ApiKeyCreateResponse } from '../model/apiKeyCreateResponse';
import { ApiKeyEditRequest } from '../model/apiKeyEditRequest';
import { ApiKeyResponse } from '../model/apiKeyResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ApiKeyService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a new API key
     *
     * @param body
     */
    createApiKey(body?: ApiKeyCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ApiKeyCreateResponse>;
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKey(apiKeyId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKey(apiKeyId: number, body?: ApiKeyEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ApiKeyResponse>;
    /**
     * Get an API key
     *
     * @param apiKeyId
     */
    getApiKey(apiKeyId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ApiKeyResponse>;
    /**
     * Get a list of all available API keys
     *
     * @param filter
     */
    getApiKeys(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ApiKeyResponse>>;
    /**
     * Create a new API key
     *
     * @param body
     */
    createApiKeyWithHttpInfo(body?: ApiKeyCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ApiKeyCreateResponse>>;
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKeyWithHttpInfo(apiKeyId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKeyWithHttpInfo(apiKeyId: number, body?: ApiKeyEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ApiKeyResponse>>;
    /**
     * Get an API key
     *
     * @param apiKeyId
     */
    getApiKeyWithHttpInfo(apiKeyId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ApiKeyResponse>>;
    /**
     * Get a list of all available API keys
     *
     * @param filter
     */
    getApiKeysWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ApiKeyResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ApiKeyService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ApiKeyService>;
}
