import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BatchCreate } from '../model/batchCreate';
import { BatchEdit } from '../model/batchEdit';
import { BatchResponse } from '../model/batchResponse';
import { DistributeAccountChargesBase } from '../model/distributeAccountChargesBase';
import { UpdateBatchStatusRequest } from '../model/updateBatchStatusRequest';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class BatchService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     *
     *
     * @param batchId
     */
    closeBatch(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     *
     *
     * @param batchId
     */
    deleteBatch(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatch(batchId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatch(batchId: number, body?: BatchEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     *
     *
     * @param batchId
     */
    getBatch(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatches(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BatchResponse>>;
    /**
     *
     *
     * @param body
     */
    openBatch(body?: BatchCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     * Update the status of a batch.  Requesting user must have BillAndBatches Create to update their own batch or to open another user&#39;s pending batch.  User must have BillsAndBatches Manage to update another user&#39;s batch to closed or pending.  If opening another user&#39;s batch, the requesting user&#39;s open batch (if any) will be set to Pending status.  See &#39;Batch Statuses&#39; section below for more information.
     *  __Batch Statuses:__    | Batch Status   | Description |  | -------------- | ----------- |  | Open           | Batch must currently be pending. Un-voids all bills in the batch. |  | Pending        | Batch must currently be open. Voids all bills in the batch.  |  | Closed         | Batch must currently be open or pending. If the batch was pending, un-voids all bills in the batch.  |
     * @param batchId ID for the batch to set status
     * @param body The new status and (optional) note on the batch. See &#39;Batch Statuses&#39; section below for available statuses.
     */
    updateBatchStatus(batchId: number, body?: UpdateBatchStatusRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     *
     *
     * @param batchId
     */
    closeBatchWithHttpInfo(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     *
     *
     * @param batchId
     */
    deleteBatchWithHttpInfo(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatchWithHttpInfo(batchId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatchWithHttpInfo(batchId: number, body?: BatchEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     *
     *
     * @param batchId
     */
    getBatchWithHttpInfo(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatchesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BatchResponse>>>;
    /**
     *
     *
     * @param body
     */
    openBatchWithHttpInfo(body?: BatchCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     * Update the status of a batch.  Requesting user must have BillAndBatches Create to update their own batch or to open another user&#39;s pending batch.  User must have BillsAndBatches Manage to update another user&#39;s batch to closed or pending.  If opening another user&#39;s batch, the requesting user&#39;s open batch (if any) will be set to Pending status.  See &#39;Batch Statuses&#39; section below for more information.
     *  __Batch Statuses:__    | Batch Status   | Description |  | -------------- | ----------- |  | Open           | Batch must currently be pending. Un-voids all bills in the batch. |  | Pending        | Batch must currently be open. Voids all bills in the batch.  |  | Closed         | Batch must currently be open or pending. If the batch was pending, un-voids all bills in the batch.  |
     * @param batchId ID for the batch to set status
     * @param body The new status and (optional) note on the batch. See &#39;Batch Statuses&#39; section below for available statuses.
     */
    updateBatchStatusWithHttpInfo(batchId: number, body?: UpdateBatchStatusRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BatchService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BatchService>;
}
