import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillAccountMeterResponse } from '../model/billAccountMeterResponse';
import { BillAccountMeterStatisticsResponse } from '../model/billAccountMeterStatisticsResponse';
import { BillAccrualExclusionRequest } from '../model/billAccrualExclusionRequest';
import { BillActionApprove } from '../model/billActionApprove';
import { BillActionCustom } from '../model/billActionCustom';
import { BillActionDelete } from '../model/billActionDelete';
import { BillActionExportHold } from '../model/billActionExportHold';
import { BillActionHeaderUpdate } from '../model/billActionHeaderUpdate';
import { BillActionMove } from '../model/billActionMove';
import { BillActionSplit } from '../model/billActionSplit';
import { BillActionVoid } from '../model/billActionVoid';
import { BillCreate } from '../model/billCreate';
import { BillDeleteActionResult } from '../model/billDeleteActionResult';
import { BillEdit } from '../model/billEdit';
import { BillEntryResponse } from '../model/billEntryResponse';
import { BillExport } from '../model/billExport';
import { BillHistoryResponse } from '../model/billHistoryResponse';
import { BillIdResponse } from '../model/billIdResponse';
import { BillLineTypeMappingResponse } from '../model/billLineTypeMappingResponse';
import { BillPaymentDetailsFileResponse } from '../model/billPaymentDetailsFileResponse';
import { BillPaymentDetailsOptionalItem } from '../model/billPaymentDetailsOptionalItem';
import { BillPaymentDetailsOptionalResponse } from '../model/billPaymentDetailsOptionalResponse';
import { BillPaymentEventCreate } from '../model/billPaymentEventCreate';
import { BillPaymentEventResponse } from '../model/billPaymentEventResponse';
import { BillResponse } from '../model/billResponse';
import { BillReversalRequest } from '../model/billReversalRequest';
import { BillUnexport } from '../model/billUnexport';
import { BodylineResponse } from '../model/bodylineResponse';
import { ChargebackTaskResponse } from '../model/chargebackTaskResponse';
import { DistributeAccountChargesToBillsRequest } from '../model/distributeAccountChargesToBillsRequest';
import { JsonBillExportResponse } from '../model/jsonBillExportResponse';
import { ListIds } from '../model/listIds';
import { MoveBillsDestination } from '../model/moveBillsDestination';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class BillService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Update approved flag for the given billIDs
     *
     * @param body approve action
     */
    billActionApprove(body?: BillActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Delete given billIDs
     *
     * @param body
     */
    billActionDelete(body?: BillActionDelete, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillDeleteActionResult>;
    /**
     * Update export hold flag for the given billIDs
     *
     * @param body export hold action
     */
    billActionExportHold(body?: BillActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplit(body?: BillActionSplit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeaders(body?: BillActionHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoid(body?: BillActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetails(body?: Array<BillPaymentDetailsOptionalItem>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillPaymentDetailsOptionalResponse>;
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFile(body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillPaymentDetailsFileResponse>;
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABill(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBills(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBill(saveAsResolved?: boolean, comment?: string, body?: BillCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillIdResponse>;
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEvent(body?: BillPaymentEventCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillPaymentEventResponse>;
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMeters(body?: DistributeAccountChargesToBillsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFile(billId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBill(billId: number, body?: BillEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillIdResponse>;
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFields(billId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves the text of a standard EnergyCAP bill export ini file for AP, GL and Payment purposes.  Payment details will be included in the profile if workflow settings for the bill export are configured to include payment details.
     *
     * @param exportMode Specifies whether the profile should be for AP, GL or Payment. Pass in \&quot;AP\&quot; for AP Profile, \&quot;GL\&quot; for GL Profile or \&quot;Payment\&quot; for Payment Profile. If this is not included in the request, it defaults to AP.
     */
    exportBillProfile(exportMode?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBills(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJson(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<JsonBillExportResponse>>;
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistory(accountId: number, billingPeriod?: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillHistoryResponse>>;
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylines(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BodylineResponse>>;
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBill(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillResponse>;
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterStatisticsResponse>>;
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActual(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarized(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalized(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatistics(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterStatisticsResponse>>;
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylines(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BodylineResponse>>;
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFields(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryData(accountId: number, beginDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillEntryResponse>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillEntryResponse>;
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistory(billId: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillHistoryResponse>>;
    /**
     * Retrieves a list of bill line type mappings
     *
     */
    getBillLineTypeMappings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillLineTypeMappingResponse>>;
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEvents(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillPaymentEventResponse>>;
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBills(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillResponse>>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccounts(body?: ListIds, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MoveBillsDestination>;
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccount(body?: BillActionMove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomAction(body?: BillActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBills(body?: BillReversalRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param body
     */
    setBillAccrualExclusion(body?: BillAccrualExclusionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBills(body?: BillUnexport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuid(billExportGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImage(billId: number, fileName?: string, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Update approved flag for the given billIDs
     *
     * @param body approve action
     */
    billActionApproveWithHttpInfo(body?: BillActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Delete given billIDs
     *
     * @param body
     */
    billActionDeleteWithHttpInfo(body?: BillActionDelete, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillDeleteActionResult>>;
    /**
     * Update export hold flag for the given billIDs
     *
     * @param body export hold action
     */
    billActionExportHoldWithHttpInfo(body?: BillActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplitWithHttpInfo(body?: BillActionSplit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeadersWithHttpInfo(body?: BillActionHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoidWithHttpInfo(body?: BillActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetailsWithHttpInfo(body?: Array<BillPaymentDetailsOptionalItem>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillPaymentDetailsOptionalResponse>>;
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFileWithHttpInfo(body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillPaymentDetailsFileResponse>>;
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABillWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBillsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBillWithHttpInfo(saveAsResolved?: boolean, comment?: string, body?: BillCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillIdResponse>>;
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEventWithHttpInfo(body?: BillPaymentEventCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillPaymentEventResponse>>;
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMetersWithHttpInfo(body?: DistributeAccountChargesToBillsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFileWithHttpInfo(billId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBillWithHttpInfo(billId: number, body?: BillEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillIdResponse>>;
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFieldsWithHttpInfo(billId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves the text of a standard EnergyCAP bill export ini file for AP, GL and Payment purposes.  Payment details will be included in the profile if workflow settings for the bill export are configured to include payment details.
     *
     * @param exportMode Specifies whether the profile should be for AP, GL or Payment. Pass in \&quot;AP\&quot; for AP Profile, \&quot;GL\&quot; for GL Profile or \&quot;Payment\&quot; for Payment Profile. If this is not included in the request, it defaults to AP.
     */
    exportBillProfileWithHttpInfo(exportMode?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBillsWithHttpInfo(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJsonWithHttpInfo(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<JsonBillExportResponse>>>;
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistoryWithHttpInfo(accountId: number, billingPeriod?: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillHistoryResponse>>>;
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylinesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BodylineResponse>>>;
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBillWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillResponse>>;
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterStatisticsResponse>>>;
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActualWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarizedWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalizedWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatisticsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterStatisticsResponse>>>;
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylinesWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BodylineResponse>>>;
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFieldsWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryDataWithHttpInfo(accountId: number, beginDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillEntryResponse>>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillEntryResponse>>;
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistoryWithHttpInfo(billId: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillHistoryResponse>>>;
    /**
     * Retrieves a list of bill line type mappings
     *
     */
    getBillLineTypeMappingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillLineTypeMappingResponse>>>;
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEventsWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillPaymentEventResponse>>>;
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillResponse>>>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccountsWithHttpInfo(body?: ListIds, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MoveBillsDestination>>;
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccountWithHttpInfo(body?: BillActionMove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomActionWithHttpInfo(body?: BillActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBillsWithHttpInfo(body?: BillReversalRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param body
     */
    setBillAccrualExclusionWithHttpInfo(body?: BillAccrualExclusionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBillsWithHttpInfo(body?: BillUnexport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuidWithHttpInfo(billExportGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImageWithHttpInfo(billId: number, fileName?: string, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BillService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BillService>;
}
