import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountBillAccountChargeSplitSettingsResponse } from '../model/accountBillAccountChargeSplitSettingsResponse';
import { BillAccountChargeSplitMethodRequest } from '../model/billAccountChargeSplitMethodRequest';
import { BillAccountChargeSplitMethodResponse } from '../model/billAccountChargeSplitMethodResponse';
import { BillAccountChargeSplitSettingsResponse } from '../model/billAccountChargeSplitSettingsResponse';
import { VendorBillAccountChargeSplitSettingsResponse } from '../model/vendorBillAccountChargeSplitSettingsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class BillAccountChargeSplitService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Deletes a specific account&#39;s setting to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    deleteAccountBillAccountChargeSplitSettings(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a specific vendor&#39;s setting to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    deleteVendorBillAccountChargeSplitSettings(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a specific account&#39;s setting to split account charges on bill import  If a rule does not currently exist for this account it is created otherwise it is updated
     *
     * @param accountId Account identifier
     * @param body
     */
    editAccountBillAccountChargeSplitSettings(accountId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountBillAccountChargeSplitSettingsResponse>;
    /**
     * Edit the method used to split account charges on bill import
     *
     * @param body Method used to split account charges on bill import
     */
    editBillAccountChargeSplitMethod(body?: BillAccountChargeSplitMethodRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillAccountChargeSplitMethodResponse>;
    /**
     * Edits a specific vendor&#39;s setting to split account charges on bill import  If a rule does not currently exist for this vendor it is created otherwise it is updated
     *
     * @param vendorId Vendor identifier
     * @param body
     */
    editVendorBillAccountChargeSplitSettings(vendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorBillAccountChargeSplitSettingsResponse>;
    /**
     * Retrieves a specific account&#39;s settings to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    getAccountBillAccountChargeSplitSettings(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountBillAccountChargeSplitSettingsResponse>;
    /**
     * Retrieves the method used to split account charges on bill import
     *
     */
    getBillAccountChargeSplitMethod(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillAccountChargeSplitMethodResponse>;
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettings(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillAccountChargeSplitSettingsResponse>;
    /**
     * Retrieves a specific vendor&#39;s settings to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    getVendorBillAccountChargeSplitSettings(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorBillAccountChargeSplitSettingsResponse>;
    /**
     * Deletes a specific account&#39;s setting to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    deleteAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a specific vendor&#39;s setting to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    deleteVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a specific account&#39;s setting to split account charges on bill import  If a rule does not currently exist for this account it is created otherwise it is updated
     *
     * @param accountId Account identifier
     * @param body
     */
    editAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountBillAccountChargeSplitSettingsResponse>>;
    /**
     * Edit the method used to split account charges on bill import
     *
     * @param body Method used to split account charges on bill import
     */
    editBillAccountChargeSplitMethodWithHttpInfo(body?: BillAccountChargeSplitMethodRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillAccountChargeSplitMethodResponse>>;
    /**
     * Edits a specific vendor&#39;s setting to split account charges on bill import  If a rule does not currently exist for this vendor it is created otherwise it is updated
     *
     * @param vendorId Vendor identifier
     * @param body
     */
    editVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorBillAccountChargeSplitSettingsResponse>>;
    /**
     * Retrieves a specific account&#39;s settings to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    getAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountBillAccountChargeSplitSettingsResponse>>;
    /**
     * Retrieves the method used to split account charges on bill import
     *
     */
    getBillAccountChargeSplitMethodWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillAccountChargeSplitMethodResponse>>;
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettingsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillAccountChargeSplitSettingsResponse>>;
    /**
     * Retrieves a specific vendor&#39;s settings to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    getVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorBillAccountChargeSplitSettingsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BillAccountChargeSplitService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BillAccountChargeSplitService>;
}
