import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillSplitDetailsRequest } from '../model/billSplitDetailsRequest';
import { BillSplitDetailsResponse } from '../model/billSplitDetailsResponse';
import { BillSplitParentDetailsResponse } from '../model/billSplitParentDetailsResponse';
import { ChargebackTaskVersionResponse } from '../model/chargebackTaskVersionResponse';
import { DistributionVersionManage } from '../model/distributionVersionManage';
import { DistributionVersionResponse } from '../model/distributionVersionResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class BillSplitService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetails(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillSplitParentDetailsResponse>>;
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitChargebackTaskByVersion(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackTaskVersionResponse>>;
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetails(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillSplitDetailsResponse>;
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistory(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersions(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplits(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetails(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillSplitParentDetailsResponse>>;
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetails(accountId: number, meterId: number, versionId: number, body?: BillSplitDetailsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillSplitDetailsResponse>;
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistory(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetailsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillSplitParentDetailsResponse>>>;
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitChargebackTaskByVersionWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackTaskVersionResponse>>>;
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetailsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillSplitDetailsResponse>>;
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistoryWithHttpInfo(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersionsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplitsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetailsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillSplitParentDetailsResponse>>>;
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetailsWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: BillSplitDetailsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillSplitDetailsResponse>>;
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistoryWithHttpInfo(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BillSplitService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BillSplitService>;
}
