import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BudgetCreate } from '../model/budgetCreate';
import { BudgetDataType } from '../model/budgetDataType';
import { BudgetEdit } from '../model/budgetEdit';
import { BudgetPeriodType } from '../model/budgetPeriodType';
import { BudgetResponse } from '../model/budgetResponse';
import { BudgetUsageMethod } from '../model/budgetUsageMethod';
import { BudgetVersionCreate } from '../model/budgetVersionCreate';
import { BudgetVersionEdit } from '../model/budgetVersionEdit';
import { BudgetVersionResponse } from '../model/budgetVersionResponse';
import { BudgetVersionSummaryResponse } from '../model/budgetVersionSummaryResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class BudgetService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a budget
     *
     * @param body Data representing the budget being created
     */
    createBudget(body?: BudgetCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetResponse>;
    /**
     * Creates a budget version
     *
     * @param budgetId The identifier for the budget to create the version on
     * @param body Data representing the budgetVersion being created
     */
    createBudgetVersion(budgetId: number, body?: BudgetVersionCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetVersionResponse>;
    /**
     * Deletes a budget
     *
     * @param budgetId The identifier for the budget being deleted
     */
    deleteBudget(budgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being deleted
     */
    deleteBudgetVersion(budgetId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a budget
     *
     * @param budgetId The identifier for the budget being edited
     * @param body Data representing the budget being edited
     */
    editBudget(budgetId: number, body?: BudgetEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetResponse>;
    /**
     * Edits a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param body Data representing the budgetVersion being edited
     */
    editBudgetVersion(budgetId: number, versionId: number, body?: BudgetVersionEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetVersionResponse>;
    /**
     * Retrieves the budget by ID
     *
     * @param budgetId The identifier for the budget being retrieved
     */
    getBudget(budgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetResponse>;
    /**
     * Retrieves a list of available budget data types
     *
     */
    getBudgetDataTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BudgetDataType>>;
    /**
     * Retrieves a list of budget period types
     *
     */
    getBudgetPeriodTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BudgetPeriodType>>;
    /**
     * Retrieves a list of available budget usage methods
     *
     */
    getBudgetUsageMethods(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BudgetUsageMethod>>;
    /**
     * Retrieves a specific version for a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     */
    getBudgetVersion(budgetId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetVersionResponse>;
    /**
     * Retrieves the summary for a specific version on a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param commodityId The optional commodity filter
     */
    getBudgetVersionSummary(budgetId: number, versionId: number, commodityId?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetVersionSummaryResponse>;
    /**
     * Retrieves all the versions for a specified budget
     *
     * @param budgetId The identifier for the budget to retrieve all versions
     */
    getBudgetVersions(budgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BudgetVersionResponse>>;
    /**
     * Retrieves all the budgets
     *
     */
    getBudgets(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BudgetResponse>>;
    /**
     * Sets a budget version as active, and all other versions as inactive.
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version to set as active
     */
    setBudgetVersionActive(budgetId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BudgetVersionResponse>;
    /**
     * Creates a budget
     *
     * @param body Data representing the budget being created
     */
    createBudgetWithHttpInfo(body?: BudgetCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetResponse>>;
    /**
     * Creates a budget version
     *
     * @param budgetId The identifier for the budget to create the version on
     * @param body Data representing the budgetVersion being created
     */
    createBudgetVersionWithHttpInfo(budgetId: number, body?: BudgetVersionCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetVersionResponse>>;
    /**
     * Deletes a budget
     *
     * @param budgetId The identifier for the budget being deleted
     */
    deleteBudgetWithHttpInfo(budgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being deleted
     */
    deleteBudgetVersionWithHttpInfo(budgetId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a budget
     *
     * @param budgetId The identifier for the budget being edited
     * @param body Data representing the budget being edited
     */
    editBudgetWithHttpInfo(budgetId: number, body?: BudgetEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetResponse>>;
    /**
     * Edits a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param body Data representing the budgetVersion being edited
     */
    editBudgetVersionWithHttpInfo(budgetId: number, versionId: number, body?: BudgetVersionEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetVersionResponse>>;
    /**
     * Retrieves the budget by ID
     *
     * @param budgetId The identifier for the budget being retrieved
     */
    getBudgetWithHttpInfo(budgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetResponse>>;
    /**
     * Retrieves a list of available budget data types
     *
     */
    getBudgetDataTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BudgetDataType>>>;
    /**
     * Retrieves a list of budget period types
     *
     */
    getBudgetPeriodTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BudgetPeriodType>>>;
    /**
     * Retrieves a list of available budget usage methods
     *
     */
    getBudgetUsageMethodsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BudgetUsageMethod>>>;
    /**
     * Retrieves a specific version for a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     */
    getBudgetVersionWithHttpInfo(budgetId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetVersionResponse>>;
    /**
     * Retrieves the summary for a specific version on a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param commodityId The optional commodity filter
     */
    getBudgetVersionSummaryWithHttpInfo(budgetId: number, versionId: number, commodityId?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetVersionSummaryResponse>>;
    /**
     * Retrieves all the versions for a specified budget
     *
     * @param budgetId The identifier for the budget to retrieve all versions
     */
    getBudgetVersionsWithHttpInfo(budgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BudgetVersionResponse>>>;
    /**
     * Retrieves all the budgets
     *
     */
    getBudgetsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BudgetResponse>>>;
    /**
     * Sets a budget version as active, and all other versions as inactive.
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version to set as active
     */
    setBudgetVersionActiveWithHttpInfo(budgetId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BudgetVersionResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BudgetService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BudgetService>;
}
