import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CalculatedBillCostRequest } from '../model/calculatedBillCostRequest';
import { CalculatedBillCostResponse } from '../model/calculatedBillCostResponse';
import { CalculatedBillDemandRequest } from '../model/calculatedBillDemandRequest';
import { CalculatedBillDemandResponse } from '../model/calculatedBillDemandResponse';
import { CalculatedBillDetailsResponse } from '../model/calculatedBillDetailsResponse';
import { CalculatedBillUseRequest } from '../model/calculatedBillUseRequest';
import { CalculatedBillUseResponse } from '../model/calculatedBillUseResponse';
import { ChargebackTaskVersionResponse } from '../model/chargebackTaskVersionResponse';
import { DistributionVersionManage } from '../model/distributionVersionManage';
import { DistributionVersionResponse } from '../model/distributionVersionResponse';
import { GenericBodylineRequest } from '../model/genericBodylineRequest';
import { GenericBodylineResponse } from '../model/genericBodylineResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class CalculatedBillService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItems(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCost(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillCostResponse>;
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemand(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDemandResponse>;
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetails(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDetailsResponse>;
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUse(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillUseResponse>;
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getCalculatedBillChargebackTaskByVersion(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackTaskVersionResponse>>;
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistory(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersions(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBills(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItems(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItems(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCost(accountId: number, meterId: number, versionId: number, body?: CalculatedBillCostRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillCostResponse>;
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemand(accountId: number, meterId: number, versionId: number, body?: CalculatedBillDemandRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDemandResponse>;
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUse(accountId: number, meterId: number, versionId: number, body?: CalculatedBillUseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillUseResponse>;
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistory(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItems(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Forces all Account and Meter Chargeback flags in the system to be recalculated
     *
     */
    recalculateChargebackFlags(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCostWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillCostResponse>>;
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemandWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDemandResponse>>;
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetailsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDetailsResponse>>;
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUseWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillUseResponse>>;
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getCalculatedBillChargebackTaskByVersionWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackTaskVersionResponse>>>;
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistoryWithHttpInfo(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersionsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCostWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: CalculatedBillCostRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillCostResponse>>;
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemandWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: CalculatedBillDemandRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDemandResponse>>;
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUseWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: CalculatedBillUseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillUseResponse>>;
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistoryWithHttpInfo(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Forces all Account and Meter Chargeback flags in the system to be recalculated
     *
     */
    recalculateChargebackFlagsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalculatedBillService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CalculatedBillService>;
}
