import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ChannelCreate } from '../model/channelCreate';
import { ChannelEdit } from '../model/channelEdit';
import { ChannelResponse } from '../model/channelResponse';
import { ChannelVersionWithBeginDateRequest } from '../model/channelVersionWithBeginDateRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ChannelService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersion(meterId: number, channelId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannel(meterId: number, body?: ChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersion(meterId: number, channelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannel(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFile(meterId: number, channelId: number, versionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersion(meterId: number, channelId: number, versionId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannel(meterId: number, channelId: number, body?: ChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannel(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannels(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChannelResponse>>;
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersionWithHttpInfo(meterId: number, channelId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannelWithHttpInfo(meterId: number, body?: ChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersionWithHttpInfo(meterId: number, channelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannelWithHttpInfo(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFileWithHttpInfo(meterId: number, channelId: number, versionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersionWithHttpInfo(meterId: number, channelId: number, versionId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannelWithHttpInfo(meterId: number, channelId: number, body?: ChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannelWithHttpInfo(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannelsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChannelResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChannelService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ChannelService>;
}
