import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ChargebackProcessorSettings } from '../model/chargebackProcessorSettings';
import { ChargebackProcessorSettingsWithoutFilters } from '../model/chargebackProcessorSettingsWithoutFilters';
import { ChargebackTaskResponse } from '../model/chargebackTaskResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ChargebackEngineService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessor(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessor(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflow(chargebackWorkflowId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackTaskResponse>>;
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStep(chargebackWorkflowStepId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessorWithHttpInfo(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessorWithHttpInfo(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflowWithHttpInfo(chargebackWorkflowId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackTaskResponse>>>;
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStepWithHttpInfo(chargebackWorkflowStepId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChargebackEngineService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ChargebackEngineService>;
}
