import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ChargebackTaskRequest } from '../model/chargebackTaskRequest';
import { ChargebackTaskResponse } from '../model/chargebackTaskResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ChargebackTaskService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the chargeback task
     */
    deleteChargebackTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves a chargeback task with details
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Retrieves a chargeback task&#39;s error log as an EXCEL file
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTaskErrorFile(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Get all chargeback tasks with details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getChargebackTasks(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackTaskResponse>>;
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTask(taskId: number, body?: ChargebackTaskRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Void all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the chargeback task
     */
    voidChargebackTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the chargeback task
     */
    deleteChargebackTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves a chargeback task with details
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Retrieves a chargeback task&#39;s error log as an EXCEL file
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTaskErrorFileWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Get all chargeback tasks with details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getChargebackTasksWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackTaskResponse>>>;
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTaskWithHttpInfo(taskId: number, body?: ChargebackTaskRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Void all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the chargeback task
     */
    voidChargebackTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChargebackTaskService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ChargebackTaskService>;
}
