import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AssignVersionsToStep } from '../model/assignVersionsToStep';
import { ChargebackWorkflowCreate } from '../model/chargebackWorkflowCreate';
import { ChargebackWorkflowDigestResponse } from '../model/chargebackWorkflowDigestResponse';
import { ChargebackWorkflowEdit } from '../model/chargebackWorkflowEdit';
import { ChargebackWorkflowResponse } from '../model/chargebackWorkflowResponse';
import { ChargebackWorkflowStepChild } from '../model/chargebackWorkflowStepChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ChargebackWorkflowService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStep(chargebackWorkflowStepId: number, billingPeriod: number, body?: AssignVersionsToStep, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowStepChild>;
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflow(body?: ChargebackWorkflowCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowResponse>;
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflow(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete all bills created by a chargeback workflow step  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    deleteChargebackWorkflowSteps(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflow(chargebackWorkflowId: number, body?: ChargebackWorkflowEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowResponse>;
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflow(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowResponse>;
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigest(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowDigestResponse>;
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStep(chargebackWorkflowStepId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowStepChild>;
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowSteps(chargebackWorkflowType?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackWorkflowStepChild>>;
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflows(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackWorkflowResponse>>;
    /**
     * Void all bills created by a chargeback workflow step for a particular billing period  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    voidChargebackWorkflowSteps(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStepWithHttpInfo(chargebackWorkflowStepId: number, billingPeriod: number, body?: AssignVersionsToStep, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowStepChild>>;
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflowWithHttpInfo(body?: ChargebackWorkflowCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowResponse>>;
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflowWithHttpInfo(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete all bills created by a chargeback workflow step  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    deleteChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflowWithHttpInfo(chargebackWorkflowId: number, body?: ChargebackWorkflowEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowResponse>>;
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflowWithHttpInfo(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowResponse>>;
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigestWithHttpInfo(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowDigestResponse>>;
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStepWithHttpInfo(chargebackWorkflowStepId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowStepChild>>;
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowType?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackWorkflowStepChild>>>;
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflowsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackWorkflowResponse>>>;
    /**
     * Void all bills created by a chargeback workflow step for a particular billing period  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    voidChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChargebackWorkflowService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ChargebackWorkflowService>;
}
