import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CollectionRequest } from '../model/collectionRequest';
import { CollectionResponse } from '../model/collectionResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class CollectionService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a collection
     *
     * @param body Data representing the collection being created
     */
    createCollection(body?: CollectionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CollectionResponse>;
    /**
     * Deletes a collection
     *
     * @param collectionId The identifier for the collection being deleted
     */
    deleteCollection(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFields(collectionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a collection
     *
     * @param collectionId The identifier for the collection being edited
     * @param body Data representing the collection being edited
     */
    editCollection(collectionId: number, body?: CollectionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CollectionResponse>;
    /**
     * Edit the custom field values on a collection
     *
     * @param collectionId The id of the collection
     * @param body The list of udf values being edited
     */
    editCollectionCustomFields(collectionId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollection(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CollectionResponse>;
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFields(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollections(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CollectionResponse>>;
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveCollections(parentCollectionId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Creates a collection
     *
     * @param body Data representing the collection being created
     */
    createCollectionWithHttpInfo(body?: CollectionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CollectionResponse>>;
    /**
     * Deletes a collection
     *
     * @param collectionId The identifier for the collection being deleted
     */
    deleteCollectionWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFieldsWithHttpInfo(collectionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a collection
     *
     * @param collectionId The identifier for the collection being edited
     * @param body Data representing the collection being edited
     */
    editCollectionWithHttpInfo(collectionId: number, body?: CollectionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CollectionResponse>>;
    /**
     * Edit the custom field values on a collection
     *
     * @param collectionId The id of the collection
     * @param body The list of udf values being edited
     */
    editCollectionCustomFieldsWithHttpInfo(collectionId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollectionWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CollectionResponse>>;
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFieldsWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollectionsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CollectionResponse>>>;
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveCollectionsWithHttpInfo(parentCollectionId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CollectionService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CollectionService>;
}
