import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CommodityEditRequest } from '../model/commodityEditRequest';
import { CommodityRequest } from '../model/commodityRequest';
import { CommodityResponse } from '../model/commodityResponse';
import { Unit } from '../model/unit';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class CommodityService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a commodity
     *
     * @param body Data representing the commodity being created
     */
    createCommodity(body?: CommodityRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CommodityResponse>;
    /**
     * Deletes a commodity
     *
     * @param commodityId The commodity Id
     */
    deleteCommodity(commodityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a commodity
     *
     * @param commodityId The commodity Id
     * @param body Data that will be used to update the commodity
     */
    editCommodity(commodityId: number, body?: CommodityEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CommodityResponse>;
    /**
     * Gets the commodities  If topmostcostcenter, topmostcollection, topmostplace or account filters are used then the commodities in use at or under that node will be returned.  The inUse filter cannot be combined with the above filters.
     *
     * @param filter The filters
     */
    getCommodities(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CommodityResponse>>;
    /**
     * Gets a commodity
     *
     * @param commodityId The commodity Id
     */
    getCommodity(commodityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CommodityResponse>;
    /**
     * Returns a list of units for a specific commodity and value type
     *
     * @param commodityId The specific commodity ID
     * @param valueType The unit type to search for. Not required. Valid values are &#39;use&#39;, &#39;demand&#39;, and &#39;cost&#39;.
     */
    getUnitsByCommodity(commodityId: number, valueType?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<Unit>>;
    /**
     * Creates a commodity
     *
     * @param body Data representing the commodity being created
     */
    createCommodityWithHttpInfo(body?: CommodityRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CommodityResponse>>;
    /**
     * Deletes a commodity
     *
     * @param commodityId The commodity Id
     */
    deleteCommodityWithHttpInfo(commodityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a commodity
     *
     * @param commodityId The commodity Id
     * @param body Data that will be used to update the commodity
     */
    editCommodityWithHttpInfo(commodityId: number, body?: CommodityEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CommodityResponse>>;
    /**
     * Gets the commodities  If topmostcostcenter, topmostcollection, topmostplace or account filters are used then the commodities in use at or under that node will be returned.  The inUse filter cannot be combined with the above filters.
     *
     * @param filter The filters
     */
    getCommoditiesWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CommodityResponse>>>;
    /**
     * Gets a commodity
     *
     * @param commodityId The commodity Id
     */
    getCommodityWithHttpInfo(commodityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CommodityResponse>>;
    /**
     * Returns a list of units for a specific commodity and value type
     *
     * @param commodityId The specific commodity ID
     * @param valueType The unit type to search for. Not required. Valid values are &#39;use&#39;, &#39;demand&#39;, and &#39;cost&#39;.
     */
    getUnitsByCommodityWithHttpInfo(commodityId: number, valueType?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<Unit>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CommodityService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CommodityService>;
}
