import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CostCenterCreate } from '../model/costCenterCreate';
import { CostCenterResponse } from '../model/costCenterResponse';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class CostCenterService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a Cost Center
     *
     * @param body Data representing the cost center being created
     */
    createCostCenter(body?: CostCenterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterResponse>;
    /**
     * Deletes a cost center
     *
     * @param costCenterId The identifier for the cost center being deleted
     */
    deleteCostCenter(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a cost center
     *
     * @param costCenterId The identifier for the cost center being edited
     * @param body Data representing the cost center being edited
     */
    editCostCenter(costCenterId: number, body?: CostCenterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterResponse>;
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenter(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterResponse>;
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenters(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterResponse>>;
    /**
     * Move list of costCenters to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of costCenterIds to move under the parentCostCenterId
     */
    moveCostCenter(parentCostCenterId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Creates a Cost Center
     *
     * @param body Data representing the cost center being created
     */
    createCostCenterWithHttpInfo(body?: CostCenterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterResponse>>;
    /**
     * Deletes a cost center
     *
     * @param costCenterId The identifier for the cost center being deleted
     */
    deleteCostCenterWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a cost center
     *
     * @param costCenterId The identifier for the cost center being edited
     * @param body Data representing the cost center being edited
     */
    editCostCenterWithHttpInfo(costCenterId: number, body?: CostCenterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterResponse>>;
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenterWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterResponse>>;
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCentersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterResponse>>>;
    /**
     * Move list of costCenters to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of costCenterIds to move under the parentCostCenterId
     */
    moveCostCenterWithHttpInfo(parentCostCenterId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CostCenterService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CostCenterService>;
}
