import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CostCenterDigestActualMonthlyResponse } from '../model/costCenterDigestActualMonthlyResponse';
import { CostCenterDigestActualYearlyResponse } from '../model/costCenterDigestActualYearlyResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class CostCenterDigestService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthly(costCenterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterDigestActualMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearly(costCenterId: number, numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterDigestActualYearlyResponse>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterDigestActualYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthlyWithHttpInfo(costCenterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterDigestActualMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyWithHttpInfo(costCenterId: number, numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterDigestActualYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterDigestActualYearlyResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CostCenterDigestService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CostCenterDigestService>;
}
