import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DataPointCreate } from '../model/dataPointCreate';
import { DataPointEdit } from '../model/dataPointEdit';
import { DataPointResponse } from '../model/dataPointResponse';
import { DataPointSentinel } from '../model/dataPointSentinel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class DataPointService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPoint(body?: DataPointCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Deletes a data point
     *
     * @param dataPointId The data point identifier
     */
    deleteDataPoint(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPoint(dataPointId: number, body?: DataPointEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinel(dataPointId: number, body?: DataPointSentinel, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPoint(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPoints(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DataPointResponse>>;
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPointWithHttpInfo(body?: DataPointCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Deletes a data point
     *
     * @param dataPointId The data point identifier
     */
    deleteDataPointWithHttpInfo(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPointWithHttpInfo(dataPointId: number, body?: DataPointEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinelWithHttpInfo(dataPointId: number, body?: DataPointSentinel, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPointWithHttpInfo(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPointsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DataPointResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataPointService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DataPointService>;
}
