import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EmissionRecordRequest } from '../model/emissionRecordRequest';
import { EmissionRecordResponse } from '../model/emissionRecordResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EmissionRecordService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create an emission record
     *
     * @param body Data representing the record being created
     */
    createEmissionRecord(body?: EmissionRecordRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionRecordResponse>;
    /**
     * Delete an emission record
     *
     * @param emissionRecordId The Id of the emission record to delete
     */
    deleteEmissionRecord(emissionRecordId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit an emission record
     *
     * @param emissionRecordId The Id of the emission record to edit
     * @param body Data representing the emission record being edited
     */
    editEmissionRecord(emissionRecordId: number, body?: EmissionRecordRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionRecordResponse>;
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecord(emissionRecordId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionRecordResponse>;
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecords(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EmissionRecordResponse>>;
    /**
     * Create an emission record
     *
     * @param body Data representing the record being created
     */
    createEmissionRecordWithHttpInfo(body?: EmissionRecordRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionRecordResponse>>;
    /**
     * Delete an emission record
     *
     * @param emissionRecordId The Id of the emission record to delete
     */
    deleteEmissionRecordWithHttpInfo(emissionRecordId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit an emission record
     *
     * @param emissionRecordId The Id of the emission record to edit
     * @param body Data representing the emission record being edited
     */
    editEmissionRecordWithHttpInfo(emissionRecordId: number, body?: EmissionRecordRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionRecordResponse>>;
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecordWithHttpInfo(emissionRecordId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionRecordResponse>>;
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecordsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EmissionRecordResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EmissionRecordService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EmissionRecordService>;
}
