import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EmissionSourceCreate } from '../model/emissionSourceCreate';
import { EmissionSourceEdit } from '../model/emissionSourceEdit';
import { EmissionSourceFactorCategoryBulkUpdate } from '../model/emissionSourceFactorCategoryBulkUpdate';
import { EmissionSourceMultiFactorCreate } from '../model/emissionSourceMultiFactorCreate';
import { EmissionSourceMultiFactorEdit } from '../model/emissionSourceMultiFactorEdit';
import { EmissionSourceMultiFactorResponse } from '../model/emissionSourceMultiFactorResponse';
import { EmissionSourceResponse } from '../model/emissionSourceResponse';
import { MeterLink } from '../model/meterLink';
import { MeterLinkRequest } from '../model/meterLinkRequest';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { UpdateSkippedResult } from '../model/updateSkippedResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EmissionSourceService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates an emissions source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSource(body?: EmissionSourceCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceResponse>;
    /**
     * Creates an emission source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithMultiFactors(body?: EmissionSourceMultiFactorCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceMultiFactorResponse>;
    /**
     * Deletes an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being deleted
     * @param deleteRecords Should this cascade to delete any records associated with this emissions source
     */
    deleteEmissionSource(emissionSourceId: number, deleteRecords?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFields(emissionSourceId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSource(emissionSourceId: number, body?: EmissionSourceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceResponse>;
    /**
     * Edit the custom field values on a emissions source
     *
     * @param emissionSourceId The id of the emissions source
     * @param body The list of udf values being edited
     */
    editEmissionSourceCustomFields(emissionSourceId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Assigns the specified scope category and factor pairings to the specified emission sources.  If one or more of the factors provided cannot be applied to the emission source, that emission source will be skipped.
     *
     * @param body
     */
    editEmissionSourceFactorCategoriesBulk(body?: EmissionSourceFactorCategoryBulkUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateSkippedResult>;
    /**
     * Edits an emission source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithMultiFactors(emissionSourceId: number, body?: EmissionSourceMultiFactorEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceMultiFactorResponse>;
    /**
     * Edit meter data in an Emission Source
     *
     * @param emissionSourceId The Emission Source identifier
     * @param body Meter data to assign to the Emission Source
     */
    editMeterLink(emissionSourceId: number, body?: MeterLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterLink>;
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSource(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceResponse>;
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFields(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactors(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceMultiFactorResponse>;
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSources(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EmissionSourceResponse>>;
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactors(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EmissionSourceMultiFactorResponse>>;
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveEmissionSources(parentCollectionId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Resets the scope category and factor pairings of the specified emission sources to their commodity default.  If no default exists for an emission source&#39;s commodity, that emission source will be skipped.
     *
     * @param body
     */
    resetEmissionSourceFactorCategoriesBulk(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateSkippedResult>;
    /**
     * Creates an emissions source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithHttpInfo(body?: EmissionSourceCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceResponse>>;
    /**
     * Creates an emission source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithMultiFactorsWithHttpInfo(body?: EmissionSourceMultiFactorCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceMultiFactorResponse>>;
    /**
     * Deletes an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being deleted
     * @param deleteRecords Should this cascade to delete any records associated with this emissions source
     */
    deleteEmissionSourceWithHttpInfo(emissionSourceId: number, deleteRecords?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithHttpInfo(emissionSourceId: number, body?: EmissionSourceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceResponse>>;
    /**
     * Edit the custom field values on a emissions source
     *
     * @param emissionSourceId The id of the emissions source
     * @param body The list of udf values being edited
     */
    editEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Assigns the specified scope category and factor pairings to the specified emission sources.  If one or more of the factors provided cannot be applied to the emission source, that emission source will be skipped.
     *
     * @param body
     */
    editEmissionSourceFactorCategoriesBulkWithHttpInfo(body?: EmissionSourceFactorCategoryBulkUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateSkippedResult>>;
    /**
     * Edits an emission source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId: number, body?: EmissionSourceMultiFactorEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceMultiFactorResponse>>;
    /**
     * Edit meter data in an Emission Source
     *
     * @param emissionSourceId The Emission Source identifier
     * @param body Meter data to assign to the Emission Source
     */
    editMeterLinkWithHttpInfo(emissionSourceId: number, body?: MeterLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterLink>>;
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceResponse>>;
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceMultiFactorResponse>>;
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EmissionSourceResponse>>>;
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactorsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EmissionSourceMultiFactorResponse>>>;
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveEmissionSourcesWithHttpInfo(parentCollectionId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Resets the scope category and factor pairings of the specified emission sources to their commodity default.  If no default exists for an emission source&#39;s commodity, that emission source will be skipped.
     *
     * @param body
     */
    resetEmissionSourceFactorCategoriesBulkWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateSkippedResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EmissionSourceService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EmissionSourceService>;
}
