import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EnergyProjectCreate } from '../model/energyProjectCreate';
import { EnergyProjectEdit } from '../model/energyProjectEdit';
import { EnergyProjectResponse } from '../model/energyProjectResponse';
import { EnergyProjectType } from '../model/energyProjectType';
import { EnergyProjectTypeCreate } from '../model/energyProjectTypeCreate';
import { ProjectManagerResponse } from '../model/projectManagerResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EnergyProjectService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates an Energy Project
     *
     * @param body Data representing the Energy project being created
     */
    createEnergyProject(body?: EnergyProjectCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyProjectResponse>;
    /**
     * Create a energy project type
     *
     * @param body
     */
    createEnergyProjectType(body?: EnergyProjectTypeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyProjectType>;
    /**
     * Deletes an Energy Project
     *
     * @param projectId The identifier for the energy project being deleted
     */
    deleteEnergyProject(projectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFields(energyProjectId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an Energy Project
     *
     * @param projectId The identifier for the energy project being edited
     * @param body
     */
    editEnergyProject(projectId: number, body?: EnergyProjectEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyProjectResponse>;
    /**
     * Edit the custom field values on a energy project
     *
     * @param energyProjectId The id of the energy project
     * @param body The list of udf values being edited
     */
    editEnergyProjectCustomFields(energyProjectId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProject(projectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyProjectResponse>;
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFields(energyProjectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManager(query?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ProjectManagerResponse>>;
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyProjectType>>;
    /**
     * Creates an Energy Project
     *
     * @param body Data representing the Energy project being created
     */
    createEnergyProjectWithHttpInfo(body?: EnergyProjectCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyProjectResponse>>;
    /**
     * Create a energy project type
     *
     * @param body
     */
    createEnergyProjectTypeWithHttpInfo(body?: EnergyProjectTypeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyProjectType>>;
    /**
     * Deletes an Energy Project
     *
     * @param projectId The identifier for the energy project being deleted
     */
    deleteEnergyProjectWithHttpInfo(projectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFieldsWithHttpInfo(energyProjectId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an Energy Project
     *
     * @param projectId The identifier for the energy project being edited
     * @param body
     */
    editEnergyProjectWithHttpInfo(projectId: number, body?: EnergyProjectEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyProjectResponse>>;
    /**
     * Edit the custom field values on a energy project
     *
     * @param energyProjectId The id of the energy project
     * @param body The list of udf values being edited
     */
    editEnergyProjectCustomFieldsWithHttpInfo(energyProjectId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProjectWithHttpInfo(projectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyProjectResponse>>;
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFieldsWithHttpInfo(energyProjectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManagerWithHttpInfo(query?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ProjectManagerResponse>>>;
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyProjectType>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EnergyProjectService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EnergyProjectService>;
}
