import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountConnectionStatusResponse } from '../model/accountConnectionStatusResponse';
import { EnergyStarCommodityMeterTypeMapping } from '../model/energyStarCommodityMeterTypeMapping';
import { EnergyStarPlaceMetricsRequest } from '../model/energyStarPlaceMetricsRequest';
import { EnergyStarPlaceSubmissionStatusResponse } from '../model/energyStarPlaceSubmissionStatusResponse';
import { EnergyStarPmMeter } from '../model/energyStarPmMeter';
import { EnergyStarPmProperty } from '../model/energyStarPmProperty';
import { EnergyStarSettingsRequest } from '../model/energyStarSettingsRequest';
import { EnergyStarSettingsResponse } from '../model/energyStarSettingsResponse';
import { EnergyStarSubmissionRequest } from '../model/energyStarSubmissionRequest';
import { EnergyStarTaskResponse } from '../model/energyStarTaskResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EnergyStarService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequests(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarSettingsResponse>;
    /**
     * Automatically submit billing data to ENERGY STAR  By default calendarized bill data for a 13-month period (excludes current and last month) in the \&quot;Ready\&quot; state for all buildings setup to automatically submit to ENERGY STAR will be submitted  If 13 months is not preferred, set up the owner&#39;s systemdata key called \&quot;EnergyStarAutoSubmitNumOfMonths\&quot; with an integer value representing the preferred number of months   For example - Today is 25th Nov 2021 - all calendarized data for Sep 2020 through Sep 2021 will be submitted  The buildings submitted will be within the user&#39;s topmost place  No data prior to the earliest period to submit set up in ENERGY STAR settings will ever be submitted
     *
     */
    autoSubmitToEnergyStar(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarTaskResponse>;
    /**
     * Initiate (create) a submission of place data to ENERGY STAR
     *
     * @param body
     */
    createEnergyStarSubmission(body?: EnergyStarSubmissionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarTaskResponse>;
    /**
     * Edit settings for ENERGY STAR submissions
     *
     * @param body ENERGY STAR settings
     */
    editEnergyStarSettings(body?: EnergyStarSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarSettingsResponse>;
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarCommodityMeterTypeMapping>>;
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarSettingsResponse>;
    /**
     * Get the submission status for places by submission period.   Places that do not match the filter criteria will not be returned.    NOTE: Deleting/voiding bills that have already been submitted will not cause submission status to change from \&quot;submitted\&quot;.
     * Returned submission status:      Submitted  - submission has been made for this place and submission period and no bills have been created or modified since the last submission      No Data    - no submission has been made for this place and submission period and current submission period has no billing data      Incomplete - no submission has been made for this place and submission period and current billing data is incomplete (some meters may not have data or some days in submission period may not have data)      Ready      - no submission has been made for this place and submission period and current billing data is complete (every meter has data for every day of this period), or submission has been made but billing data has been added or modified since the last submission
     * @param submissionBeginPeriod The beginning submission period to select
     * @param submissionEndPeriod The ending submission period to select; set equal to beginning submission period get one period
     * @param filter API filter string containing conditions
     */
    getEnergyStarSubmissionStatusList(submissionBeginPeriod: number, submissionEndPeriod: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPlaceSubmissionStatusResponse>>;
    /**
     * Get an ENERGY STAR task with its details
     *
     * @param energyStarTaskId
     */
    getEnergyStarTask(energyStarTaskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarTaskResponse>;
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasks(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarTaskResponse>>;
    /**
     * Get the connection status for a Portfolio Manager account and database
     *
     * @param pmUserName User name used to log in to Portfolio Manager
     */
    getPMConnectionStatus(pmUserName?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountConnectionStatusResponse>;
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperties(includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPmProperty>>;
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperty(pmPropertyId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPmProperty>;
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMeters(pmPropertyId: number, includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPmMeter>>;
    /**
     * Unlink owner from portfolio manager account
     *
     * @param deleteData If true, delete EnergyStar metrics and score. False by default
     */
    unlinkOwnerFromPortfolioManager(deleteData?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Update ENERGY STAR metrics for the places matching the request criteria.
     *
     * @param body Periods and list of place identifiers for which to update metrics
     */
    updateEnergyStarMetrics(body?: EnergyStarPlaceMetricsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarTaskResponse>;
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequestsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarSettingsResponse>>;
    /**
     * Automatically submit billing data to ENERGY STAR  By default calendarized bill data for a 13-month period (excludes current and last month) in the \&quot;Ready\&quot; state for all buildings setup to automatically submit to ENERGY STAR will be submitted  If 13 months is not preferred, set up the owner&#39;s systemdata key called \&quot;EnergyStarAutoSubmitNumOfMonths\&quot; with an integer value representing the preferred number of months   For example - Today is 25th Nov 2021 - all calendarized data for Sep 2020 through Sep 2021 will be submitted  The buildings submitted will be within the user&#39;s topmost place  No data prior to the earliest period to submit set up in ENERGY STAR settings will ever be submitted
     *
     */
    autoSubmitToEnergyStarWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarTaskResponse>>;
    /**
     * Initiate (create) a submission of place data to ENERGY STAR
     *
     * @param body
     */
    createEnergyStarSubmissionWithHttpInfo(body?: EnergyStarSubmissionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarTaskResponse>>;
    /**
     * Edit settings for ENERGY STAR submissions
     *
     * @param body ENERGY STAR settings
     */
    editEnergyStarSettingsWithHttpInfo(body?: EnergyStarSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarSettingsResponse>>;
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarCommodityMeterTypeMapping>>>;
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarSettingsResponse>>;
    /**
     * Get the submission status for places by submission period.   Places that do not match the filter criteria will not be returned.    NOTE: Deleting/voiding bills that have already been submitted will not cause submission status to change from \&quot;submitted\&quot;.
     * Returned submission status:      Submitted  - submission has been made for this place and submission period and no bills have been created or modified since the last submission      No Data    - no submission has been made for this place and submission period and current submission period has no billing data      Incomplete - no submission has been made for this place and submission period and current billing data is incomplete (some meters may not have data or some days in submission period may not have data)      Ready      - no submission has been made for this place and submission period and current billing data is complete (every meter has data for every day of this period), or submission has been made but billing data has been added or modified since the last submission
     * @param submissionBeginPeriod The beginning submission period to select
     * @param submissionEndPeriod The ending submission period to select; set equal to beginning submission period get one period
     * @param filter API filter string containing conditions
     */
    getEnergyStarSubmissionStatusListWithHttpInfo(submissionBeginPeriod: number, submissionEndPeriod: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPlaceSubmissionStatusResponse>>>;
    /**
     * Get an ENERGY STAR task with its details
     *
     * @param energyStarTaskId
     */
    getEnergyStarTaskWithHttpInfo(energyStarTaskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarTaskResponse>>;
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasksWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarTaskResponse>>>;
    /**
     * Get the connection status for a Portfolio Manager account and database
     *
     * @param pmUserName User name used to log in to Portfolio Manager
     */
    getPMConnectionStatusWithHttpInfo(pmUserName?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountConnectionStatusResponse>>;
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertiesWithHttpInfo(includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPmProperty>>>;
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertyWithHttpInfo(pmPropertyId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPmProperty>>;
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMetersWithHttpInfo(pmPropertyId: number, includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPmMeter>>>;
    /**
     * Unlink owner from portfolio manager account
     *
     * @param deleteData If true, delete EnergyStar metrics and score. False by default
     */
    unlinkOwnerFromPortfolioManagerWithHttpInfo(deleteData?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Update ENERGY STAR metrics for the places matching the request criteria.
     *
     * @param body Periods and list of place identifiers for which to update metrics
     */
    updateEnergyStarMetricsWithHttpInfo(body?: EnergyStarPlaceMetricsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarTaskResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EnergyStarService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EnergyStarService>;
}
