import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EsaChannelCreate } from '../model/esaChannelCreate';
import { EsaChannelEdit } from '../model/esaChannelEdit';
import { EsaChannelResponse } from '../model/esaChannelResponse';
import { EsaChannelVersionCreateWithBeginDate } from '../model/esaChannelVersionCreateWithBeginDate';
import { EsaChannelVersionEdit } from '../model/esaChannelVersionEdit';
import { EsaChannelVersionResponse } from '../model/esaChannelVersionResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EsaChannelService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannel(body?: EsaChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelResponse>;
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersion(esaChannelId: number, body?: EsaChannelVersionCreateWithBeginDate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelVersionResponse>;
    /**
     * Deletes an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    deleteEsaChannel(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannel(esaChannelId: number, body?: EsaChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelResponse>;
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersion(esaChannelId: number, versionId: number, body?: EsaChannelVersionEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelVersionResponse>;
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannel(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelResponse>;
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersion(esaChannelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelVersionResponse>;
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersions(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaChannelVersionResponse>>;
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannels(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaChannelResponse>>;
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannelWithHttpInfo(body?: EsaChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelResponse>>;
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersionWithHttpInfo(esaChannelId: number, body?: EsaChannelVersionCreateWithBeginDate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelVersionResponse>>;
    /**
     * Deletes an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    deleteEsaChannelWithHttpInfo(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannelWithHttpInfo(esaChannelId: number, body?: EsaChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelResponse>>;
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersionWithHttpInfo(esaChannelId: number, versionId: number, body?: EsaChannelVersionEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelVersionResponse>>;
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannelWithHttpInfo(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelResponse>>;
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersionWithHttpInfo(esaChannelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelVersionResponse>>;
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersionsWithHttpInfo(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaChannelVersionResponse>>>;
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannelsWithHttpInfo(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaChannelResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EsaChannelService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EsaChannelService>;
}
