import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EditEsaPlaceSizesRequest } from '../model/editEsaPlaceSizesRequest';
import { EsaPlaceCreate } from '../model/esaPlaceCreate';
import { EsaPlaceDataRollupRequest } from '../model/esaPlaceDataRollupRequest';
import { EsaPlaceEdit } from '../model/esaPlaceEdit';
import { EsaPlaceResponse } from '../model/esaPlaceResponse';
import { PlaceSizeChild } from '../model/placeSizeChild';
import { PlaceSizeResponse } from '../model/placeSizeResponse';
import { ScheduleResponse } from '../model/scheduleResponse';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EsaPlaceService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollup(body?: EsaPlaceDataRollupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Creates an ESA place
     *
     * @param body Data representing the ESA place being created
     */
    createEsaPlace(body?: EsaPlaceCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaPlaceResponse>;
    /**
     * Deletes an ESA place
     *
     * @param placeId The identifier for the ESA place being deleted
     */
    deleteEsaPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlace(placeId: number, body?: EsaPlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaPlaceResponse>;
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedules(placeId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ScheduleResponse>>;
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistory(placeId: number, body?: EditEsaPlaceSizesRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaPlaceResponse>;
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizes(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeResponse>>;
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedules(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ScheduleResponse>>;
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistory(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlaces(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaPlaceResponse>>;
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlace(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollupWithHttpInfo(body?: EsaPlaceDataRollupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Creates an ESA place
     *
     * @param body Data representing the ESA place being created
     */
    createEsaPlaceWithHttpInfo(body?: EsaPlaceCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaPlaceResponse>>;
    /**
     * Deletes an ESA place
     *
     * @param placeId The identifier for the ESA place being deleted
     */
    deleteEsaPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlaceWithHttpInfo(placeId: number, body?: EsaPlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaPlaceResponse>>;
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedulesWithHttpInfo(placeId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ScheduleResponse>>>;
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistoryWithHttpInfo(placeId: number, body?: EditEsaPlaceSizesRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaPlaceResponse>>;
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeResponse>>>;
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedulesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ScheduleResponse>>>;
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistoryWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlacesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaPlaceResponse>>>;
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlaceWithHttpInfo(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EsaPlaceService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EsaPlaceService>;
}
