import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EsaDeleteReadingResponse } from '../model/esaDeleteReadingResponse';
import { EsaDeleteReadingSummarizedResponse } from '../model/esaDeleteReadingSummarizedResponse';
import { EsaReadingCreate } from '../model/esaReadingCreate';
import { EsaReadingCreateResponse } from '../model/esaReadingCreateResponse';
import { EsaReadingDelete } from '../model/esaReadingDelete';
import { EsaReadingResponse } from '../model/esaReadingResponse';
import { EsaReadingSummarizedDelete } from '../model/esaReadingSummarizedDelete';
import { EsaReadingSummarizedResponse } from '../model/esaReadingSummarizedResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class EsaReadingService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create new readings. Existing readings at the same time for a given channel will be overwritten.
     *
     * @param body Readings to be imported
     */
    createEsaReadings(body?: Array<EsaReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingCreateResponse>;
    /**
     * Deletes existing channel readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body
     */
    deleteEsaReadings(body?: Array<EsaReadingDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaDeleteReadingResponse>;
    /**
     * Deletes existing summarized readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.  If the summarized reading is system-generated, the endpoint will return an error indicating that it cannot be deleted.
     *
     * @param body
     */
    deleteEsaSummarizedReadings(body?: Array<EsaReadingSummarizedDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaDeleteReadingSummarizedResponse>;
    /**
     * Retrieves all raw and processed ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaReadings(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaReadingResponse>>;
    /**
     * Retrieves all summarized ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaSummarizedReadings(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaReadingSummarizedResponse>>;
    /**
     * Retrieves all summarized ESA readings and exports them as a CSV file. File contents can be filtered and ordered.
     *
     * @param filter
     * @param orderBy
     */
    getEsaSummarizedReadingsAsCSV(filter?: string, orderBy?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Creates and Edits summarized readings for a datapoint and channel
     *
     * @param body
     */
    upsertEsaSummarizedReading(body?: Array<EsaReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingCreateResponse>;
    /**
     * Create new readings. Existing readings at the same time for a given channel will be overwritten.
     *
     * @param body Readings to be imported
     */
    createEsaReadingsWithHttpInfo(body?: Array<EsaReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingCreateResponse>>;
    /**
     * Deletes existing channel readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body
     */
    deleteEsaReadingsWithHttpInfo(body?: Array<EsaReadingDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaDeleteReadingResponse>>;
    /**
     * Deletes existing summarized readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.  If the summarized reading is system-generated, the endpoint will return an error indicating that it cannot be deleted.
     *
     * @param body
     */
    deleteEsaSummarizedReadingsWithHttpInfo(body?: Array<EsaReadingSummarizedDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaDeleteReadingSummarizedResponse>>;
    /**
     * Retrieves all raw and processed ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaReadingsWithHttpInfo(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaReadingResponse>>>;
    /**
     * Retrieves all summarized ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaSummarizedReadingsWithHttpInfo(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaReadingSummarizedResponse>>>;
    /**
     * Retrieves all summarized ESA readings and exports them as a CSV file. File contents can be filtered and ordered.
     *
     * @param filter
     * @param orderBy
     */
    getEsaSummarizedReadingsAsCSVWithHttpInfo(filter?: string, orderBy?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Creates and Edits summarized readings for a datapoint and channel
     *
     * @param body
     */
    upsertEsaSummarizedReadingWithHttpInfo(body?: Array<EsaReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingCreateResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EsaReadingService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EsaReadingService>;
}
