import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FileDataTypeResponse } from '../model/fileDataTypeResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class FileStoreService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get a list of file data types, their supported extensions, and max size
     *
     */
    getFileDataTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FileDataTypeResponse>>;
    /**
     * Upload a file
     * | File Data Type | File Data Type Id | Supported File Types                                                                                                                                                                                                                                                                             | Maximum Size |  |----------------|-------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------|  | Image          | 16                | jpg, png, svg, gif, heic                                                                                                                                                                                                                                                                               | 100 MB       |  | PDF            | 17                | pdf                                                                                                                                                                                                                                                                                              | 100 MB       |  | Document       | 18                | MS Word (doc, dot, wbk, docx, docm, dotx, dotm, docb)&lt;br /&gt;Excel (xls, xlt, xlm, xlsx, xlsm, xltx, xltm, xlsb, xlw)&lt;br /&gt;PowerPoint (ppt, pot, pps, pptx, pptm, potx, potm, ppsx, ppsm, sldx, sldm)&lt;br /&gt;OpenOffice (odt, ods, odp)&lt;br /&gt;OneNote (one)&lt;br /&gt;Other (rtf, txt, csv, xml)&lt;br /&gt; Zip (zip) | 100 MB       |
     * @param fileDataTypeId The data type of the file. You can retrieve a list of supported data types by calling the GetFileDataTypes API
     * @param fileName The name of the file
     * @param body Binary data containing the file contents
     */
    uploadFile(fileDataTypeId: number, fileName?: string, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Get a list of file data types, their supported extensions, and max size
     *
     */
    getFileDataTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FileDataTypeResponse>>>;
    /**
     * Upload a file
     * | File Data Type | File Data Type Id | Supported File Types                                                                                                                                                                                                                                                                             | Maximum Size |  |----------------|-------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------|  | Image          | 16                | jpg, png, svg, gif, heic                                                                                                                                                                                                                                                                               | 100 MB       |  | PDF            | 17                | pdf                                                                                                                                                                                                                                                                                              | 100 MB       |  | Document       | 18                | MS Word (doc, dot, wbk, docx, docm, dotx, dotm, docb)&lt;br /&gt;Excel (xls, xlt, xlm, xlsx, xlsm, xltx, xltm, xlsb, xlw)&lt;br /&gt;PowerPoint (ppt, pot, pps, pptx, pptm, potx, potm, ppsx, ppsm, sldx, sldm)&lt;br /&gt;OpenOffice (odt, ods, odp)&lt;br /&gt;OneNote (one)&lt;br /&gt;Other (rtf, txt, csv, xml)&lt;br /&gt; Zip (zip) | 100 MB       |
     * @param fileDataTypeId The data type of the file. You can retrieve a list of supported data types by calling the GetFileDataTypes API
     * @param fileName The name of the file
     * @param body Binary data containing the file contents
     */
    uploadFileWithHttpInfo(fileDataTypeId: number, fileName?: string, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<FileStoreService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FileStoreService>;
}
