import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FlagEdit } from '../model/flagEdit';
import { FlagIssueEdit } from '../model/flagIssueEdit';
import { FlagIssueListAction } from '../model/flagIssueListAction';
import { FlagIssueResponse } from '../model/flagIssueResponse';
import { FlagListAction } from '../model/flagListAction';
import { FlagResponse } from '../model/flagResponse';
import { FlagTypeChild } from '../model/flagTypeChild';
import { FlagTypeCreate } from '../model/flagTypeCreate';
import { FlagWidget } from '../model/flagWidget';
import { SingleBoolean } from '../model/singleBoolean';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class FlagService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccount(costCenterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagWidget>;
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeter(placeId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagWidget>;
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagType(body?: FlagTypeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagTypeChild>;
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagType(flagTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit flag data for a specified entity
     * This API supports a wide variety of Flag-related actions. Below are summaries of expected outcomes for possible combinations of property values.      Create Flag(the entity is not yet flagged, therefore there is no \&quot;modified\&quot; info)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                                                                                   Action                                                                                                                    |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                                                                                                                     |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                                                                                                                                       |  | null                     | null                     | null                     | null                     | null                     | null                 | null                 | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                                                                                                           |  | null                     | **not null**             | **not null**             | **not null**             | **not null**             | false                | false                | Exception, must have a type                                                                                                                                                                                                                 |  | **not null**             | null                     | null                     | null                     | null                     | false                | false                | Flagged, unresolved, specified type                                                                                                                                                                                                         |  | **not null**             | **not null**             | null                     | null                     | null                     | false                | false                | Flagged, unresolved(ignoring specified status), specified type                                                                                                                                                                              |  | **not null**             | null                     | **not null**             | null                     | null                     | false                | false                | Flagged, unresolved, specified type, cost recovery                                                                                                                                                                                          |  | **not null**             | null                     | null                     | **not null**&lt;sup&gt;1&lt;/sup&gt; | null                     | false                | false                | Flagged, unresolved, specified type&lt;br /&gt;&lt;sup&gt;1&lt;/sup&gt;If assignees not empty, assigned                                                                                                                                                       |  | **not null**             | null                     | null                     | null                     | **not null**             | false                | false                | Flagged, unresolved, specified type, comment                                                                                                                                                                                                |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment                                                            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;3&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;No action; will not release a newly flagged bill for export |    Edit Unresolved Flag (the entity is already flagged)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    | ReleaseExportHold |                                                                       Action                                                                        |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**          | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                             |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**      | Exception, must have at least one set                                                                                                               |  | null                     | null                     | null                     | null                     | null                     | false                | false             | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                   |  | **system or user type**  | null                     | null                     | null                     | null                     | false                | false             | Flag type updated                                                                                                                                   |  | null                     | **resolved**             | null                     | null                     | null                     | false                | false             | Resolved                                                                                                                                            |  | null                     | **resolved**             | null                     | null                     | null                     | false                | **true**          | Resolved, released for export                                                                                                                       |  | null                     | null                     | **not null**             | null                     | null                     | false                | false             | Updated, cost recovery                                                                                                                              |  | null                     | null                     | null                     | **not null**             | null                     | false                | false             | Assigned                                                                                                                                            |  | null                     | null                     | null                     | null                     | **not null**             | false                | false             | Updated, comment                                                                                                                                    |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment                   |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |    Edit Resolved Flag (the entity is already flagged)    |        FlagTypeId        |        FlagStatusId        |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                              Action                                                               |  | ------------------------ | -------------------------- | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | --------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                       | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                           |  | null                     | null                       | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                             |  | null                     | null                       | null                     | null                     | null                     | false                | false                | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                 |  | **system or user type**  | null                       | null                     | null                     | null                     | false                | false                | Updated, specified type                                                                                                           |  | null                     | **non-null**               | null                     | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | **not null**             | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | **not null**             | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | null                     | **not null**             | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false                | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;      |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, released from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param body The flag edit request
     */
    editFlag(entityType: string, entityId: number, body?: FlagEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagResponse>;
    /**
     *
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param flagResolveComment Optional comment that will be recorded in the flag event when resolving the issue
     * @param body The flag issue edit request
     */
    editFlagIssues(entityType: string, entityId: number, flagResolveComment?: string, body?: Array<FlagIssueEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FlagIssueResponse>>;
    /**
     * Updates flags for a given list of entities. If the entity does not currently have a flag, one will be created.
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param body The changes to be made to the flags
     */
    flagAction(entityType: string, body?: FlagListAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchy(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchy(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchy(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchy(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Updates flag issues for a given list of flag issue ids
     *
     * @param body The changes to be made to the flag issues
     */
    flagIssueAction(body?: FlagIssueListAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlag(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagResponse>;
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssues(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FlagIssueResponse>>;
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FlagTypeChild>>;
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccountWithHttpInfo(costCenterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagWidget>>;
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeterWithHttpInfo(placeId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagWidget>>;
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagTypeWithHttpInfo(body?: FlagTypeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagTypeChild>>;
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagTypeWithHttpInfo(flagTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit flag data for a specified entity
     * This API supports a wide variety of Flag-related actions. Below are summaries of expected outcomes for possible combinations of property values.      Create Flag(the entity is not yet flagged, therefore there is no \&quot;modified\&quot; info)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                                                                                   Action                                                                                                                    |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                                                                                                                     |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                                                                                                                                       |  | null                     | null                     | null                     | null                     | null                     | null                 | null                 | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                                                                                                           |  | null                     | **not null**             | **not null**             | **not null**             | **not null**             | false                | false                | Exception, must have a type                                                                                                                                                                                                                 |  | **not null**             | null                     | null                     | null                     | null                     | false                | false                | Flagged, unresolved, specified type                                                                                                                                                                                                         |  | **not null**             | **not null**             | null                     | null                     | null                     | false                | false                | Flagged, unresolved(ignoring specified status), specified type                                                                                                                                                                              |  | **not null**             | null                     | **not null**             | null                     | null                     | false                | false                | Flagged, unresolved, specified type, cost recovery                                                                                                                                                                                          |  | **not null**             | null                     | null                     | **not null**&lt;sup&gt;1&lt;/sup&gt; | null                     | false                | false                | Flagged, unresolved, specified type&lt;br /&gt;&lt;sup&gt;1&lt;/sup&gt;If assignees not empty, assigned                                                                                                                                                       |  | **not null**             | null                     | null                     | null                     | **not null**             | false                | false                | Flagged, unresolved, specified type, comment                                                                                                                                                                                                |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment                                                            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;3&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;No action; will not release a newly flagged bill for export |    Edit Unresolved Flag (the entity is already flagged)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    | ReleaseExportHold |                                                                       Action                                                                        |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**          | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                             |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**      | Exception, must have at least one set                                                                                                               |  | null                     | null                     | null                     | null                     | null                     | false                | false             | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                   |  | **system or user type**  | null                     | null                     | null                     | null                     | false                | false             | Flag type updated                                                                                                                                   |  | null                     | **resolved**             | null                     | null                     | null                     | false                | false             | Resolved                                                                                                                                            |  | null                     | **resolved**             | null                     | null                     | null                     | false                | **true**          | Resolved, released for export                                                                                                                       |  | null                     | null                     | **not null**             | null                     | null                     | false                | false             | Updated, cost recovery                                                                                                                              |  | null                     | null                     | null                     | **not null**             | null                     | false                | false             | Assigned                                                                                                                                            |  | null                     | null                     | null                     | null                     | **not null**             | false                | false             | Updated, comment                                                                                                                                    |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment                   |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |    Edit Resolved Flag (the entity is already flagged)    |        FlagTypeId        |        FlagStatusId        |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                              Action                                                               |  | ------------------------ | -------------------------- | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | --------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                       | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                           |  | null                     | null                       | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                             |  | null                     | null                       | null                     | null                     | null                     | false                | false                | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                 |  | **system or user type**  | null                       | null                     | null                     | null                     | false                | false                | Updated, specified type                                                                                                           |  | null                     | **non-null**               | null                     | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | **not null**             | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | **not null**             | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | null                     | **not null**             | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false                | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;      |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, released from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param body The flag edit request
     */
    editFlagWithHttpInfo(entityType: string, entityId: number, body?: FlagEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagResponse>>;
    /**
     *
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param flagResolveComment Optional comment that will be recorded in the flag event when resolving the issue
     * @param body The flag issue edit request
     */
    editFlagIssuesWithHttpInfo(entityType: string, entityId: number, flagResolveComment?: string, body?: Array<FlagIssueEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FlagIssueResponse>>>;
    /**
     * Updates flags for a given list of entities. If the entity does not currently have a flag, one will be created.
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param body The changes to be made to the flags
     */
    flagActionWithHttpInfo(entityType: string, body?: FlagListAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchyWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchyWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchyWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchyWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Updates flag issues for a given list of flag issue ids
     *
     * @param body The changes to be made to the flag issues
     */
    flagIssueActionWithHttpInfo(body?: FlagIssueListAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagWithHttpInfo(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagResponse>>;
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssuesWithHttpInfo(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FlagIssueResponse>>>;
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FlagTypeChild>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<FlagService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FlagService>;
}
