import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { GHGFactorCategory } from '../model/gHGFactorCategory';
import { GHGFactorRegion } from '../model/gHGFactorRegion';
import { GHGFactorResponse } from '../model/gHGFactorResponse';
import { GHGFactorVersionHistoryResponse } from '../model/gHGFactorVersionHistoryResponse';
import { GHGScopeResponse } from '../model/gHGScopeResponse';
import { GHGSettingResponse } from '../model/gHGSettingResponse';
import { GHGasDefaultSettingRequest } from '../model/gHGasDefaultSettingRequest';
import { GHGasDefaultSettingResponse } from '../model/gHGasDefaultSettingResponse';
import { MeterActionCreateEmissionSource } from '../model/meterActionCreateEmissionSource';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class GHGService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create emission sources for existing meters.
     *
     * @param body The ids of the meters for which to create emission sources
     */
    createEmissionSourceForMeter(body?: MeterActionCreateEmissionSource, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the default GHG scopes and factors that are applied to new meters.  Only included CommodityIds will be updated.  If a CommodityId is not included in the list the currently assigned value will remain.  To remove a default for a particular CommodityId set its ScopeCategoryId and DefaultFactor to null.
     *
     * @param body The default GHG scope and factor to be applied
     */
    editDefaultGHGSettingsMultiFactor(body?: GHGasDefaultSettingRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GHGasDefaultSettingResponse>;
    /**
     * Get the default GHG scopes and factors that are applied to new meters  GHG License is required to call this endpoint
     *
     */
    getDefaultGHGSettingsMultiFactor(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GHGasDefaultSettingResponse>;
    /**
     * Retrieves all the ghg factor categories
     *
     */
    getGHGFactorCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGFactorCategory>>;
    /**
     * Retrieves all the ghg factor regions
     *
     */
    getGHGFactorRegions(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGFactorRegion>>;
    /**
     * Get the version history of a specific GHG factor
     *
     * @param factorId The GHG factor to retrieve history for
     */
    getGHGFactorVersionHistory(factorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGFactorVersionHistoryResponse>>;
    /**
     * Retrieves all the ghg factors
     *
     * @param filter The api filters&gt;
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGHGFactors(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGFactorResponse>>;
    /**
     * Get all GHG scope categories and scopes  GHG License is required to call this endpoint
     *
     */
    getGHGScopesWithCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGScopeResponse>>;
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettings(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GHGSettingResponse>;
    /**
     * Create emission sources for existing meters.
     *
     * @param body The ids of the meters for which to create emission sources
     */
    createEmissionSourceForMeterWithHttpInfo(body?: MeterActionCreateEmissionSource, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the default GHG scopes and factors that are applied to new meters.  Only included CommodityIds will be updated.  If a CommodityId is not included in the list the currently assigned value will remain.  To remove a default for a particular CommodityId set its ScopeCategoryId and DefaultFactor to null.
     *
     * @param body The default GHG scope and factor to be applied
     */
    editDefaultGHGSettingsMultiFactorWithHttpInfo(body?: GHGasDefaultSettingRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GHGasDefaultSettingResponse>>;
    /**
     * Get the default GHG scopes and factors that are applied to new meters  GHG License is required to call this endpoint
     *
     */
    getDefaultGHGSettingsMultiFactorWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GHGasDefaultSettingResponse>>;
    /**
     * Retrieves all the ghg factor categories
     *
     */
    getGHGFactorCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGFactorCategory>>>;
    /**
     * Retrieves all the ghg factor regions
     *
     */
    getGHGFactorRegionsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGFactorRegion>>>;
    /**
     * Get the version history of a specific GHG factor
     *
     * @param factorId The GHG factor to retrieve history for
     */
    getGHGFactorVersionHistoryWithHttpInfo(factorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGFactorVersionHistoryResponse>>>;
    /**
     * Retrieves all the ghg factors
     *
     * @param filter The api filters&gt;
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGHGFactorsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGFactorResponse>>>;
    /**
     * Get all GHG scope categories and scopes  GHG License is required to call this endpoint
     *
     */
    getGHGScopesWithCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGScopeResponse>>>;
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettingsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GHGSettingResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<GHGService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<GHGService>;
}
