import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { GLSubcodeRequest } from '../model/gLSubcodeRequest';
import { GLSubcodeResponse } from '../model/gLSubcodeResponse';
import { GeneralLedgerRequest } from '../model/generalLedgerRequest';
import { GeneralLedgerResponse } from '../model/generalLedgerResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class GeneralLedgerService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a General Ledger
     *
     * @param body Data representing the general ledger being created
     */
    createGeneralLedger(body?: GeneralLedgerRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GeneralLedgerResponse>;
    /**
     * Edit General Ledger Subcode definitions - update name, type and if \&quot;list\&quot; type edit (add/delete/edit) pick list values.   One or more subcodes can be edited.
     *
     * @param body Provide the subcode definition
     */
    editGLSubCodes(body?: Array<GLSubcodeRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GLSubcodeResponse>>;
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedger(generalLedgerId: number, body?: GeneralLedgerRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GeneralLedgerResponse>;
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCode(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GLSubcodeResponse>;
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValues(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<string>>;
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GLSubcodeResponse>>;
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedger(generalLedgerId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GeneralLedgerResponse>;
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgers(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GeneralLedgerResponse>>;
    /**
     * Creates a General Ledger
     *
     * @param body Data representing the general ledger being created
     */
    createGeneralLedgerWithHttpInfo(body?: GeneralLedgerRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GeneralLedgerResponse>>;
    /**
     * Edit General Ledger Subcode definitions - update name, type and if \&quot;list\&quot; type edit (add/delete/edit) pick list values.   One or more subcodes can be edited.
     *
     * @param body Provide the subcode definition
     */
    editGLSubCodesWithHttpInfo(body?: Array<GLSubcodeRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GLSubcodeResponse>>>;
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedgerWithHttpInfo(generalLedgerId: number, body?: GeneralLedgerRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GeneralLedgerResponse>>;
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCodeWithHttpInfo(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GLSubcodeResponse>>;
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValuesWithHttpInfo(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<string>>>;
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GLSubcodeResponse>>>;
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedgerWithHttpInfo(generalLedgerId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GeneralLedgerResponse>>;
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GeneralLedgerResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<GeneralLedgerService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<GeneralLedgerService>;
}
