import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CostCenterChild } from '../model/costCenterChild';
import { HierarchicalCollections } from '../model/hierarchicalCollections';
import { HierarchicalCostCenters } from '../model/hierarchicalCostCenters';
import { HierarchicalPlaces } from '../model/hierarchicalPlaces';
import { HierarchicalSpaces } from '../model/hierarchicalSpaces';
import { PlaceChild } from '../model/placeChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class HierarchyService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlaces(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterChild>>;
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCenters(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceChild>>;
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccounts(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCostCenters>;
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollections(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCollections>;
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCenters(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCostCenters>;
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPoints(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalSpaces>;
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSources(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCollections>;
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMeters(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalPlaces>;
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlaces(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalPlaces>;
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpaces(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalSpaces>;
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollection(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCollections>;
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenter(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCostCenters>;
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalPlaces>;
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalSpaces>;
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlacesWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterChild>>>;
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCentersWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceChild>>>;
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccountsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCostCenters>>;
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollectionsWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCollections>>;
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCentersWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCostCenters>>;
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPointsWithHttpInfo(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalSpaces>>;
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSourcesWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCollections>>;
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMetersWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalPlaces>>;
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlacesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalPlaces>>;
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpacesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalSpaces>>;
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollectionWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCollections>>;
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenterWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCostCenters>>;
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalPlaces>>;
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalSpaces>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HierarchyService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HierarchyService>;
}
