import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillImportKickoutDetailsResponse } from '../model/billImportKickoutDetailsResponse';
import { BillImportProfileRequest } from '../model/billImportProfileRequest';
import { BillImportProfileResponse } from '../model/billImportProfileResponse';
import { BillImportRequest } from '../model/billImportRequest';
import { BillImportTaskKickoutSummaryResponse } from '../model/billImportTaskKickoutSummaryResponse';
import { BillKickoutImportRequest } from '../model/billKickoutImportRequest';
import { DetailedGuidResponse } from '../model/detailedGuidResponse';
import { EsaReadingImportProfileCreate } from '../model/esaReadingImportProfileCreate';
import { EsaReadingImportProfileEdit } from '../model/esaReadingImportProfileEdit';
import { EsaReadingImportProfileResponse } from '../model/esaReadingImportProfileResponse';
import { EsaReadingImportRequest } from '../model/esaReadingImportRequest';
import { GuidResponse } from '../model/guidResponse';
import { ReadingImportProfileRequest } from '../model/readingImportProfileRequest';
import { ReadingImportProfileResponse } from '../model/readingImportProfileResponse';
import { ReadingImportRequest } from '../model/readingImportRequest';
import { RecordImportProfileEdit } from '../model/recordImportProfileEdit';
import { RecordImportProfileRequest } from '../model/recordImportProfileRequest';
import { RecordImportProfileResponse } from '../model/recordImportProfileResponse';
import { RecordImportRequest } from '../model/recordImportRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ImportService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImport(body?: BillImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfile(body?: EsaReadingImportProfileCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingImportProfileResponse>;
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfile(body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingImportProfileResponse>;
    /**
     * Creates an emission record import profile
     *
     * @param body Object containing settings for the new profile
     */
    createRecordImportProfile(body?: RecordImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RecordImportProfileResponse>;
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes an ESA reading import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteEsaReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes an emission record import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteRecordImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfile(profileId: number, body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportProfileResponse>;
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfile(profileId: number, body?: EsaReadingImportProfileEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingImportProfileResponse>;
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfile(profileId: number, body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingImportProfileResponse>;
    /**
     * Edits an emission record import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings to change
     */
    editRecordImportProfile(profileId: number, body?: RecordImportProfileEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RecordImportProfileResponse>;
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetails(taskGuid: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportKickoutDetailsResponse>;
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFile(taskGuid: string, filename: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportKickoutDetailsResponse>;
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportProfileResponse>;
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillImportProfileResponse>>;
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingImportProfileResponse>;
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaReadingImportProfileResponse>>;
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingImportProfileResponse>;
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ReadingImportProfileResponse>>;
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RecordImportProfileResponse>;
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RecordImportProfileResponse>>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummary(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportTaskKickoutSummaryResponse>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFile(taskGuid: string, filename: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportTaskKickoutSummaryResponse>;
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickouts(taskGuid: string, body?: BillKickoutImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     * This endpoint allows the import of a emission records import file.  The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEmissionRecordsWithProfile(body?: RecordImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfile(body?: EsaReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DetailedGuidResponse>>;
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImport(body?: ReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfile(body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportProfileResponse>;
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImportWithHttpInfo(body?: BillImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfileWithHttpInfo(body?: EsaReadingImportProfileCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingImportProfileResponse>>;
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfileWithHttpInfo(body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingImportProfileResponse>>;
    /**
     * Creates an emission record import profile
     *
     * @param body Object containing settings for the new profile
     */
    createRecordImportProfileWithHttpInfo(body?: RecordImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RecordImportProfileResponse>>;
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes an ESA reading import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteEsaReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes an emission record import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteRecordImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfileWithHttpInfo(profileId: number, body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportProfileResponse>>;
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfileWithHttpInfo(profileId: number, body?: EsaReadingImportProfileEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingImportProfileResponse>>;
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfileWithHttpInfo(profileId: number, body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingImportProfileResponse>>;
    /**
     * Edits an emission record import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings to change
     */
    editRecordImportProfileWithHttpInfo(profileId: number, body?: RecordImportProfileEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RecordImportProfileResponse>>;
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsWithHttpInfo(taskGuid: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportKickoutDetailsResponse>>;
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFileWithHttpInfo(taskGuid: string, filename: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportKickoutDetailsResponse>>;
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportProfileResponse>>;
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillImportProfileResponse>>>;
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingImportProfileResponse>>;
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaReadingImportProfileResponse>>>;
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingImportProfileResponse>>;
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ReadingImportProfileResponse>>>;
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RecordImportProfileResponse>>;
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RecordImportProfileResponse>>>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummaryWithHttpInfo(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportTaskKickoutSummaryResponse>>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFileWithHttpInfo(taskGuid: string, filename: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportTaskKickoutSummaryResponse>>;
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickoutsWithHttpInfo(taskGuid: string, body?: BillKickoutImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     * This endpoint allows the import of a emission records import file.  The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEmissionRecordsWithProfileWithHttpInfo(body?: RecordImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfileWithHttpInfo(body?: EsaReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DetailedGuidResponse>>>;
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImportWithHttpInfo(body?: ReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfileWithHttpInfo(body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportProfileResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ImportService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ImportService>;
}
