import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillActionMoveList } from '../model/billActionMoveList';
import { BillDeleteActionResult } from '../model/billDeleteActionResult';
import { BillExportOptions } from '../model/billExportOptions';
import { BillHeaderUpdate } from '../model/billHeaderUpdate';
import { BillUnexportOptions } from '../model/billUnexportOptions';
import { ChargebackProcessorSettingsForSplits } from '../model/chargebackProcessorSettingsForSplits';
import { ChargebackTaskResponse } from '../model/chargebackTaskResponse';
import { DistributeAccountChargesBase } from '../model/distributeAccountChargesBase';
import { DynamicListRequest } from '../model/dynamicListRequest';
import { FilterEdit } from '../model/filterEdit';
import { FilterResponse } from '../model/filterResponse';
import { FlagEdit } from '../model/flagEdit';
import { FlagIssueEditAction } from '../model/flagIssueEditAction';
import { ListActionAccrualExclusion } from '../model/listActionAccrualExclusion';
import { ListActionApprove } from '../model/listActionApprove';
import { ListActionCustom } from '../model/listActionCustom';
import { ListActionExportHold } from '../model/listActionExportHold';
import { ListActionReverse } from '../model/listActionReverse';
import { ListActionVoid } from '../model/listActionVoid';
import { ListColumnEdit } from '../model/listColumnEdit';
import { ListCopy } from '../model/listCopy';
import { ListCreate } from '../model/listCreate';
import { ListCreateResponse } from '../model/listCreateResponse';
import { ListEdit } from '../model/listEdit';
import { ListResponse } from '../model/listResponse';
import { ListResponseListField } from '../model/listResponseListField';
import { MoveBillsDestination } from '../model/moveBillsDestination';
import { ShareRequest } from '../model/shareRequest';
import { ShareResponse } from '../model/shareResponse';
import { ToggleVisible } from '../model/toggleVisible';
import { UpdateResult } from '../model/updateResult';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ListService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Approve/unapprove account bills
     *
     * @param accountId The account to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    accountBillListApprove(accountId: number, body?: ListActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomAction(accountId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Delete all bills for account
     *
     * @param accountId The account to delete all bills from
     */
    accountBillListDeleteBills(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillDeleteActionResult>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExport(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExport(accountId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Hold/release account bills for export
     *
     * @param accountId The account to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    accountBillListExportHold(accountId: number, body?: ListActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexport(accountId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoid(accountId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillList(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountList(accountId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Approve/unapprove bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing approve flag
     */
    approveBillList(listId: number, body?: ListActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomAction(listId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordList(collectionId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExport(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Create a new list as a copy of an existing list
     *
     * @param listId The list identifier of the existing list
     * @param body The list create properties
     */
    createAndCopyList(listId: number, body?: ListCopy, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListCreateResponse>;
    /**
     * Create a new list with default list settings
     *
     * @param body The list create properties
     */
    createDefaultList(body?: ListCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListCreateResponse>;
    /**
     * Delete all bills in a bill list
     *
     * @param listId The list identifier
     */
    deleteBillsInBillList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillDeleteActionResult>;
    /**
     * Delete a list.  For a list to be deleted you must have created the list or have Manage permission and the list is shared with anyone.
     *
     * @param listId The id of the list to delete
     */
    deleteList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInList(listId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Edit a list
     *
     * @param listId The list identifier of the existing list
     * @param body The list edit properties
     */
    editList(listId: number, body?: ListEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListCreateResponse>;
    /**
     * Edit the column definition for the list.  For list columns to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body
     */
    editListColumns(listId: number, body?: Array<ListColumnEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ListResponseListField>>;
    /**
     * Set list filters  If a filter exists in the database, but is not passed in it will be deleted.  For list filters to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body List of filters being set
     */
    editListFilters(listId: number, body?: Array<FilterEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Update the shared users and user groups for a list.  To remove sharing completely set SharedWithEveryone to false, SharedUserIds to [], and SharedUserGroupIds to [].  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     * @param body Users and user groups to share the list with
     */
    editListShare(listId: number, body?: ShareRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ShareResponse>;
    /**
     * Update the visibility of a list for the current user.  You must have created the list or have access to it.
     *
     * @param listId The shared list identifier
     * @param body Set shared list visibility
     */
    editListShareVisibility(listId: number, body?: ToggleVisible, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListCreateResponse>;
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordList(emissionSourceId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExport(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillList(listId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Hold/release bill list for export
     *
     * @param listId The list identifier
     * @param body Boolean representing exportHold flag
     */
    exportHoldBillList(listId: number, body?: ListActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Create and/or update flags for all bills in a list
     *
     * @param listId Bill list containing a list of bills that will have flags created or updated
     * @param body DTO containing the new state of the flags on each bill in the list
     */
    flagBillListAction(listId: number, body?: FlagEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update flag issuess for all issues in a list
     *
     * @param listId Flag Issue list containing a list of flag issues to be updated
     * @param body DTO containing the new state of the flag Issue on each flag issue in the list
     */
    flagIssueBillListAction(listId: number, body?: FlagIssueEditAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Get the definition and data for a list type
     *
     * @param listTypeId The list type for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body DTO containing the list of initial filters to apply and a flag indicating whether to reset the current columns.  Only one list of the specified list type exists, so columns and filters are shared for every dynamic list of the list type.  Filters provided will be saved to the database.
     */
    getDynamicListWithData(listTypeId: number, pageSize?: number, pageNumber?: number, body?: DynamicListRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Get the filters for a list
     *
     * @param listId The list for which the filters are to be retrieved
     */
    getListFilters(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Get the shared users and user groups for a list.  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     */
    getListShare(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ShareResponse>;
    /**
     * Get the definition and data for a list.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listId The list for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getListWithData(listId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Get lists.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listTypeId Type of list
     */
    getLists(listTypeId?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ListCreateResponse>>;
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountList(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MoveBillsDestination>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MoveBillsDestination>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param listId The list identifier
     */
    listExport(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillList(meterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Approve/unapprove meter bills
     *
     * @param meterId The meter to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    meterBillListApprove(meterId: number, body?: ListActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomAction(meterId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Delete all bills for meter
     *
     * @param meterId The meter to delete all bills from
     */
    meterBillListDeleteBills(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillDeleteActionResult>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExport(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExport(meterId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Hold/release meter bills for export
     *
     * @param meterId The meter to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    meterBillListExportHold(meterId: number, body?: ListActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexport(meterId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoid(meterId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillList(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountList(accountId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromList(listId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Reset a list to its default columns and filters.  For a list to be reset you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     */
    resetList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillList(accountId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillList(listId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillList(meterId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param accountId The account whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setAccountBillListAccrualExclusion(accountId: number, body?: ListActionAccrualExclusion, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param listId The list whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the provided list should be excluded from accruals or should have exclusion undone
     */
    setBillListAccrualExclusion(listId: number, body?: ListActionAccrualExclusion, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param meterId The meter whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setMeterBillListAccrualExclusion(meterId: number, body?: ListActionAccrualExclusion, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillList(listId: number, body?: ChargebackProcessorSettingsForSplits, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillList(listId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeaders(accountId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeaders(listId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeaders(meterId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillList(listId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Approve/unapprove account bills
     *
     * @param accountId The account to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    accountBillListApproveWithHttpInfo(accountId: number, body?: ListActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomActionWithHttpInfo(accountId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Delete all bills for account
     *
     * @param accountId The account to delete all bills from
     */
    accountBillListDeleteBillsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillDeleteActionResult>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExportWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExportWithHttpInfo(accountId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Hold/release account bills for export
     *
     * @param accountId The account to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    accountBillListExportHoldWithHttpInfo(accountId: number, body?: ListActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexportWithHttpInfo(accountId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoidWithHttpInfo(accountId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillListWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountListWithHttpInfo(accountId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Approve/unapprove bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing approve flag
     */
    approveBillListWithHttpInfo(listId: number, body?: ListActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomActionWithHttpInfo(listId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordListWithHttpInfo(collectionId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExportWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Create a new list as a copy of an existing list
     *
     * @param listId The list identifier of the existing list
     * @param body The list create properties
     */
    createAndCopyListWithHttpInfo(listId: number, body?: ListCopy, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListCreateResponse>>;
    /**
     * Create a new list with default list settings
     *
     * @param body The list create properties
     */
    createDefaultListWithHttpInfo(body?: ListCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListCreateResponse>>;
    /**
     * Delete all bills in a bill list
     *
     * @param listId The list identifier
     */
    deleteBillsInBillListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillDeleteActionResult>>;
    /**
     * Delete a list.  For a list to be deleted you must have created the list or have Manage permission and the list is shared with anyone.
     *
     * @param listId The id of the list to delete
     */
    deleteListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInListWithHttpInfo(listId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Edit a list
     *
     * @param listId The list identifier of the existing list
     * @param body The list edit properties
     */
    editListWithHttpInfo(listId: number, body?: ListEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListCreateResponse>>;
    /**
     * Edit the column definition for the list.  For list columns to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body
     */
    editListColumnsWithHttpInfo(listId: number, body?: Array<ListColumnEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ListResponseListField>>>;
    /**
     * Set list filters  If a filter exists in the database, but is not passed in it will be deleted.  For list filters to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body List of filters being set
     */
    editListFiltersWithHttpInfo(listId: number, body?: Array<FilterEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Update the shared users and user groups for a list.  To remove sharing completely set SharedWithEveryone to false, SharedUserIds to [], and SharedUserGroupIds to [].  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     * @param body Users and user groups to share the list with
     */
    editListShareWithHttpInfo(listId: number, body?: ShareRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ShareResponse>>;
    /**
     * Update the visibility of a list for the current user.  You must have created the list or have access to it.
     *
     * @param listId The shared list identifier
     * @param body Set shared list visibility
     */
    editListShareVisibilityWithHttpInfo(listId: number, body?: ToggleVisible, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListCreateResponse>>;
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordListWithHttpInfo(emissionSourceId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExportWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillListWithHttpInfo(listId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Hold/release bill list for export
     *
     * @param listId The list identifier
     * @param body Boolean representing exportHold flag
     */
    exportHoldBillListWithHttpInfo(listId: number, body?: ListActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Create and/or update flags for all bills in a list
     *
     * @param listId Bill list containing a list of bills that will have flags created or updated
     * @param body DTO containing the new state of the flags on each bill in the list
     */
    flagBillListActionWithHttpInfo(listId: number, body?: FlagEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update flag issuess for all issues in a list
     *
     * @param listId Flag Issue list containing a list of flag issues to be updated
     * @param body DTO containing the new state of the flag Issue on each flag issue in the list
     */
    flagIssueBillListActionWithHttpInfo(listId: number, body?: FlagIssueEditAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Get the definition and data for a list type
     *
     * @param listTypeId The list type for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body DTO containing the list of initial filters to apply and a flag indicating whether to reset the current columns.  Only one list of the specified list type exists, so columns and filters are shared for every dynamic list of the list type.  Filters provided will be saved to the database.
     */
    getDynamicListWithDataWithHttpInfo(listTypeId: number, pageSize?: number, pageNumber?: number, body?: DynamicListRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Get the filters for a list
     *
     * @param listId The list for which the filters are to be retrieved
     */
    getListFiltersWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Get the shared users and user groups for a list.  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     */
    getListShareWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ShareResponse>>;
    /**
     * Get the definition and data for a list.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listId The list for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getListWithDataWithHttpInfo(listId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Get lists.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listTypeId Type of list
     */
    getListsWithHttpInfo(listTypeId?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ListCreateResponse>>>;
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountListWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MoveBillsDestination>>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MoveBillsDestination>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param listId The list identifier
     */
    listExportWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillListWithHttpInfo(meterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Approve/unapprove meter bills
     *
     * @param meterId The meter to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    meterBillListApproveWithHttpInfo(meterId: number, body?: ListActionApprove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomActionWithHttpInfo(meterId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Delete all bills for meter
     *
     * @param meterId The meter to delete all bills from
     */
    meterBillListDeleteBillsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillDeleteActionResult>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExportWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExportWithHttpInfo(meterId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Hold/release meter bills for export
     *
     * @param meterId The meter to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    meterBillListExportHoldWithHttpInfo(meterId: number, body?: ListActionExportHold, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexportWithHttpInfo(meterId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoidWithHttpInfo(meterId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillListWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountListWithHttpInfo(accountId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromListWithHttpInfo(listId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Reset a list to its default columns and filters.  For a list to be reset you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     */
    resetListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillListWithHttpInfo(accountId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillListWithHttpInfo(listId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillListWithHttpInfo(meterId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param accountId The account whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setAccountBillListAccrualExclusionWithHttpInfo(accountId: number, body?: ListActionAccrualExclusion, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param listId The list whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the provided list should be excluded from accruals or should have exclusion undone
     */
    setBillListAccrualExclusionWithHttpInfo(listId: number, body?: ListActionAccrualExclusion, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param meterId The meter whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setMeterBillListAccrualExclusionWithHttpInfo(meterId: number, body?: ListActionAccrualExclusion, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillListWithHttpInfo(listId: number, body?: ChargebackProcessorSettingsForSplits, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillListWithHttpInfo(listId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeadersWithHttpInfo(accountId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeadersWithHttpInfo(listId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeadersWithHttpInfo(meterId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillListWithHttpInfo(listId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ListService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ListService>;
}
