import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EmissionSourceLinkRequest } from '../model/emissionSourceLinkRequest';
import { GHGFactorsResponse } from '../model/gHGFactorsResponse';
import { MeterBillResponse } from '../model/meterBillResponse';
import { MeterCalendarizedUseVsWeatherResponse } from '../model/meterCalendarizedUseVsWeatherResponse';
import { MeterCreate } from '../model/meterCreate';
import { MeterEdit } from '../model/meterEdit';
import { MeterGroupMember } from '../model/meterGroupMember';
import { MeterGroupResponse } from '../model/meterGroupResponse';
import { MeterRateResponse } from '../model/meterRateResponse';
import { MeterResponse } from '../model/meterResponse';
import { MeterSerialNumberHistoryRequest } from '../model/meterSerialNumberHistoryRequest';
import { MeterSerialNumberHistoryResponse } from '../model/meterSerialNumberHistoryResponse';
import { MeterTemplateResponse } from '../model/meterTemplateResponse';
import { MeterUDFResponse } from '../model/meterUDFResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WatticsDataPoint } from '../model/watticsDataPoint';
import { WatticsDataPointRequest } from '../model/watticsDataPointRequest';
import { WebhookCustomAction } from '../model/webhookCustomAction';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class MeterService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeter(body?: MeterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterResponse>;
    /**
     * Deletes a meter
     *
     * @param meterId The identifier for the meter being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteMeter(meterId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFile(meterId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLink(meterId: number, body?: EmissionSourceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceLinkRequest>;
    /**
     * Edits a meter&#39;s group memberships.   Note that all groups a meter should belong to must be passed in. Passing in one group means that the meter will belong to one group only,   even if it previously belonged to several.  Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param meterId The meter identifier whose group memberships are being edited
     * @param body The groups the meter will belong to
     */
    editMeterGroupMembership(meterId: number, body?: Array<MeterGroupMember>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterGroupResponse>>;
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersion(meterId: number, body?: MeterSerialNumberHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterSerialNumberHistoryResponse>;
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFs(meterId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnits(meterId: number, body?: MeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterResponse>;
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLink(meterId: number, body?: WatticsDataPointRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WatticsDataPoint>;
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherData(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterCalendarizedUseVsWeatherResponse>>;
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactors(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGFactorsResponse>>;
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeter(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterResponse>;
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBills(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterBillResponse>>;
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroups(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterGroupResponse>>;
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRates(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterRateResponse>>;
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplates(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterTemplateResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfs(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeters(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterUDFResponse>>;
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMeters(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterResponse>>;
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeter(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomAction(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeterWithHttpInfo(body?: MeterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterResponse>>;
    /**
     * Deletes a meter
     *
     * @param meterId The identifier for the meter being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteMeterWithHttpInfo(meterId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFileWithHttpInfo(meterId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLinkWithHttpInfo(meterId: number, body?: EmissionSourceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceLinkRequest>>;
    /**
     * Edits a meter&#39;s group memberships.   Note that all groups a meter should belong to must be passed in. Passing in one group means that the meter will belong to one group only,   even if it previously belonged to several.  Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param meterId The meter identifier whose group memberships are being edited
     * @param body The groups the meter will belong to
     */
    editMeterGroupMembershipWithHttpInfo(meterId: number, body?: Array<MeterGroupMember>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterGroupResponse>>>;
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersionWithHttpInfo(meterId: number, body?: MeterSerialNumberHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterSerialNumberHistoryResponse>>;
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFsWithHttpInfo(meterId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnitsWithHttpInfo(meterId: number, body?: MeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterResponse>>;
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLinkWithHttpInfo(meterId: number, body?: WatticsDataPointRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WatticsDataPoint>>;
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherDataWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterCalendarizedUseVsWeatherResponse>>>;
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactorsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGFactorsResponse>>>;
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeterWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterResponse>>;
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBillsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterBillResponse>>>;
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroupsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterGroupResponse>>>;
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRatesWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterRateResponse>>>;
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplatesWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterTemplateResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterUDFResponse>>>;
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMetersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterResponse>>>;
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeterWithHttpInfo(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomActionWithHttpInfo(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MeterService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MeterService>;
}
