import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { MeterDigestActualAndCalendarizedMonthlyResponse } from '../model/meterDigestActualAndCalendarizedMonthlyResponse';
import { MeterDigestActualAndCalendarizedYearlyResponse } from '../model/meterDigestActualAndCalendarizedYearlyResponse';
import { MeterDigestCalendarizedTrendResponse } from '../model/meterDigestCalendarizedTrendResponse';
import { MeterDigestNormalizedMonthlyResponse } from '../model/meterDigestNormalizedMonthlyResponse';
import { MeterDigestNormalizedYearlyResponse } from '../model/meterDigestNormalizedYearlyResponse';
import { MeterDigestSavingsMonthlyResponse } from '../model/meterDigestSavingsMonthlyResponse';
import { MeterDigestSavingsYearlyResponse } from '../model/meterDigestSavingsYearlyResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class MeterDigestService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrend(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestCalendarizedTrendResponse>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestNormalizedMonthlyResponse>;
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestNormalizedMonthlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestNormalizedYearlyResponse>;
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestSavingsMonthlyResponse>;
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestSavingsMonthlyResponse>>;
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestSavingsYearlyResponse>;
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestSavingsYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrendWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestCalendarizedTrendResponse>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestNormalizedMonthlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestNormalizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestNormalizedYearlyResponse>>>;
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestSavingsMonthlyResponse>>;
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestSavingsMonthlyResponse>>>;
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestSavingsYearlyResponse>>;
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestSavingsYearlyResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MeterDigestService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MeterDigestService>;
}
