import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FilterResponse } from '../model/filterResponse';
import { GroupMemberRequest } from '../model/groupMemberRequest';
import { GroupMeterGroupResponse } from '../model/groupMeterGroupResponse';
import { MeterCategoryRequest } from '../model/meterCategoryRequest';
import { MeterCategoryResponse } from '../model/meterCategoryResponse';
import { MeterGroupMemberChild } from '../model/meterGroupMemberChild';
import { MeterGroupRequest } from '../model/meterGroupRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class MeterGroupService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a meter group category
     *
     * @param body Data representing the meter group category being created
     */
    createMeterCategory(body?: MeterCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterCategoryResponse>;
    /**
     * Create a meter group
     *
     * @param body Data representing the meter group being created
     */
    createMeterGroup(body?: MeterGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupMeterGroupResponse>;
    /**
     * Delete a meter group category
     *
     * @param categoryId Id of the category to delete
     */
    deleteMeterCategory(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a user-created meter group
     *
     * @param meterGroupId
     */
    deleteMeterGroup(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Update a meter group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the meter group category
     */
    editMeterCategory(categoryId: number, body?: MeterCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterCategoryResponse>;
    /**
     * Edit a meter group
     *
     * @param meterGroupId Id of the group to edit
     * @param body Data representing the meter group being edited
     */
    editMeterGroup(meterGroupId: number, body?: MeterGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupMeterGroupResponse>;
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroups(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GroupMeterGroupResponse>>;
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterCategoryResponse>>;
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategory(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterCategoryResponse>;
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroup(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupMeterGroupResponse>;
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembers(groupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterGroupMemberChild>>;
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFilters(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Include all group members in charts
     *
     * @param meterGroupId
     */
    includeAllMeterGroupMemberInCharts(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserMeterAutoGroupsMembership(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param meterGroupId The meter group to refresh
     */
    recalculateUserMeterAutoGroupMemebership(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupMeterGroupResponse>;
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param meterGroupId
     * @param meterId
     * @param body
     */
    updateMeterGroupMember(meterGroupId: number, meterId: number, body?: GroupMemberRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterGroupMemberChild>;
    /**
     * Create a meter group category
     *
     * @param body Data representing the meter group category being created
     */
    createMeterCategoryWithHttpInfo(body?: MeterCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterCategoryResponse>>;
    /**
     * Create a meter group
     *
     * @param body Data representing the meter group being created
     */
    createMeterGroupWithHttpInfo(body?: MeterGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupMeterGroupResponse>>;
    /**
     * Delete a meter group category
     *
     * @param categoryId Id of the category to delete
     */
    deleteMeterCategoryWithHttpInfo(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a user-created meter group
     *
     * @param meterGroupId
     */
    deleteMeterGroupWithHttpInfo(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Update a meter group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the meter group category
     */
    editMeterCategoryWithHttpInfo(categoryId: number, body?: MeterCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterCategoryResponse>>;
    /**
     * Edit a meter group
     *
     * @param meterGroupId Id of the group to edit
     * @param body Data representing the meter group being edited
     */
    editMeterGroupWithHttpInfo(meterGroupId: number, body?: MeterGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupMeterGroupResponse>>;
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroupsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GroupMeterGroupResponse>>>;
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterCategoryResponse>>>;
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategoryWithHttpInfo(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterCategoryResponse>>;
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroupWithHttpInfo(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupMeterGroupResponse>>;
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembersWithHttpInfo(groupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterGroupMemberChild>>>;
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFiltersWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Include all group members in charts
     *
     * @param meterGroupId
     */
    includeAllMeterGroupMemberInChartsWithHttpInfo(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserMeterAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param meterGroupId The meter group to refresh
     */
    recalculateUserMeterAutoGroupMemebershipWithHttpInfo(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupMeterGroupResponse>>;
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param meterGroupId
     * @param meterId
     * @param body
     */
    updateMeterGroupMemberWithHttpInfo(meterGroupId: number, meterId: number, body?: GroupMemberRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterGroupMemberChild>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MeterGroupService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MeterGroupService>;
}
