import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { MeterGroupDigestRankingResponse } from '../model/meterGroupDigestRankingResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class MeterGroupDigestService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRanking(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterGroupDigestRankingResponse>;
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRankingWithHttpInfo(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterGroupDigestRankingResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MeterGroupDigestService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MeterGroupDigestService>;
}
