import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { NotificationBadgeResponse } from '../model/notificationBadgeResponse';
import { NotificationDetailsResponse } from '../model/notificationDetailsResponse';
import { NotificationResponse } from '../model/notificationResponse';
import { NotificationSettingRequest } from '../model/notificationSettingRequest';
import { NotificationSettingsResponse } from '../model/notificationSettingsResponse';
import { NotificationSystemSettingsRequest } from '../model/notificationSystemSettingsRequest';
import { NotificationType } from '../model/notificationType';
import { NotificationUpdateRequest } from '../model/notificationUpdateRequest';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class NotificationService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get a specific notification for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotification(notificationId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationResponse>;
    /**
     * Get total number of notifications that are unread and unarchived for the current user.  Use lastCheckDateTimeUtc to get the number of new notifications since the passed in date and time.  By default, only the latest 250 notifications will be taken into account. Use the &#39;noLimit&#39; query parameter to override this behavior.
     *
     * @param lastCheckDateTimeUtc Used when calculating the number of new notifications. Must be a UTC DateTime in the format yyyy-MM-ddTHH:mm:ssZ. If not passed the TotalNotifications and NewNotifications will be equal.
     * @param noLimit If true, will return the badge totals for all of the user&#39;s notifications, not just the 250 most recent ones
     */
    getNotificationBadgeTotals(lastCheckDateTimeUtc?: Date, noLimit?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationBadgeResponse>;
    /**
     * Get a specific notification&#39;s details for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotificationDetails(notificationId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationDetailsResponse>;
    /**
     * The default notification settings assigned to new users
     *
     */
    getNotificationSystemSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationSettingsResponse>;
    /**
     * Get a list of notification types
     *
     */
    getNotificationTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<NotificationType>>;
    /**
     * The notification settings for the current user
     *
     */
    getNotificationUserSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationSettingsResponse>;
    /**
     * Get all notifications for the current user
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getNotifications(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<NotificationResponse>>;
    /**
     * Update a list of notifications based on the notification ids and action passed in  Only notifications for the current user can be updated
     *
     * @param body List of notification ids and action to perform
     */
    updateListOfNotifications(body?: NotificationUpdateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettings(body?: NotificationSystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationSettingsResponse>;
    /**
     * Update the notification settings for the current user
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationUserSettings(body?: Array<NotificationSettingRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationSettingsResponse>;
    /**
     * Get a specific notification for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotificationWithHttpInfo(notificationId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationResponse>>;
    /**
     * Get total number of notifications that are unread and unarchived for the current user.  Use lastCheckDateTimeUtc to get the number of new notifications since the passed in date and time.  By default, only the latest 250 notifications will be taken into account. Use the &#39;noLimit&#39; query parameter to override this behavior.
     *
     * @param lastCheckDateTimeUtc Used when calculating the number of new notifications. Must be a UTC DateTime in the format yyyy-MM-ddTHH:mm:ssZ. If not passed the TotalNotifications and NewNotifications will be equal.
     * @param noLimit If true, will return the badge totals for all of the user&#39;s notifications, not just the 250 most recent ones
     */
    getNotificationBadgeTotalsWithHttpInfo(lastCheckDateTimeUtc?: Date, noLimit?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationBadgeResponse>>;
    /**
     * Get a specific notification&#39;s details for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotificationDetailsWithHttpInfo(notificationId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationDetailsResponse>>;
    /**
     * The default notification settings assigned to new users
     *
     */
    getNotificationSystemSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationSettingsResponse>>;
    /**
     * Get a list of notification types
     *
     */
    getNotificationTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<NotificationType>>>;
    /**
     * The notification settings for the current user
     *
     */
    getNotificationUserSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationSettingsResponse>>;
    /**
     * Get all notifications for the current user
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getNotificationsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<NotificationResponse>>>;
    /**
     * Update a list of notifications based on the notification ids and action passed in  Only notifications for the current user can be updated
     *
     * @param body List of notification ids and action to perform
     */
    updateListOfNotificationsWithHttpInfo(body?: NotificationUpdateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettingsWithHttpInfo(body?: NotificationSystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationSettingsResponse>>;
    /**
     * Update the notification settings for the current user
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationUserSettingsWithHttpInfo(body?: Array<NotificationSettingRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationSettingsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NotificationService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NotificationService>;
}
