import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeleteReadingResponse } from '../model/deleteReadingResponse';
import { Reading } from '../model/reading';
import { ReadingCreate } from '../model/readingCreate';
import { ReadingDelete } from '../model/readingDelete';
import { ReadingResponse } from '../model/readingResponse';
import { Readings } from '../model/readings';
import { ReadingsObservation } from '../model/readingsObservation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ObservationService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadings(body?: Array<ReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingResponse>;
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadings(body?: Array<ReadingDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DeleteReadingResponse>;
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReading(readingId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReading(readingId: number, body?: Reading, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingsObservation>;
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadings(channelId: number, beginDate?: Date, endDate?: Date, originalValue?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Readings>;
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadingsWithHttpInfo(body?: Array<ReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingResponse>>;
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadingsWithHttpInfo(body?: Array<ReadingDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DeleteReadingResponse>>;
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReadingWithHttpInfo(readingId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReadingWithHttpInfo(readingId: number, body?: Reading, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingsObservation>>;
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadingsWithHttpInfo(channelId: number, beginDate?: Date, endDate?: Date, originalValue?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Readings>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ObservationService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ObservationService>;
}
