import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EnergyProjectResponse } from '../model/energyProjectResponse';
import { EnergyStarPlaceHierarchyResponse } from '../model/energyStarPlaceHierarchyResponse';
import { EnergyStarPlaceLinkRequest } from '../model/energyStarPlaceLinkRequest';
import { EnergyStarPlaceLinkResponse } from '../model/energyStarPlaceLinkResponse';
import { EnergyStarPmProperty } from '../model/energyStarPmProperty';
import { PlaceCreate } from '../model/placeCreate';
import { PlaceEdit } from '../model/placeEdit';
import { PlaceGroupMember } from '../model/placeGroupMember';
import { PlaceGroupResponse } from '../model/placeGroupResponse';
import { PlaceResponse } from '../model/placeResponse';
import { PlaceSizeChild } from '../model/placeSizeChild';
import { PlaceSizeCreate } from '../model/placeSizeCreate';
import { PlaceSubmissionTypeRequest } from '../model/placeSubmissionTypeRequest';
import { PlaceTypeRequest } from '../model/placeTypeRequest';
import { PlaceTypeResponse } from '../model/placeTypeResponse';
import { PlaceUDFResponse } from '../model/placeUDFResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WatticsSite } from '../model/watticsSite';
import { WatticsSiteRequest } from '../model/watticsSiteRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class PlaceService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a place
     *
     * @param body Data representing the place being created
     */
    createPlace(body?: PlaceCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceResponse>;
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSize(placeId: number, body?: PlaceSizeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceSizeChild>;
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceType(body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceTypeResponse>;
    /**
     * Deletes a place
     *
     * @param placeId The identifier for the place being deleted
     */
    deletePlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSize(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceType(placeTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFile(placeId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLink(placeId: number, body?: EnergyStarPlaceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceLinkResponse>;
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlace(placeId: number, body?: PlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceResponse>;
    /**
     * Edits a place&#39;s group memberships.   Note that all groups a place should belong to must be passed in. Passing in one group means that the place will belong to one group only,   even if it previously belonged to several.   Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param placeId The place identifier whose group memberships are being edited
     * @param body The groups the place will belong to
     */
    editPlaceGroupMembership(placeId: number, body?: Array<PlaceGroupMember>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceGroupResponse>>;
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeList(placeId: number, body?: Array<PlaceSizeCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceType(placeTypeId: number, body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceTypeResponse>;
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFs(placeId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLink(placeId: number, body?: WatticsSiteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WatticsSite>;
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyProjectResponse>>;
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlace(placeId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPmProperty>;
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchy(placeId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPlaceHierarchyResponse>>;
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLink(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceLinkResponse>;
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetrics(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceHierarchyResponse>;
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceResponse>;
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroups(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceGroupResponse>>;
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSize(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceSizeChild>;
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizes(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Retrieves one place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    getPlaceType(placeTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceTypeResponse>;
    /**
     * Retrieves all place types
     *
     * @param filter
     */
    getPlaceTypes(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceTypeResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfs(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaces(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceUDFResponse>>;
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlace(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStar(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionType(body?: PlaceSubmissionTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Creates a place
     *
     * @param body Data representing the place being created
     */
    createPlaceWithHttpInfo(body?: PlaceCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceResponse>>;
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSizeWithHttpInfo(placeId: number, body?: PlaceSizeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceSizeChild>>;
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceTypeWithHttpInfo(body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceTypeResponse>>;
    /**
     * Deletes a place
     *
     * @param placeId The identifier for the place being deleted
     */
    deletePlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSizeWithHttpInfo(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceTypeWithHttpInfo(placeTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFileWithHttpInfo(placeId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLinkWithHttpInfo(placeId: number, body?: EnergyStarPlaceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceLinkResponse>>;
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlaceWithHttpInfo(placeId: number, body?: PlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceResponse>>;
    /**
     * Edits a place&#39;s group memberships.   Note that all groups a place should belong to must be passed in. Passing in one group means that the place will belong to one group only,   even if it previously belonged to several.   Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param placeId The place identifier whose group memberships are being edited
     * @param body The groups the place will belong to
     */
    editPlaceGroupMembershipWithHttpInfo(placeId: number, body?: Array<PlaceGroupMember>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceGroupResponse>>>;
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeListWithHttpInfo(placeId: number, body?: Array<PlaceSizeCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceTypeWithHttpInfo(placeTypeId: number, body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceTypeResponse>>;
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFsWithHttpInfo(placeId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLinkWithHttpInfo(placeId: number, body?: WatticsSiteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WatticsSite>>;
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyProjectResponse>>>;
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlaceWithHttpInfo(placeId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPmProperty>>;
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchyWithHttpInfo(placeId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPlaceHierarchyResponse>>>;
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLinkWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceLinkResponse>>;
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetricsWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceHierarchyResponse>>;
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceResponse>>;
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroupsWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceGroupResponse>>>;
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSizeWithHttpInfo(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceSizeChild>>;
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Retrieves one place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    getPlaceTypeWithHttpInfo(placeTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceTypeResponse>>;
    /**
     * Retrieves all place types
     *
     * @param filter
     */
    getPlaceTypesWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceTypeResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfsWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceUDFResponse>>>;
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlaceWithHttpInfo(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStarWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionTypeWithHttpInfo(body?: PlaceSubmissionTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlaceService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlaceService>;
}
