import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BenchmarkCategoryResponse } from '../model/benchmarkCategoryResponse';
import { BenchmarkSettingsEdit } from '../model/benchmarkSettingsEdit';
import { BenchmarkSettingsResponse } from '../model/benchmarkSettingsResponse';
import { BenchmarkValueRequest } from '../model/benchmarkValueRequest';
import { BenchmarkValuesResponse } from '../model/benchmarkValuesResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class PlaceBenchmarkService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValue(benchmarkIndicator: number, placeId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValue(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSetting(benchmarkIndicator: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettings(body?: BenchmarkSettingsEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkSettingsResponse>;
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValues(benchmarkIndicator: number, placeId: number, body?: Array<BenchmarkValueRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValues(benchmarkIndicator: number, placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Get all place benchmark categories in the database
     *
     */
    getPlaceBenchmarkCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BenchmarkCategoryResponse>>;
    /**
     * Get all the place benchmark names and categories for the owner
     *
     */
    getPlaceBenchmarkSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkSettingsResponse>;
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValue(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValueWithHttpInfo(benchmarkIndicator: number, placeId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValueWithHttpInfo(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSettingWithHttpInfo(benchmarkIndicator: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettingsWithHttpInfo(body?: BenchmarkSettingsEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkSettingsResponse>>;
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValuesWithHttpInfo(benchmarkIndicator: number, placeId: number, body?: Array<BenchmarkValueRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValuesWithHttpInfo(benchmarkIndicator: number, placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    /**
     * Get all place benchmark categories in the database
     *
     */
    getPlaceBenchmarkCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BenchmarkCategoryResponse>>>;
    /**
     * Get all the place benchmark names and categories for the owner
     *
     */
    getPlaceBenchmarkSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkSettingsResponse>>;
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValueWithHttpInfo(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlaceBenchmarkService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlaceBenchmarkService>;
}
