import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { PlaceDigestActualAndCalendarizedMonthlyResponse } from '../model/placeDigestActualAndCalendarizedMonthlyResponse';
import { PlaceDigestActualAndCalendarizedYearlyResponse } from '../model/placeDigestActualAndCalendarizedYearlyResponse';
import { PlaceDigestComparisonResponse } from '../model/placeDigestComparisonResponse';
import { PlaceDigestEnergyUseIntensity } from '../model/placeDigestEnergyUseIntensity';
import { PlaceDigestNormalizedMonthlyResponse } from '../model/placeDigestNormalizedMonthlyResponse';
import { PlaceDigestNormalizedYearlyResponse } from '../model/placeDigestNormalizedYearlyResponse';
import { PlaceDigestSavingsMonthlyResponse } from '../model/placeDigestSavingsMonthlyResponse';
import { PlaceDigestSavingsYearlyResponse } from '../model/placeDigestSavingsYearlyResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class PlaceDigestService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartData(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestEnergyUseIntensity>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparison(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestComparisonResponse>;
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparison(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestComparisonResponse>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestNormalizedMonthlyResponse>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestNormalizedMonthlyResponse>>;
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparison(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestComparisonResponse>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestNormalizedYearlyResponse>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestSavingsMonthlyResponse>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestSavingsMonthlyResponse>>;
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestSavingsYearlyResponse>;
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestSavingsYearlyResponse>>;
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartDataWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestEnergyUseIntensity>>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparisonWithHttpInfo(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestComparisonResponse>>;
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparisonWithHttpInfo(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestComparisonResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestNormalizedMonthlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestNormalizedMonthlyResponse>>>;
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparisonWithHttpInfo(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestComparisonResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestNormalizedYearlyResponse>>>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestSavingsMonthlyResponse>>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestSavingsMonthlyResponse>>>;
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestSavingsYearlyResponse>>;
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestSavingsYearlyResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlaceDigestService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlaceDigestService>;
}
