import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FilterResponse } from '../model/filterResponse';
import { GroupMemberRequest } from '../model/groupMemberRequest';
import { GroupPlaceGroupMember } from '../model/groupPlaceGroupMember';
import { GroupPlaceGroupResponse } from '../model/groupPlaceGroupResponse';
import { PlaceCategoryRequest } from '../model/placeCategoryRequest';
import { PlaceCategoryResponse } from '../model/placeCategoryResponse';
import { PlaceGroupRequest } from '../model/placeGroupRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class PlaceGroupService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a place group category
     *
     * @param body Data representing the place group category being created
     */
    createPlaceCategory(body?: PlaceCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceCategoryResponse>;
    /**
     * Create a place group
     *
     * @param body Data representing the place group being created
     */
    createPlaceGroup(body?: PlaceGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupPlaceGroupResponse>;
    /**
     * Delete a place group category
     *
     * @param categoryId Id of the category to delete
     */
    deletePlaceCategory(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a user-created place group
     *
     * @param placeGroupId
     */
    deletePlaceGroup(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Update a place group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the place group category
     */
    editPlaceCategory(categoryId: number, body?: PlaceCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceCategoryResponse>;
    /**
     * Edit a place group
     *
     * @param placeGroupId Id of the group to edit
     * @param body Data representing the place group being edited
     */
    editPlaceGroup(placeGroupId: number, body?: PlaceGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupPlaceGroupResponse>;
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroups(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GroupPlaceGroupResponse>>;
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceCategoryResponse>>;
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategory(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceCategoryResponse>;
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroup(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupPlaceGroupResponse>;
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembers(placeGroupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GroupPlaceGroupMember>>;
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFilters(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Include all group members in charts
     *
     * @param placeGroupId
     */
    includeAllPlaceGroupMemberInCharts(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserPlaceAutoGroupsMembership(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param placeGroupId The place group to refresh
     */
    recalculateUserPlaceAutoGroupMemebership(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupPlaceGroupResponse>;
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param placeGroupId
     * @param placeId
     * @param body
     */
    updatePlaceGroupMember(placeGroupId: number, placeId: number, body?: GroupMemberRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupPlaceGroupMember>;
    /**
     * Creates a place group category
     *
     * @param body Data representing the place group category being created
     */
    createPlaceCategoryWithHttpInfo(body?: PlaceCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceCategoryResponse>>;
    /**
     * Create a place group
     *
     * @param body Data representing the place group being created
     */
    createPlaceGroupWithHttpInfo(body?: PlaceGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupPlaceGroupResponse>>;
    /**
     * Delete a place group category
     *
     * @param categoryId Id of the category to delete
     */
    deletePlaceCategoryWithHttpInfo(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a user-created place group
     *
     * @param placeGroupId
     */
    deletePlaceGroupWithHttpInfo(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Update a place group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the place group category
     */
    editPlaceCategoryWithHttpInfo(categoryId: number, body?: PlaceCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceCategoryResponse>>;
    /**
     * Edit a place group
     *
     * @param placeGroupId Id of the group to edit
     * @param body Data representing the place group being edited
     */
    editPlaceGroupWithHttpInfo(placeGroupId: number, body?: PlaceGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupPlaceGroupResponse>>;
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroupsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GroupPlaceGroupResponse>>>;
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceCategoryResponse>>>;
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategoryWithHttpInfo(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceCategoryResponse>>;
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroupWithHttpInfo(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupPlaceGroupResponse>>;
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembersWithHttpInfo(placeGroupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GroupPlaceGroupMember>>>;
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFiltersWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Include all group members in charts
     *
     * @param placeGroupId
     */
    includeAllPlaceGroupMemberInChartsWithHttpInfo(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserPlaceAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param placeGroupId The place group to refresh
     */
    recalculateUserPlaceAutoGroupMemebershipWithHttpInfo(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupPlaceGroupResponse>>;
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param placeGroupId
     * @param placeId
     * @param body
     */
    updatePlaceGroupMemberWithHttpInfo(placeGroupId: number, placeId: number, body?: GroupMemberRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupPlaceGroupMember>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlaceGroupService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlaceGroupService>;
}
