import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { PlaceGroupDigestAreaDemandRankingResponse } from '../model/placeGroupDigestAreaDemandRankingResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class PlaceGroupDigestService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRanking(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceGroupDigestAreaDemandRankingResponse>;
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRankingWithHttpInfo(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceGroupDigestAreaDemandRankingResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlaceGroupDigestService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlaceGroupDigestService>;
}
