import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { PrimaryUseCreate } from '../model/primaryUseCreate';
import { PrimaryUseResponse } from '../model/primaryUseResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class PrimaryUseService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a Primary Use
     *
     * @param body Data representing the Primary Use being created
     */
    createPrimaryUse(body?: PrimaryUseCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PrimaryUseResponse>;
    /**
     * Deletes a primary use
     *
     * @param primaryUseId The identifier for the primary use being deleted
     */
    deletePrimaryUse(primaryUseId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves all Primary Uses. The array of Primary Uses can be filtered by Primary Use type. Possible values for this filter include: \&quot;meter\&quot;, \&quot;place\&quot;. See the filter property for more details
     *
     * @param filter
     */
    getPrimaryUses(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PrimaryUseResponse>>;
    /**
     * Creates a Primary Use
     *
     * @param body Data representing the Primary Use being created
     */
    createPrimaryUseWithHttpInfo(body?: PrimaryUseCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PrimaryUseResponse>>;
    /**
     * Deletes a primary use
     *
     * @param primaryUseId The identifier for the primary use being deleted
     */
    deletePrimaryUseWithHttpInfo(primaryUseId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves all Primary Uses. The array of Primary Uses can be filtered by Primary Use type. Possible values for this filter include: \&quot;meter\&quot;, \&quot;place\&quot;. See the filter property for more details
     *
     * @param filter
     */
    getPrimaryUsesWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PrimaryUseResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PrimaryUseService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PrimaryUseService>;
}
