import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FilterResponse } from '../model/filterResponse';
import { ReportDistributionCreateRequest } from '../model/reportDistributionCreateRequest';
import { ReportDistributionDetailsResponse } from '../model/reportDistributionDetailsResponse';
import { ReportDistributionEditRequest } from '../model/reportDistributionEditRequest';
import { ReportDistributionLogDetailsResponse } from '../model/reportDistributionLogDetailsResponse';
import { ReportDistributionLogResponse } from '../model/reportDistributionLogResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ReportDistributionService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a Report Distribution
     *
     * @param body Data representing the report distribution being created
     */
    createReportDistribution(body?: ReportDistributionCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportDistributionDetailsResponse>;
    /**
     * Deletes a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to delete
     */
    deleteReportDistribution(reportDistributionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete report distribution logs older than the number of days provided only if  the number of logs per distribution is in excess of 100.  100 latest logs per distribution will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteReportDistributionLogsOlderThan(olderThanDays?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to edit
     * @param body Data representing the report distribution being edited
     */
    editReportDistribution(reportDistributionId: number, body?: ReportDistributionEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportDistributionDetailsResponse>;
    /**
     * Run a report distribution and send the report out immediately  This does not affect the current distribution schedule
     *
     * @param reportDistributionId Id of the report distribution to run
     * @param overrideUserIds List of systemuserIds to send the distribution to. If not provided the currently configured recipients will receive the report.  If this is provided it is used in place of the currently configured recipients
     */
    executeReportDistribution(reportDistributionId: number, overrideUserIds?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportDistributionLogResponse>;
    /**
     * Get a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistribution(reportDistributionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportDistributionDetailsResponse>;
    /**
     * Get a Report Distribution Filters
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionFilters(reportDistributionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Get the details for a report distribution log
     *
     * @param reportDistributionLogId Id of the report distribution log to get the details for
     */
    getReportDistributionLogDetails(reportDistributionLogId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportDistributionLogDetailsResponse>;
    /**
     * Get a list of report distribution logs
     *
     * @param includeInProgress Option to include in progress distributions.  False by default
     */
    getReportDistributionLogs(includeInProgress?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ReportDistributionLogResponse>>;
    /**
     * Get all Report Distributions
     *
     * @param filter
     */
    getReportDistributions(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ReportDistributionDetailsResponse>>;
    /**
     * Run all report distributions  Sends reports based on configured schedule  DistributedReportSettings - Manage permission required.
     *
     */
    runReportDistributions(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Create a Report Distribution
     *
     * @param body Data representing the report distribution being created
     */
    createReportDistributionWithHttpInfo(body?: ReportDistributionCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportDistributionDetailsResponse>>;
    /**
     * Deletes a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to delete
     */
    deleteReportDistributionWithHttpInfo(reportDistributionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete report distribution logs older than the number of days provided only if  the number of logs per distribution is in excess of 100.  100 latest logs per distribution will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteReportDistributionLogsOlderThanWithHttpInfo(olderThanDays?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to edit
     * @param body Data representing the report distribution being edited
     */
    editReportDistributionWithHttpInfo(reportDistributionId: number, body?: ReportDistributionEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportDistributionDetailsResponse>>;
    /**
     * Run a report distribution and send the report out immediately  This does not affect the current distribution schedule
     *
     * @param reportDistributionId Id of the report distribution to run
     * @param overrideUserIds List of systemuserIds to send the distribution to. If not provided the currently configured recipients will receive the report.  If this is provided it is used in place of the currently configured recipients
     */
    executeReportDistributionWithHttpInfo(reportDistributionId: number, overrideUserIds?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportDistributionLogResponse>>;
    /**
     * Get a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionWithHttpInfo(reportDistributionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportDistributionDetailsResponse>>;
    /**
     * Get a Report Distribution Filters
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionFiltersWithHttpInfo(reportDistributionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Get the details for a report distribution log
     *
     * @param reportDistributionLogId Id of the report distribution log to get the details for
     */
    getReportDistributionLogDetailsWithHttpInfo(reportDistributionLogId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportDistributionLogDetailsResponse>>;
    /**
     * Get a list of report distribution logs
     *
     * @param includeInProgress Option to include in progress distributions.  False by default
     */
    getReportDistributionLogsWithHttpInfo(includeInProgress?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ReportDistributionLogResponse>>>;
    /**
     * Get all Report Distributions
     *
     * @param filter
     */
    getReportDistributionsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ReportDistributionDetailsResponse>>>;
    /**
     * Run all report distributions  Sends reports based on configured schedule  DistributedReportSettings - Manage permission required.
     *
     */
    runReportDistributionsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ReportDistributionService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ReportDistributionService>;
}
