import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { RouteDetailsResponse } from '../model/routeDetailsResponse';
import { RouteMeter } from '../model/routeMeter';
import { RouteMeterChannelLatestReadingResponse } from '../model/routeMeterChannelLatestReadingResponse';
import { RouteRequest } from '../model/routeRequest';
import { RouteResponse } from '../model/routeResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class RouteService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeter(routeId: number, body?: RouteMeter, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRoute(body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Deletes a route
     *
     * @param id The identifier for the route being deleted
     */
    deleteRoute(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRoute(id: number, body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRoute(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetails(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteDetailsResponse>;
    /**
     * Retrieves all routes
     *
     */
    getRoutes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RouteResponse>>;
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReading(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RouteMeterChannelLatestReadingResponse>>;
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeter(routeId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeterWithHttpInfo(routeId: number, body?: RouteMeter, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRouteWithHttpInfo(body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Deletes a route
     *
     * @param id The identifier for the route being deleted
     */
    deleteRouteWithHttpInfo(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRouteWithHttpInfo(id: number, body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRouteWithHttpInfo(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetailsWithHttpInfo(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteDetailsResponse>>;
    /**
     * Retrieves all routes
     *
     */
    getRoutesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RouteResponse>>>;
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReadingWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RouteMeterChannelLatestReadingResponse>>>;
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeterWithHttpInfo(routeId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<RouteService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<RouteService>;
}
