import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AdjustedCostTypeResponse } from '../model/adjustedCostTypeResponse';
import { AucRangeRequest } from '../model/aucRangeRequest';
import { AucRangeResponse } from '../model/aucRangeResponse';
import { BaselineProcessorRequest } from '../model/baselineProcessorRequest';
import { BaselineProcessorResponse } from '../model/baselineProcessorResponse';
import { BulkBaselineProcessorRequest } from '../model/bulkBaselineProcessorRequest';
import { BulkMeterCostAvoidanceSettings } from '../model/bulkMeterCostAvoidanceSettings';
import { CalculateSavingsRequest } from '../model/calculateSavingsRequest';
import { CostAvoidanceTask } from '../model/costAvoidanceTask';
import { FilterEdit } from '../model/filterEdit';
import { FilterResponse } from '../model/filterResponse';
import { GenericCount } from '../model/genericCount';
import { ManualAdjustmentRequest } from '../model/manualAdjustmentRequest';
import { OtherSavingsCategory } from '../model/otherSavingsCategory';
import { OtherSavingsCategoryRequest } from '../model/otherSavingsCategoryRequest';
import { OtherSavingsRequest } from '../model/otherSavingsRequest';
import { OtherSavingsResponse } from '../model/otherSavingsResponse';
import { SavingsMeterBillDailyResponse } from '../model/savingsMeterBillDailyResponse';
import { SavingsMeterBillResponse } from '../model/savingsMeterBillResponse';
import { SpecialAdjustmentCreate } from '../model/specialAdjustmentCreate';
import { SpecialAdjustmentEdit } from '../model/specialAdjustmentEdit';
import { SpecialAdjustmentMethod } from '../model/specialAdjustmentMethod';
import { SpecialAdjustmentResponse } from '../model/specialAdjustmentResponse';
import { SpecialAdjustmentType } from '../model/specialAdjustmentType';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SavingsService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Mass update certain cost avoidance settings for meters that match the filter conditions  Baseline and Savings will be reprocessed for affected meters
     *
     * @param body Filters and new cost avoidance setting values
     */
    bulkEditMeterCostAvoidanceSettings(body?: BulkMeterCostAvoidanceSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostAvoidanceTask>;
    /**
     * Regenerate cost avoidance baseline for the meters that match the filter conditions and then reprocess their savings
     *
     * @param body Settings and filter conditions for baseline processing
     */
    bulkGenerateBaseline(body?: BulkBaselineProcessorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostAvoidanceTask>;
    /**
     * Calculate savings for the meters that match the filter conditions, using the provided settings
     *
     * @param body Settings and filter conditions for savings processing
     */
    calculateSavings(body?: CalculateSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostAvoidanceTask>;
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavings(meterId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsResponse>;
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategory(body?: OtherSavingsCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsCategory>;
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustment(meterId: number, body?: SpecialAdjustmentCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecialAdjustmentResponse>;
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavings(meterId: number, otherSavingsId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentById(meterId: number, specialAdjustmentId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for one or more commodities  Cost Avoidance Savings will be re-calculated for all bills for meters having the affected commodities
     *
     * @param body Data representing one or more average unit cost ranges to edit
     */
    editAucRanges(body?: Array<AucRangeRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AucRangeResponse>>;
    /**
     *
     *
     */
    editCostAvoidanceSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavings(meterId: number, otherSavingsId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsResponse>;
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustment(meterId: number, specialAdjustmentId: number, body?: SpecialAdjustmentEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecialAdjustmentResponse>;
    /**
     * Executes the baseline and cost avoidance processors with provided baseline and cost avoidance settings for the provided meter.   Results are not saved unless the \&quot;save\&quot; flag is set to true.  If \&quot;save\&quot; is true, MeterSavingsSettings-Manage permission is also required
     *
     * @param meterId ID of the meter for which baseline will be reprocessed
     * @param save If true, the baseline results will be saved to the database
     * @param body Provided baseline and avoidance settings
     */
    generateBaseline(meterId: number, save?: boolean, body?: BaselineProcessorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BaselineProcessorResponse>;
    /**
     * Executes the baseline processor with stored baseline settings for the provided meter
     *
     * @param meterId ID of the meter for which baseline data will be returned
     */
    generateBaselineGet(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BaselineProcessorResponse>;
    /**
     * Get a other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     */
    getAllOtherSavings(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<OtherSavingsResponse>>;
    /**
     * Get the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for each commodity
     *
     */
    getAucRanges(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AucRangeResponse>>;
    /**
     * Return available filters for Cost Avoidance processors  Filters:  - Commodity ID  - Commodity Name  - Meter Group Name  - Building Group Name  - Topmost Place Code  - Topmost Place Name
     *
     */
    getCostAvoidanceFilters(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Count the number of meters that match the filter conditions for cost avoidance bulk actions
     *
     * @param onlyMetersInCAP Whether or not to only include meters in the count which are already participating in cost avoidance
     * @param body The filters used when counting the meters
     */
    getCostAvoidanceMeterCount(onlyMetersInCAP?: boolean, body?: Array<FilterEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GenericCount>;
    /**
     *
     *
     */
    getCostAvoidanceSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Get one other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     * @param otherSavingsId The identifier for the other savings record which is being retrieved
     */
    getOneOtherSavings(meterId: number, otherSavingsId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsResponse>;
    /**
     * Get other savings categories
     *
     */
    getOtherSavingsCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<OtherSavingsCategory>>;
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeList(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AdjustedCostTypeResponse>>;
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBill(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SavingsMeterBillResponse>;
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDaily(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SavingsMeterBillDailyResponse>;
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillList(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SavingsMeterBillResponse>>;
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostAvoidanceTask>;
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasks(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostAvoidanceTask>>;
    /**
     * Get a single special adjustment by its unique ID
     *
     * @param meterId The meter for which to return the special adjustment
     * @param specialAdjustmentId Unique ID of the special adjustment to return
     */
    getSpecialAdjustment(meterId: number, specialAdjustmentId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecialAdjustmentResponse>;
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethods(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecialAdjustmentMethod>>;
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecialAdjustmentType>>;
    /**
     * Get all the special adjustments for the meter
     *
     * @param meterId The meter for which to return special adjustment
     */
    getSpecialAdjustments(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecialAdjustmentResponse>>;
    /**
     * Creates or removes manual adjustments to savings for a provided meter and bill
     *
     * @param meterId The meter for which the manual adjustment is being made
     * @param billId The bill for which the manual adjustment is being made
     * @param body
     */
    manualAdjustment(meterId: number, billId: number, body?: ManualAdjustmentRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Mass update certain cost avoidance settings for meters that match the filter conditions  Baseline and Savings will be reprocessed for affected meters
     *
     * @param body Filters and new cost avoidance setting values
     */
    bulkEditMeterCostAvoidanceSettingsWithHttpInfo(body?: BulkMeterCostAvoidanceSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostAvoidanceTask>>;
    /**
     * Regenerate cost avoidance baseline for the meters that match the filter conditions and then reprocess their savings
     *
     * @param body Settings and filter conditions for baseline processing
     */
    bulkGenerateBaselineWithHttpInfo(body?: BulkBaselineProcessorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostAvoidanceTask>>;
    /**
     * Calculate savings for the meters that match the filter conditions, using the provided settings
     *
     * @param body Settings and filter conditions for savings processing
     */
    calculateSavingsWithHttpInfo(body?: CalculateSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostAvoidanceTask>>;
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavingsWithHttpInfo(meterId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsResponse>>;
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategoryWithHttpInfo(body?: OtherSavingsCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsCategory>>;
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustmentWithHttpInfo(meterId: number, body?: SpecialAdjustmentCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecialAdjustmentResponse>>;
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavingsWithHttpInfo(meterId: number, otherSavingsId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentByIdWithHttpInfo(meterId: number, specialAdjustmentId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for one or more commodities  Cost Avoidance Savings will be re-calculated for all bills for meters having the affected commodities
     *
     * @param body Data representing one or more average unit cost ranges to edit
     */
    editAucRangesWithHttpInfo(body?: Array<AucRangeRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AucRangeResponse>>>;
    /**
     *
     *
     */
    editCostAvoidanceSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavingsWithHttpInfo(meterId: number, otherSavingsId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsResponse>>;
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustmentWithHttpInfo(meterId: number, specialAdjustmentId: number, body?: SpecialAdjustmentEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecialAdjustmentResponse>>;
    /**
     * Executes the baseline and cost avoidance processors with provided baseline and cost avoidance settings for the provided meter.   Results are not saved unless the \&quot;save\&quot; flag is set to true.  If \&quot;save\&quot; is true, MeterSavingsSettings-Manage permission is also required
     *
     * @param meterId ID of the meter for which baseline will be reprocessed
     * @param save If true, the baseline results will be saved to the database
     * @param body Provided baseline and avoidance settings
     */
    generateBaselineWithHttpInfo(meterId: number, save?: boolean, body?: BaselineProcessorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BaselineProcessorResponse>>;
    /**
     * Executes the baseline processor with stored baseline settings for the provided meter
     *
     * @param meterId ID of the meter for which baseline data will be returned
     */
    generateBaselineGetWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BaselineProcessorResponse>>;
    /**
     * Get a other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     */
    getAllOtherSavingsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<OtherSavingsResponse>>>;
    /**
     * Get the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for each commodity
     *
     */
    getAucRangesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AucRangeResponse>>>;
    /**
     * Return available filters for Cost Avoidance processors  Filters:  - Commodity ID  - Commodity Name  - Meter Group Name  - Building Group Name  - Topmost Place Code  - Topmost Place Name
     *
     */
    getCostAvoidanceFiltersWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Count the number of meters that match the filter conditions for cost avoidance bulk actions
     *
     * @param onlyMetersInCAP Whether or not to only include meters in the count which are already participating in cost avoidance
     * @param body The filters used when counting the meters
     */
    getCostAvoidanceMeterCountWithHttpInfo(onlyMetersInCAP?: boolean, body?: Array<FilterEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GenericCount>>;
    /**
     *
     *
     */
    getCostAvoidanceSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Get one other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     * @param otherSavingsId The identifier for the other savings record which is being retrieved
     */
    getOneOtherSavingsWithHttpInfo(meterId: number, otherSavingsId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsResponse>>;
    /**
     * Get other savings categories
     *
     */
    getOtherSavingsCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<OtherSavingsCategory>>>;
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeListWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AdjustedCostTypeResponse>>>;
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillWithHttpInfo(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SavingsMeterBillResponse>>;
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDailyWithHttpInfo(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SavingsMeterBillDailyResponse>>;
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillListWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SavingsMeterBillResponse>>>;
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostAvoidanceTask>>;
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasksWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostAvoidanceTask>>>;
    /**
     * Get a single special adjustment by its unique ID
     *
     * @param meterId The meter for which to return the special adjustment
     * @param specialAdjustmentId Unique ID of the special adjustment to return
     */
    getSpecialAdjustmentWithHttpInfo(meterId: number, specialAdjustmentId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecialAdjustmentResponse>>;
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethodsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecialAdjustmentMethod>>>;
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecialAdjustmentType>>>;
    /**
     * Get all the special adjustments for the meter
     *
     * @param meterId The meter for which to return special adjustment
     */
    getSpecialAdjustmentsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecialAdjustmentResponse>>>;
    /**
     * Creates or removes manual adjustments to savings for a provided meter and bill
     *
     * @param meterId The meter for which the manual adjustment is being made
     * @param billId The bill for which the manual adjustment is being made
     * @param body
     */
    manualAdjustmentWithHttpInfo(meterId: number, billId: number, body?: ManualAdjustmentRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SavingsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SavingsService>;
}
