import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ScheduleCreate } from '../model/scheduleCreate';
import { ScheduleEdit } from '../model/scheduleEdit';
import { ScheduleResponse } from '../model/scheduleResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class ScheduleService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createSchedule(body?: ScheduleCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ScheduleResponse>;
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteSchedule(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editSchedule(scheduleId: number, body?: ScheduleEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ScheduleResponse>;
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getSchedule(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ScheduleResponse>;
    /**
     * Retrieves all schedules
     *
     */
    getSchedules(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ScheduleResponse>>;
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createScheduleWithHttpInfo(body?: ScheduleCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ScheduleResponse>>;
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteScheduleWithHttpInfo(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editScheduleWithHttpInfo(scheduleId: number, body?: ScheduleEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ScheduleResponse>>;
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getScheduleWithHttpInfo(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ScheduleResponse>>;
    /**
     * Retrieves all schedules
     *
     */
    getSchedulesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ScheduleResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ScheduleService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ScheduleService>;
}
