import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { SearchResponse } from '../model/searchResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SearchService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Searches for Accounts, Meters, Cost Centers, Places, Place Groups, Emissions Sources, and Collections that match the provided query text
     * Unless searching by id, not all properties on child objects are set in the response DTO, this is for performance reasons
     * @param query The text to search
     * @param limit The maximum number of items to return per entity type. Defaults to 10, valid range of 0 to 100.               0 is treated as default for backwards compatibility reasons.
     */
    getSearchResult(query?: string, limit?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SearchResponse>;
    /**
     * Searches for Accounts, Meters, Cost Centers, Places, Place Groups, Emissions Sources, and Collections that match the provided query text
     * Unless searching by id, not all properties on child objects are set in the response DTO, this is for performance reasons
     * @param query The text to search
     * @param limit The maximum number of items to return per entity type. Defaults to 10, valid range of 0 to 100.               0 is treated as default for backwards compatibility reasons.
     */
    getSearchResultWithHttpInfo(query?: string, limit?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SearchResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SearchService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SearchService>;
}
