import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EsaSentinelPredictionResponse } from '../model/esaSentinelPredictionResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SentinelService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves all sentinel predictions for a given ESA channel within a specified local date/time range.
     *
     * @param esaChannelId The ID of the ESA channel to retrieve predictions for.
     * @param startLocalDate The start local date/time of the range for which predictions are requested.  If equal to endLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions since this date and time (exclusive).
     * @param endLocalDate The end local date/time of the range for which predictions are requested  If equal to startLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions up to (and including) this date and time.
     */
    getSentinelPredictions(esaChannelId: number, startLocalDate?: Date, endLocalDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaSentinelPredictionResponse>>;
    /**
     * Retrieves all sentinel predictions for a given ESA channel within a specified local date/time range.
     *
     * @param esaChannelId The ID of the ESA channel to retrieve predictions for.
     * @param startLocalDate The start local date/time of the range for which predictions are requested.  If equal to endLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions since this date and time (exclusive).
     * @param endLocalDate The end local date/time of the range for which predictions are requested  If equal to startLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions up to (and including) this date and time.
     */
    getSentinelPredictionsWithHttpInfo(esaChannelId: number, startLocalDate?: Date, endLocalDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaSentinelPredictionResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SentinelService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SentinelService>;
}
