import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FilterResponse } from '../model/filterResponse';
import { Setup } from '../model/setup';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SetupService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Returns an Excel file used within SetupSheets
     *
     * @param type
     * @param filter
     */
    getSetupSheet(type?: string, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Returns the applicable filters for a given type to filter down SetupSheet Templates
     *
     * @param type
     */
    getSetupSheetFilters(type?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Import a budget setup sheet
     *
     * @param budgetId The budget identifier
     * @param versionId The budget version identifier
     * @param body The budget sheet file contents
     */
    postBudgetSetupSheet(budgetId: number, versionId: number, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Setup>;
    /**
     * Processes a SetupSheet Excel file  Accepts a base64 string representation of an xlsx file  File must be Microsoft Excel 2007 or later.
     *
     * @param body
     */
    postSetupSheet(body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Setup>;
    /**
     * Returns an Excel file used within SetupSheets
     *
     * @param type
     * @param filter
     */
    getSetupSheetWithHttpInfo(type?: string, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Returns the applicable filters for a given type to filter down SetupSheet Templates
     *
     * @param type
     */
    getSetupSheetFiltersWithHttpInfo(type?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Import a budget setup sheet
     *
     * @param budgetId The budget identifier
     * @param versionId The budget version identifier
     * @param body The budget sheet file contents
     */
    postBudgetSetupSheetWithHttpInfo(budgetId: number, versionId: number, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Setup>>;
    /**
     * Processes a SetupSheet Excel file  Accepts a base64 string representation of an xlsx file  File must be Microsoft Excel 2007 or later.
     *
     * @param body
     */
    postSetupSheetWithHttpInfo(body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Setup>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SetupService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SetupService>;
}
