import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountAlertRequest } from '../model/accountAlertRequest';
import { AccountAlertResponse } from '../model/accountAlertResponse';
import { AccountCodeHistoryRequest } from '../model/accountCodeHistoryRequest';
import { AccountCodeHistoryResponse } from '../model/accountCodeHistoryResponse';
import { AccountEdit } from '../model/accountEdit';
import { AccountMeterEdit } from '../model/accountMeterEdit';
import { AccountMeterRateResponse } from '../model/accountMeterRateResponse';
import { AccountMeterRequest } from '../model/accountMeterRequest';
import { AccountMeterResponse } from '../model/accountMeterResponse';
import { AccountRateRequest } from '../model/accountRateRequest';
import { AccountResponse } from '../model/accountResponse';
import { CreateTemplateFromBill } from '../model/createTemplateFromBill';
import { FormTemplateRequest } from '../model/formTemplateRequest';
import { FormTemplateResponse } from '../model/formTemplateResponse';
import { GeneralLedgerRequest } from '../model/generalLedgerRequest';
import { GeneralLedgerResponse } from '../model/generalLedgerResponse';
import { GenericCount } from '../model/genericCount';
import { LinkSubAccountsRequest } from '../model/linkSubAccountsRequest';
import { TemplateResponse } from '../model/templateResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WebhookCustomAction } from '../model/webhookCustomAction';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlert(accountId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAlertResponse>;
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeter(body?: Array<AccountMeterRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountMeterResponse>>;
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRate(accountMeterId: number, body?: AccountRateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountMeterRateResponse>;
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBill(billId: number, accountId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateResponse>;
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplate(accountMeterId: number, body?: FormTemplateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FormTemplateResponse>;
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBill(billId: number, meterId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateResponse>;
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlert(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeter(accountMeterId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignment(accountMeterId: number, formTemplateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccount(accountId: number, body?: AccountEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountResponse>;
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersion(accountId: number, body?: AccountCodeHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountCodeHistoryResponse>;
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeter(accountMeterId: number, deleteBills?: boolean, body?: AccountMeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountMeterResponse>;
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateList(accountMeterId: number, body?: Array<AccountRateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountMeterRateResponse>>;
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFs(accountId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateList(accountMeterId: number, body?: Array<FormTemplateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FormTemplateResponse>>;
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedger(generalLedgerId: number, body?: GeneralLedgerRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GeneralLedgerResponse>;
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccounts(summaryAccountId: number, body?: LinkSubAccountsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GenericCount>;
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccount(parentCostCenterId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomAction(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccount(summaryAccountId: number, subAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccounts(summaryAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlert(accountId: number, alertId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAlertResponse>;
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplate(templateId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlertWithHttpInfo(accountId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAlertResponse>>;
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeterWithHttpInfo(body?: Array<AccountMeterRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountMeterResponse>>>;
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRateWithHttpInfo(accountMeterId: number, body?: AccountRateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountMeterRateResponse>>;
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBillWithHttpInfo(billId: number, accountId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateResponse>>;
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplateWithHttpInfo(accountMeterId: number, body?: FormTemplateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FormTemplateResponse>>;
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBillWithHttpInfo(billId: number, meterId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateResponse>>;
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlertWithHttpInfo(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeterWithHttpInfo(accountMeterId: number, deleteBills?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignmentWithHttpInfo(accountMeterId: number, formTemplateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccountWithHttpInfo(accountId: number, body?: AccountEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountResponse>>;
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersionWithHttpInfo(accountId: number, body?: AccountCodeHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountCodeHistoryResponse>>;
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeterWithHttpInfo(accountMeterId: number, deleteBills?: boolean, body?: AccountMeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountMeterResponse>>;
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateListWithHttpInfo(accountMeterId: number, body?: Array<AccountRateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountMeterRateResponse>>>;
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFsWithHttpInfo(accountId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateListWithHttpInfo(accountMeterId: number, body?: Array<FormTemplateRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FormTemplateResponse>>>;
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedgerWithHttpInfo(generalLedgerId: number, body?: GeneralLedgerRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GeneralLedgerResponse>>;
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccountsWithHttpInfo(summaryAccountId: number, body?: LinkSubAccountsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GenericCount>>;
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccountWithHttpInfo(parentCostCenterId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomActionWithHttpInfo(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccountWithHttpInfo(summaryAccountId: number, subAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccountsWithHttpInfo(summaryAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlertWithHttpInfo(accountId: number, alertId: number, body?: AccountAlertRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAlertResponse>>;
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplateWithHttpInfo(templateId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService>;
}
