import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountAlertResponse } from '../model/accountAlertResponse';
import { AccountDigestActualMonthlyResponse } from '../model/accountDigestActualMonthlyResponse';
import { AccountDigestActualYearlyResponse } from '../model/accountDigestActualYearlyResponse';
import { AccountRateResponse } from '../model/accountRateResponse';
import { AccountResponse } from '../model/accountResponse';
import { AccountTemplateResponse } from '../model/accountTemplateResponse';
import { AccountUDFResponse } from '../model/accountUDFResponse';
import { BillSplitDetailsResponse } from '../model/billSplitDetailsResponse';
import { BillSplitParentDetailsResponse } from '../model/billSplitParentDetailsResponse';
import { DistributionVersionResponse } from '../model/distributionVersionResponse';
import { GLSubcodeResponse } from '../model/gLSubcodeResponse';
import { GeneralLedgerResponse } from '../model/generalLedgerResponse';
import { SearchAccountMeterBillEntry } from '../model/searchAccountMeterBillEntry';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFile(accountId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccount(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountResponse>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthly(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountDigestActualMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearly(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountDigestActualYearlyResponse>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountDigestActualYearlyResponse>>;
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlert(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAlertResponse>;
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlerts(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountAlertResponse>>;
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetails(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillSplitParentDetailsResponse>>;
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRates(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountRateResponse>>;
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplates(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountTemplateResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfs(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccounts(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AccountUDFResponse>>;
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetails(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillSplitDetailsResponse>;
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistory(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplits(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCode(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GLSubcodeResponse>;
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValues(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<string>>;
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GLSubcodeResponse>>;
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedger(generalLedgerId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GeneralLedgerResponse>;
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgers(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GeneralLedgerResponse>>;
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccounts(query?: string, includeInactiveAccounts?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SearchAccountMeterBillEntry>>;
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFileWithHttpInfo(accountId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccountWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthlyWithHttpInfo(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountDigestActualMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearlyWithHttpInfo(accountId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountDigestActualYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountDigestActualYearlyResponse>>>;
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlertWithHttpInfo(accountId: number, alertId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAlertResponse>>;
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlertsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountAlertResponse>>>;
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetailsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillSplitParentDetailsResponse>>>;
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRatesWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountRateResponse>>>;
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplatesWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountTemplateResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AccountUDFResponse>>>;
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetailsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillSplitDetailsResponse>>;
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistoryWithHttpInfo(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplitsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCodeWithHttpInfo(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GLSubcodeResponse>>;
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValuesWithHttpInfo(subCodeIndex: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<string>>>;
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GLSubcodeResponse>>>;
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedgerWithHttpInfo(generalLedgerId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GeneralLedgerResponse>>;
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GeneralLedgerResponse>>>;
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccountsWithHttpInfo(query?: string, includeInactiveAccounts?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SearchAccountMeterBillEntry>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService>;
}
