import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ApiKeyEditRequest } from '../model/apiKeyEditRequest';
import { ApiKeyResponse } from '../model/apiKeyResponse';
import { BenchmarkSettingsEdit } from '../model/benchmarkSettingsEdit';
import { BenchmarkSettingsResponse } from '../model/benchmarkSettingsResponse';
import { CostCategoryEdit } from '../model/costCategoryEdit';
import { CostCategoryResponse } from '../model/costCategoryResponse';
import { ReportingSettingRequest } from '../model/reportingSettingRequest';
import { ReportingSettingResponse } from '../model/reportingSettingResponse';
import { RollupUnitUpdate } from '../model/rollupUnitUpdate';
import { SystemSettingsRequest } from '../model/systemSettingsRequest';
import { SystemSettingsResponse } from '../model/systemSettingsResponse';
import { TaskResponse } from '../model/taskResponse';
import { UDFCreate } from '../model/uDFCreate';
import { UDFEdit } from '../model/uDFEdit';
import { UDFResponse } from '../model/uDFResponse';
import { UDFUpdate } from '../model/uDFUpdate';
import { WebhookCreateRequest } from '../model/webhookCreateRequest';
import { WebhookEditRequest } from '../model/webhookEditRequest';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { WebhookResponse } from '../model/webhookResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDF(body?: UDFCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UDFResponse>;
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhook(body?: WebhookCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookResponse>;
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKey(apiKeyId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSetting(benchmarkIndicator: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDF(udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhook(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThan(olderThanDays?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKey(apiKeyId: number, body?: ApiKeyEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ApiKeyResponse>;
    /**
     * Edits a cost category
     *
     * @param costCategoryId The identifier of the cost category to edit
     * @param body Object containing settings to change
     */
    editCostCategory(costCategoryId: number, body?: CostCategoryEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCategoryResponse>;
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFields(udfType: string, body?: Array<UDFUpdate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFResponse>>;
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettings(body?: BenchmarkSettingsEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkSettingsResponse>;
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettings(body?: SystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SystemSettingsResponse>;
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDF(udfId: number, body?: UDFEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UDFResponse>;
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhook(webhookId: number, body?: WebhookEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookResponse>;
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppAction(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettings(body?: ReportingSettingRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReportingSettingResponse>;
    /**
     * Update common and global use units
     *
     * @param body
     */
    updateUseRollupUnits(body?: RollupUnitUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TaskResponse>;
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDFWithHttpInfo(body?: UDFCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UDFResponse>>;
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhookWithHttpInfo(body?: WebhookCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookResponse>>;
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKeyWithHttpInfo(apiKeyId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSettingWithHttpInfo(benchmarkIndicator: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDFWithHttpInfo(udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhookWithHttpInfo(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThanWithHttpInfo(olderThanDays?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKeyWithHttpInfo(apiKeyId: number, body?: ApiKeyEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ApiKeyResponse>>;
    /**
     * Edits a cost category
     *
     * @param costCategoryId The identifier of the cost category to edit
     * @param body Object containing settings to change
     */
    editCostCategoryWithHttpInfo(costCategoryId: number, body?: CostCategoryEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCategoryResponse>>;
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFieldsWithHttpInfo(udfType: string, body?: Array<UDFUpdate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFResponse>>>;
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettingsWithHttpInfo(body?: BenchmarkSettingsEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkSettingsResponse>>;
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettingsWithHttpInfo(body?: SystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SystemSettingsResponse>>;
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDFWithHttpInfo(udfId: number, body?: UDFEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UDFResponse>>;
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhookWithHttpInfo(webhookId: number, body?: WebhookEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookResponse>>;
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppActionWithHttpInfo(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettingsWithHttpInfo(body?: ReportingSettingRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReportingSettingResponse>>;
    /**
     * Update common and global use units
     *
     * @param body
     */
    updateUseRollupUnitsWithHttpInfo(body?: RollupUnitUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TaskResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService>;
}
