import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BatchCreate } from '../model/batchCreate';
import { BatchEdit } from '../model/batchEdit';
import { BatchResponse } from '../model/batchResponse';
import { BillCreate } from '../model/billCreate';
import { BillEntryResponse } from '../model/billEntryResponse';
import { BillIdResponse } from '../model/billIdResponse';
import { BillImportProfileRequest } from '../model/billImportProfileRequest';
import { BillImportProfileResponse } from '../model/billImportProfileResponse';
import { BillImportRequest } from '../model/billImportRequest';
import { BillKickoutImportRequest } from '../model/billKickoutImportRequest';
import { GuidResponse } from '../model/guidResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImport(body?: BillImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     *
     *
     * @param batchId
     */
    closeBatch(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBill(saveAsResolved?: boolean, comment?: string, body?: BillCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillIdResponse>;
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatch(batchId: number, body?: BatchEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfile(profileId: number, body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportProfileResponse>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryData(accountId: number, beginDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillEntryResponse>;
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportProfileResponse>;
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillImportProfileResponse>>;
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickouts(taskGuid: string, body?: BillKickoutImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     *
     *
     * @param body
     */
    openBatch(body?: BatchCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfile(body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportProfileResponse>;
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImportWithHttpInfo(body?: BillImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     *
     *
     * @param batchId
     */
    closeBatchWithHttpInfo(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBillWithHttpInfo(saveAsResolved?: boolean, comment?: string, body?: BillCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillIdResponse>>;
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatchWithHttpInfo(batchId: number, body?: BatchEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfileWithHttpInfo(profileId: number, body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportProfileResponse>>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryDataWithHttpInfo(accountId: number, beginDate?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillEntryResponse>>;
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportProfileResponse>>;
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillImportProfileResponse>>>;
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickoutsWithHttpInfo(taskGuid: string, body?: BillKickoutImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    /**
     *
     *
     * @param body
     */
    openBatchWithHttpInfo(body?: BatchCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfileWithHttpInfo(body?: BillImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportProfileResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService>;
}
