import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillActionCustom } from '../model/billActionCustom';
import { BillActionHeaderUpdate } from '../model/billActionHeaderUpdate';
import { BillActionVoid } from '../model/billActionVoid';
import { BillEdit } from '../model/billEdit';
import { BillHeaderUpdate } from '../model/billHeaderUpdate';
import { BillIdResponse } from '../model/billIdResponse';
import { BillPaymentDetailsFileResponse } from '../model/billPaymentDetailsFileResponse';
import { BillPaymentDetailsOptionalItem } from '../model/billPaymentDetailsOptionalItem';
import { BillPaymentDetailsOptionalResponse } from '../model/billPaymentDetailsOptionalResponse';
import { BillPaymentEventCreate } from '../model/billPaymentEventCreate';
import { BillPaymentEventResponse } from '../model/billPaymentEventResponse';
import { BillReversalRequest } from '../model/billReversalRequest';
import { DistributeAccountChargesBase } from '../model/distributeAccountChargesBase';
import { DistributeAccountChargesToBillsRequest } from '../model/distributeAccountChargesToBillsRequest';
import { ListActionCustom } from '../model/listActionCustom';
import { ListActionReverse } from '../model/listActionReverse';
import { ListActionVoid } from '../model/listActionVoid';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomAction(accountId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoid(accountId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeaders(body?: BillActionHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoid(body?: BillActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomAction(listId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetails(body?: Array<BillPaymentDetailsOptionalItem>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillPaymentDetailsOptionalResponse>;
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFile(body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillPaymentDetailsFileResponse>;
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABill(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBills(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEvent(body?: BillPaymentEventCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillPaymentEventResponse>;
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMeters(body?: DistributeAccountChargesToBillsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatch(batchId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInList(listId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBill(billId: number, body?: BillEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillIdResponse>;
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFields(billId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomAction(meterId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoid(meterId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomAction(body?: BillActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillList(accountId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillList(listId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBills(body?: BillReversalRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillList(meterId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeaders(accountId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeaders(listId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeaders(meterId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImage(billId: number, fileName?: string, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillList(listId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomActionWithHttpInfo(accountId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoidWithHttpInfo(accountId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeadersWithHttpInfo(body?: BillActionHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoidWithHttpInfo(body?: BillActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomActionWithHttpInfo(listId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetailsWithHttpInfo(body?: Array<BillPaymentDetailsOptionalItem>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillPaymentDetailsOptionalResponse>>;
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFileWithHttpInfo(body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillPaymentDetailsFileResponse>>;
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABillWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBillsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEventWithHttpInfo(body?: BillPaymentEventCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillPaymentEventResponse>>;
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMetersWithHttpInfo(body?: DistributeAccountChargesToBillsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatchWithHttpInfo(batchId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInListWithHttpInfo(listId: number, body?: DistributeAccountChargesBase, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBillWithHttpInfo(billId: number, body?: BillEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillIdResponse>>;
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFieldsWithHttpInfo(billId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomActionWithHttpInfo(meterId: number, body?: ListActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoidWithHttpInfo(meterId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomActionWithHttpInfo(body?: BillActionCustom, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillListWithHttpInfo(accountId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillListWithHttpInfo(listId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBillsWithHttpInfo(body?: BillReversalRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillListWithHttpInfo(meterId: number, body?: ListActionReverse, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeadersWithHttpInfo(accountId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeadersWithHttpInfo(listId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeadersWithHttpInfo(meterId: number, body?: BillHeaderUpdate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImageWithHttpInfo(billId: number, fileName?: string, body?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillListWithHttpInfo(listId: number, body?: ListActionVoid, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService>;
}
