import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Activity } from '../model/activity';
import { ApprovalWorkflowSettings } from '../model/approvalWorkflowSettings';
import { AuditSettingsResponse } from '../model/auditSettingsResponse';
import { BatchResponse } from '../model/batchResponse';
import { BatchWorkflowSettings } from '../model/batchWorkflowSettings';
import { BillAccountMeterResponse } from '../model/billAccountMeterResponse';
import { BillAccountMeterStatisticsResponse } from '../model/billAccountMeterStatisticsResponse';
import { BillActionHistoricalExport } from '../model/billActionHistoricalExport';
import { BillEntryResponse } from '../model/billEntryResponse';
import { BillExport } from '../model/billExport';
import { BillHistoryResponse } from '../model/billHistoryResponse';
import { BillImportKickoutDetailsResponse } from '../model/billImportKickoutDetailsResponse';
import { BillImportTaskKickoutSummaryResponse } from '../model/billImportTaskKickoutSummaryResponse';
import { BillImportWorkflowSettings } from '../model/billImportWorkflowSettings';
import { BillPaymentEventResponse } from '../model/billPaymentEventResponse';
import { BillResponse } from '../model/billResponse';
import { BillViewResponse } from '../model/billViewResponse';
import { BodylineResponse } from '../model/bodylineResponse';
import { ExportWorkflowSettings } from '../model/exportWorkflowSettings';
import { JsonBillExportResponse } from '../model/jsonBillExportResponse';
import { ListResponse } from '../model/listResponse';
import { MeterBillResponse } from '../model/meterBillResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExport(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillList(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountList(accountId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFile(billId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJson(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<JsonBillExportResponse>>;
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     *
     *
     * @param exportFileName
     * @param body
     */
    exportHistoricalBills(exportFileName?: string, body?: BillActionHistoricalExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistory(accountId: number, billingPeriod?: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillHistoryResponse>>;
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylines(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BodylineResponse>>;
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflow(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ApprovalWorkflowSettings>;
    /**
     * Gets all audit settings
     *
     */
    getAuditSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AuditSettingsResponse>;
    /**
     *
     *
     * @param batchId
     */
    getBatch(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchResponse>;
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflow(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchWorkflowSettings>;
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatches(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BatchResponse>>;
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBill(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillResponse>;
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterStatisticsResponse>>;
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActual(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarized(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalized(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterResponse>>;
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatistics(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillAccountMeterStatisticsResponse>>;
    /**
     * List of a bill IDs that were created or modified since the given date.
     *
     * @param date Created or modified datetime; Defaults to yesterday at the current time
     */
    getBillActivity(date?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<Activity>>;
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylines(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BodylineResponse>>;
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFields(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillId(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillEntryResponse>;
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistory(billId: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillHistoryResponse>>;
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetails(taskGuid: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportKickoutDetailsResponse>;
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFile(taskGuid: string, filename: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportKickoutDetailsResponse>;
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportWorkflowSettings>;
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEvents(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillPaymentEventResponse>>;
    /**
     * Retrieves properties for bill view
     *
     * @param billId The bill identifier
     */
    getBillView(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillViewResponse>;
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBills(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillResponse>>;
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflow(exportMode?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ExportWorkflowSettings>;
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBills(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterBillResponse>>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummary(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportTaskKickoutSummaryResponse>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFile(taskGuid: string, filename: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportTaskKickoutSummaryResponse>;
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillList(meterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExport(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillList(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<string>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExportWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillListWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountListWithHttpInfo(accountId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFileWithHttpInfo(billId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJsonWithHttpInfo(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<JsonBillExportResponse>>>;
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     *
     *
     * @param exportFileName
     * @param body
     */
    exportHistoricalBillsWithHttpInfo(exportFileName?: string, body?: BillActionHistoricalExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistoryWithHttpInfo(accountId: number, billingPeriod?: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillHistoryResponse>>>;
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylinesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BodylineResponse>>>;
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflowWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ApprovalWorkflowSettings>>;
    /**
     * Gets all audit settings
     *
     */
    getAuditSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AuditSettingsResponse>>;
    /**
     *
     *
     * @param batchId
     */
    getBatchWithHttpInfo(batchId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchResponse>>;
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflowWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchWorkflowSettings>>;
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatchesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BatchResponse>>>;
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBillWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillResponse>>;
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterStatisticsResponse>>>;
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActualWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarizedWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalizedWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterResponse>>>;
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatisticsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillAccountMeterStatisticsResponse>>>;
    /**
     * List of a bill IDs that were created or modified since the given date.
     *
     * @param date Created or modified datetime; Defaults to yesterday at the current time
     */
    getBillActivityWithHttpInfo(date?: Date, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<Activity>>>;
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylinesWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BodylineResponse>>>;
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFieldsWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillIdWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillEntryResponse>>;
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistoryWithHttpInfo(billId: number, numberOfYears?: number, includeVoid?: boolean, includeAccrual?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillHistoryResponse>>>;
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsWithHttpInfo(taskGuid: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportKickoutDetailsResponse>>;
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFileWithHttpInfo(taskGuid: string, filename: string, kickoutMessage?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportKickoutDetailsResponse>>;
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportWorkflowSettings>>;
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEventsWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillPaymentEventResponse>>>;
    /**
     * Retrieves properties for bill view
     *
     * @param billId The bill identifier
     */
    getBillViewWithHttpInfo(billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillViewResponse>>;
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillResponse>>>;
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflowWithHttpInfo(exportMode?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ExportWorkflowSettings>>;
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBillsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterBillResponse>>>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummaryWithHttpInfo(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportTaskKickoutSummaryResponse>>;
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFileWithHttpInfo(taskGuid: string, filename: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportTaskKickoutSummaryResponse>>;
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillListWithHttpInfo(meterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExportWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillListWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<string>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService>;
}
