import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BenchmarkValueRequest } from '../model/benchmarkValueRequest';
import { BenchmarkValuesResponse } from '../model/benchmarkValuesResponse';
import { EditEsaPlaceSizesRequest } from '../model/editEsaPlaceSizesRequest';
import { EnergyStarPlaceLinkRequest } from '../model/energyStarPlaceLinkRequest';
import { EnergyStarPlaceLinkResponse } from '../model/energyStarPlaceLinkResponse';
import { EnergyStarSettingsResponse } from '../model/energyStarSettingsResponse';
import { EsaPlaceDataRollupRequest } from '../model/esaPlaceDataRollupRequest';
import { EsaPlaceEdit } from '../model/esaPlaceEdit';
import { EsaPlaceResponse } from '../model/esaPlaceResponse';
import { PlaceEdit } from '../model/placeEdit';
import { PlaceResponse } from '../model/placeResponse';
import { PlaceSizeChild } from '../model/placeSizeChild';
import { PlaceSizeCreate } from '../model/placeSizeCreate';
import { PlaceSubmissionTypeRequest } from '../model/placeSubmissionTypeRequest';
import { PlaceTypeRequest } from '../model/placeTypeRequest';
import { PlaceTypeResponse } from '../model/placeTypeResponse';
import { ScheduleCreate } from '../model/scheduleCreate';
import { ScheduleEdit } from '../model/scheduleEdit';
import { ScheduleResponse } from '../model/scheduleResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WatticsSite } from '../model/watticsSite';
import { WatticsSiteRequest } from '../model/watticsSiteRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequests(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarSettingsResponse>;
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollup(body?: EsaPlaceDataRollupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValue(benchmarkIndicator: number, placeId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSize(placeId: number, body?: PlaceSizeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceSizeChild>;
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceType(body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceTypeResponse>;
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createSchedule(body?: ScheduleCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ScheduleResponse>;
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValue(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSize(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceType(placeTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteSchedule(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLink(placeId: number, body?: EnergyStarPlaceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceLinkResponse>;
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlace(placeId: number, body?: EsaPlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaPlaceResponse>;
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedules(placeId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ScheduleResponse>>;
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistory(placeId: number, body?: EditEsaPlaceSizesRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlace(placeId: number, body?: PlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceResponse>;
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValues(benchmarkIndicator: number, placeId: number, body?: Array<BenchmarkValueRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeList(placeId: number, body?: Array<PlaceSizeCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceType(placeTypeId: number, body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceTypeResponse>;
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFs(placeId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editSchedule(scheduleId: number, body?: ScheduleEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ScheduleResponse>;
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLink(placeId: number, body?: WatticsSiteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WatticsSite>;
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlace(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlace(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStar(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionType(body?: PlaceSubmissionTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValue(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequestsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarSettingsResponse>>;
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollupWithHttpInfo(body?: EsaPlaceDataRollupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValueWithHttpInfo(benchmarkIndicator: number, placeId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSizeWithHttpInfo(placeId: number, body?: PlaceSizeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceSizeChild>>;
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceTypeWithHttpInfo(body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceTypeResponse>>;
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createScheduleWithHttpInfo(body?: ScheduleCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ScheduleResponse>>;
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValueWithHttpInfo(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSizeWithHttpInfo(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceTypeWithHttpInfo(placeTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteScheduleWithHttpInfo(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLinkWithHttpInfo(placeId: number, body?: EnergyStarPlaceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceLinkResponse>>;
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlaceWithHttpInfo(placeId: number, body?: EsaPlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaPlaceResponse>>;
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedulesWithHttpInfo(placeId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ScheduleResponse>>>;
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistoryWithHttpInfo(placeId: number, body?: EditEsaPlaceSizesRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlaceWithHttpInfo(placeId: number, body?: PlaceEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceResponse>>;
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValuesWithHttpInfo(benchmarkIndicator: number, placeId: number, body?: Array<BenchmarkValueRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeListWithHttpInfo(placeId: number, body?: Array<PlaceSizeCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceTypeWithHttpInfo(placeTypeId: number, body?: PlaceTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceTypeResponse>>;
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFsWithHttpInfo(placeId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editScheduleWithHttpInfo(scheduleId: number, body?: ScheduleEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ScheduleResponse>>;
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLinkWithHttpInfo(placeId: number, body?: WatticsSiteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WatticsSite>>;
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlaceWithHttpInfo(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlaceWithHttpInfo(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStarWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionTypeWithHttpInfo(body?: PlaceSubmissionTypeRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValueWithHttpInfo(benchmarkIndicator: number, placeId: number, placeBenchmarkId: number, body?: BenchmarkValueRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService>;
}
