import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BenchmarkValuesResponse } from '../model/benchmarkValuesResponse';
import { CostCenterChild } from '../model/costCenterChild';
import { EnergyProjectResponse } from '../model/energyProjectResponse';
import { EnergyProjectType } from '../model/energyProjectType';
import { EnergyStarCommodityMeterTypeMapping } from '../model/energyStarCommodityMeterTypeMapping';
import { EnergyStarPlaceHierarchyResponse } from '../model/energyStarPlaceHierarchyResponse';
import { EnergyStarPlaceLinkResponse } from '../model/energyStarPlaceLinkResponse';
import { EnergyStarPmMeter } from '../model/energyStarPmMeter';
import { EnergyStarPmProperty } from '../model/energyStarPmProperty';
import { EnergyStarSettingsResponse } from '../model/energyStarSettingsResponse';
import { EsaPlaceResponse } from '../model/esaPlaceResponse';
import { HierarchicalPlaces } from '../model/hierarchicalPlaces';
import { HierarchicalSpaces } from '../model/hierarchicalSpaces';
import { PlaceDigestActualAndCalendarizedMonthlyResponse } from '../model/placeDigestActualAndCalendarizedMonthlyResponse';
import { PlaceDigestActualAndCalendarizedYearlyResponse } from '../model/placeDigestActualAndCalendarizedYearlyResponse';
import { PlaceDigestComparisonResponse } from '../model/placeDigestComparisonResponse';
import { PlaceDigestEnergyUseIntensity } from '../model/placeDigestEnergyUseIntensity';
import { PlaceDigestNormalizedMonthlyResponse } from '../model/placeDigestNormalizedMonthlyResponse';
import { PlaceDigestNormalizedYearlyResponse } from '../model/placeDigestNormalizedYearlyResponse';
import { PlaceDigestSavingsMonthlyResponse } from '../model/placeDigestSavingsMonthlyResponse';
import { PlaceDigestSavingsYearlyResponse } from '../model/placeDigestSavingsYearlyResponse';
import { PlaceGroupResponse } from '../model/placeGroupResponse';
import { PlaceResponse } from '../model/placeResponse';
import { PlaceSizeChild } from '../model/placeSizeChild';
import { PlaceSizeResponse } from '../model/placeSizeResponse';
import { PlaceUDFResponse } from '../model/placeUDFResponse';
import { ProjectManagerResponse } from '../model/projectManagerResponse';
import { ScheduleResponse } from '../model/scheduleResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlaces(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterChild>>;
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFields(energyProjectId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFile(placeId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValues(benchmarkIndicator: number, placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BenchmarkValuesResponse>;
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProject(projectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyProjectResponse>;
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFields(energyProjectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManager(query?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ProjectManagerResponse>>;
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyProjectType>>;
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyProjectResponse>>;
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarCommodityMeterTypeMapping>>;
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlace(placeId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPmProperty>;
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchy(placeId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPlaceHierarchyResponse>>;
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLink(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceLinkResponse>;
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetrics(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceHierarchyResponse>;
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarSettingsResponse>;
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaPlaceResponse>;
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizes(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeResponse>>;
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedules(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ScheduleResponse>>;
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistory(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlaces(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaPlaceResponse>>;
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartData(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestEnergyUseIntensity>>;
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceResponse>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparison(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestComparisonResponse>;
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparison(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestComparisonResponse>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroups(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceGroupResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestNormalizedMonthlyResponse>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestNormalizedMonthlyResponse>>;
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparison(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestComparisonResponse>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestNormalizedYearlyResponse>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestSavingsMonthlyResponse>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestSavingsMonthlyResponse>>;
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearly(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestSavingsYearlyResponse>;
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestSavingsYearlyResponse>>;
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSize(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceSizeChild>;
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizes(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceSizeChild>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfs(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaces(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceUDFResponse>>;
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperties(includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPmProperty>>;
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperty(pmPropertyId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPmProperty>;
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMeters(pmPropertyId: number, includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPmMeter>>;
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getSchedule(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ScheduleResponse>;
    /**
     * Retrieves all schedules
     *
     */
    getSchedules(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ScheduleResponse>>;
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPoints(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalSpaces>;
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMeters(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalPlaces>;
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlaces(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalPlaces>;
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpaces(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalSpaces>;
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalPlaces>;
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalSpaces>;
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlacesWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterChild>>>;
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFieldsWithHttpInfo(energyProjectId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFileWithHttpInfo(placeId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValuesWithHttpInfo(benchmarkIndicator: number, placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BenchmarkValuesResponse>>;
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProjectWithHttpInfo(projectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyProjectResponse>>;
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFieldsWithHttpInfo(energyProjectId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManagerWithHttpInfo(query?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ProjectManagerResponse>>>;
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyProjectType>>>;
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyProjectResponse>>>;
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarCommodityMeterTypeMapping>>>;
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlaceWithHttpInfo(placeId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPmProperty>>;
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchyWithHttpInfo(placeId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPlaceHierarchyResponse>>>;
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLinkWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceLinkResponse>>;
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetricsWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceHierarchyResponse>>;
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarSettingsResponse>>;
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaPlaceResponse>>;
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeResponse>>>;
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedulesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ScheduleResponse>>>;
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistoryWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlacesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaPlaceResponse>>>;
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartDataWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestEnergyUseIntensity>>>;
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparisonWithHttpInfo(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestComparisonResponse>>;
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparisonWithHttpInfo(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestComparisonResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroupsWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceGroupResponse>>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestNormalizedMonthlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestNormalizedMonthlyResponse>>>;
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparisonWithHttpInfo(placeId: number, chartMonthsToExclude?: number, numMonths?: number, comparisonYearsAgo?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestComparisonResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestNormalizedYearlyResponse>>>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestSavingsMonthlyResponse>>;
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestSavingsMonthlyResponse>>>;
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearlyWithHttpInfo(placeId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestSavingsYearlyResponse>>;
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestSavingsYearlyResponse>>>;
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSizeWithHttpInfo(placeId: number, placeSizeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceSizeChild>>;
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceSizeChild>>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfsWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceUDFResponse>>>;
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertiesWithHttpInfo(includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPmProperty>>>;
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertyWithHttpInfo(pmPropertyId: number, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPmProperty>>;
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMetersWithHttpInfo(pmPropertyId: number, includeOnlyUnlinked?: boolean, verbose?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPmMeter>>>;
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getScheduleWithHttpInfo(scheduleId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ScheduleResponse>>;
    /**
     * Retrieves all schedules
     *
     */
    getSchedulesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ScheduleResponse>>>;
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPointsWithHttpInfo(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalSpaces>>;
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMetersWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalPlaces>>;
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlacesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalPlaces>>;
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpacesWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalSpaces>>;
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalPlaces>>;
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalSpaces>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService>;
}
