import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AssignVersionsToStep } from '../model/assignVersionsToStep';
import { BillSplitDetailsRequest } from '../model/billSplitDetailsRequest';
import { BillSplitDetailsResponse } from '../model/billSplitDetailsResponse';
import { CalculatedBillCostRequest } from '../model/calculatedBillCostRequest';
import { CalculatedBillCostResponse } from '../model/calculatedBillCostResponse';
import { CalculatedBillDemandRequest } from '../model/calculatedBillDemandRequest';
import { CalculatedBillDemandResponse } from '../model/calculatedBillDemandResponse';
import { CalculatedBillUseRequest } from '../model/calculatedBillUseRequest';
import { CalculatedBillUseResponse } from '../model/calculatedBillUseResponse';
import { ChargebackWorkflowCreate } from '../model/chargebackWorkflowCreate';
import { ChargebackWorkflowEdit } from '../model/chargebackWorkflowEdit';
import { ChargebackWorkflowResponse } from '../model/chargebackWorkflowResponse';
import { ChargebackWorkflowStepChild } from '../model/chargebackWorkflowStepChild';
import { DistributionVersionManage } from '../model/distributionVersionManage';
import { DistributionVersionResponse } from '../model/distributionVersionResponse';
import { GenericBodylineRequest } from '../model/genericBodylineRequest';
import { GenericBodylineResponse } from '../model/genericBodylineResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStep(chargebackWorkflowStepId: number, billingPeriod: number, body?: AssignVersionsToStep, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowStepChild>;
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflow(body?: ChargebackWorkflowCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowResponse>;
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflow(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflow(chargebackWorkflowId: number, body?: ChargebackWorkflowEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowResponse>;
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItems(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetails(accountId: number, meterId: number, versionId: number, body?: BillSplitDetailsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillSplitDetailsResponse>;
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistory(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCost(accountId: number, meterId: number, versionId: number, body?: CalculatedBillCostRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillCostResponse>;
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemand(accountId: number, meterId: number, versionId: number, body?: CalculatedBillDemandRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDemandResponse>;
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUse(accountId: number, meterId: number, versionId: number, body?: CalculatedBillUseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillUseResponse>;
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistory(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItems(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStepWithHttpInfo(chargebackWorkflowStepId: number, billingPeriod: number, body?: AssignVersionsToStep, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowStepChild>>;
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflowWithHttpInfo(body?: ChargebackWorkflowCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowResponse>>;
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflowWithHttpInfo(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflowWithHttpInfo(chargebackWorkflowId: number, body?: ChargebackWorkflowEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowResponse>>;
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetailsWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: BillSplitDetailsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillSplitDetailsResponse>>;
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistoryWithHttpInfo(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCostWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: CalculatedBillCostRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillCostResponse>>;
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemandWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: CalculatedBillDemandRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDemandResponse>>;
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUseWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: CalculatedBillUseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillUseResponse>>;
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistoryWithHttpInfo(accountId: number, meterId: number, body?: Array<DistributionVersionManage>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, body?: Array<GenericBodylineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService>;
}
