import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ChargebackWorkflowDigestResponse } from '../model/chargebackWorkflowDigestResponse';
import { ChargebackWorkflowResponse } from '../model/chargebackWorkflowResponse';
import { ChargebackWorkflowSettings } from '../model/chargebackWorkflowSettings';
import { ChargebackWorkflowStepChild } from '../model/chargebackWorkflowStepChild';
import { CustomerResponse } from '../model/customerResponse';
import { DistributionVersionResponse } from '../model/distributionVersionResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersions(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersions(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflow(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowResponse>;
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigest(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowDigestResponse>;
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowSettings>;
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStep(chargebackWorkflowStepId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowStepChild>;
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowSteps(chargebackWorkflowType?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackWorkflowStepChild>>;
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflows(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackWorkflowResponse>>;
    /**
     * Retrieves an array of customers.
     *
     * @param filter
     */
    getCustomers(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CustomerResponse>>;
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersionsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersionsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflowWithHttpInfo(chargebackWorkflowId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowResponse>>;
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigestWithHttpInfo(chargebackWorkflowStepId: number, billingPeriod?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowDigestResponse>>;
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowSettings>>;
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStepWithHttpInfo(chargebackWorkflowStepId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowStepChild>>;
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowType?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackWorkflowStepChild>>>;
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflowsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackWorkflowResponse>>>;
    /**
     * Retrieves an array of customers.
     *
     * @param filter
     */
    getCustomersWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CustomerResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService>;
}
