import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillActionSplit } from '../model/billActionSplit';
import { ChargebackProcessorSettings } from '../model/chargebackProcessorSettings';
import { ChargebackProcessorSettingsForAggregations } from '../model/chargebackProcessorSettingsForAggregations';
import { ChargebackProcessorSettingsForSplits } from '../model/chargebackProcessorSettingsForSplits';
import { ChargebackProcessorSettingsWithoutFilters } from '../model/chargebackProcessorSettingsWithoutFilters';
import { ChargebackTaskRequest } from '../model/chargebackTaskRequest';
import { ChargebackTaskResponse } from '../model/chargebackTaskResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplit(body?: BillActionSplit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessor(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessor(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregations(body?: ChargebackProcessorSettingsForAggregations, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflow(chargebackWorkflowId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChargebackTaskResponse>>;
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStep(chargebackWorkflowStepId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillList(listId: number, body?: ChargebackProcessorSettingsForSplits, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTask(taskId: number, body?: ChargebackTaskRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplitWithHttpInfo(body?: BillActionSplit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessorWithHttpInfo(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessorWithHttpInfo(body?: ChargebackProcessorSettings, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregationsWithHttpInfo(body?: ChargebackProcessorSettingsForAggregations, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflowWithHttpInfo(chargebackWorkflowId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChargebackTaskResponse>>>;
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStepWithHttpInfo(chargebackWorkflowStepId: number, body?: ChargebackProcessorSettingsWithoutFilters, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillListWithHttpInfo(listId: number, body?: ChargebackProcessorSettingsForSplits, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTaskWithHttpInfo(taskId: number, body?: ChargebackTaskRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService>;
}
