import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CollectionResponse } from '../model/collectionResponse';
import { HierarchicalCollections } from '../model/hierarchicalCollections';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFields(collectionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollection(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CollectionResponse>;
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFields(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollections(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CollectionResponse>>;
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollections(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCollections>;
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSources(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCollections>;
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollection(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCollections>;
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFieldsWithHttpInfo(collectionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollectionWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CollectionResponse>>;
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFieldsWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollectionsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CollectionResponse>>>;
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollectionsWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCollections>>;
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSourcesWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCollections>>;
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollectionWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCollections>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService>;
}
