import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CostCenterDigestActualMonthlyResponse } from '../model/costCenterDigestActualMonthlyResponse';
import { CostCenterDigestActualYearlyResponse } from '../model/costCenterDigestActualYearlyResponse';
import { CostCenterResponse } from '../model/costCenterResponse';
import { HierarchicalCostCenters } from '../model/hierarchicalCostCenters';
import { PlaceChild } from '../model/placeChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCenters(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceChild>>;
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenter(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterResponse>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthly(costCenterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterDigestActualMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearly(costCenterId: number, numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostCenterDigestActualYearlyResponse>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterDigestActualYearlyResponse>>;
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenters(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostCenterResponse>>;
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccounts(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCostCenters>;
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCenters(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCostCenters>;
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenter(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HierarchicalCostCenters>;
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCentersWithHttpInfo(body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceChild>>>;
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenterWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthlyWithHttpInfo(costCenterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterDigestActualMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterDigestActualMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyWithHttpInfo(costCenterId: number, numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostCenterDigestActualYearlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterDigestActualYearlyResponse>>>;
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCentersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostCenterResponse>>>;
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccountsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCostCenters>>;
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCentersWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCostCenters>>;
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenterWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<HierarchicalCostCenters>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService>;
}
