import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DashboardCopy } from '../model/dashboardCopy';
import { DashboardCreate } from '../model/dashboardCreate';
import { DashboardEdit } from '../model/dashboardEdit';
import { DashboardResponse } from '../model/dashboardResponse';
import { MapDashboardSettingsRequest } from '../model/mapDashboardSettingsRequest';
import { MapDashboardSettingsResponse } from '../model/mapDashboardSettingsResponse';
import { SpecificWidgetResponse } from '../model/specificWidgetResponse';
import { ToggleVisible } from '../model/toggleVisible';
import { WidgetCreate } from '../model/widgetCreate';
import { WidgetEdit } from '../model/widgetEdit';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Add a widget to a dashboard  To add widgets to a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    addWidget(dashboardId: number, body?: WidgetCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificWidgetResponse>;
    /**
     * Copy a dashboard  To copy a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Request object
     */
    copyDashboard(dashboardId: number, body?: DashboardCopy, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DashboardResponse>;
    /**
     * Creates a dashboard
     *
     * @param body
     */
    createDashboard(body?: DashboardCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DashboardResponse>;
    /**
     * Update the visibility of a dashboard for the current user  This must be a dashboard you can see  Which means you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Set Visibility
     */
    dashboardActionVisible(dashboardId: number, body?: ToggleVisible, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DashboardResponse>;
    /**
     * Delete a dashboard  To delete a dashboard you must have created it  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Specific dashboard
     */
    deleteDashboard(dashboardId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a dashboard  To edit a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId
     * @param body
     */
    editDashboard(dashboardId: number, body?: DashboardEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DashboardResponse>;
    /**
     * Reorder, edit, and delete specific widgets on a dashboard.  To edit dashboard widgets you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    editDashboardWidgets(dashboardId: number, body?: Array<WidgetEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecificWidgetResponse>>;
    /**
     * Applies display settings and filters to a map dashboard. These settings are specific to map dashboards, and cannot be applied to standard dashboards.  To apply these settings, You must also have either:  Created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier of the dashboard to apply these settings to
     * @param body Object containing the settings to be applied.
     */
    editMapDashboardSettings(dashboardId: number, body?: MapDashboardSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MapDashboardSettingsResponse>;
    /**
     * Gets the current display settings and filters for a specific map dashboard. Cannot be used to retreive settings for a standard dashboard.
     *
     * @param dashboardId The identifier of the dashboard to get the settings of
     */
    getMapDashboardSettings(dashboardId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MapDashboardSettingsResponse>;
    /**
     * Add a widget to a dashboard  To add widgets to a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    addWidgetWithHttpInfo(dashboardId: number, body?: WidgetCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificWidgetResponse>>;
    /**
     * Copy a dashboard  To copy a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Request object
     */
    copyDashboardWithHttpInfo(dashboardId: number, body?: DashboardCopy, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DashboardResponse>>;
    /**
     * Creates a dashboard
     *
     * @param body
     */
    createDashboardWithHttpInfo(body?: DashboardCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DashboardResponse>>;
    /**
     * Update the visibility of a dashboard for the current user  This must be a dashboard you can see  Which means you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Set Visibility
     */
    dashboardActionVisibleWithHttpInfo(dashboardId: number, body?: ToggleVisible, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DashboardResponse>>;
    /**
     * Delete a dashboard  To delete a dashboard you must have created it  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Specific dashboard
     */
    deleteDashboardWithHttpInfo(dashboardId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a dashboard  To edit a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId
     * @param body
     */
    editDashboardWithHttpInfo(dashboardId: number, body?: DashboardEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DashboardResponse>>;
    /**
     * Reorder, edit, and delete specific widgets on a dashboard.  To edit dashboard widgets you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    editDashboardWidgetsWithHttpInfo(dashboardId: number, body?: Array<WidgetEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecificWidgetResponse>>>;
    /**
     * Applies display settings and filters to a map dashboard. These settings are specific to map dashboards, and cannot be applied to standard dashboards.  To apply these settings, You must also have either:  Created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier of the dashboard to apply these settings to
     * @param body Object containing the settings to be applied.
     */
    editMapDashboardSettingsWithHttpInfo(dashboardId: number, body?: MapDashboardSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MapDashboardSettingsResponse>>;
    /**
     * Gets the current display settings and filters for a specific map dashboard. Cannot be used to retreive settings for a standard dashboard.
     *
     * @param dashboardId The identifier of the dashboard to get the settings of
     */
    getMapDashboardSettingsWithHttpInfo(dashboardId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MapDashboardSettingsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService>;
}
