import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EmissionSourceMultiFactorResponse } from '../model/emissionSourceMultiFactorResponse';
import { EmissionSourceResponse } from '../model/emissionSourceResponse';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFields(emissionSourceId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSource(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceResponse>;
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFields(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactors(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceMultiFactorResponse>;
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSources(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EmissionSourceResponse>>;
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactors(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EmissionSourceMultiFactorResponse>>;
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceResponse>>;
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceMultiFactorResponse>>;
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EmissionSourceResponse>>>;
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactorsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EmissionSourceMultiFactorResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService>;
}
