import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillExport } from '../model/billExport';
import { BillExportOptions } from '../model/billExportOptions';
import { BillUnexport } from '../model/billUnexport';
import { BillUnexportOptions } from '../model/billUnexportOptions';
import { UpdateResult } from '../model/updateResult';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExport(accountId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexport(accountId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillList(listId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBills(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExport(meterId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexport(meterId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillList(listId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBills(body?: BillUnexport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuid(billExportGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExportWithHttpInfo(accountId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexportWithHttpInfo(accountId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillListWithHttpInfo(listId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBillsWithHttpInfo(body?: BillExport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExportWithHttpInfo(meterId: number, body?: BillExportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexportWithHttpInfo(meterId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillListWithHttpInfo(listId: number, body?: BillUnexportOptions, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBillsWithHttpInfo(body?: BillUnexport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuidWithHttpInfo(billExportGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService>;
}
