import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountAuditSettingsResponse } from '../model/accountAuditSettingsResponse';
import { FlagIssueResponse } from '../model/flagIssueResponse';
import { FlagResponse } from '../model/flagResponse';
import { FlagTypeChild } from '../model/flagTypeChild';
import { FlagTypeCreate } from '../model/flagTypeCreate';
import { FlagWidget } from '../model/flagWidget';
import { SingleBoolean } from '../model/singleBoolean';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccount(costCenterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagWidget>;
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeter(placeId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagWidget>;
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagType(body?: FlagTypeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagTypeChild>;
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagType(flagTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchy(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchy(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchy(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchy(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SingleBoolean>;
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettings(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AccountAuditSettingsResponse>;
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlag(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<FlagResponse>;
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssues(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FlagIssueResponse>>;
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FlagTypeChild>>;
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccountWithHttpInfo(costCenterId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagWidget>>;
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeterWithHttpInfo(placeId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagWidget>>;
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagTypeWithHttpInfo(body?: FlagTypeCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagTypeChild>>;
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagTypeWithHttpInfo(flagTypeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchyWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchyWithHttpInfo(costCenterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchyWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchyWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SingleBoolean>>;
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettingsWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AccountAuditSettingsResponse>>;
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagWithHttpInfo(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<FlagResponse>>;
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssuesWithHttpInfo(entityType: string, entityId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FlagIssueResponse>>>;
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FlagTypeChild>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService>;
}
