import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FilterResponse } from '../model/filterResponse';
import { GroupMeterGroupResponse } from '../model/groupMeterGroupResponse';
import { GroupPlaceGroupMember } from '../model/groupPlaceGroupMember';
import { GroupPlaceGroupResponse } from '../model/groupPlaceGroupResponse';
import { MeterCategoryResponse } from '../model/meterCategoryResponse';
import { MeterGroupDigestRankingResponse } from '../model/meterGroupDigestRankingResponse';
import { MeterGroupMemberChild } from '../model/meterGroupMemberChild';
import { PlaceCategoryResponse } from '../model/placeCategoryResponse';
import { PlaceGroupDigestAreaDemandRankingResponse } from '../model/placeGroupDigestAreaDemandRankingResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroups(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GroupMeterGroupResponse>>;
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroups(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GroupPlaceGroupResponse>>;
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterCategoryResponse>>;
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategory(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterCategoryResponse>;
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroup(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupMeterGroupResponse>;
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembers(groupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterGroupMemberChild>>;
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRanking(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterGroupDigestRankingResponse>;
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategories(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceCategoryResponse>>;
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategory(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceCategoryResponse>;
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroup(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GroupPlaceGroupResponse>;
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembers(placeGroupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GroupPlaceGroupMember>>;
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRanking(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceGroupDigestAreaDemandRankingResponse>;
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFilters(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFilters(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroupsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GroupMeterGroupResponse>>>;
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroupsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GroupPlaceGroupResponse>>>;
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterCategoryResponse>>>;
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategoryWithHttpInfo(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterCategoryResponse>>;
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroupWithHttpInfo(meterGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupMeterGroupResponse>>;
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembersWithHttpInfo(groupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterGroupMemberChild>>>;
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRankingWithHttpInfo(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterGroupDigestRankingResponse>>;
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategoriesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceCategoryResponse>>>;
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategoryWithHttpInfo(categoryId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceCategoryResponse>>;
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroupWithHttpInfo(placeGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GroupPlaceGroupResponse>>;
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembersWithHttpInfo(placeGroupId: number, alwaysLimitByTopmost?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GroupPlaceGroupMember>>>;
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRankingWithHttpInfo(groupId: number, dataView: string, chart: string, billingPeriodOption?: string, startPeriod?: number, endPeriod?: number, commodityId?: number, commodityCategoryId?: number, highToLowRanking?: boolean, showExcludedMembers?: boolean, showZeroAverages?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceGroupDigestAreaDemandRankingResponse>>;
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFiltersWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFiltersWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService>;
}
