import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeleteReadingResponse } from '../model/deleteReadingResponse';
import { GuidResponse } from '../model/guidResponse';
import { Reading } from '../model/reading';
import { ReadingCreate } from '../model/readingCreate';
import { ReadingDelete } from '../model/readingDelete';
import { ReadingImportProfileRequest } from '../model/readingImportProfileRequest';
import { ReadingImportProfileResponse } from '../model/readingImportProfileResponse';
import { ReadingImportRequest } from '../model/readingImportRequest';
import { ReadingResponse } from '../model/readingResponse';
import { ReadingsObservation } from '../model/readingsObservation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfile(body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingImportProfileResponse>;
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadings(body?: Array<ReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingResponse>;
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadings(body?: Array<ReadingDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DeleteReadingResponse>;
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReading(readingId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfile(profileId: number, body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingImportProfileResponse>;
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReading(readingId: number, body?: Reading, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingsObservation>;
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ReadingImportProfileResponse>;
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ReadingImportProfileResponse>>;
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImport(body?: ReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GuidResponse>;
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfileWithHttpInfo(body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingImportProfileResponse>>;
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadingsWithHttpInfo(body?: Array<ReadingCreate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingResponse>>;
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadingsWithHttpInfo(body?: Array<ReadingDelete>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DeleteReadingResponse>>;
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReadingWithHttpInfo(readingId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfileWithHttpInfo(profileId: number, body?: ReadingImportProfileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingImportProfileResponse>>;
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReadingWithHttpInfo(readingId: number, body?: Reading, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingsObservation>>;
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ReadingImportProfileResponse>>;
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ReadingImportProfileResponse>>>;
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImportWithHttpInfo(body?: ReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GuidResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService>;
}
