import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CalculatedBillDetailsResponse } from '../model/calculatedBillDetailsResponse';
import { CreateUtilityPlatformMeter } from '../model/createUtilityPlatformMeter';
import { DataPointCreate } from '../model/dataPointCreate';
import { DataPointResponse } from '../model/dataPointResponse';
import { DetailedGuidResponse } from '../model/detailedGuidResponse';
import { EsaChannelCreate } from '../model/esaChannelCreate';
import { EsaChannelResponse } from '../model/esaChannelResponse';
import { EsaReadingImportProfileCreate } from '../model/esaReadingImportProfileCreate';
import { EsaReadingImportProfileResponse } from '../model/esaReadingImportProfileResponse';
import { EsaReadingImportRequest } from '../model/esaReadingImportRequest';
import { MeterCreate } from '../model/meterCreate';
import { MeterResponse } from '../model/meterResponse';
import { RouteRequest } from '../model/routeRequest';
import { RouteResponse } from '../model/routeResponse';
import { UpsertAggregateMeterRequest } from '../model/upsertAggregateMeterRequest';
import { UtilityPlatformMeter } from '../model/utilityPlatformMeter';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPoint(body?: DataPointCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannel(body?: EsaChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelResponse>;
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfile(body?: EsaReadingImportProfileCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingImportProfileResponse>;
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeter(body?: MeterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterResponse>;
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRoute(body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlace(placeId: number, body?: Array<CreateUtilityPlatformMeter>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UtilityPlatformMeter>>;
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfile(body?: EsaReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DetailedGuidResponse>>;
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeter(placeId: number, body?: UpsertAggregateMeterRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDetailsResponse>;
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPointWithHttpInfo(body?: DataPointCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannelWithHttpInfo(body?: EsaChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelResponse>>;
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfileWithHttpInfo(body?: EsaReadingImportProfileCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingImportProfileResponse>>;
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeterWithHttpInfo(body?: MeterCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterResponse>>;
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRouteWithHttpInfo(body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlaceWithHttpInfo(placeId: number, body?: Array<CreateUtilityPlatformMeter>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UtilityPlatformMeter>>>;
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfileWithHttpInfo(body?: EsaReadingImportRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DetailedGuidResponse>>>;
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeterWithHttpInfo(placeId: number, body?: UpsertAggregateMeterRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDetailsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService>;
}
