import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AddressLookup } from '../model/addressLookup';
import { ChannelCreate } from '../model/channelCreate';
import { ChannelEdit } from '../model/channelEdit';
import { ChannelResponse } from '../model/channelResponse';
import { ChannelVersionWithBeginDateRequest } from '../model/channelVersionWithBeginDateRequest';
import { DataAccessRelease } from '../model/dataAccessRelease';
import { DataPointEdit } from '../model/dataPointEdit';
import { DataPointResponse } from '../model/dataPointResponse';
import { DataPointSentinel } from '../model/dataPointSentinel';
import { EmissionSourceLinkRequest } from '../model/emissionSourceLinkRequest';
import { EsaChannelEdit } from '../model/esaChannelEdit';
import { EsaChannelResponse } from '../model/esaChannelResponse';
import { EsaChannelVersionCreateWithBeginDate } from '../model/esaChannelVersionCreateWithBeginDate';
import { EsaChannelVersionEdit } from '../model/esaChannelVersionEdit';
import { EsaChannelVersionResponse } from '../model/esaChannelVersionResponse';
import { EsaReadingImportProfileEdit } from '../model/esaReadingImportProfileEdit';
import { EsaReadingImportProfileResponse } from '../model/esaReadingImportProfileResponse';
import { MeterEdit } from '../model/meterEdit';
import { MeterResponse } from '../model/meterResponse';
import { MeterSearchRequest } from '../model/meterSearchRequest';
import { MeterSerialNumberHistoryRequest } from '../model/meterSerialNumberHistoryRequest';
import { MeterSerialNumberHistoryResponse } from '../model/meterSerialNumberHistoryResponse';
import { MoveCreateMeter } from '../model/moveCreateMeter';
import { RouteMeter } from '../model/routeMeter';
import { RouteRequest } from '../model/routeRequest';
import { RouteResponse } from '../model/routeResponse';
import { SendDataAccessReleaseRequest } from '../model/sendDataAccessReleaseRequest';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdateResult } from '../model/updateResult';
import { WatticsDataPoint } from '../model/watticsDataPoint';
import { WatticsDataPointRequest } from '../model/watticsDataPointRequest';
import { WebhookCustomAction } from '../model/webhookCustomAction';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsMetersEditspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeter(routeId: number, body?: RouteMeter, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersion(meterId: number, channelId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersion(esaChannelId: number, body?: EsaChannelVersionCreateWithBeginDate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelVersionResponse>;
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannel(meterId: number, body?: ChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersion(meterId: number, channelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannel(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersion(meterId: number, channelId: number, versionId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPoint(dataPointId: number, body?: DataPointEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLink(meterId: number, body?: EmissionSourceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionSourceLinkRequest>;
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannel(esaChannelId: number, body?: EsaChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelResponse>;
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersion(esaChannelId: number, versionId: number, body?: EsaChannelVersionEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelVersionResponse>;
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfile(profileId: number, body?: EsaReadingImportProfileEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingImportProfileResponse>;
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannel(meterId: number, channelId: number, body?: ChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersion(meterId: number, body?: MeterSerialNumberHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterSerialNumberHistoryResponse>;
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFs(meterId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnits(meterId: number, body?: MeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterResponse>;
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRoute(id: number, body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLink(meterId: number, body?: WatticsDataPointRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WatticsDataPoint>;
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinel(dataPointId: number, body?: DataPointSentinel, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetails(dataAccessReleaseId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataAccessRelease>;
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeter(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdateResult>;
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomAction(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeter(routeId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMeters(pageSize?: number, pageNumber?: number, body?: MeterSearchRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MoveCreateMeter>>;
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddresses(address?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AddressLookup>>;
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmail(meterId: number, body?: SendDataAccessReleaseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeterWithHttpInfo(routeId: number, body?: RouteMeter, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersionWithHttpInfo(meterId: number, channelId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersionWithHttpInfo(esaChannelId: number, body?: EsaChannelVersionCreateWithBeginDate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelVersionResponse>>;
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannelWithHttpInfo(meterId: number, body?: ChannelCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersionWithHttpInfo(meterId: number, channelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannelWithHttpInfo(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersionWithHttpInfo(meterId: number, channelId: number, versionId: number, body?: ChannelVersionWithBeginDateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPointWithHttpInfo(dataPointId: number, body?: DataPointEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLinkWithHttpInfo(meterId: number, body?: EmissionSourceLinkRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionSourceLinkRequest>>;
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannelWithHttpInfo(esaChannelId: number, body?: EsaChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelResponse>>;
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersionWithHttpInfo(esaChannelId: number, versionId: number, body?: EsaChannelVersionEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelVersionResponse>>;
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfileWithHttpInfo(profileId: number, body?: EsaReadingImportProfileEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingImportProfileResponse>>;
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannelWithHttpInfo(meterId: number, channelId: number, body?: ChannelEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersionWithHttpInfo(meterId: number, body?: MeterSerialNumberHistoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterSerialNumberHistoryResponse>>;
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFsWithHttpInfo(meterId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnitsWithHttpInfo(meterId: number, body?: MeterEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterResponse>>;
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRouteWithHttpInfo(id: number, body?: RouteRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLinkWithHttpInfo(meterId: number, body?: WatticsDataPointRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WatticsDataPoint>>;
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinelWithHttpInfo(dataPointId: number, body?: DataPointSentinel, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetailsWithHttpInfo(dataAccessReleaseId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataAccessRelease>>;
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeterWithHttpInfo(parentPlaceId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdateResult>>;
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomActionWithHttpInfo(body?: WebhookCustomAction, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeterWithHttpInfo(routeId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMetersWithHttpInfo(pageSize?: number, pageNumber?: number, body?: MeterSearchRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MoveCreateMeter>>>;
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddressesWithHttpInfo(address?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AddressLookup>>>;
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmailWithHttpInfo(meterId: number, body?: SendDataAccessReleaseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsMetersEditspanService>;
}
