import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AdjustedCostTypeResponse } from '../model/adjustedCostTypeResponse';
import { BillSplitParentDetailsResponse } from '../model/billSplitParentDetailsResponse';
import { CalculatedBillCostResponse } from '../model/calculatedBillCostResponse';
import { CalculatedBillDemandResponse } from '../model/calculatedBillDemandResponse';
import { CalculatedBillDetailsResponse } from '../model/calculatedBillDetailsResponse';
import { CalculatedBillUseResponse } from '../model/calculatedBillUseResponse';
import { ChannelResponse } from '../model/channelResponse';
import { CostAvoidanceTask } from '../model/costAvoidanceTask';
import { DataPointResponse } from '../model/dataPointResponse';
import { DistributionVersionResponse } from '../model/distributionVersionResponse';
import { EsaChannelResponse } from '../model/esaChannelResponse';
import { EsaChannelVersionResponse } from '../model/esaChannelVersionResponse';
import { EsaReadingImportProfileResponse } from '../model/esaReadingImportProfileResponse';
import { GHGFactorsResponse } from '../model/gHGFactorsResponse';
import { GHGSettingResponse } from '../model/gHGSettingResponse';
import { GenericBodylineResponse } from '../model/genericBodylineResponse';
import { MeterCalendarizedUseVsWeatherResponse } from '../model/meterCalendarizedUseVsWeatherResponse';
import { MeterDigestActualAndCalendarizedMonthlyResponse } from '../model/meterDigestActualAndCalendarizedMonthlyResponse';
import { MeterDigestActualAndCalendarizedYearlyResponse } from '../model/meterDigestActualAndCalendarizedYearlyResponse';
import { MeterDigestCalendarizedTrendResponse } from '../model/meterDigestCalendarizedTrendResponse';
import { MeterDigestNormalizedMonthlyResponse } from '../model/meterDigestNormalizedMonthlyResponse';
import { MeterDigestNormalizedYearlyResponse } from '../model/meterDigestNormalizedYearlyResponse';
import { MeterDigestSavingsMonthlyResponse } from '../model/meterDigestSavingsMonthlyResponse';
import { MeterDigestSavingsYearlyResponse } from '../model/meterDigestSavingsYearlyResponse';
import { MeterGroupResponse } from '../model/meterGroupResponse';
import { MeterRateResponse } from '../model/meterRateResponse';
import { MeterResponse } from '../model/meterResponse';
import { MeterTemplateResponse } from '../model/meterTemplateResponse';
import { MeterUDFResponse } from '../model/meterUDFResponse';
import { Readings } from '../model/readings';
import { RouteDetailsResponse } from '../model/routeDetailsResponse';
import { RouteMeterChannelLatestReadingResponse } from '../model/routeMeterChannelLatestReadingResponse';
import { RouteResponse } from '../model/routeResponse';
import { SavingsMeterBillDailyResponse } from '../model/savingsMeterBillDailyResponse';
import { SavingsMeterBillResponse } from '../model/savingsMeterBillResponse';
import { SpecialAdjustmentMethod } from '../model/specialAdjustmentMethod';
import { SpecialAdjustmentType } from '../model/specialAdjustmentType';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UtilityPlatformMeter } from '../model/utilityPlatformMeter';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsMetersViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFile(meterId: number, channelId: number, versionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFile(meterId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItems(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCost(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillCostResponse>;
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemand(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDemandResponse>;
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetails(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDetailsResponse>;
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUse(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillUseResponse>;
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistory(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBills(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DistributionVersionResponse>>;
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherData(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterCalendarizedUseVsWeatherResponse>>;
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPoint(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataPointResponse>;
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPoints(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<DataPointResponse>>;
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannel(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelResponse>;
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersion(esaChannelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaChannelVersionResponse>;
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersions(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaChannelVersionResponse>>;
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannels(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaChannelResponse>>;
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaReadingImportProfileResponse>;
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EsaReadingImportProfileResponse>>;
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactors(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GHGFactorsResponse>>;
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeter(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterResponse>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetails(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillSplitParentDetailsResponse>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrend(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestCalendarizedTrendResponse>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestActualAndCalendarizedYearlyResponse>;
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannel(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChannelResponse>;
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannels(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ChannelResponse>>;
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettings(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GHGSettingResponse>;
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroups(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterGroupResponse>>;
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItems(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<GenericBodylineResponse>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestNormalizedMonthlyResponse>;
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestNormalizedMonthlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestNormalizedYearlyResponse>;
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRates(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterRateResponse>>;
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestSavingsMonthlyResponse>;
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestSavingsMonthlyResponse>>;
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearly(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MeterDigestSavingsYearlyResponse>;
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyList(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterDigestSavingsYearlyResponse>>;
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplates(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterTemplateResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfs(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeters(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterUDFResponse>>;
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadings(channelId: number, beginDate?: Date, endDate?: Date, originalValue?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Readings>;
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRoute(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteResponse>;
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetails(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RouteDetailsResponse>;
    /**
     * Retrieves all routes
     *
     */
    getRoutes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RouteResponse>>;
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReading(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RouteMeterChannelLatestReadingResponse>>;
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeList(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AdjustedCostTypeResponse>>;
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBill(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SavingsMeterBillResponse>;
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDaily(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SavingsMeterBillDailyResponse>;
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillList(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SavingsMeterBillResponse>>;
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTask(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CostAvoidanceTask>;
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasks(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<CostAvoidanceTask>>;
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethods(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecialAdjustmentMethod>>;
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecialAdjustmentType>>;
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMeters(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterResponse>>;
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UtilityPlatformMeter>>;
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFileWithHttpInfo(meterId: number, channelId: number, versionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFileWithHttpInfo(meterId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCostWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillCostResponse>>;
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemandWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDemandResponse>>;
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetailsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDetailsResponse>>;
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUseWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillUseResponse>>;
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistoryWithHttpInfo(accountId: number, meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DistributionVersionResponse>>>;
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherDataWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterCalendarizedUseVsWeatherResponse>>>;
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPointWithHttpInfo(dataPointId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataPointResponse>>;
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPointsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<DataPointResponse>>>;
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannelWithHttpInfo(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelResponse>>;
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersionWithHttpInfo(esaChannelId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaChannelVersionResponse>>;
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersionsWithHttpInfo(esaChannelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaChannelVersionResponse>>>;
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannelsWithHttpInfo(filter?: string, orderBy?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaChannelResponse>>>;
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaReadingImportProfileResponse>>;
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EsaReadingImportProfileResponse>>>;
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactorsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GHGFactorsResponse>>>;
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeterWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterResponse>>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetailsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillSplitParentDetailsResponse>>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrendWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestCalendarizedTrendResponse>>;
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestActualAndCalendarizedYearlyResponse>>;
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestActualAndCalendarizedYearlyResponse>>>;
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannelWithHttpInfo(meterId: number, channelId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChannelResponse>>;
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannelsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ChannelResponse>>>;
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettingsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GHGSettingResponse>>;
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroupsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterGroupResponse>>>;
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItemsWithHttpInfo(accountId: number, meterId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<GenericBodylineResponse>>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestNormalizedMonthlyResponse>>;
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestNormalizedMonthlyResponse>>>;
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestNormalizedYearlyResponse>>;
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestNormalizedYearlyResponse>>>;
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRatesWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterRateResponse>>>;
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestSavingsMonthlyResponse>>;
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestSavingsMonthlyResponse>>>;
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearlyWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MeterDigestSavingsYearlyResponse>>;
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyListWithHttpInfo(numberOfYears?: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterDigestSavingsYearlyResponse>>>;
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplatesWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterTemplateResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfsWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterUDFResponse>>>;
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadingsWithHttpInfo(channelId: number, beginDate?: Date, endDate?: Date, originalValue?: boolean, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Readings>>;
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRouteWithHttpInfo(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteResponse>>;
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetailsWithHttpInfo(id: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RouteDetailsResponse>>;
    /**
     * Retrieves all routes
     *
     */
    getRoutesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RouteResponse>>>;
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReadingWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RouteMeterChannelLatestReadingResponse>>>;
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeListWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AdjustedCostTypeResponse>>>;
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillWithHttpInfo(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SavingsMeterBillResponse>>;
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDailyWithHttpInfo(meterId: number, billId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SavingsMeterBillDailyResponse>>;
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillListWithHttpInfo(meterId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SavingsMeterBillResponse>>>;
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTaskWithHttpInfo(taskId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CostAvoidanceTask>>;
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasksWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<CostAvoidanceTask>>>;
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethodsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecialAdjustmentMethod>>>;
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecialAdjustmentType>>>;
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMetersWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterResponse>>>;
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UtilityPlatformMeter>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsMetersViewspanService>;
}
