import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BillActionMove } from '../model/billActionMove';
import { BillActionMoveList } from '../model/billActionMoveList';
import { ListIds } from '../model/listIds';
import { MoveBillsDestination } from '../model/moveBillsDestination';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccounts(body?: ListIds, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MoveBillsDestination>;
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountList(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MoveBillsDestination>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForList(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MoveBillsDestination>;
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccount(body?: BillActionMove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountList(accountId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromList(listId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccountsWithHttpInfo(body?: ListIds, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MoveBillsDestination>>;
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountListWithHttpInfo(accountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MoveBillsDestination>>;
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForListWithHttpInfo(listId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MoveBillsDestination>>;
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccountWithHttpInfo(body?: BillActionMove, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountListWithHttpInfo(accountId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromListWithHttpInfo(listId: number, body?: BillActionMoveList, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService>;
}
