import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { RateEdit } from '../model/rateEdit';
import { RateResponse } from '../model/rateResponse';
import { RateVersionRequest } from '../model/rateVersionRequest';
import { RateVersionResponse } from '../model/rateVersionResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a rate schedule version
     * Allows the user to create a new version for a rate schedule for use in chargeback scenarios where use or demand cost for calculated bills must be created from a predefined unit cost.            ### Validation          * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Inserting a rate version before an existing version will set the new version&#39;s end date to the effective date of the subsequent version.  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule to receive the new version
     * @param body The properties of the rate schedule version to be created
     */
    createRateVersion(rateId: number, body?: RateVersionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RateVersionResponse>;
    /**
     * Delete a version of a rate schedule
     * ### Validation  * The last remaining rate version may not be deleted    ### Other Remarks  * When a rate version is deleted, if there is a preceding rate version, then its end date will be reset to the end date of the deleted rate version.
     * @param rateId Unique identifier of the rate schedule to which the version being deleted belongs
     * @param versionId Unique identifier of the rate schedule version to delete
     */
    deleteRateVersion(rateId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a rate
     *
     * @param rateId Unique identifier of the rate schedule to be edited
     * @param body Updated properties of the rate schedule to be edited
     */
    editRate(rateId: number, body?: RateEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RateResponse>;
    /**
     * Edit a rate schedule version
     * ### Validation  * Effective date of the edited version      * Must be after the effective date of the previous version      * Must be prior to the effective date of the next version  * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule whose version will be edited
     * @param versionId Unique identifier of the rate schedule version to be edited
     * @param body Updated properties of the rate schedule version to be edited
     */
    editRateVersion(rateId: number, versionId: number, body?: RateVersionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RateVersionResponse>;
    /**
     * Create a rate schedule version
     * Allows the user to create a new version for a rate schedule for use in chargeback scenarios where use or demand cost for calculated bills must be created from a predefined unit cost.            ### Validation          * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Inserting a rate version before an existing version will set the new version&#39;s end date to the effective date of the subsequent version.  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule to receive the new version
     * @param body The properties of the rate schedule version to be created
     */
    createRateVersionWithHttpInfo(rateId: number, body?: RateVersionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RateVersionResponse>>;
    /**
     * Delete a version of a rate schedule
     * ### Validation  * The last remaining rate version may not be deleted    ### Other Remarks  * When a rate version is deleted, if there is a preceding rate version, then its end date will be reset to the end date of the deleted rate version.
     * @param rateId Unique identifier of the rate schedule to which the version being deleted belongs
     * @param versionId Unique identifier of the rate schedule version to delete
     */
    deleteRateVersionWithHttpInfo(rateId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a rate
     *
     * @param rateId Unique identifier of the rate schedule to be edited
     * @param body Updated properties of the rate schedule to be edited
     */
    editRateWithHttpInfo(rateId: number, body?: RateEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RateResponse>>;
    /**
     * Edit a rate schedule version
     * ### Validation  * Effective date of the edited version      * Must be after the effective date of the previous version      * Must be prior to the effective date of the next version  * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule whose version will be edited
     * @param versionId Unique identifier of the rate schedule version to be edited
     * @param body Updated properties of the rate schedule version to be edited
     */
    editRateVersionWithHttpInfo(rateId: number, versionId: number, body?: RateVersionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RateVersionResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService>;
}
