import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { EmissionRecordResponse } from '../model/emissionRecordResponse';
import { ListResponse } from '../model/listResponse';
import { RecordImportProfileResponse } from '../model/recordImportProfileResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordList(collectionId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExport(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordList(emissionSourceId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ListResponse>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExport(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecord(emissionRecordId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EmissionRecordResponse>;
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecords(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EmissionRecordResponse>>;
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfile(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RecordImportProfileResponse>;
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfiles(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RecordImportProfileResponse>>;
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordListWithHttpInfo(collectionId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExportWithHttpInfo(collectionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordListWithHttpInfo(emissionSourceId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ListResponse>>;
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExportWithHttpInfo(emissionSourceId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecordWithHttpInfo(emissionRecordId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EmissionRecordResponse>>;
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecordsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EmissionRecordResponse>>>;
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfileWithHttpInfo(profileId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RecordImportProfileResponse>>;
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfilesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RecordImportProfileResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService>;
}
