import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DistributedReportsConfiguration } from '../model/distributedReportsConfiguration';
import { FilterEdit } from '../model/filterEdit';
import { FilterResponse } from '../model/filterResponse';
import { QuickReport } from '../model/quickReport';
import { ReportCreate } from '../model/reportCreate';
import { ReportEdit } from '../model/reportEdit';
import { ReportSubscriptionRequest } from '../model/reportSubscriptionRequest';
import { ReportSubscriptionScheduleTypeResponse } from '../model/reportSubscriptionScheduleTypeResponse';
import { ShareRequest } from '../model/shareRequest';
import { ShareResponse } from '../model/shareResponse';
import { SpecificReportResponse } from '../model/specificReportResponse';
import { ToggleVisible } from '../model/toggleVisible';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsReportsRunspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Subscribe to a report and receive scheduled emails  This must be a saved report that belongs to or is shared with the current user  Only SSRS reports are supported
     *
     * @param specificReportId
     * @param body
     */
    createReportSubscription(specificReportId: number, body?: ReportSubscriptionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificReportResponse>;
    /**
     * Save a specific report to Saved Reports
     *
     * @param specificReportId The specific report to save
     * @param body The specific report create properties
     */
    createSpecificReport(specificReportId: number, body?: ReportCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificReportResponse>;
    /**
     * Delete a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     */
    deleteReportSubscription(specificReportId: number, reportSubscriptionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     *
     *
     * @param specificReportId
     */
    deleteSpecificReport(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Execute a report, save it in a given format, and email it to a list of recipients.   If distributing reports, returns a 204 No Content if onlySendIfData is set to True and the report generated no data;   returns a 200 and the generated report for download or an empty body if onlySendIfData is set to True
     *
     * @param specificReportId The ID of the specific report to run
     * @param body Allows the user to run one report and optionally email it to one or more recipients. They can optionally specify whether or not the report(s) should be sent if they contain no data.
     */
    distributeReport(specificReportId: number, body?: DistributedReportsConfiguration, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be edited
     * @param body The list of filters to apply
     */
    editReportFilters(specificReportId: number, body?: Array<FilterEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Edit a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     * @param body
     */
    editReportSubscription(specificReportId: number, reportSubscriptionId: number, body?: ReportSubscriptionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificReportResponse>;
    /**
     * Edit a specific report
     *
     * @param specificReportId The specific report to edit
     * @param body The specific report edit properties
     */
    editSpecificReport(specificReportId: number, body?: ReportEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificReportResponse>;
    /**
     * Get the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be retrieved
     */
    getReportFilters(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<FilterResponse>>;
    /**
     * Get sharing information for a report
     * Only the user who created the report or a report administrator is permitted to get sharing details for a report.
     * @param specificReportId The specific report for which to retrieve sharing information
     */
    getReportSharingDetails(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ShareResponse>;
    /**
     * Get a list of all available report subscription schedule types, and their day indicator values
     *
     */
    getReportSubscriptionScheduleTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<ReportSubscriptionScheduleTypeResponse>>;
    /**
     * Get a report by its specificReportID.
     *
     * @param specificReportId
     */
    getSpecificReport(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificReportResponse>;
    /**
     * Get a filterable list of installed, saved, and shared reports available to the current user.
     *
     * @param filter
     */
    getSpecificReports(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<SpecificReportResponse>>;
    /**
     * Execute and email report subscriptions that are ready to be run
     *
     */
    processReportSubscriptions(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Generates a \&quot;quick report\&quot; in the specified export format (or in its preferred export format if not specified) as identified by the provided report code and applying ONLY the filters supplied.
     *
     * @param body
     */
    runQuickReport(body?: QuickReport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Run a report and download in the provided format
     *
     * @param specificReportId The ID of the specific report to run
     * @param format The format in which the generated report should be downloaded. Supported options are [\&quot;excel\&quot;, \&quot;csv\&quot;, \&quot;pdf\&quot;, \&quot;word\&quot;]
     */
    runReport(specificReportId: number, format?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Share a saved report with other users
     *
     * @param specificReportId ID of the saved report to share
     * @param body Updated sharing details for the report
     */
    shareSavedReport(specificReportId: number, body?: ShareRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ShareResponse>;
    /**
     * Update the visibility of a report for the current user  This must be a report you can see  Which means you must have created the report  or have ReportAdministrator Manage permission and the report is shared at all  or have SharedReports View permission and the report is shared with you
     *
     * @param specificReportId Specific dashboard
     * @param body Set Visibility
     */
    toggleSharedReportVisibility(specificReportId: number, body?: ToggleVisible, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecificReportResponse>;
    /**
     * Subscribe to a report and receive scheduled emails  This must be a saved report that belongs to or is shared with the current user  Only SSRS reports are supported
     *
     * @param specificReportId
     * @param body
     */
    createReportSubscriptionWithHttpInfo(specificReportId: number, body?: ReportSubscriptionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificReportResponse>>;
    /**
     * Save a specific report to Saved Reports
     *
     * @param specificReportId The specific report to save
     * @param body The specific report create properties
     */
    createSpecificReportWithHttpInfo(specificReportId: number, body?: ReportCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificReportResponse>>;
    /**
     * Delete a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     */
    deleteReportSubscriptionWithHttpInfo(specificReportId: number, reportSubscriptionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     *
     *
     * @param specificReportId
     */
    deleteSpecificReportWithHttpInfo(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Execute a report, save it in a given format, and email it to a list of recipients.   If distributing reports, returns a 204 No Content if onlySendIfData is set to True and the report generated no data;   returns a 200 and the generated report for download or an empty body if onlySendIfData is set to True
     *
     * @param specificReportId The ID of the specific report to run
     * @param body Allows the user to run one report and optionally email it to one or more recipients. They can optionally specify whether or not the report(s) should be sent if they contain no data.
     */
    distributeReportWithHttpInfo(specificReportId: number, body?: DistributedReportsConfiguration, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be edited
     * @param body The list of filters to apply
     */
    editReportFiltersWithHttpInfo(specificReportId: number, body?: Array<FilterEdit>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Edit a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     * @param body
     */
    editReportSubscriptionWithHttpInfo(specificReportId: number, reportSubscriptionId: number, body?: ReportSubscriptionRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificReportResponse>>;
    /**
     * Edit a specific report
     *
     * @param specificReportId The specific report to edit
     * @param body The specific report edit properties
     */
    editSpecificReportWithHttpInfo(specificReportId: number, body?: ReportEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificReportResponse>>;
    /**
     * Get the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be retrieved
     */
    getReportFiltersWithHttpInfo(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<FilterResponse>>>;
    /**
     * Get sharing information for a report
     * Only the user who created the report or a report administrator is permitted to get sharing details for a report.
     * @param specificReportId The specific report for which to retrieve sharing information
     */
    getReportSharingDetailsWithHttpInfo(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ShareResponse>>;
    /**
     * Get a list of all available report subscription schedule types, and their day indicator values
     *
     */
    getReportSubscriptionScheduleTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<ReportSubscriptionScheduleTypeResponse>>>;
    /**
     * Get a report by its specificReportID.
     *
     * @param specificReportId
     */
    getSpecificReportWithHttpInfo(specificReportId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificReportResponse>>;
    /**
     * Get a filterable list of installed, saved, and shared reports available to the current user.
     *
     * @param filter
     */
    getSpecificReportsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<SpecificReportResponse>>>;
    /**
     * Execute and email report subscriptions that are ready to be run
     *
     */
    processReportSubscriptionsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Generates a \&quot;quick report\&quot; in the specified export format (or in its preferred export format if not specified) as identified by the provided report code and applying ONLY the filters supplied.
     *
     * @param body
     */
    runQuickReportWithHttpInfo(body?: QuickReport, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Run a report and download in the provided format
     *
     * @param specificReportId The ID of the specific report to run
     * @param format The format in which the generated report should be downloaded. Supported options are [\&quot;excel\&quot;, \&quot;csv\&quot;, \&quot;pdf\&quot;, \&quot;word\&quot;]
     */
    runReportWithHttpInfo(specificReportId: number, format?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Share a saved report with other users
     *
     * @param specificReportId ID of the saved report to share
     * @param body Updated sharing details for the report
     */
    shareSavedReportWithHttpInfo(specificReportId: number, body?: ShareRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ShareResponse>>;
    /**
     * Update the visibility of a report for the current user  This must be a report you can see  Which means you must have created the report  or have ReportAdministrator Manage permission and the report is shared at all  or have SharedReports View permission and the report is shared with you
     *
     * @param specificReportId Specific dashboard
     * @param body Set Visibility
     */
    toggleSharedReportVisibilityWithHttpInfo(specificReportId: number, body?: ToggleVisible, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecificReportResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsReportsRunspanService>;
}
