import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { OtherSavingsCategory } from '../model/otherSavingsCategory';
import { OtherSavingsCategoryRequest } from '../model/otherSavingsCategoryRequest';
import { OtherSavingsRequest } from '../model/otherSavingsRequest';
import { OtherSavingsResponse } from '../model/otherSavingsResponse';
import { SpecialAdjustmentCreate } from '../model/specialAdjustmentCreate';
import { SpecialAdjustmentEdit } from '../model/specialAdjustmentEdit';
import { SpecialAdjustmentResponse } from '../model/specialAdjustmentResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavings(meterId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsResponse>;
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategory(body?: OtherSavingsCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsCategory>;
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustment(meterId: number, body?: SpecialAdjustmentCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecialAdjustmentResponse>;
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavings(meterId: number, otherSavingsId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentById(meterId: number, specialAdjustmentId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavings(meterId: number, otherSavingsId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<OtherSavingsResponse>;
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustment(meterId: number, specialAdjustmentId: number, body?: SpecialAdjustmentEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<SpecialAdjustmentResponse>;
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavingsWithHttpInfo(meterId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsResponse>>;
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategoryWithHttpInfo(body?: OtherSavingsCategoryRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsCategory>>;
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustmentWithHttpInfo(meterId: number, body?: SpecialAdjustmentCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecialAdjustmentResponse>>;
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavingsWithHttpInfo(meterId: number, otherSavingsId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentByIdWithHttpInfo(meterId: number, specialAdjustmentId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavingsWithHttpInfo(meterId: number, otherSavingsId: number, body?: OtherSavingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<OtherSavingsResponse>>;
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustmentWithHttpInfo(meterId: number, specialAdjustmentId: number, body?: SpecialAdjustmentEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<SpecialAdjustmentResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService>;
}
