import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { NotificationSettingsResponse } from '../model/notificationSettingsResponse';
import { NotificationSystemSettingsRequest } from '../model/notificationSystemSettingsRequest';
import { UserCreateRequest } from '../model/userCreateRequest';
import { UserEditRequest } from '../model/userEditRequest';
import { UserGroupRequest } from '../model/userGroupRequest';
import { UserGroupResponse } from '../model/userGroupResponse';
import { UserResponse } from '../model/userResponse';
import { UserRoleRequest } from '../model/userRoleRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUser(body?: UserCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroup(body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserGroupResponse>;
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroup(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRole(userId: number, body?: UserRoleRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUser(userId: number, body?: UserEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroup(userGroupId: number, body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserGroupResponse>;
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettings(body?: NotificationSystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<NotificationSettingsResponse>;
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUserWithHttpInfo(body?: UserCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroupWithHttpInfo(body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserGroupResponse>>;
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroupWithHttpInfo(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRoleWithHttpInfo(userId: number, body?: UserRoleRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUserWithHttpInfo(userId: number, body?: UserEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroupWithHttpInfo(userGroupId: number, body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserGroupResponse>>;
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettingsWithHttpInfo(body?: NotificationSystemSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<NotificationSettingsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService>;
}
