import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CommodityDigestActualYearlyResponse } from '../model/commodityDigestActualYearlyResponse';
import { RateDigestActualYearlyResponse } from '../model/rateDigestActualYearlyResponse';
import { RateResponse } from '../model/rateResponse';
import { RateVersionResponse } from '../model/rateVersionResponse';
import { TemplateVersion } from '../model/templateVersion';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UnitResponse } from '../model/unitResponse';
import { VendorContractResponse } from '../model/vendorContractResponse';
import { VendorDigestActualYearlyResponse } from '../model/vendorDigestActualYearlyResponse';
import { VendorResponse } from '../model/vendorResponse';
import { VendorUDFResponse } from '../model/vendorUDFResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Download file for a rate custom field
     *
     * @param rateId
     * @param versionId
     * @param udfId
     */
    downloadRateCustomFieldFile(rateId: number, versionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFile(vendorId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves rolled up actual billing data by commodities for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param commodityId The commodity to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getCommodityActualYearly(commodityId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CommodityDigestActualYearlyResponse>;
    /**
     * Get a rate schedule
     *
     * @param rateId Unique ID of the rate schedule
     */
    getRate(rateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RateResponse>;
    /**
     * Retrieves rolled up actual billing data by rate for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param rateId The rate to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getRateActualYearly(rateId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RateDigestActualYearlyResponse>;
    /**
     * Get the unit used by a rate. The unit is determined by the usage unit on the most recent template assigned to a meter with the given rate.
     *
     * @param rateId Unique identifier of the rate schedule for which the unit will be retrieved
     */
    getRateUnit(rateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UnitResponse>;
    /**
     * Get a rate version with its details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     * @param versionId ID of the rate schedule version to retrieve
     */
    getRateVersion(rateId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RateVersionResponse>;
    /**
     * Get a list of all versions for a rate schedule with their details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     */
    getRateVersions(rateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RateVersionResponse>>;
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRates(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<RateResponse>>;
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendor(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorResponse>;
    /**
     * Retrieves rolled up actual billing data by vendor for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param vendorId The vendor to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getVendorActualYearly(vendorId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorDigestActualYearlyResponse>;
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContracts(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<VendorContractResponse>>;
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplate(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateVersion>;
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfs(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendors(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<VendorResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<VendorUDFResponse>>;
    /**
     * Download file for a rate custom field
     *
     * @param rateId
     * @param versionId
     * @param udfId
     */
    downloadRateCustomFieldFileWithHttpInfo(rateId: number, versionId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFileWithHttpInfo(vendorId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves rolled up actual billing data by commodities for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param commodityId The commodity to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getCommodityActualYearlyWithHttpInfo(commodityId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CommodityDigestActualYearlyResponse>>;
    /**
     * Get a rate schedule
     *
     * @param rateId Unique ID of the rate schedule
     */
    getRateWithHttpInfo(rateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RateResponse>>;
    /**
     * Retrieves rolled up actual billing data by rate for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param rateId The rate to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getRateActualYearlyWithHttpInfo(rateId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RateDigestActualYearlyResponse>>;
    /**
     * Get the unit used by a rate. The unit is determined by the usage unit on the most recent template assigned to a meter with the given rate.
     *
     * @param rateId Unique identifier of the rate schedule for which the unit will be retrieved
     */
    getRateUnitWithHttpInfo(rateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UnitResponse>>;
    /**
     * Get a rate version with its details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     * @param versionId ID of the rate schedule version to retrieve
     */
    getRateVersionWithHttpInfo(rateId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RateVersionResponse>>;
    /**
     * Get a list of all versions for a rate schedule with their details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     */
    getRateVersionsWithHttpInfo(rateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RateVersionResponse>>>;
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRatesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<RateResponse>>>;
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendorWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorResponse>>;
    /**
     * Retrieves rolled up actual billing data by vendor for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param vendorId The vendor to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getVendorActualYearlyWithHttpInfo(vendorId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorDigestActualYearlyResponse>>;
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContractsWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<VendorContractResponse>>>;
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplateWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateVersion>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfsWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<VendorResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<VendorUDFResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService>;
}
