import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { TemplateVendorLineRequest } from '../model/templateVendorLineRequest';
import { TemplateVersion } from '../model/templateVersion';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { VendorRequest } from '../model/vendorRequest';
import { VendorResponse } from '../model/vendorResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplate(sourceVendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendor(vendorId: number, body?: VendorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorResponse>;
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFs(vendorId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplate(vendorId: number, body?: Array<TemplateVendorLineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateVersion>;
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplateWithHttpInfo(sourceVendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendorWithHttpInfo(vendorId: number, body?: VendorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorResponse>>;
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFsWithHttpInfo(vendorId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplateWithHttpInfo(vendorId: number, body?: Array<TemplateVendorLineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateVersion>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService>;
}
