import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { GenericCount } from '../model/genericCount';
import { LinkSubAccountsRequest } from '../model/linkSubAccountsRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SummaryAccountService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccounts(summaryAccountId: number, body?: LinkSubAccountsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GenericCount>;
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccount(summaryAccountId: number, subAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccounts(summaryAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccountsWithHttpInfo(summaryAccountId: number, body?: LinkSubAccountsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GenericCount>>;
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccountWithHttpInfo(summaryAccountId: number, subAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccountsWithHttpInfo(summaryAccountId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SummaryAccountService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SummaryAccountService>;
}
