import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { UserCreateRequest } from '../model/userCreateRequest';
import { UserEditRequest } from '../model/userEditRequest';
import { UserResponse } from '../model/userResponse';
import { UserRoleRequest } from '../model/userRoleRequest';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class SystemUserService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUser(body?: UserCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRole(userId: number, body?: UserRoleRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUser(userId: number, body?: UserEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Return a specific user and its properties. Requires View permission for Users &amp; Roles
     *
     * @param userId The ID of the user to return
     */
    getUser(userId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserResponse>;
    /**
     * Gets a list of users.  Requires View permission for Users &amp; Roles.   If this permission is not available, restricted set of properties are returned.
     *
     * @param filter
     */
    getUsers(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UserResponse>>;
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUserWithHttpInfo(body?: UserCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRoleWithHttpInfo(userId: number, body?: UserRoleRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUserWithHttpInfo(userId: number, body?: UserEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Return a specific user and its properties. Requires View permission for Users &amp; Roles
     *
     * @param userId The ID of the user to return
     */
    getUserWithHttpInfo(userId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserResponse>>;
    /**
     * Gets a list of users.  Requires View permission for Users &amp; Roles.   If this permission is not available, restricted set of properties are returned.
     *
     * @param filter
     */
    getUsersWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UserResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SystemUserService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SystemUserService>;
}
