import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { TaskEdit } from '../model/taskEdit';
import { TaskResponse } from '../model/taskResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class TaskService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Edits the note/comment associated with a task
     *
     * @param taskId The identifier for the task being edited
     * @param body Data representing the note
     */
    editTask(taskId: number, body?: TaskEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TaskResponse>;
    /**
     * Retrieves a task by its GUID. The output property could potentially contain a large amount of data. If response time or size becomes an issue, use field reduction to eliminate the output field.
     *
     * @param taskGuid The GUID of the task
     */
    getTask(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TaskResponse>;
    /**
     * Retrieves a task&#39;s error log as an EXCEL file by its GUID.  At this time error logs can be downloaded for \&quot;ReadingImport\&quot; task type only
     *
     * @param taskGuid The GUID of the task
     */
    getTaskOutputFile(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Retrieves a list of tasks
     *
     * @param taskTypeCode Task type code. Acceptable values are:       AuditGroup,       CostAvoidance,      Report,      Chargeback,      SetupSheet,      UnitsOfMeasure,      Accrual,      BillImport,       EnergyStar,      BillExport,      ReadingImport,      SummarizeReading,      BillUnexport,      V7CostAvoidance,      V7Accrual,      Budget      CostUnitUpdate,      RecordImportPfl,      EsaReadingImpPfl,      RecordImport  *This combines record import setup sheet tasks and record import with a profile tasks,      EsaReadingImport  *This combines Esa readings import setup sheet tasks and Esa Reading import with a profile tasks
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTasks(taskTypeCode?: string, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<TaskResponse>>;
    /**
     * Edits the note/comment associated with a task
     *
     * @param taskId The identifier for the task being edited
     * @param body Data representing the note
     */
    editTaskWithHttpInfo(taskId: number, body?: TaskEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TaskResponse>>;
    /**
     * Retrieves a task by its GUID. The output property could potentially contain a large amount of data. If response time or size becomes an issue, use field reduction to eliminate the output field.
     *
     * @param taskGuid The GUID of the task
     */
    getTaskWithHttpInfo(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TaskResponse>>;
    /**
     * Retrieves a task&#39;s error log as an EXCEL file by its GUID.  At this time error logs can be downloaded for \&quot;ReadingImport\&quot; task type only
     *
     * @param taskGuid The GUID of the task
     */
    getTaskOutputFileWithHttpInfo(taskGuid: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Retrieves a list of tasks
     *
     * @param taskTypeCode Task type code. Acceptable values are:       AuditGroup,       CostAvoidance,      Report,      Chargeback,      SetupSheet,      UnitsOfMeasure,      Accrual,      BillImport,       EnergyStar,      BillExport,      ReadingImport,      SummarizeReading,      BillUnexport,      V7CostAvoidance,      V7Accrual,      Budget      CostUnitUpdate,      RecordImportPfl,      EsaReadingImpPfl,      RecordImport  *This combines record import setup sheet tasks and record import with a profile tasks,      EsaReadingImport  *This combines Esa readings import setup sheet tasks and Esa Reading import with a profile tasks
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTasksWithHttpInfo(taskTypeCode?: string, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<TaskResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TaskService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TaskService>;
}
