import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CreateTemplateFromBill } from '../model/createTemplateFromBill';
import { TemplateResponse } from '../model/templateResponse';
import { TemplateVersion } from '../model/templateVersion';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class TemplateService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBill(billId: number, accountId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateResponse>;
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBill(billId: number, meterId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateResponse>;
    /**
     * Retrieves one template
     *
     * @param templateId The template identifier for the template being retrieved
     */
    getTemplate(templateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateResponse>;
    /**
     * Retrieves one template version for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     * @param versionId The identifier for the template version being retrieved
     */
    getTemplateVersion(templateId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateVersion>;
    /**
     * Retrieves all template versions for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     */
    getTemplateVersions(templateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<TemplateVersion>>;
    /**
     * Retrieves all templates
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTemplates(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<TemplateResponse>>;
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplate(templateId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBillWithHttpInfo(billId: number, accountId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateResponse>>;
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBillWithHttpInfo(billId: number, meterId: number, body?: CreateTemplateFromBill, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateResponse>>;
    /**
     * Retrieves one template
     *
     * @param templateId The template identifier for the template being retrieved
     */
    getTemplateWithHttpInfo(templateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateResponse>>;
    /**
     * Retrieves one template version for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     * @param versionId The identifier for the template version being retrieved
     */
    getTemplateVersionWithHttpInfo(templateId: number, versionId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateVersion>>;
    /**
     * Retrieves all template versions for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     */
    getTemplateVersionsWithHttpInfo(templateId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<TemplateVersion>>>;
    /**
     * Retrieves all templates
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTemplatesWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<TemplateResponse>>>;
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplateWithHttpInfo(templateId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TemplateService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TemplateService>;
}
