import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { UDFCreate } from '../model/uDFCreate';
import { UDFEdit } from '../model/uDFEdit';
import { UDFResponse } from '../model/uDFResponse';
import { UDFUpdate } from '../model/uDFUpdate';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class UDFService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDF(body?: UDFCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UDFResponse>;
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDF(udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFields(udfType: string, body?: Array<UDFUpdate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFResponse>>;
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDF(udfId: number, body?: UDFEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UDFResponse>;
    /**
     * Retrieves one user defined field / custom field
     *
     * @param udfId The user defined field / custom field identifier
     */
    getUDF(udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UDFResponse>;
    /**
     * Retrieves all User defined fields/custom fields.   The array of UDFs can be filtered by UDF type.   Possible values for this filter include: \&quot;Account\&quot;, \&quot;Meter\&quot;, \&quot;Place\&quot;, \&quot;Vendor\&quot;, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;.  See the filter property for more details
     *
     * @param filter
     */
    getUDFs(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFResponse>>;
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDFWithHttpInfo(body?: UDFCreate, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UDFResponse>>;
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDFWithHttpInfo(udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFieldsWithHttpInfo(udfType: string, body?: Array<UDFUpdate>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFResponse>>>;
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDFWithHttpInfo(udfId: number, body?: UDFEdit, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UDFResponse>>;
    /**
     * Retrieves one user defined field / custom field
     *
     * @param udfId The user defined field / custom field identifier
     */
    getUDFWithHttpInfo(udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UDFResponse>>;
    /**
     * Retrieves all User defined fields/custom fields.   The array of UDFs can be filtered by UDF type.   Possible values for this filter include: \&quot;Account\&quot;, \&quot;Meter\&quot;, \&quot;Place\&quot;, \&quot;Vendor\&quot;, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;.  See the filter property for more details
     *
     * @param filter
     */
    getUDFsWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UDFService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UDFService>;
}
