import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { UserChild } from '../model/userChild';
import { UserGroupRequest } from '../model/userGroupRequest';
import { UserGroupResponse } from '../model/userGroupResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class UserGroupService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroup(body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserGroupResponse>;
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroup(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroup(userGroupId: number, body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserGroupResponse>;
    /**
     * Gets a user group
     *
     * @param userGroupId Id of the user group to return
     */
    getUserGroup(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UserGroupResponse>;
    /**
     * Gets a list of user group members
     *
     * @param userGroupId Id of the user group to get the list of members
     */
    getUserGroupMembers(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UserChild>>;
    /**
     * Gets a list of user groups
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUserGroups(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UserGroupResponse>>;
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroupWithHttpInfo(body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserGroupResponse>>;
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroupWithHttpInfo(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroupWithHttpInfo(userGroupId: number, body?: UserGroupRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserGroupResponse>>;
    /**
     * Gets a user group
     *
     * @param userGroupId Id of the user group to return
     */
    getUserGroupWithHttpInfo(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UserGroupResponse>>;
    /**
     * Gets a list of user group members
     *
     * @param userGroupId Id of the user group to get the list of members
     */
    getUserGroupMembersWithHttpInfo(userGroupId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UserChild>>>;
    /**
     * Gets a list of user groups
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUserGroupsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UserGroupResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UserGroupService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UserGroupService>;
}
