import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AddressLookup } from '../model/addressLookup';
import { CalculatedBillDetailsResponse } from '../model/calculatedBillDetailsResponse';
import { ChargebackProcessorSettingsForAggregations } from '../model/chargebackProcessorSettingsForAggregations';
import { ChargebackTaskResponse } from '../model/chargebackTaskResponse';
import { CreateUtilityPlatformMeter } from '../model/createUtilityPlatformMeter';
import { DataAccessRelease } from '../model/dataAccessRelease';
import { DataAccessReleaseNoFileRequest } from '../model/dataAccessReleaseNoFileRequest';
import { DataAccessReleaseRequest } from '../model/dataAccessReleaseRequest';
import { DataAccessReleaseState } from '../model/dataAccessReleaseState';
import { MeterSearchRequest } from '../model/meterSearchRequest';
import { MoveCreateMeter } from '../model/moveCreateMeter';
import { SendDataAccessReleaseRequest } from '../model/sendDataAccessReleaseRequest';
import { UpsertAggregateMeterRequest } from '../model/upsertAggregateMeterRequest';
import { UtilityPlatformMeter } from '../model/utilityPlatformMeter';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class UtilityPlatformService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Apply a release to a meter
     *
     * @param meterId The id of the meter
     * @param body
     */
    assignDataAccessRelease(meterId: number, body?: DataAccessReleaseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataAccessReleaseState>;
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlace(placeId: number, body?: Array<CreateUtilityPlatformMeter>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UtilityPlatformMeter>>;
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregations(body?: ChargebackProcessorSettingsForAggregations, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackTaskResponse>;
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetails(dataAccessReleaseId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataAccessRelease>;
    /**
     * Get the status of a meter&#39;s data access release
     *
     * @param meterId The meter to get release state for
     */
    getDataAccessReleaseState(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<DataAccessReleaseState>;
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlace(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UtilityPlatformMeter>>;
    /**
     * Release all account and meters to a specific place
     *
     * @param placeId The id of the place for the released meters
     * @param body
     */
    releaseAccountAndAllMeterToABuilding(placeId: number, body?: DataAccessReleaseNoFileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMeters(pageSize?: number, pageNumber?: number, body?: MeterSearchRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MoveCreateMeter>>;
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddresses(address?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<AddressLookup>>;
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmail(meterId: number, body?: SendDataAccessReleaseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeter(placeId: number, body?: UpsertAggregateMeterRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<CalculatedBillDetailsResponse>;
    /**
     * Apply a release to a meter
     *
     * @param meterId The id of the meter
     * @param body
     */
    assignDataAccessReleaseWithHttpInfo(meterId: number, body?: DataAccessReleaseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataAccessReleaseState>>;
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlaceWithHttpInfo(placeId: number, body?: Array<CreateUtilityPlatformMeter>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UtilityPlatformMeter>>>;
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregationsWithHttpInfo(body?: ChargebackProcessorSettingsForAggregations, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackTaskResponse>>;
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetailsWithHttpInfo(dataAccessReleaseId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataAccessRelease>>;
    /**
     * Get the status of a meter&#39;s data access release
     *
     * @param meterId The meter to get release state for
     */
    getDataAccessReleaseStateWithHttpInfo(meterId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<DataAccessReleaseState>>;
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlaceWithHttpInfo(placeId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UtilityPlatformMeter>>>;
    /**
     * Release all account and meters to a specific place
     *
     * @param placeId The id of the place for the released meters
     * @param body
     */
    releaseAccountAndAllMeterToABuildingWithHttpInfo(placeId: number, body?: DataAccessReleaseNoFileRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMetersWithHttpInfo(pageSize?: number, pageNumber?: number, body?: MeterSearchRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MoveCreateMeter>>>;
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddressesWithHttpInfo(address?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<AddressLookup>>>;
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmailWithHttpInfo(meterId: number, body?: SendDataAccessReleaseRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeterWithHttpInfo(placeId: number, body?: UpsertAggregateMeterRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<CalculatedBillDetailsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UtilityPlatformService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UtilityPlatformService>;
}
