import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { TemplateVendorLineRequest } from '../model/templateVendorLineRequest';
import { TemplateVersion } from '../model/templateVersion';
import { UDFFieldChild } from '../model/uDFFieldChild';
import { UDFValue } from '../model/uDFValue';
import { UpdatedOnlyResult } from '../model/updatedOnlyResult';
import { VendorAuditEnable } from '../model/vendorAuditEnable';
import { VendorContractResponse } from '../model/vendorContractResponse';
import { VendorRequest } from '../model/vendorRequest';
import { VendorResponse } from '../model/vendorResponse';
import { VendorUDFResponse } from '../model/vendorUDFResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class VendorService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Add accounts to a vendor
     *
     * @param vendorId The identifier for the vendor to which accounts are being added
     * @param body List of accountIds to move a new vendor
     */
    addAccounts(vendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplate(sourceVendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Creates a vendor
     *
     * @param body Data representing the vendor being created
     */
    createVendor(body?: VendorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorResponse>;
    /**
     * Deletes a vendor
     *
     * @param vendorId The identifier for the vendor being deleted
     */
    deleteVendor(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFile(vendorId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendor(vendorId: number, body?: VendorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorResponse>;
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFs(vendorId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendor(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<VendorResponse>;
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContracts(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<VendorContractResponse>>;
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplate(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateVersion>;
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfs(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<UDFFieldChild>>;
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendors(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<VendorResponse>>;
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfs(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<VendorUDFResponse>>;
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplate(vendorId: number, body?: Array<TemplateVendorLineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TemplateVersion>;
    /**
     * Enable or disable all accounts assigned to a vendor from audits
     *
     * @param vendorId The identifier for the vendor to act upon
     * @param body
     */
    setVendorAccountsAuditExclusion(vendorId: number, body?: VendorAuditEnable, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<UpdatedOnlyResult>;
    /**
     * Add accounts to a vendor
     *
     * @param vendorId The identifier for the vendor to which accounts are being added
     * @param body List of accountIds to move a new vendor
     */
    addAccountsWithHttpInfo(vendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplateWithHttpInfo(sourceVendorId: number, body?: Array<number>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Creates a vendor
     *
     * @param body Data representing the vendor being created
     */
    createVendorWithHttpInfo(body?: VendorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorResponse>>;
    /**
     * Deletes a vendor
     *
     * @param vendorId The identifier for the vendor being deleted
     */
    deleteVendorWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFileWithHttpInfo(vendorId: number, udfId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendorWithHttpInfo(vendorId: number, body?: VendorRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorResponse>>;
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFsWithHttpInfo(vendorId: number, body?: Array<UDFValue>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendorWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<VendorResponse>>;
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContractsWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<VendorContractResponse>>>;
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplateWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateVersion>>;
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfsWithHttpInfo(vendorId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<UDFFieldChild>>>;
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<VendorResponse>>>;
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfsWithHttpInfo(filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<VendorUDFResponse>>>;
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplateWithHttpInfo(vendorId: number, body?: Array<TemplateVendorLineRequest>, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TemplateVersion>>;
    /**
     * Enable or disable all accounts assigned to a vendor from audits
     *
     * @param vendorId The identifier for the vendor to act upon
     * @param body
     */
    setVendorAccountsAuditExclusionWithHttpInfo(vendorId: number, body?: VendorAuditEnable, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<UpdatedOnlyResult>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<VendorService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<VendorService>;
}
