import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { WebhookCreateRequest } from '../model/webhookCreateRequest';
import { WebhookEditRequest } from '../model/webhookEditRequest';
import { WebhookEventTypeChild } from '../model/webhookEventTypeChild';
import { WebhookLogDetailsResponse } from '../model/webhookLogDetailsResponse';
import { WebhookLogResponse } from '../model/webhookLogResponse';
import { WebhookResponse } from '../model/webhookResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class WebhookService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhook(body?: WebhookCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookResponse>;
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhook(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThan(olderThanDays?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<any>;
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhook(webhookId: number, body?: WebhookEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookResponse>;
    /**
     * Get a single webhook
     *
     * @param webhookId
     */
    getWebhook(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookResponse>;
    /**
     * Get webhook event types
     *
     */
    getWebhookEventTypes(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<WebhookEventTypeChild>>;
    /**
     * Get details for a webhook log
     *
     * @param webhookId
     * @param webhookLogId
     */
    getWebhookLogDetails(webhookId: number, webhookLogId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WebhookLogDetailsResponse>;
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogs(webhookId: number, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<WebhookLogResponse>>;
    /**
     * Get a list of all webhooks
     *
     * @param filter
     */
    getWebhooks(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<WebhookResponse>>;
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhookWithHttpInfo(body?: WebhookCreateRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookResponse>>;
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhookWithHttpInfo(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThanWithHttpInfo(olderThanDays?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<any>>;
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhookWithHttpInfo(webhookId: number, body?: WebhookEditRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookResponse>>;
    /**
     * Get a single webhook
     *
     * @param webhookId
     */
    getWebhookWithHttpInfo(webhookId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookResponse>>;
    /**
     * Get webhook event types
     *
     */
    getWebhookEventTypesWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<WebhookEventTypeChild>>>;
    /**
     * Get details for a webhook log
     *
     * @param webhookId
     * @param webhookLogId
     */
    getWebhookLogDetailsWithHttpInfo(webhookId: number, webhookLogId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WebhookLogDetailsResponse>>;
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogsWithHttpInfo(webhookId: number, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<WebhookLogResponse>>>;
    /**
     * Get a list of all webhooks
     *
     * @param filter
     */
    getWebhooksWithHttpInfo(filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<WebhookResponse>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<WebhookService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WebhookService>;
}
