import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ActionableBillCounts } from '../model/actionableBillCounts';
import { ActualVsBudgetResponse } from '../model/actualVsBudgetResponse';
import { AggregatedComparisonResponseGHGPerformanceComparison } from '../model/aggregatedComparisonResponseGHGPerformanceComparison';
import { AggregatedItemRankResponse } from '../model/aggregatedItemRankResponse';
import { AggregatedMonthlyCAPTrendResponse } from '../model/aggregatedMonthlyCAPTrendResponse';
import { AggregatedResponseGHGBuildingRank } from '../model/aggregatedResponseGHGBuildingRank';
import { AggregatedResponseItemRankWithUnitResponse } from '../model/aggregatedResponseItemRankWithUnitResponse';
import { BillsOverdueFromVendorResponse } from '../model/billsOverdueFromVendorResponse';
import { EnergyStarPlaceHierarchyResponse } from '../model/energyStarPlaceHierarchyResponse';
import { EsaIntervalDataResponse } from '../model/esaIntervalDataResponse';
import { EsaSentinelPredictionsResponse } from '../model/esaSentinelPredictionsResponse';
import { GHGCarbonFootprintResponse } from '../model/gHGCarbonFootprintResponse';
import { MapWidgetResponse } from '../model/mapWidgetResponse';
import { MeterCost } from '../model/meterCost';
import { MissingBillWidget } from '../model/missingBillWidget';
import { PeriodRangeComparisonDetailed } from '../model/periodRangeComparisonDetailed';
import { PlaceCost } from '../model/placeCost';
import { PlaceDigestActualAndCalendarizedMonthlyResponse } from '../model/placeDigestActualAndCalendarizedMonthlyResponse';
import { PlaceDigestEnergyUseIntensity } from '../model/placeDigestEnergyUseIntensity';
import { PlaceDigestGHGYearlyResponse } from '../model/placeDigestGHGYearlyResponse';
import { Readings } from '../model/readings';
import { RollingComparisonResponse } from '../model/rollingComparisonResponse';
import { TimeSeriesDataResponse } from '../model/timeSeriesDataResponse';
import { TrendDataResponse } from '../model/trendDataResponse';
import { WidgetResponse } from '../model/widgetResponse';
import { WidgetSavingsYearlyResponse } from '../model/widgetSavingsYearlyResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class WidgetService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Retrieves data for cost avoidance by commodity dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    costAvoidanceByCommodity(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WidgetSavingsYearlyResponse>;
    /**
     *
     *
     * @param specificWidgetId
     * @param filter
     */
    executeSprocWidget(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PeriodRangeComparisonDetailed>;
    /**
     * Returns counts of bills Held from Export, bills Waiting for Export to AP, bills Waiting for Export to GL, bills which are Not Approved, bills with unresolved flags,   and bills created in the past seven days.
     *
     * @param specificWidgetId Identifier for a specific Bill Status widget on a dashboard
     * @param filter Filter string which may add to or override saved filter values during this request
     */
    getActionableBillCounts(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ActionableBillCounts>;
    /**
     * Gets the actual vs budget widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getActualVsBudget(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ActualVsBudgetResponse>;
    /**
     * Retrieves data about bills that have not yet been received from vendors.  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsOverdueFromVendor(specificWidgetId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<BillsOverdueFromVendorResponse>>;
    /**
     * Retrieves the carbon footprint data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprint(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestGHGYearlyResponse>;
    /**
     * Retrieves yearly Carbon Emissions data that is split by year, then by Gas Type and one of the following group types:  ( Scope, Scope Category, Commodity ). Also includes target data, if target comparisons are enabled and set.
     *
     * @param specificWidgetId Specific Widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprintData(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<GHGCarbonFootprintResponse>;
    /**
     * Retrieves data for commodity cost dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCommodityCost(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<PlaceDigestActualAndCalendarizedMonthlyResponse>;
    /**
     * Returns Cost Avoidance Savings Program-to-date. The user can set the topmost place and/or commodity filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCostAvoidanceProgramSavings(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WidgetSavingsYearlyResponse>;
    /**
     * Retrieves a list of buildings for the Multiple ENERGY STAR Buildings widget.  The widget is expecting zero, one, or many buildings, and alters its layout based on how many results it receives.    Validation:  - The provided specific widget must exist  - The provided specific widget must be an Multiple ENERGY STAR Buildings widget
     *
     * @param specificWidgetId Identifier for a specific ENERGY STAR widget on a dashboard
     * @param numberOfYears Only used when a single building is returned. The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     * @param filter Filter string which may add to or override saved filter values during this request
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarMultipleBuildings(specificWidgetId: number, numberOfYears?: number, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<EnergyStarPlaceHierarchyResponse>>;
    /**
     * Retrieves ENERGY STAR place score history for a building    Validation:  - The provided specific widget must exist  - The provided specific widget must be an ENERGY STAR Single Building widget
     *
     * @param specificWidgetId Identifier for a specific Single ENERGY STAR Building widget on a dashboard
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarSingleBuilding(specificWidgetId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EnergyStarPlaceHierarchyResponse>;
    /**
     * Returns data for the ESA demand interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaDemandIntervalDataWidget(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaIntervalDataResponse>;
    /**
     * Returns data for the esa interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaIntervalDataWidget(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaIntervalDataResponse>;
    /**
     * Retrieve Trend Insights (previously \&quot;ESA Sentinel\&quot;) readings and predictions for a Channel.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getEsaSentinelWidget(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<EsaSentinelPredictionsResponse>;
    /**
     * Retrieves energy use intensity data for a specific widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter API filters
     */
    getEuiChartWidgetData(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceDigestEnergyUseIntensity>>;
    /**
     * Get building rank by GHG emissions or intensity.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGBuildingRank(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AggregatedResponseGHGBuildingRank>;
    /**
     * Gets the greenhouse gas performance by commodity, scope or scope category.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGPerformance(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AggregatedComparisonResponseGHGPerformanceComparison>;
    /**
     * Get ranking by GHG emissions.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGRanking(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AggregatedResponseItemRankWithUnitResponse>;
    /**
     * Retrieves interval data for a specific widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     */
    getIntervalData(specificWidgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<Readings>>;
    /**
     * Gets the bar rank and tree map widgets.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getItemRank(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AggregatedItemRankResponse>;
    /**
     * Retrieves map data for a specific map widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     */
    getMapWidget(specificWidgetId: number, chartMonthsToExclude?: number, numMonths?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<MapWidgetResponse>;
    /**
     * Returns gaps in billing data for a date range specified by the  Bill Date Range filter.   A gap is defined as at least one day that falls within the account&#39;s service dates and   not included in any bill for that account meter.  The Allowable Gap Days filter specifies the number of days that must be in the gap  before it will be included in the results.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMissingBills(specificWidgetId: number, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MissingBillWidget>>;
    /**
     * Gets data for the Monthly Cost Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyCostTrend(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TimeSeriesDataResponse>;
    /**
     * Returns data for the monthly trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getMonthlyTrend(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TrendDataResponse>;
    /**
     * Gets data for the Monthly Use Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyUseTrend(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<TimeSeriesDataResponse>;
    /**
     * Retrieves the most expensive building data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveBuildings(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<PlaceCost>>;
    /**
     * Retrieves the most expensive meters data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveMeters(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<MeterCost>>;
    /**
     * Retrieves data for the Rolling Monthly Comparison Widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getRollingComparison(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<RollingComparisonResponse>;
    /**
     * Retrieves an array of widgets.
     *
     */
    getWidgets(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<Array<WidgetResponse>>;
    /**
     * Returns data for the monthly savings trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    monthlyCAPTrend(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<AggregatedMonthlyCAPTrendResponse>;
    /**
     * Retrieves data for cost avoidance by commodity dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    costAvoidanceByCommodityWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WidgetSavingsYearlyResponse>>;
    /**
     *
     *
     * @param specificWidgetId
     * @param filter
     */
    executeSprocWidgetWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PeriodRangeComparisonDetailed>>;
    /**
     * Returns counts of bills Held from Export, bills Waiting for Export to AP, bills Waiting for Export to GL, bills which are Not Approved, bills with unresolved flags,   and bills created in the past seven days.
     *
     * @param specificWidgetId Identifier for a specific Bill Status widget on a dashboard
     * @param filter Filter string which may add to or override saved filter values during this request
     */
    getActionableBillCountsWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ActionableBillCounts>>;
    /**
     * Gets the actual vs budget widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getActualVsBudgetWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ActualVsBudgetResponse>>;
    /**
     * Retrieves data about bills that have not yet been received from vendors.  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsOverdueFromVendorWithHttpInfo(specificWidgetId: number, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<BillsOverdueFromVendorResponse>>>;
    /**
     * Retrieves the carbon footprint data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprintWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestGHGYearlyResponse>>;
    /**
     * Retrieves yearly Carbon Emissions data that is split by year, then by Gas Type and one of the following group types:  ( Scope, Scope Category, Commodity ). Also includes target data, if target comparisons are enabled and set.
     *
     * @param specificWidgetId Specific Widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprintDataWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<GHGCarbonFootprintResponse>>;
    /**
     * Retrieves data for commodity cost dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCommodityCostWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<PlaceDigestActualAndCalendarizedMonthlyResponse>>;
    /**
     * Returns Cost Avoidance Savings Program-to-date. The user can set the topmost place and/or commodity filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCostAvoidanceProgramSavingsWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WidgetSavingsYearlyResponse>>;
    /**
     * Retrieves a list of buildings for the Multiple ENERGY STAR Buildings widget.  The widget is expecting zero, one, or many buildings, and alters its layout based on how many results it receives.    Validation:  - The provided specific widget must exist  - The provided specific widget must be an Multiple ENERGY STAR Buildings widget
     *
     * @param specificWidgetId Identifier for a specific ENERGY STAR widget on a dashboard
     * @param numberOfYears Only used when a single building is returned. The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     * @param filter Filter string which may add to or override saved filter values during this request
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarMultipleBuildingsWithHttpInfo(specificWidgetId: number, numberOfYears?: number, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<EnergyStarPlaceHierarchyResponse>>>;
    /**
     * Retrieves ENERGY STAR place score history for a building    Validation:  - The provided specific widget must exist  - The provided specific widget must be an ENERGY STAR Single Building widget
     *
     * @param specificWidgetId Identifier for a specific Single ENERGY STAR Building widget on a dashboard
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarSingleBuildingWithHttpInfo(specificWidgetId: number, numberOfYears?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EnergyStarPlaceHierarchyResponse>>;
    /**
     * Returns data for the ESA demand interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaDemandIntervalDataWidgetWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaIntervalDataResponse>>;
    /**
     * Returns data for the esa interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaIntervalDataWidgetWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaIntervalDataResponse>>;
    /**
     * Retrieve Trend Insights (previously \&quot;ESA Sentinel\&quot;) readings and predictions for a Channel.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getEsaSentinelWidgetWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<EsaSentinelPredictionsResponse>>;
    /**
     * Retrieves energy use intensity data for a specific widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter API filters
     */
    getEuiChartWidgetDataWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceDigestEnergyUseIntensity>>>;
    /**
     * Get building rank by GHG emissions or intensity.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGBuildingRankWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AggregatedResponseGHGBuildingRank>>;
    /**
     * Gets the greenhouse gas performance by commodity, scope or scope category.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGPerformanceWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AggregatedComparisonResponseGHGPerformanceComparison>>;
    /**
     * Get ranking by GHG emissions.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGRankingWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AggregatedResponseItemRankWithUnitResponse>>;
    /**
     * Retrieves interval data for a specific widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     */
    getIntervalDataWithHttpInfo(specificWidgetId: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<Readings>>>;
    /**
     * Gets the bar rank and tree map widgets.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getItemRankWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AggregatedItemRankResponse>>;
    /**
     * Retrieves map data for a specific map widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     */
    getMapWidgetWithHttpInfo(specificWidgetId: number, chartMonthsToExclude?: number, numMonths?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<MapWidgetResponse>>;
    /**
     * Returns gaps in billing data for a date range specified by the  Bill Date Range filter.   A gap is defined as at least one day that falls within the account&#39;s service dates and   not included in any bill for that account meter.  The Allowable Gap Days filter specifies the number of days that must be in the gap  before it will be included in the results.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMissingBillsWithHttpInfo(specificWidgetId: number, filter?: string, pageSize?: number, pageNumber?: number, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MissingBillWidget>>>;
    /**
     * Gets data for the Monthly Cost Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyCostTrendWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TimeSeriesDataResponse>>;
    /**
     * Returns data for the monthly trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getMonthlyTrendWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TrendDataResponse>>;
    /**
     * Gets data for the Monthly Use Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyUseTrendWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<TimeSeriesDataResponse>>;
    /**
     * Retrieves the most expensive building data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveBuildingsWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<PlaceCost>>>;
    /**
     * Retrieves the most expensive meters data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveMetersWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<MeterCost>>>;
    /**
     * Retrieves data for the Rolling Monthly Comparison Widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getRollingComparisonWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<RollingComparisonResponse>>;
    /**
     * Retrieves an array of widgets.
     *
     */
    getWidgetsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<Array<WidgetResponse>>>;
    /**
     * Returns data for the monthly savings trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    monthlyCAPTrendWithHttpInfo(specificWidgetId: number, filter?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<AggregatedMonthlyCAPTrendResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<WidgetService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WidgetService>;
}
