import { HttpClient, HttpHeaders } from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ApprovalWorkflowSettings } from '../model/approvalWorkflowSettings';
import { BatchWorkflowSettings } from '../model/batchWorkflowSettings';
import { BillImportWorkflowSettings } from '../model/billImportWorkflowSettings';
import { ChargebackWorkflowSettings } from '../model/chargebackWorkflowSettings';
import { ExportWorkflowSettings } from '../model/exportWorkflowSettings';
import { WorkflowSettingsRequest } from '../model/workflowSettingsRequest';
import { WorkflowSettingsResponse } from '../model/workflowSettingsResponse';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class WorkflowService {
    protected http: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(http: HttpClient, basePath: string, configuration: Configuration);
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    private extendObj;
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Update bill workflow settings
     *
     * @param body All workflow settings
     */
    editWorkflow(body?: WorkflowSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WorkflowSettingsResponse>;
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflow(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ApprovalWorkflowSettings>;
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflow(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BatchWorkflowSettings>;
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<BillImportWorkflowSettings>;
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettings(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ChargebackWorkflowSettings>;
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflow(exportMode?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<ExportWorkflowSettings>;
    /**
     * Get bill workflow settings
     *
     */
    getWorkflow(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<WorkflowSettingsResponse>;
    /**
     * Update bill workflow settings
     *
     * @param body All workflow settings
     */
    editWorkflowWithHttpInfo(body?: WorkflowSettingsRequest, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WorkflowSettingsResponse>>;
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflowWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ApprovalWorkflowSettings>>;
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflowWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BatchWorkflowSettings>>;
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<BillImportWorkflowSettings>>;
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettingsWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ChargebackWorkflowSettings>>;
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflowWithHttpInfo(exportMode?: string, extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<ExportWorkflowSettings>>;
    /**
     * Get bill workflow settings
     *
     */
    getWorkflowWithHttpInfo(extraHttpRequestParams?: {
        search: string | {
            [param: string]: string | string[];
        };
    }, extraHttpRequestHeaders?: {
        [header: string]: string | string[];
    }): Observable<HttpResponse<WorkflowSettingsResponse>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<WorkflowService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WorkflowService>;
}
