import * as i0 from '@angular/core';
import { InjectionToken, Optional, Inject, Injectable, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpHeaders, HttpParams, provideHttpClient, withInterceptorsFromDi } from '@angular/common/http';
import { map } from 'rxjs/operators';
import { CommonModule } from '@angular/common';

const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

class Configuration {
    apiKeys;
    username;
    password;
    accessToken;
    basePath;
    withCredentials;
    constructor(configurationParameters = {}) {
        if (configurationParameters.apiKeys) {
            this.apiKeys = configurationParameters.apiKeys;
        }
        if (this.username) {
            this.username = configurationParameters.username;
        }
        if (this.password) {
            this.password = configurationParameters.password;
        }
        if (this.accessToken) {
            this.accessToken = configurationParameters.accessToken;
        }
        if (this.basePath) {
            this.basePath = configurationParameters.basePath;
        }
        if (this.withCredentials) {
            this.withCredentials = configurationParameters.withCredentials;
        }
    }
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2_ = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AccountService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an account
     *
     * @param body Data representing the account being created
     */
    createAccount(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlert(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountAlertWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an account. Currently NO confirmation is required
     *
     * @param accountId The identifier for the account being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteAccount(accountId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountWithHttpInfo(accountId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlert(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFile(accountId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadAccountCustomFieldFileWithHttpInfo(accountId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccount(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersion(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountCodeVersionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFs(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountUDFsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccount(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlert(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlerts(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountAlertsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettings(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountAuditSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRates(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountRatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplates(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountTemplatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfs(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountUdfsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccounts(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For a given accountId, startDate and endDates for a bill get a billing period recommendation  The billing period will be in YYYYMM format YYYY represents the 4 digit year and MM is the two digit month 01 for Jan to 12 for Dec
     *
     * @param accountId The identifier for the account for which bill is being created
     * @param startDate The start date of the bill
     * @param endDate The end date of the bill
     */
    getDefaultBillingPeriod(accountId, startDate, endDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDefaultBillingPeriodWithHttpInfo(accountId, startDate, endDate, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccount(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveAccountWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processAccountCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccounts(query, includeInactiveAccounts, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchAccountsWithHttpInfo(query, includeInactiveAccounts, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Enable or disable Accounts from audits
     *
     * @param body
     */
    setAccountAuditExclusion(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setAccountAuditExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlert(accountId, alertId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountAlertWithHttpInfo(accountId, alertId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update audit settings for an account.   Every audit must be included but supplying null for its settings will remove them.
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param accountId The account identifier
     * @param body The new state of the audit settings
     */
    updateAccountAuditSettings(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountAuditSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an account
     *
     * @param body Data representing the account being created
     */
    createAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Post, path, requestOptions);
    }
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlertWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling createAccountAlert.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Post, path, requestOptions);
    }
    /**
     * Deletes an account. Currently NO confirmation is required
     *
     * @param accountId The identifier for the account being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteAccountWithHttpInfo(accountId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling deleteAccount.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Delete, path, requestOptions);
    }
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert/${alertId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'alertId' + '}', String(alertId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling deleteAccountAlert.');
        }
        // verify required parameter 'alertId' is not null or undefined
        if (alertId === null || alertId === undefined) {
            throw new Error('Required parameter alertId was null or undefined when calling deleteAccountAlert.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Delete, path, requestOptions);
    }
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFileWithHttpInfo(accountId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/account/${accountId}/udf/${udfId}/download'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling downloadAccountCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadAccountCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccountWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccount.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/codeversion'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccountCodeVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/udf'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccountUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccountWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccount.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert/${alertId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'alertId' + '}', String(alertId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountAlert.');
        }
        // verify required parameter 'alertId' is not null or undefined
        if (alertId === null || alertId === undefined) {
            throw new Error('Required parameter alertId was null or undefined when calling getAccountAlert.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlertsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountAlerts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/account/${accountId}/auditSetting'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountAuditSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/rate'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountRates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/template'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountTemplates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/udf'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * For a given accountId, startDate and endDates for a bill get a billing period recommendation  The billing period will be in YYYYMM format YYYY represents the 4 digit year and MM is the two digit month 01 for Jan to 12 for Dec
     *
     * @param accountId The identifier for the account for which bill is being created
     * @param startDate The start date of the bill
     * @param endDate The end date of the bill
     */
    getDefaultBillingPeriodWithHttpInfo(accountId, startDate, endDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billingPeriod'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getDefaultBillingPeriod.');
        }
        if (startDate !== undefined) {
            queryParameters = queryParameters.set('startDate', startDate.toISOString());
        }
        if (endDate !== undefined) {
            queryParameters = queryParameters.set('endDate', endDate.toISOString());
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccountWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentCostCenter/${parentCostCenterId}/account'
            .replace('${' + 'parentCostCenterId' + '}', String(parentCostCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCostCenterId' is not null or undefined
        if (parentCostCenterId === null || parentCostCenterId === undefined) {
            throw new Error('Required parameter parentCostCenterId was null or undefined when calling moveAccount.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202211/account/customAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccountsWithHttpInfo(query, includeInactiveAccounts, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (query !== undefined) {
            queryParameters = queryParameters.set('query', query);
        }
        if (includeInactiveAccounts !== undefined) {
            queryParameters = queryParameters.set('includeInactiveAccounts', includeInactiveAccounts);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Get, path, requestOptions);
    }
    /**
     * Enable or disable Accounts from audits
     *
     * @param body
     */
    setAccountAuditExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/account/auditEnabled';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlertWithHttpInfo(accountId, alertId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert/${alertId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'alertId' + '}', String(alertId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling updateAccountAlert.');
        }
        // verify required parameter 'alertId' is not null or undefined
        if (alertId === null || alertId === undefined) {
            throw new Error('Required parameter alertId was null or undefined when calling updateAccountAlert.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    /**
     * Update audit settings for an account.   Every audit must be included but supplying null for its settings will remove them.
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param accountId The account identifier
     * @param body The new state of the audit settings
     */
    updateAccountAuditSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/account/${accountId}/auditSetting'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling updateAccountAuditSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2_.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2Z = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AccountDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthly(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualMonthlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearly(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualYearlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/digest/actual/monthly'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Z.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Z.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/digest/actual/yearly'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Z.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Z.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2Y = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AccountMeterService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRate(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountRateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplate(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createFormTemplateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeter(accountMeterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountMeterWithHttpInfo(accountMeterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignment(accountMeterId, formTemplateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteTemplateAssignmentWithHttpInfo(accountMeterId, formTemplateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeter(accountMeterId, deleteBills, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountMeterWithHttpInfo(accountMeterId, deleteBills, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateList(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountRateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateList(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editFormTemplateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Post, path, requestOptions);
    }
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/rate'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling createAccountRate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Post, path, requestOptions);
    }
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/template'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling createFormTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Post, path, requestOptions);
    }
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeterWithHttpInfo(accountMeterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling deleteAccountMeter.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Delete, path, requestOptions);
    }
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignmentWithHttpInfo(accountMeterId, formTemplateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/template/${formTemplateId}'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId))
            .replace('${' + 'formTemplateId' + '}', String(formTemplateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling deleteTemplateAssignment.');
        }
        // verify required parameter 'formTemplateId' is not null or undefined
        if (formTemplateId === null || formTemplateId === undefined) {
            throw new Error('Required parameter formTemplateId was null or undefined when calling deleteTemplateAssignment.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Delete, path, requestOptions);
    }
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeterWithHttpInfo(accountMeterId, deleteBills, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling editAccountMeter.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Put, path, requestOptions);
    }
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/rate'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling editAccountRateList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Put, path, requestOptions);
    }
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/template'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling editFormTemplateList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Y.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountMeterService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountMeterService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccountMeterService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2X = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AccrualService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete all bills created by the Accrual task   If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the accrual task
     */
    deleteAccrualTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Accrual settings
     *
     */
    getAccrualSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccrualSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run the accrual processor engine using the supplied settings to generate accrual bills
     *
     * @param filter Accrual data selection filters
     * @param body Accrual processor settings
     */
    processAccruals(filter, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processAccrualsWithHttpInfo(filter, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void all bills created by the Accrual task  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the accrual task
     */
    voidAccrualTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills created by the Accrual task   If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the accrual task
     */
    deleteAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual/${taskId}/delete'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling deleteAccrualTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2X.Post, path, requestOptions);
    }
    /**
     * Get Accrual settings
     *
     */
    getAccrualSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2X.Get, path, requestOptions);
    }
    /**
     * Run the accrual processor engine using the supplied settings to generate accrual bills
     *
     * @param filter Accrual data selection filters
     * @param body Accrual processor settings
     */
    processAccrualsWithHttpInfo(filter, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2X.Post, path, requestOptions);
    }
    /**
     * Void all bills created by the Accrual task  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the accrual task
     */
    voidAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual/${taskId}/void'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling voidAccrualTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2X.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccrualService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccrualService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AccrualService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2W = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ActivityService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * List of a bill IDs that were created or modified since the given date.
     *
     * @param date Created or modified datetime; Defaults to yesterday at the current time
     */
    getBillActivity(date, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillActivityWithHttpInfo(date, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * List of a bill IDs that were created or modified since the given date.
     *
     * @param date Created or modified datetime; Defaults to yesterday at the current time
     */
    getBillActivityWithHttpInfo(date, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/activity/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (date !== undefined) {
            queryParameters = queryParameters.set('date', date.toISOString());
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2W.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ActivityService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ActivityService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ActivityService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2V = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AdminService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edit accounting settings
     *
     * @param body
     */
    editAccountingSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the license details.
     *
     * @param body
     */
    editLicenseDetails(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editLicenseDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the list of account periods
     *
     */
    getAccountPeriods(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountPeriodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get accounting settings
     *
     */
    getAccountingSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountingSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get license details.
     *
     */
    getLicenseDetails(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getLicenseDetailsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve the organization logo, if configured. Only URLs or JPEG, PNG, and SVG images are acceptable organization logos. If the saved base64 image is of a different file type, it will return an error.
     *
     */
    getOrganizationLogo(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getOrganizationLogoWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the system reporting settings
     *
     */
    getReportingSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportingSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    getSystemSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSystemSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get system settings
     *
     */
    getSystemSettingsNew(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSystemSettingsNewWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppAction(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processCustomAppActionWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setReportingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    updateSystemSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit accounting settings
     *
     * @param body
     */
    editAccountingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/accounting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Put, path, requestOptions);
    }
    /**
     * Edit the license details.
     *
     * @param body
     */
    editLicenseDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/license';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Put, path, requestOptions);
    }
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/admin/systemSettings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Put, path, requestOptions);
    }
    /**
     * Get the list of account periods
     *
     */
    getAccountPeriodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/accountperiod';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     * Get accounting settings
     *
     */
    getAccountingSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/accounting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     * Get license details.
     *
     */
    getLicenseDetailsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/license';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     * Retrieve the organization logo, if configured. Only URLs or JPEG, PNG, and SVG images are acceptable organization logos. If the saved base64 image is of a different file type, it will return an error.
     *
     */
    getOrganizationLogoWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/logo';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     * Get the system reporting settings
     *
     */
    getReportingSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202305/admin/reportingSettings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     *
     *
     */
    getSystemSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/systemsetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     * Get system settings
     *
     */
    getSystemSettingsNewWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/systemSettings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Get, path, requestOptions);
    }
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppActionWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/customapplicationaction/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling processCustomAppAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Put, path, requestOptions);
    }
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202305/admin/reportingSettings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param body
     */
    updateSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/systemsetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2V.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AdminService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AdminService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AdminService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2U = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ApiService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get filters for an API
     *
     * @param apiId The api Id
     */
    getApiFilters(apiId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApiFiltersWithHttpInfo(apiId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get filters for an API
     *
     * @param apiId The api Id
     */
    getApiFiltersWithHttpInfo(apiId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/api/${apiId}/filter'
            .replace('${' + 'apiId' + '}', String(apiId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiId' is not null or undefined
        if (apiId === null || apiId === undefined) {
            throw new Error('Required parameter apiId was null or undefined when calling getApiFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2U.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApiService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApiService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApiService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2T = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ApiKeyService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a new API key
     *
     * @param body
     */
    createApiKey(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createApiKeyWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKey(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKey(apiKeyId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editApiKeyWithHttpInfo(apiKeyId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an API key
     *
     * @param apiKeyId
     */
    getApiKey(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all available API keys
     *
     * @param filter
     */
    getApiKeys(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApiKeysWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new API key
     *
     * @param body
     */
    createApiKeyWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2T.Post, path, requestOptions);
    }
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey/${apiKeyId}'
            .replace('${' + 'apiKeyId' + '}', String(apiKeyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiKeyId' is not null or undefined
        if (apiKeyId === null || apiKeyId === undefined) {
            throw new Error('Required parameter apiKeyId was null or undefined when calling deleteApiKey.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2T.Delete, path, requestOptions);
    }
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKeyWithHttpInfo(apiKeyId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey/${apiKeyId}'
            .replace('${' + 'apiKeyId' + '}', String(apiKeyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiKeyId' is not null or undefined
        if (apiKeyId === null || apiKeyId === undefined) {
            throw new Error('Required parameter apiKeyId was null or undefined when calling editApiKey.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2T.Put, path, requestOptions);
    }
    /**
     * Get an API key
     *
     * @param apiKeyId
     */
    getApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey/${apiKeyId}'
            .replace('${' + 'apiKeyId' + '}', String(apiKeyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiKeyId' is not null or undefined
        if (apiKeyId === null || apiKeyId === undefined) {
            throw new Error('Required parameter apiKeyId was null or undefined when calling getApiKey.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2T.Get, path, requestOptions);
    }
    /**
     * Get a list of all available API keys
     *
     * @param filter
     */
    getApiKeysWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2T.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApiKeyService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApiKeyService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApiKeyService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2S = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AuditService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Run audits on a bill list
     *
     * @param listId The list of bills to audit
     */
    execAuditEngine(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.execAuditEngineWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets all audit settings
     *
     */
    getAuditSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAuditSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update audit settings
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param body The new state of the audit settings
     */
    updateAuditSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAuditSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run audits on a bill list
     *
     * @param listId The list of bills to audit
     */
    execAuditEngineWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/audit/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (listId !== undefined) {
            queryParameters = queryParameters.set('listId', listId);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2S.Post, path, requestOptions);
    }
    /**
     * Gets all audit settings
     *
     */
    getAuditSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/audit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2S.Get, path, requestOptions);
    }
    /**
     * Update audit settings
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param body The new state of the audit settings
     */
    updateAuditSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/audit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2S.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AuditService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AuditService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AuditService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2R = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class AuthenticationService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     */
    beta(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.betaWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * My.EnergyCap.Com needs a way to get a token from a partition name. Pass in a partition, create and return a token for provided partition.
     *
     * @param partition
     */
    createTokenForPartition(partition, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createTokenForPartitionWithHttpInfo(partition, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    login(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.loginWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Logout user- if they were logged in using a cookie
     *
     */
    logout(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.logoutWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    betaWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/internal/beta';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2R.Post, path, requestOptions);
    }
    /**
     * My.EnergyCap.Com needs a way to get a token from a partition name. Pass in a partition, create and return a token for provided partition.
     *
     * @param partition
     */
    createTokenForPartitionWithHttpInfo(partition, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/exchange/eco';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (partition !== undefined) {
            queryParameters = queryParameters.set('partition', partition);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2R.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param body
     */
    loginWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/login';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2R.Post, path, requestOptions);
    }
    /**
     * Logout user- if they were logged in using a cookie
     *
     */
    logoutWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/logout';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2R.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AuthenticationService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AuthenticationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AuthenticationService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2Q = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class BatchService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param batchId
     */
    closeBatch(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.closeBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     */
    deleteBatch(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatch(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeAccountChargesToMetersForBillsInBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatch(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     */
    getBatch(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatches(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    openBatch(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.openBatchWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the status of a batch.  Requesting user must have BillAndBatches Create to update their own batch or to open another user&#39;s pending batch.  User must have BillsAndBatches Manage to update another user&#39;s batch to closed or pending.  If opening another user&#39;s batch, the requesting user&#39;s open batch (if any) will be set to Pending status.  See &#39;Batch Statuses&#39; section below for more information.
     *  __Batch Statuses:__    | Batch Status   | Description |  | -------------- | ----------- |  | Open           | Batch must currently be pending. Un-voids all bills in the batch. |  | Pending        | Batch must currently be open. Voids all bills in the batch.  |  | Closed         | Batch must currently be open or pending. If the batch was pending, un-voids all bills in the batch.  |
     * @param batchId ID for the batch to set status
     * @param body The new status and (optional) note on the batch. See &#39;Batch Statuses&#39; section below for available statuses.
     */
    updateBatchStatus(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateBatchStatusWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     */
    closeBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/close/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling closeBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     */
    deleteBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling deleteBatch.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Delete, path, requestOptions);
    }
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/batch/${batchId}/distributeAccountCharges'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling distributeAccountChargesToMetersForBillsInBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling editBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     */
    getBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling getBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatchesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param body
     */
    openBatchWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Post, path, requestOptions);
    }
    /**
     * Update the status of a batch.  Requesting user must have BillAndBatches Create to update their own batch or to open another user&#39;s pending batch.  User must have BillsAndBatches Manage to update another user&#39;s batch to closed or pending.  If opening another user&#39;s batch, the requesting user&#39;s open batch (if any) will be set to Pending status.  See &#39;Batch Statuses&#39; section below for more information.
     *  __Batch Statuses:__    | Batch Status   | Description |  | -------------- | ----------- |  | Open           | Batch must currently be pending. Un-voids all bills in the batch. |  | Pending        | Batch must currently be open. Voids all bills in the batch.  |  | Closed         | Batch must currently be open or pending. If the batch was pending, un-voids all bills in the batch.  |
     * @param batchId ID for the batch to set status
     * @param body The new status and (optional) note on the batch. See &#39;Batch Statuses&#39; section below for available statuses.
     */
    updateBatchStatusWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/batch/${batchId}/status'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling updateBatchStatus.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2Q.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BatchService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BatchService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BatchService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2P = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class BillService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Update approved flag for the given billIDs
     *
     * @param body approve action
     */
    billActionApprove(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionApproveWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete given billIDs
     *
     * @param body
     */
    billActionDelete(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionDeleteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update export hold flag for the given billIDs
     *
     * @param body export hold action
     */
    billActionExportHold(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionExportHoldWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplit(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionSplitWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeaders(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionUpdateHeadersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoid(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionVoidWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetails(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billPaymentDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billPaymentDetailsFileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABill(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.cleanABillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBills(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.cleanDirtyBillsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBill(saveAsResolved, comment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBillWithHttpInfo(saveAsResolved, comment, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEvent(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBillPaymentEventWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMeters(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeAccountChargesToMetersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFile(billId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadBillCustomFieldFileWithHttpInfo(billId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBill(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFields(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillCustomFieldsWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the text of a standard EnergyCAP bill export ini file for AP, GL and Payment purposes.  Payment details will be included in the profile if workflow settings for the bill export are configured to include payment details.
     *
     * @param exportMode Specifies whether the profile should be for AP, GL or Payment. Pass in \&quot;AP\&quot; for AP Profile, \&quot;GL\&quot; for GL Profile or \&quot;Payment\&quot; for Payment Profile. If this is not included in the request, it defaults to AP.
     */
    exportBillProfile(exportMode, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillProfileWithHttpInfo(exportMode, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBills(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJson(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillsAsJsonWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistory(accountId, billingPeriod, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountBillHistoryWithHttpInfo(accountId, billingPeriod, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylines(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllBillsBodylinesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBill(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterActualByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterCalendarizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterNormalizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterStatisticsByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActual(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersActualWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarized(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersCalendarizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalized(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersNormalizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatistics(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersStatisticsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylines(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillBodylinesWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFields(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillCustomFieldsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryData(accountId, beginDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillEntryDataWithHttpInfo(accountId, beginDate, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillEntryDataByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistory(billId, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillHistoryWithHttpInfo(billId, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of bill line type mappings
     *
     */
    getBillLineTypeMappings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillLineTypeMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEvents(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillPaymentEventsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBills(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccounts(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPossibleDestinationAccountsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccount(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveBillsToAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processBillCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBills(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param body
     */
    setBillAccrualExclusion(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setBillAccrualExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBills(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unexportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuid(billExportGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unexportBillsByGuidWithHttpInfo(billExportGuid, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImage(billId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.uploadBillImageWithHttpInfo(billId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update approved flag for the given billIDs
     *
     * @param body approve action
     */
    billActionApproveWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/approve';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Delete given billIDs
     *
     * @param body
     */
    billActionDeleteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/delete';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Post, path, requestOptions);
    }
    /**
     * Update export hold flag for the given billIDs
     *
     * @param body export hold action
     */
    billActionExportHoldWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/exporthold';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplitWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/split';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Post, path, requestOptions);
    }
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeadersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billHeaders';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoidWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/void';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/bill/billPaymentDetails';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/bill/billPaymentDetailsFile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/octet-stream'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/cleanBill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling cleanABill.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBillsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/cleanBill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBillWithHttpInfo(saveAsResolved, comment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (saveAsResolved !== undefined) {
            queryParameters = queryParameters.set('saveAsResolved', saveAsResolved);
        }
        if (comment !== undefined) {
            queryParameters = queryParameters.set('comment', comment);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Post, path, requestOptions);
    }
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEventWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202504/bill/paymentEvent';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Post, path, requestOptions);
    }
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMetersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/bill/distributeAccountCharges';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFileWithHttpInfo(billId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202202/bill/${billId}/udf/${udfId}/download'
            .replace('${' + 'billId' + '}', String(billId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling downloadBillCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadBillCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBillWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling editBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFieldsWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202202/bill/${billId}/udf'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling editBillCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Retrieves the text of a standard EnergyCAP bill export ini file for AP, GL and Payment purposes.  Payment details will be included in the profile if workflow settings for the bill export are configured to include payment details.
     *
     * @param exportMode Specifies whether the profile should be for AP, GL or Payment. Pass in \&quot;AP\&quot; for AP Profile, \&quot;GL\&quot; for GL Profile or \&quot;Payment\&quot; for Payment Profile. If this is not included in the request, it defaults to AP.
     */
    exportBillProfileWithHttpInfo(exportMode, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/exportProfile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (exportMode !== undefined) {
            queryParameters = queryParameters.set('exportMode', exportMode);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/export';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJsonWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/bill/export/json';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Post, path, requestOptions);
    }
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistoryWithHttpInfo(accountId, billingPeriod, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billHistory'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountBillHistory.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (includeVoid !== undefined) {
            queryParameters = queryParameters.set('includeVoid', includeVoid);
        }
        if (includeAccrual !== undefined) {
            queryParameters = queryParameters.set('includeAccrual', includeAccrual);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylinesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/bodyline';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/actual'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterActualByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/calendarized'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterCalendarizedByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/normalized'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterNormalizedByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/statistics'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterStatisticsByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActualWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/actual';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/calendarized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/normalized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatisticsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/statistics';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylinesWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/bill/${billId}/bodyline'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillBodylines.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFieldsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202202/bill/${billId}/udf'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryDataWithHttpInfo(accountId, beginDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billEntry'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillEntryData.');
        }
        if (beginDate !== undefined) {
            queryParameters = queryParameters.set('beginDate', beginDate.toISOString());
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billEntry'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillEntryDataByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistoryWithHttpInfo(billId, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billHistory'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillHistory.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (includeVoid !== undefined) {
            queryParameters = queryParameters.set('includeVoid', includeVoid);
        }
        if (includeAccrual !== undefined) {
            queryParameters = queryParameters.set('includeAccrual', includeAccrual);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of bill line type mappings
     *
     */
    getBillLineTypeMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/bill/billLineTypeMapping';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEventsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202504/bill/${billId}/paymentEvent'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillPaymentEvents.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccountsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/possibleDestinationAccounts';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/moveBills';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/customAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/reverse';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param body
     */
    setBillAccrualExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/accrualExclusion';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/unexport';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuidWithHttpInfo(billExportGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/unexport/${billExportGuid}'
            .replace('${' + 'billExportGuid' + '}', String(billExportGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billExportGuid' is not null or undefined
        if (billExportGuid === null || billExportGuid === undefined) {
            throw new Error('Required parameter billExportGuid was null or undefined when calling unexportBillsByGuid.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Put, path, requestOptions);
    }
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImageWithHttpInfo(billId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/bill/${billId}/billImage'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling uploadBillImage.');
        }
        if (fileName !== undefined) {
            queryParameters = queryParameters.set('fileName', fileName);
        }
        // to determine the Accept header
        let produces = [
            'application/json',
            'text/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/octet-stream'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2P.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2O = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class BillAccountChargeSplitService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a specific account&#39;s setting to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    deleteAccountBillAccountChargeSplitSettings(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a specific vendor&#39;s setting to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    deleteVendorBillAccountChargeSplitSettings(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a specific account&#39;s setting to split account charges on bill import  If a rule does not currently exist for this account it is created otherwise it is updated
     *
     * @param accountId Account identifier
     * @param body
     */
    editAccountBillAccountChargeSplitSettings(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the method used to split account charges on bill import
     *
     * @param body Method used to split account charges on bill import
     */
    editBillAccountChargeSplitMethod(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillAccountChargeSplitMethodWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a specific vendor&#39;s setting to split account charges on bill import  If a rule does not currently exist for this vendor it is created otherwise it is updated
     *
     * @param vendorId Vendor identifier
     * @param body
     */
    editVendorBillAccountChargeSplitSettings(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific account&#39;s settings to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    getAccountBillAccountChargeSplitSettings(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the method used to split account charges on bill import
     *
     */
    getBillAccountChargeSplitMethod(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountChargeSplitMethodWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettings(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountChargeSplitSettingsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific vendor&#39;s settings to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    getVendorBillAccountChargeSplitSettings(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a specific account&#39;s setting to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    deleteAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling deleteAccountBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Delete, path, requestOptions);
    }
    /**
     * Deletes a specific vendor&#39;s setting to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    deleteVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling deleteVendorBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Delete, path, requestOptions);
    }
    /**
     * Edits a specific account&#39;s setting to split account charges on bill import  If a rule does not currently exist for this account it is created otherwise it is updated
     *
     * @param accountId Account identifier
     * @param body
     */
    editAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccountBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Put, path, requestOptions);
    }
    /**
     * Edit the method used to split account charges on bill import
     *
     * @param body Method used to split account charges on bill import
     */
    editBillAccountChargeSplitMethodWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/method';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Put, path, requestOptions);
    }
    /**
     * Edits a specific vendor&#39;s setting to split account charges on bill import  If a rule does not currently exist for this vendor it is created otherwise it is updated
     *
     * @param vendorId Vendor identifier
     * @param body
     */
    editVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling editVendorBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Put, path, requestOptions);
    }
    /**
     * Retrieves a specific account&#39;s settings to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    getAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Get, path, requestOptions);
    }
    /**
     * Retrieves the method used to split account charges on bill import
     *
     */
    getBillAccountChargeSplitMethodWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/method';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Get, path, requestOptions);
    }
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettingsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Get, path, requestOptions);
    }
    /**
     * Retrieves a specific vendor&#39;s settings to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    getVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2O.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillAccountChargeSplitService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillAccountChargeSplitService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillAccountChargeSplitService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2N = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class BillSplitService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetails(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountBillSplitParentDetailsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitChargebackTaskByVersion(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitChargebackTaskByVersionWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetails(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistory(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersions(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplits(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetails(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterBillSplitParentDetailsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetails(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistory(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageBillSplitVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetailsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billSplit/parent'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountBillSplitParentDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitChargebackTaskByVersionWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit/${versionId}/chargebackTask'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplitChargebackTaskByVersion.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getBillSplitChargebackTaskByVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBillSplitChargebackTaskByVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit/${versionId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplitDetails.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getBillSplitDetails.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBillSplitDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplitVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getBillSplitVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billSplit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplitsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billSplit'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplits.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetailsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/billSplit/parent'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterBillSplitParentDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Get, path, requestOptions);
    }
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit/${versionId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageBillSplitDetails.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageBillSplitDetails.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageBillSplitDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Put, path, requestOptions);
    }
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageBillSplitVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageBillSplitVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2N.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillSplitService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillSplitService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillSplitService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2M = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class BillViewService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves properties for bill view
     *
     * @param billId The bill identifier
     */
    getBillView(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillViewWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves properties for bill view
     *
     * @param billId The bill identifier
     */
    getBillViewWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billView/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillView.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2M.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillViewService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillViewService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BillViewService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2L = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class BudgetService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a budget
     *
     * @param body Data representing the budget being created
     */
    createBudget(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBudgetWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a budget version
     *
     * @param budgetId The identifier for the budget to create the version on
     * @param body Data representing the budgetVersion being created
     */
    createBudgetVersion(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBudgetVersionWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a budget
     *
     * @param budgetId The identifier for the budget being deleted
     */
    deleteBudget(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being deleted
     */
    deleteBudgetVersion(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a budget
     *
     * @param budgetId The identifier for the budget being edited
     * @param body Data representing the budget being edited
     */
    editBudget(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBudgetWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param body Data representing the budgetVersion being edited
     */
    editBudgetVersion(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBudgetVersionWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the budget by ID
     *
     * @param budgetId The identifier for the budget being retrieved
     */
    getBudget(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of available budget data types
     *
     */
    getBudgetDataTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetDataTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of budget period types
     *
     */
    getBudgetPeriodTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetPeriodTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of available budget usage methods
     *
     */
    getBudgetUsageMethods(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetUsageMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific version for a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     */
    getBudgetVersion(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the summary for a specific version on a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param commodityId The optional commodity filter
     */
    getBudgetVersionSummary(budgetId, versionId, commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetVersionSummaryWithHttpInfo(budgetId, versionId, commodityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the versions for a specified budget
     *
     * @param budgetId The identifier for the budget to retrieve all versions
     */
    getBudgetVersions(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetVersionsWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the budgets
     *
     */
    getBudgets(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Sets a budget version as active, and all other versions as inactive.
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version to set as active
     */
    setBudgetVersionActive(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setBudgetVersionActiveWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a budget
     *
     * @param body Data representing the budget being created
     */
    createBudgetWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Post, path, requestOptions);
    }
    /**
     * Creates a budget version
     *
     * @param budgetId The identifier for the budget to create the version on
     * @param body Data representing the budgetVersion being created
     */
    createBudgetVersionWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling createBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Post, path, requestOptions);
    }
    /**
     * Deletes a budget
     *
     * @param budgetId The identifier for the budget being deleted
     */
    deleteBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling deleteBudget.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Delete, path, requestOptions);
    }
    /**
     * Deletes a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being deleted
     */
    deleteBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling deleteBudgetVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling deleteBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Delete, path, requestOptions);
    }
    /**
     * Edits a budget
     *
     * @param budgetId The identifier for the budget being edited
     * @param body Data representing the budget being edited
     */
    editBudgetWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling editBudget.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Put, path, requestOptions);
    }
    /**
     * Edits a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param body Data representing the budgetVersion being edited
     */
    editBudgetVersionWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling editBudgetVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Put, path, requestOptions);
    }
    /**
     * Retrieves the budget by ID
     *
     * @param budgetId The identifier for the budget being retrieved
     */
    getBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudget.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of available budget data types
     *
     */
    getBudgetDataTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/dataType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of budget period types
     *
     */
    getBudgetPeriodTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/periodType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of available budget usage methods
     *
     */
    getBudgetUsageMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/usageMethod';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves a specific version for a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     */
    getBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudgetVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves the summary for a specific version on a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param commodityId The optional commodity filter
     */
    getBudgetVersionSummaryWithHttpInfo(budgetId, versionId, commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}/summary'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudgetVersionSummary.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBudgetVersionSummary.');
        }
        if (commodityId !== undefined) {
            queryParameters = queryParameters.set('commodityId', commodityId);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves all the versions for a specified budget
     *
     * @param budgetId The identifier for the budget to retrieve all versions
     */
    getBudgetVersionsWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudgetVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Retrieves all the budgets
     *
     */
    getBudgetsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Get, path, requestOptions);
    }
    /**
     * Sets a budget version as active, and all other versions as inactive.
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version to set as active
     */
    setBudgetVersionActiveWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}/active'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling setBudgetVersionActive.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling setBudgetVersionActive.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2L.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BudgetService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BudgetService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BudgetService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2K = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CalculatedBillService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItems(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCost(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillCostWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemand(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetails(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUse(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillUseWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getCalculatedBillChargebackTaskByVersion(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillChargebackTaskByVersionWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistory(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersions(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBills(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItems(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItems(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageAccountLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCost(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculateBillCostWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemand(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUse(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculateBillUseWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistory(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItems(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageMeterLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Forces all Account and Meter Chargeback flags in the system to be recalculated
     *
     */
    recalculateChargebackFlags(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateChargebackFlagsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/accountLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getAccountLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getAccountLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCostWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/cost'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillCost.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillCost.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillCost.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/demand'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillDemand.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillDemand.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillDemand.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillDetails.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillDetails.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUseWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/use'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillUse.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillUse.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillUse.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get all chargeback tasks with details for a specific version on an account and meter
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getCalculatedBillChargebackTaskByVersionWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/chargebackTask'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculatedBillChargebackTaskByVersion.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculatedBillChargebackTaskByVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculatedBillChargebackTaskByVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculatedBillVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculatedBillVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/calculatedBill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/calculatedBill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculatedBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/meterLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getMeterLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getMeterLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/accountLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageAccountLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageAccountLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageAccountLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCostWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/cost'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculateBillCost.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculateBillCost.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageCalculateBillCost.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/demand'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculateBillDemand.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculateBillDemand.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageCalculateBillDemand.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUseWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/use'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculateBillUse.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculateBillUse.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageCalculateBillUse.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Put, path, requestOptions);
    }
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculatedBillVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculatedBillVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/meterLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageMeterLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageMeterLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageMeterLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Put, path, requestOptions);
    }
    /**
     * Forces all Account and Meter Chargeback flags in the system to be recalculated
     *
     */
    recalculateChargebackFlagsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/recalculateChargebackFlags';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2K.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CalculatedBillService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CalculatedBillService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CalculatedBillService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2J = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ChannelService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersion(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createChannelVersionWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannel(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterChannelWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersion(meterId, channelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChannelVersionWithHttpInfo(meterId, channelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannel(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFile(meterId, channelId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadChannelVersionCustomFieldFileWithHttpInfo(meterId, channelId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersion(meterId, channelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editChannelVersionWithHttpInfo(meterId, channelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannel(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterChannelWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannel(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannels(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterChannelsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersionWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}/version'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createChannelVersion.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling createChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Post, path, requestOptions);
    }
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannelWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createMeterChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Post, path, requestOptions);
    }
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersionWithHttpInfo(meterId, channelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}/version/${versionId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteChannelVersion.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling deleteChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling deleteChannelVersion.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Delete, path, requestOptions);
    }
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteMeterChannel.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling deleteMeterChannel.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Delete, path, requestOptions);
    }
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFileWithHttpInfo(meterId, channelId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/meter/${meterId}/channel/${channelId}/version/${versionId}/udf/${udfId}/download'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId))
            .replace('${' + 'versionId' + '}', String(versionId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Get, path, requestOptions);
    }
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersionWithHttpInfo(meterId, channelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}/version/${versionId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editChannelVersion.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling editChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Put, path, requestOptions);
    }
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannelWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterChannel.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling editMeterChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Put, path, requestOptions);
    }
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterChannel.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling getMeterChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Get, path, requestOptions);
    }
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannelsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterChannels.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2J.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChannelService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChannelService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChannelService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2I = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ChargebackEngineService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeBillSplitProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeCalculateBillProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflow(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeProcessorByWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStep(chargebackWorkflowStepId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeProcessorByWorkflowStepWithHttpInfo(chargebackWorkflowStepId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billSplit/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2I.Post, path, requestOptions);
    }
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/calculatedBill/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2I.Post, path, requestOptions);
    }
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/chargebackWorkflow/${chargebackWorkflowId}/exec'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling executeProcessorByWorkflow.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2I.Post, path, requestOptions);
    }
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStepWithHttpInfo(chargebackWorkflowStepId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/exec'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling executeProcessorByWorkflowStep.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2I.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackEngineService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackEngineService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackEngineService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2H = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ChargebackTaskService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the chargeback task
     */
    deleteChargebackTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a chargeback task with details
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a chargeback task&#39;s error log as an EXCEL file
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTaskErrorFile(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackTaskErrorFileWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all chargeback tasks with details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getChargebackTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTask(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateChargebackTaskWithHttpInfo(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the chargeback task
     */
    voidChargebackTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the chargeback task
     */
    deleteChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}/delete'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling deleteChargebackTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2H.Post, path, requestOptions);
    }
    /**
     * Retrieves a chargeback task with details
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling getChargebackTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2H.Get, path, requestOptions);
    }
    /**
     * Retrieves a chargeback task&#39;s error log as an EXCEL file
     *
     * @param taskId Identifier for the chargeback task
     */
    getChargebackTaskErrorFileWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}/errorOutput'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling getChargebackTaskErrorFile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2H.Get, path, requestOptions);
    }
    /**
     * Get all chargeback tasks with details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getChargebackTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2H.Get, path, requestOptions);
    }
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTaskWithHttpInfo(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling updateChargebackTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2H.Put, path, requestOptions);
    }
    /**
     * Void all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the chargeback task
     */
    voidChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}/void'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling voidChargebackTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2H.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackTaskService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackTaskService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackTaskService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2G = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ChargebackWorkflowService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStep(chargebackWorkflowStepId, billingPeriod, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.assignVersionsToStepWithHttpInfo(chargebackWorkflowStepId, billingPeriod, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflow(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createChargebackWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflow(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills created by a chargeback workflow step  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    deleteChargebackWorkflowSteps(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflow(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editChargebackWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflow(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigest(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowDigestWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStep(chargebackWorkflowStepId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowStepWithHttpInfo(chargebackWorkflowStepId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowSteps(chargebackWorkflowType, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowType, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflows(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void all bills created by a chargeback workflow step for a particular billing period  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    voidChargebackWorkflowSteps(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStepWithHttpInfo(chargebackWorkflowStepId, billingPeriod, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/billingPeriod/${billingPeriod}/version'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId))
            .replace('${' + 'billingPeriod' + '}', String(billingPeriod));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling assignVersionsToStep.');
        }
        // verify required parameter 'billingPeriod' is not null or undefined
        if (billingPeriod === null || billingPeriod === undefined) {
            throw new Error('Required parameter billingPeriod was null or undefined when calling assignVersionsToStep.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Put, path, requestOptions);
    }
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Post, path, requestOptions);
    }
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowId}'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling deleteChargebackWorkflow.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Delete, path, requestOptions);
    }
    /**
     * Delete all bills created by a chargeback workflow step  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    deleteChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/delete'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling deleteChargebackWorkflowSteps.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Post, path, requestOptions);
    }
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowId}'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling editChargebackWorkflow.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Put, path, requestOptions);
    }
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowId}'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling getChargebackWorkflow.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Get, path, requestOptions);
    }
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigestWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowStepId}/digest'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling getChargebackWorkflowDigest.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Get, path, requestOptions);
    }
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStepWithHttpInfo(chargebackWorkflowStepId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling getChargebackWorkflowStep.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Get, path, requestOptions);
    }
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowType, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (chargebackWorkflowType !== undefined) {
            queryParameters = queryParameters.set('chargebackWorkflowType', chargebackWorkflowType);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Get, path, requestOptions);
    }
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflowsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Get, path, requestOptions);
    }
    /**
     * Void all bills created by a chargeback workflow step for a particular billing period  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    voidChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/void'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling voidChargebackWorkflowSteps.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2G.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackWorkflowService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackWorkflowService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChargebackWorkflowService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2F = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CollectionService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a collection
     *
     * @param body Data representing the collection being created
     */
    createCollection(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCollectionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a collection
     *
     * @param collectionId The identifier for the collection being deleted
     */
    deleteCollection(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFields(collectionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadCollectionCustomFieldsWithHttpInfo(collectionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a collection
     *
     * @param collectionId The identifier for the collection being edited
     * @param body Data representing the collection being edited
     */
    editCollection(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCollectionWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a collection
     *
     * @param collectionId The id of the collection
     * @param body The list of udf values being edited
     */
    editCollectionCustomFields(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCollectionCustomFieldsWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollection(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFields(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionCustomFieldsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollections(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveCollections(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveCollectionsWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a collection
     *
     * @param body Data representing the collection being created
     */
    createCollectionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Post, path, requestOptions);
    }
    /**
     * Deletes a collection
     *
     * @param collectionId The identifier for the collection being deleted
     */
    deleteCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling deleteCollection.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Delete, path, requestOptions);
    }
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFieldsWithHttpInfo(collectionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/collection/${collectionId}/udf/${udfId}/download'
            .replace('${' + 'collectionId' + '}', String(collectionId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling downloadCollectionCustomFields.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadCollectionCustomFields.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Get, path, requestOptions);
    }
    /**
     * Edits a collection
     *
     * @param collectionId The identifier for the collection being edited
     * @param body Data representing the collection being edited
     */
    editCollectionWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling editCollection.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a collection
     *
     * @param collectionId The id of the collection
     * @param body The list of udf values being edited
     */
    editCollectionCustomFieldsWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/collection/${collectionId}/udf'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling editCollectionCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Put, path, requestOptions);
    }
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling getCollection.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Get, path, requestOptions);
    }
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFieldsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/collection/${collectionId}/udf'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling getCollectionCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Get, path, requestOptions);
    }
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollectionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveCollectionsWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202309/parentCollection/${parentCollectionId}/collection'
            .replace('${' + 'parentCollectionId' + '}', String(parentCollectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCollectionId' is not null or undefined
        if (parentCollectionId === null || parentCollectionId === undefined) {
            throw new Error('Required parameter parentCollectionId was null or undefined when calling moveCollections.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2F.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CollectionService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CollectionService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CollectionService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2E = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CommodityService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a commodity
     *
     * @param body Data representing the commodity being created
     */
    createCommodity(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCommodityWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a commodity
     *
     * @param commodityId The commodity Id
     */
    deleteCommodity(commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCommodityWithHttpInfo(commodityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a commodity
     *
     * @param commodityId The commodity Id
     * @param body Data that will be used to update the commodity
     */
    editCommodity(commodityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCommodityWithHttpInfo(commodityId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the commodities  If topmostcostcenter, topmostcollection, topmostplace or account filters are used then the commodities in use at or under that node will be returned.  The inUse filter cannot be combined with the above filters.
     *
     * @param filter The filters
     */
    getCommodities(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommoditiesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a commodity
     *
     * @param commodityId The commodity Id
     */
    getCommodity(commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommodityWithHttpInfo(commodityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a list of units for a specific commodity and value type
     *
     * @param commodityId The specific commodity ID
     * @param valueType The unit type to search for. Not required. Valid values are &#39;use&#39;, &#39;demand&#39;, and &#39;cost&#39;.
     */
    getUnitsByCommodity(commodityId, valueType, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUnitsByCommodityWithHttpInfo(commodityId, valueType, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a commodity
     *
     * @param body Data representing the commodity being created
     */
    createCommodityWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/commodity';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2E.Post, path, requestOptions);
    }
    /**
     * Deletes a commodity
     *
     * @param commodityId The commodity Id
     */
    deleteCommodityWithHttpInfo(commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/commodity/${commodityId}'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling deleteCommodity.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2E.Delete, path, requestOptions);
    }
    /**
     * Edits a commodity
     *
     * @param commodityId The commodity Id
     * @param body Data that will be used to update the commodity
     */
    editCommodityWithHttpInfo(commodityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/commodity/${commodityId}'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling editCommodity.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2E.Put, path, requestOptions);
    }
    /**
     * Gets the commodities  If topmostcostcenter, topmostcollection, topmostplace or account filters are used then the commodities in use at or under that node will be returned.  The inUse filter cannot be combined with the above filters.
     *
     * @param filter The filters
     */
    getCommoditiesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/commodity';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2E.Get, path, requestOptions);
    }
    /**
     * Gets a commodity
     *
     * @param commodityId The commodity Id
     */
    getCommodityWithHttpInfo(commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/commodity/${commodityId}'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling getCommodity.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2E.Get, path, requestOptions);
    }
    /**
     * Returns a list of units for a specific commodity and value type
     *
     * @param commodityId The specific commodity ID
     * @param valueType The unit type to search for. Not required. Valid values are &#39;use&#39;, &#39;demand&#39;, and &#39;cost&#39;.
     */
    getUnitsByCommodityWithHttpInfo(commodityId, valueType, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/commodity/${commodityId}/unit'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling getUnitsByCommodity.');
        }
        if (valueType !== undefined) {
            queryParameters = queryParameters.set('valueType', valueType);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2E.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2D = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CommodityCategoryService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a commodity category
     *
     * @param body Data representing the commodity category being created
     */
    createCommodityCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCommodityCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     */
    deleteCommodityCategory(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCommodityCategoryWithHttpInfo(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     * @param body Data representing the commodity category being created
     */
    editCommodityCategory(commodityCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCommodityCategoryWithHttpInfo(commodityCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the commodity categories
     *
     */
    getCommodityCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommodityCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a commodity category by ID
     *
     * @param commodityCategoryId The commodity category identifier
     */
    getCommodityCategory(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommodityCategoryWithHttpInfo(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a commodity category
     *
     * @param body Data representing the commodity category being created
     */
    createCommodityCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2D.Post, path, requestOptions);
    }
    /**
     * Deletes a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     */
    deleteCommodityCategoryWithHttpInfo(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory/${commodityCategoryId}'
            .replace('${' + 'commodityCategoryId' + '}', String(commodityCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityCategoryId' is not null or undefined
        if (commodityCategoryId === null || commodityCategoryId === undefined) {
            throw new Error('Required parameter commodityCategoryId was null or undefined when calling deleteCommodityCategory.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2D.Delete, path, requestOptions);
    }
    /**
     * Edits a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     * @param body Data representing the commodity category being created
     */
    editCommodityCategoryWithHttpInfo(commodityCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory/${commodityCategoryId}'
            .replace('${' + 'commodityCategoryId' + '}', String(commodityCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityCategoryId' is not null or undefined
        if (commodityCategoryId === null || commodityCategoryId === undefined) {
            throw new Error('Required parameter commodityCategoryId was null or undefined when calling editCommodityCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2D.Put, path, requestOptions);
    }
    /**
     * Gets the commodity categories
     *
     */
    getCommodityCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2D.Get, path, requestOptions);
    }
    /**
     * Gets a commodity category by ID
     *
     * @param commodityCategoryId The commodity category identifier
     */
    getCommodityCategoryWithHttpInfo(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory/${commodityCategoryId}'
            .replace('${' + 'commodityCategoryId' + '}', String(commodityCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityCategoryId' is not null or undefined
        if (commodityCategoryId === null || commodityCategoryId === undefined) {
            throw new Error('Required parameter commodityCategoryId was null or undefined when calling getCommodityCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2D.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityCategoryService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityCategoryService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityCategoryService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2C = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CommodityDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves rolled up actual billing data by commodities for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param commodityId The commodity to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getCommodityActualYearly(commodityId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommodityActualYearlyWithHttpInfo(commodityId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by commodities for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param commodityId The commodity to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getCommodityActualYearlyWithHttpInfo(commodityId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/commodity/${commodityId}/digest/actual/yearly'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling getCommodityActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2C.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CommodityDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2B = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CostCategoryService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits a cost category
     *
     * @param costCategoryId The identifier of the cost category to edit
     * @param body Object containing settings to change
     */
    editCostCategory(costCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCostCategoryWithHttpInfo(costCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all cost categories
     *
     */
    getCostCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a cost category
     *
     * @param costCategoryId The identifier of the cost category to edit
     * @param body Object containing settings to change
     */
    editCostCategoryWithHttpInfo(costCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/costCategory/${costCategoryId}'
            .replace('${' + 'costCategoryId' + '}', String(costCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCategoryId' is not null or undefined
        if (costCategoryId === null || costCategoryId === undefined) {
            throw new Error('Required parameter costCategoryId was null or undefined when calling editCostCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2B.Put, path, requestOptions);
    }
    /**
     * Get all cost categories
     *
     */
    getCostCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/costCategory';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2B.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCategoryService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCategoryService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCategoryService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2A = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CostCenterService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a Cost Center
     *
     * @param body Data representing the cost center being created
     */
    createCostCenter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCostCenterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a cost center
     *
     * @param costCenterId The identifier for the cost center being deleted
     */
    deleteCostCenter(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a cost center
     *
     * @param costCenterId The identifier for the cost center being edited
     * @param body Data representing the cost center being edited
     */
    editCostCenter(costCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCostCenterWithHttpInfo(costCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenter(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCentersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of costCenters to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of costCenterIds to move under the parentCostCenterId
     */
    moveCostCenter(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveCostCenterWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a Cost Center
     *
     * @param body Data representing the cost center being created
     */
    createCostCenterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2A.Post, path, requestOptions);
    }
    /**
     * Deletes a cost center
     *
     * @param costCenterId The identifier for the cost center being deleted
     */
    deleteCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling deleteCostCenter.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2A.Delete, path, requestOptions);
    }
    /**
     * Edits a cost center
     *
     * @param costCenterId The identifier for the cost center being edited
     * @param body Data representing the cost center being edited
     */
    editCostCenterWithHttpInfo(costCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling editCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2A.Put, path, requestOptions);
    }
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2A.Get, path, requestOptions);
    }
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCentersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2A.Get, path, requestOptions);
    }
    /**
     * Move list of costCenters to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of costCenterIds to move under the parentCostCenterId
     */
    moveCostCenterWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentCostCenter/${parentCostCenterId}/costCenter'
            .replace('${' + 'parentCostCenterId' + '}', String(parentCostCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCostCenterId' is not null or undefined
        if (parentCostCenterId === null || parentCostCenterId === undefined) {
            throw new Error('Required parameter parentCostCenterId was null or undefined when calling moveCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2A.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCenterService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCenterService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCenterService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2z = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CostCenterDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthly(costCenterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualMonthlyWithHttpInfo(costCenterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearly(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualYearlyWithHttpInfo(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthlyWithHttpInfo(costCenterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/${costCenterId}/digest/actual/monthly'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenterActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2z.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2z.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyWithHttpInfo(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/${costCenterId}/digest/actual/yearly'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenterActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2z.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2z.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCenterDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCenterDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CostCenterDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2y = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CountryService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves a list of all possible countries
     *
     */
    getCountries(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCountriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of all possible countries
     *
     */
    getCountriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/country';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2y.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CountryService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CountryService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CountryService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2x = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class CustomerService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves an array of customers.
     *
     * @param filter
     */
    getCustomers(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCustomersWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of customers.
     *
     * @param filter
     */
    getCustomersWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/customer';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2x.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CustomerService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CustomerService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CustomerService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2w = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class DashboardService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Add a widget to a dashboard  To add widgets to a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    addWidget(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.addWidgetWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Copy a dashboard  To copy a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Request object
     */
    copyDashboard(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.copyDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a dashboard
     *
     * @param body
     */
    createDashboard(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createDashboardWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the visibility of a dashboard for the current user  This must be a dashboard you can see  Which means you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Set Visibility
     */
    dashboardActionVisible(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.dashboardActionVisibleWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a dashboard  To delete a dashboard you must have created it  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Specific dashboard
     */
    deleteDashboard(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteDashboardWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a dashboard  To edit a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId
     * @param body
     */
    editDashboard(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits the public display settings for a dashboard. Settings can only be applied to public dashboards. Filter settings cannot be applied to Map dashboards.  To apply these settings, you must have the PublicDashboardsOrMaps Manage permission.  You must also have either created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier for the dashboard to apply settings to.
     * @param body An object containing the settings to be applied.
     */
    editDashboardSettings(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the shared users and user groups for a dashboard  To remove sharing completely set SharedWithEveryone to false, SharedUserIds to [], and SharedUserGroupIds to []  You must have created the dashboard and have SharedDashboardsOrMaps Create permission  or have DashboardAdministrator Manage permission and the dashboard must be shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Dashboard Identifier
     * @param body users and user groups to share the dashboard with
     */
    editDashboardShare(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardShareWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reorder, edit, and delete specific widgets on a dashboard.  To edit dashboard widgets you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    editDashboardWidgets(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardWidgetsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Applies display settings and filters to a map dashboard. These settings are specific to map dashboards, and cannot be applied to standard dashboards.  To apply these settings, You must also have either:  Created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier of the dashboard to apply these settings to
     * @param body Object containing the settings to be applied.
     */
    editMapDashboardSettings(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMapDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a dashboard.  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     */
    getDashboard(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDashboardWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the individual users and user groups a dashboard is shared with  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Dashboard Identifier
     */
    getDashboardShare(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDashboardShareWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all widgets on a dashboard  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Dashboard Identifier
     */
    getDashboardWidgets(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDashboardWidgetsWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of dashboards. The array of dashboards can be filtered by a number of criteria. See the filter property for more details  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param filter
     */
    getDashboards(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDashboardsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the current display settings and filters for a specific map dashboard. Cannot be used to retreive settings for a standard dashboard.
     *
     * @param dashboardId The identifier of the dashboard to get the settings of
     */
    getMapDashboardSettings(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMapDashboardSettingsWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Add a widget to a dashboard  To add widgets to a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    addWidgetWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/widget'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling addWidget.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Post, path, requestOptions);
    }
    /**
     * Copy a dashboard  To copy a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Request object
     */
    copyDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/copy'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling copyDashboard.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Post, path, requestOptions);
    }
    /**
     * Creates a dashboard
     *
     * @param body
     */
    createDashboardWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Post, path, requestOptions);
    }
    /**
     * Update the visibility of a dashboard for the current user  This must be a dashboard you can see  Which means you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Set Visibility
     */
    dashboardActionVisibleWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/visible'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling dashboardActionVisible.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Put, path, requestOptions);
    }
    /**
     * Delete a dashboard  To delete a dashboard you must have created it  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Specific dashboard
     */
    deleteDashboardWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling deleteDashboard.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Delete, path, requestOptions);
    }
    /**
     * Edit a dashboard  To edit a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId
     * @param body
     */
    editDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboard.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Put, path, requestOptions);
    }
    /**
     * Edits the public display settings for a dashboard. Settings can only be applied to public dashboards. Filter settings cannot be applied to Map dashboards.  To apply these settings, you must have the PublicDashboardsOrMaps Manage permission.  You must also have either created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier for the dashboard to apply settings to.
     * @param body An object containing the settings to be applied.
     */
    editDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/publicsetting'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboardSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Put, path, requestOptions);
    }
    /**
     * Update the shared users and user groups for a dashboard  To remove sharing completely set SharedWithEveryone to false, SharedUserIds to [], and SharedUserGroupIds to []  You must have created the dashboard and have SharedDashboardsOrMaps Create permission  or have DashboardAdministrator Manage permission and the dashboard must be shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Dashboard Identifier
     * @param body users and user groups to share the dashboard with
     */
    editDashboardShareWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/share'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboardShare.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Put, path, requestOptions);
    }
    /**
     * Reorder, edit, and delete specific widgets on a dashboard.  To edit dashboard widgets you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    editDashboardWidgetsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/widget'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboardWidgets.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Put, path, requestOptions);
    }
    /**
     * Applies display settings and filters to a map dashboard. These settings are specific to map dashboards, and cannot be applied to standard dashboards.  To apply these settings, You must also have either:  Created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier of the dashboard to apply these settings to
     * @param body Object containing the settings to be applied.
     */
    editMapDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/mapsetting'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editMapDashboardSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Put, path, requestOptions);
    }
    /**
     * Retrieves a dashboard.  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     */
    getDashboardWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling getDashboard.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Get, path, requestOptions);
    }
    /**
     * Get the individual users and user groups a dashboard is shared with  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Dashboard Identifier
     */
    getDashboardShareWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/share'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling getDashboardShare.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Get, path, requestOptions);
    }
    /**
     * Get all widgets on a dashboard  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Dashboard Identifier
     */
    getDashboardWidgetsWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/widget'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling getDashboardWidgets.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of dashboards. The array of dashboards can be filtered by a number of criteria. See the filter property for more details  For a dashboard to be returned you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param filter
     */
    getDashboardsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Get, path, requestOptions);
    }
    /**
     * Gets the current display settings and filters for a specific map dashboard. Cannot be used to retreive settings for a standard dashboard.
     *
     * @param dashboardId The identifier of the dashboard to get the settings of
     */
    getMapDashboardSettingsWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/mapsetting'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling getMapDashboardSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2w.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2v = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class DataPointService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPoint(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createDataPointWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a data point
     *
     * @param dataPointId The data point identifier
     */
    deleteDataPoint(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPoint(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDataPointWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinel(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.enableSentinelWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPoint(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPoints(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataPointsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPointWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2v.Post, path, requestOptions);
    }
    /**
     * Deletes a data point
     *
     * @param dataPointId The data point identifier
     */
    deleteDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling deleteDataPoint.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2v.Delete, path, requestOptions);
    }
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPointWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling editDataPoint.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2v.Put, path, requestOptions);
    }
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinelWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}/sentinel'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling enableSentinel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2v.Put, path, requestOptions);
    }
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling getDataPoint.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2v.Get, path, requestOptions);
    }
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPointsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2v.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DataPointService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DataPointService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DataPointService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2u = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EmissionRecordService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create an emission record
     *
     * @param body Data representing the record being created
     */
    createEmissionRecord(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionRecordWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an emission record
     *
     * @param emissionRecordId The Id of the emission record to delete
     */
    deleteEmissionRecord(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an emission record
     *
     * @param emissionRecordId The Id of the emission record to edit
     * @param body Data representing the emission record being edited
     */
    editEmissionRecord(emissionRecordId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionRecordWithHttpInfo(emissionRecordId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecord(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecords(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionRecordsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create an emission record
     *
     * @param body Data representing the record being created
     */
    createEmissionRecordWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2u.Post, path, requestOptions);
    }
    /**
     * Delete an emission record
     *
     * @param emissionRecordId The Id of the emission record to delete
     */
    deleteEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord/${emissionRecordId}'
            .replace('${' + 'emissionRecordId' + '}', String(emissionRecordId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionRecordId' is not null or undefined
        if (emissionRecordId === null || emissionRecordId === undefined) {
            throw new Error('Required parameter emissionRecordId was null or undefined when calling deleteEmissionRecord.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2u.Delete, path, requestOptions);
    }
    /**
     * Edit an emission record
     *
     * @param emissionRecordId The Id of the emission record to edit
     * @param body Data representing the emission record being edited
     */
    editEmissionRecordWithHttpInfo(emissionRecordId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord/${emissionRecordId}'
            .replace('${' + 'emissionRecordId' + '}', String(emissionRecordId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionRecordId' is not null or undefined
        if (emissionRecordId === null || emissionRecordId === undefined) {
            throw new Error('Required parameter emissionRecordId was null or undefined when calling editEmissionRecord.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2u.Put, path, requestOptions);
    }
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord/${emissionRecordId}'
            .replace('${' + 'emissionRecordId' + '}', String(emissionRecordId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionRecordId' is not null or undefined
        if (emissionRecordId === null || emissionRecordId === undefined) {
            throw new Error('Required parameter emissionRecordId was null or undefined when calling getEmissionRecord.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2u.Get, path, requestOptions);
    }
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecordsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2u.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EmissionRecordService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EmissionRecordService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EmissionRecordService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2t = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EmissionSourceService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an emissions source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSource(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionSourceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an emission source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithMultiFactors(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionSourceWithMultiFactorsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being deleted
     * @param deleteRecords Should this cascade to delete any records associated with this emissions source
     */
    deleteEmissionSource(emissionSourceId, deleteRecords, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEmissionSourceWithHttpInfo(emissionSourceId, deleteRecords, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFields(emissionSourceId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSource(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a emissions source
     *
     * @param emissionSourceId The id of the emissions source
     * @param body The list of udf values being edited
     */
    editEmissionSourceCustomFields(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Assigns the specified scope category and factor pairings to the specified emission sources.  If one or more of the factors provided cannot be applied to the emission source, that emission source will be skipped.
     *
     * @param body
     */
    editEmissionSourceFactorCategoriesBulk(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an emission source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithMultiFactors(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit meter data in an Emission Source
     *
     * @param emissionSourceId The Emission Source identifier
     * @param body Meter data to assign to the Emission Source
     */
    editMeterLink(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterLinkWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSource(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourceWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFields(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactors(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSources(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourcesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourcesWithMultiFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveEmissionSources(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveEmissionSourcesWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Resets the scope category and factor pairings of the specified emission sources to their commodity default.  If no default exists for an emission source&#39;s commodity, that emission source will be skipped.
     *
     * @param body
     */
    resetEmissionSourceFactorCategoriesBulk(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.resetEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an emissions source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Post, path, requestOptions);
    }
    /**
     * Creates an emission source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithMultiFactorsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Post, path, requestOptions);
    }
    /**
     * Deletes an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being deleted
     * @param deleteRecords Should this cascade to delete any records associated with this emissions source
     */
    deleteEmissionSourceWithHttpInfo(emissionSourceId, deleteRecords, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling deleteEmissionSource.');
        }
        if (deleteRecords !== undefined) {
            queryParameters = queryParameters.set('deleteRecords', deleteRecords);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Delete, path, requestOptions);
    }
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/${emissionSourceId}/udf/${udfId}/download'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling downloadEmissionSourceCustomFields.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadEmissionSourceCustomFields.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Get, path, requestOptions);
    }
    /**
     * Edits an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editEmissionSource.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a emissions source
     *
     * @param emissionSourceId The id of the emissions source
     * @param body The list of udf values being edited
     */
    editEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/${emissionSourceId}/udf'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editEmissionSourceCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    /**
     * Assigns the specified scope category and factor pairings to the specified emission sources.  If one or more of the factors provided cannot be applied to the emission source, that emission source will be skipped.
     *
     * @param body
     */
    editEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/factorCategory/update';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    /**
     * Edits an emission source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editEmissionSourceWithMultiFactors.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    /**
     * Edit meter data in an Emission Source
     *
     * @param emissionSourceId The Emission Source identifier
     * @param body Meter data to assign to the Emission Source
     */
    editMeterLinkWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/emissionSource/${emissionSourceId}/meter'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editMeterLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling getEmissionSource.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Get, path, requestOptions);
    }
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/${emissionSourceId}/udf'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling getEmissionSourceCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Get, path, requestOptions);
    }
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling getEmissionSourceWithMultiFactors.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Get, path, requestOptions);
    }
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Get, path, requestOptions);
    }
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveEmissionSourcesWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202309/parentCollection/${parentCollectionId}/emissionSource'
            .replace('${' + 'parentCollectionId' + '}', String(parentCollectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCollectionId' is not null or undefined
        if (parentCollectionId === null || parentCollectionId === undefined) {
            throw new Error('Required parameter parentCollectionId was null or undefined when calling moveEmissionSources.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    /**
     * Resets the scope category and factor pairings of the specified emission sources to their commodity default.  If no default exists for an emission source&#39;s commodity, that emission source will be skipped.
     *
     * @param body
     */
    resetEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/factorCategory/reset';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2t.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EmissionSourceService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EmissionSourceService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EmissionSourceService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2s = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EnergyManagerService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param question
     */
    ask(question, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.askWithHttpInfo(question, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param question
     */
    askWithHttpInfo(question, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/energymanager/ask';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (question !== undefined) {
            queryParameters = queryParameters.set('question', question);
        }
        // to determine the Accept header
        let produces = [
            'text/plain',
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2s.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyManagerService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyManagerService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyManagerService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2r = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EnergyProjectService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an Energy Project
     *
     * @param body Data representing the Energy project being created
     */
    createEnergyProject(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEnergyProjectWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a energy project type
     *
     * @param body
     */
    createEnergyProjectType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEnergyProjectTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an Energy Project
     *
     * @param projectId The identifier for the energy project being deleted
     */
    deleteEnergyProject(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFields(energyProjectId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an Energy Project
     *
     * @param projectId The identifier for the energy project being edited
     * @param body
     */
    editEnergyProject(projectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyProjectWithHttpInfo(projectId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a energy project
     *
     * @param energyProjectId The id of the energy project
     * @param body The list of udf values being edited
     */
    editEnergyProjectCustomFields(energyProjectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProject(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFields(energyProjectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManager(query, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectManagerWithHttpInfo(query, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an Energy Project
     *
     * @param body Data representing the Energy project being created
     */
    createEnergyProjectWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Post, path, requestOptions);
    }
    /**
     * Create a energy project type
     *
     * @param body
     */
    createEnergyProjectTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/energyprojecttype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Post, path, requestOptions);
    }
    /**
     * Deletes an Energy Project
     *
     * @param projectId The identifier for the energy project being deleted
     */
    deleteEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/${projectId}'
            .replace('${' + 'projectId' + '}', String(projectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'projectId' is not null or undefined
        if (projectId === null || projectId === undefined) {
            throw new Error('Required parameter projectId was null or undefined when calling deleteEnergyProject.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Delete, path, requestOptions);
    }
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/energyproject/${energyProjectId}/udf/${udfId}/download'
            .replace('${' + 'energyProjectId' + '}', String(energyProjectId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyProjectId' is not null or undefined
        if (energyProjectId === null || energyProjectId === undefined) {
            throw new Error('Required parameter energyProjectId was null or undefined when calling downloadEnergyProjectCustomFields.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadEnergyProjectCustomFields.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Get, path, requestOptions);
    }
    /**
     * Edits an Energy Project
     *
     * @param projectId The identifier for the energy project being edited
     * @param body
     */
    editEnergyProjectWithHttpInfo(projectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/${projectId}'
            .replace('${' + 'projectId' + '}', String(projectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'projectId' is not null or undefined
        if (projectId === null || projectId === undefined) {
            throw new Error('Required parameter projectId was null or undefined when calling editEnergyProject.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a energy project
     *
     * @param energyProjectId The id of the energy project
     * @param body The list of udf values being edited
     */
    editEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/energyproject/${energyProjectId}/udf'
            .replace('${' + 'energyProjectId' + '}', String(energyProjectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyProjectId' is not null or undefined
        if (energyProjectId === null || energyProjectId === undefined) {
            throw new Error('Required parameter energyProjectId was null or undefined when calling editEnergyProjectCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Put, path, requestOptions);
    }
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/${projectId}'
            .replace('${' + 'projectId' + '}', String(projectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'projectId' is not null or undefined
        if (projectId === null || projectId === undefined) {
            throw new Error('Required parameter projectId was null or undefined when calling getEnergyProject.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Get, path, requestOptions);
    }
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/energyproject/${energyProjectId}/udf'
            .replace('${' + 'energyProjectId' + '}', String(energyProjectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyProjectId' is not null or undefined
        if (energyProjectId === null || energyProjectId === undefined) {
            throw new Error('Required parameter energyProjectId was null or undefined when calling getEnergyProjectCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Get, path, requestOptions);
    }
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManagerWithHttpInfo(query, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/projectmanager';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (query !== undefined) {
            queryParameters = queryParameters.set('query', query);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Get, path, requestOptions);
    }
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/energyprojecttype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2r.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyProjectService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyProjectService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyProjectService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2q = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EnergyStarService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequests(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.acceptPropertyAndMeterSharingRequestsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Automatically submit billing data to ENERGY STAR  By default calendarized bill data for a 13-month period (excludes current and last month) in the \&quot;Ready\&quot; state for all buildings setup to automatically submit to ENERGY STAR will be submitted  If 13 months is not preferred, set up the owner&#39;s systemdata key called \&quot;EnergyStarAutoSubmitNumOfMonths\&quot; with an integer value representing the preferred number of months   For example - Today is 25th Nov 2021 - all calendarized data for Sep 2020 through Sep 2021 will be submitted  The buildings submitted will be within the user&#39;s topmost place  No data prior to the earliest period to submit set up in ENERGY STAR settings will ever be submitted
     *
     */
    autoSubmitToEnergyStar(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.autoSubmitToEnergyStarWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Initiate (create) a submission of place data to ENERGY STAR
     *
     * @param body
     */
    createEnergyStarSubmission(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEnergyStarSubmissionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit settings for ENERGY STAR submissions
     *
     * @param body ENERGY STAR settings
     */
    editEnergyStarSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyStarSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarCommodityMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the submission status for places by submission period.   Places that do not match the filter criteria will not be returned.    NOTE: Deleting/voiding bills that have already been submitted will not cause submission status to change from \&quot;submitted\&quot;.
     * Returned submission status:      Submitted  - submission has been made for this place and submission period and no bills have been created or modified since the last submission      No Data    - no submission has been made for this place and submission period and current submission period has no billing data      Incomplete - no submission has been made for this place and submission period and current billing data is incomplete (some meters may not have data or some days in submission period may not have data)      Ready      - no submission has been made for this place and submission period and current billing data is complete (every meter has data for every day of this period), or submission has been made but billing data has been added or modified since the last submission
     * @param submissionBeginPeriod The beginning submission period to select
     * @param submissionEndPeriod The ending submission period to select; set equal to beginning submission period get one period
     * @param filter API filter string containing conditions
     */
    getEnergyStarSubmissionStatusList(submissionBeginPeriod, submissionEndPeriod, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarSubmissionStatusListWithHttpInfo(submissionBeginPeriod, submissionEndPeriod, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an ENERGY STAR task with its details
     *
     * @param energyStarTaskId
     */
    getEnergyStarTask(energyStarTaskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarTaskWithHttpInfo(energyStarTaskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the connection status for a Portfolio Manager account and database
     *
     * @param pmUserName User name used to log in to Portfolio Manager
     */
    getPMConnectionStatus(pmUserName, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPMConnectionStatusWithHttpInfo(pmUserName, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperties(includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPortfolioManagerPropertiesWithHttpInfo(includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperty(pmPropertyId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPortfolioManagerPropertyWithHttpInfo(pmPropertyId, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMeters(pmPropertyId, includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPortfolioManagerPropertyMetersWithHttpInfo(pmPropertyId, includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink owner from portfolio manager account
     *
     * @param deleteData If true, delete EnergyStar metrics and score. False by default
     */
    unlinkOwnerFromPortfolioManager(deleteData, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkOwnerFromPortfolioManagerWithHttpInfo(deleteData, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update ENERGY STAR metrics for the places matching the request criteria.
     *
     * @param body Periods and list of place identifiers for which to update metrics
     */
    updateEnergyStarMetrics(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateEnergyStarMetricsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequestsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/acceptShares';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Put, path, requestOptions);
    }
    /**
     * Automatically submit billing data to ENERGY STAR  By default calendarized bill data for a 13-month period (excludes current and last month) in the \&quot;Ready\&quot; state for all buildings setup to automatically submit to ENERGY STAR will be submitted  If 13 months is not preferred, set up the owner&#39;s systemdata key called \&quot;EnergyStarAutoSubmitNumOfMonths\&quot; with an integer value representing the preferred number of months   For example - Today is 25th Nov 2021 - all calendarized data for Sep 2020 through Sep 2021 will be submitted  The buildings submitted will be within the user&#39;s topmost place  No data prior to the earliest period to submit set up in ENERGY STAR settings will ever be submitted
     *
     */
    autoSubmitToEnergyStarWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/autosubmit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Post, path, requestOptions);
    }
    /**
     * Initiate (create) a submission of place data to ENERGY STAR
     *
     * @param body
     */
    createEnergyStarSubmissionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/submit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Post, path, requestOptions);
    }
    /**
     * Edit settings for ENERGY STAR submissions
     *
     * @param body ENERGY STAR settings
     */
    editEnergyStarSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Put, path, requestOptions);
    }
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202109/energyStar/commodity';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get the submission status for places by submission period.   Places that do not match the filter criteria will not be returned.    NOTE: Deleting/voiding bills that have already been submitted will not cause submission status to change from \&quot;submitted\&quot;.
     * Returned submission status:      Submitted  - submission has been made for this place and submission period and no bills have been created or modified since the last submission      No Data    - no submission has been made for this place and submission period and current submission period has no billing data      Incomplete - no submission has been made for this place and submission period and current billing data is incomplete (some meters may not have data or some days in submission period may not have data)      Ready      - no submission has been made for this place and submission period and current billing data is complete (every meter has data for every day of this period), or submission has been made but billing data has been added or modified since the last submission
     * @param submissionBeginPeriod The beginning submission period to select
     * @param submissionEndPeriod The ending submission period to select; set equal to beginning submission period get one period
     * @param filter API filter string containing conditions
     */
    getEnergyStarSubmissionStatusListWithHttpInfo(submissionBeginPeriod, submissionEndPeriod, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/submissionStatus';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'submissionBeginPeriod' is not null or undefined
        if (submissionBeginPeriod === null || submissionBeginPeriod === undefined) {
            throw new Error('Required parameter submissionBeginPeriod was null or undefined when calling getEnergyStarSubmissionStatusList.');
        }
        // verify required parameter 'submissionEndPeriod' is not null or undefined
        if (submissionEndPeriod === null || submissionEndPeriod === undefined) {
            throw new Error('Required parameter submissionEndPeriod was null or undefined when calling getEnergyStarSubmissionStatusList.');
        }
        if (submissionBeginPeriod !== undefined) {
            queryParameters = queryParameters.set('submissionBeginPeriod', submissionBeginPeriod);
        }
        if (submissionEndPeriod !== undefined) {
            queryParameters = queryParameters.set('submissionEndPeriod', submissionEndPeriod);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get an ENERGY STAR task with its details
     *
     * @param energyStarTaskId
     */
    getEnergyStarTaskWithHttpInfo(energyStarTaskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/task/${energyStarTaskId}'
            .replace('${' + 'energyStarTaskId' + '}', String(energyStarTaskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyStarTaskId' is not null or undefined
        if (energyStarTaskId === null || energyStarTaskId === undefined) {
            throw new Error('Required parameter energyStarTaskId was null or undefined when calling getEnergyStarTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get the connection status for a Portfolio Manager account and database
     *
     * @param pmUserName User name used to log in to Portfolio Manager
     */
    getPMConnectionStatusWithHttpInfo(pmUserName, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/connectionstatus';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (pmUserName !== undefined) {
            queryParameters = queryParameters.set('pmUserName', pmUserName);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertiesWithHttpInfo(includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/pmProperty';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (includeOnlyUnlinked !== undefined) {
            queryParameters = queryParameters.set('includeOnlyUnlinked', includeOnlyUnlinked);
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertyWithHttpInfo(pmPropertyId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/pmProperty/${pmPropertyId}'
            .replace('${' + 'pmPropertyId' + '}', String(pmPropertyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'pmPropertyId' is not null or undefined
        if (pmPropertyId === null || pmPropertyId === undefined) {
            throw new Error('Required parameter pmPropertyId was null or undefined when calling getPortfolioManagerProperty.');
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMetersWithHttpInfo(pmPropertyId, includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/pmProperty/${pmPropertyId}/pmMeter'
            .replace('${' + 'pmPropertyId' + '}', String(pmPropertyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'pmPropertyId' is not null or undefined
        if (pmPropertyId === null || pmPropertyId === undefined) {
            throw new Error('Required parameter pmPropertyId was null or undefined when calling getPortfolioManagerPropertyMeters.');
        }
        if (includeOnlyUnlinked !== undefined) {
            queryParameters = queryParameters.set('includeOnlyUnlinked', includeOnlyUnlinked);
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Get, path, requestOptions);
    }
    /**
     * Unlink owner from portfolio manager account
     *
     * @param deleteData If true, delete EnergyStar metrics and score. False by default
     */
    unlinkOwnerFromPortfolioManagerWithHttpInfo(deleteData, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/unlink';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (deleteData !== undefined) {
            queryParameters = queryParameters.set('deleteData', deleteData);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Delete, path, requestOptions);
    }
    /**
     * Update ENERGY STAR metrics for the places matching the request criteria.
     *
     * @param body Periods and list of place identifiers for which to update metrics
     */
    updateEnergyStarMetricsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/metrics';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2q.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyStarService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyStarService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyStarService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2p = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EnvironmentService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     */
    environment(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.environmentWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    environmentWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/environment';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2p.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnvironmentService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnvironmentService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnvironmentService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2o = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EsaChannelService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannel(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaChannelWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersion(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaChannelVersionWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    deleteEsaChannel(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannel(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaChannelWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersion(esaChannelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaChannelVersionWithHttpInfo(esaChannelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannel(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersion(esaChannelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelVersionWithHttpInfo(esaChannelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersions(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelVersionsWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannels(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannelWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Post, path, requestOptions);
    }
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersionWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling createEsaChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Post, path, requestOptions);
    }
    /**
     * Deletes an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    deleteEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling deleteEsaChannel.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Delete, path, requestOptions);
    }
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannelWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling editEsaChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Put, path, requestOptions);
    }
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersionWithHttpInfo(esaChannelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version/${versionId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling editEsaChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editEsaChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Put, path, requestOptions);
    }
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getEsaChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Get, path, requestOptions);
    }
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersionWithHttpInfo(esaChannelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version/${versionId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getEsaChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getEsaChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersionsWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getEsaChannelVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannelsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2o.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaChannelService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaChannelService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaChannelService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2n = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EsaPlaceService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.bulkEditDataRollupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA place
     *
     * @param body Data representing the ESA place being created
     */
    createEsaPlace(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an ESA place
     *
     * @param placeId The identifier for the ESA place being deleted
     */
    deleteEsaPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlace(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedules(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaPlaceSchedulesWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistory(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaPlaceSizeHistoryWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizes(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceChildrenSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedules(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceSchedulesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistory(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceSizeHistoryWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlaces(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlace(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveEsaPlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/dataRollup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Put, path, requestOptions);
    }
    /**
     * Creates an ESA place
     *
     * @param body Data representing the ESA place being created
     */
    createEsaPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Post, path, requestOptions);
    }
    /**
     * Deletes an ESA place
     *
     * @param placeId The identifier for the ESA place being deleted
     */
    deleteEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deleteEsaPlace.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Delete, path, requestOptions);
    }
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEsaPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Put, path, requestOptions);
    }
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedulesWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaplace/${placeId}/schedule'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEsaPlaceSchedules.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Put, path, requestOptions);
    }
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistoryWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}/placeSize'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEsaPlaceSizeHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Put, path, requestOptions);
    }
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Get, path, requestOptions);
    }
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}/placeSize/child'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlaceChildrenSizes.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Get, path, requestOptions);
    }
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedulesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaplace/${placeId}/schedule'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlaceSchedules.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Get, path, requestOptions);
    }
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistoryWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}/placeSize/history'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlaceSizeHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Get, path, requestOptions);
    }
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/parentPlace/${parentPlaceId}/place'
            .replace('${' + 'parentPlaceId' + '}', String(parentPlaceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentPlaceId' is not null or undefined
        if (parentPlaceId === null || parentPlaceId === undefined) {
            throw new Error('Required parameter parentPlaceId was null or undefined when calling moveEsaPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2n.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaPlaceService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaPlaceService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaPlaceService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2m = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class EsaReadingService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create new readings. Existing readings at the same time for a given channel will be overwritten.
     *
     * @param body Readings to be imported
     */
    createEsaReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes existing channel readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body
     */
    deleteEsaReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes existing summarized readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.  If the summarized reading is system-generated, the endpoint will return an error indicating that it cannot be deleted.
     *
     * @param body
     */
    deleteEsaSummarizedReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaSummarizedReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all raw and processed ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaReadings(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all summarized ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaSummarizedReadings(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaSummarizedReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all summarized ESA readings and exports them as a CSV file. File contents can be filtered and ordered.
     *
     * @param filter
     * @param orderBy
     */
    getEsaSummarizedReadingsAsCSV(filter, orderBy, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaSummarizedReadingsAsCSVWithHttpInfo(filter, orderBy, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates and Edits summarized readings for a datapoint and channel
     *
     * @param body
     */
    upsertEsaSummarizedReading(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.upsertEsaSummarizedReadingWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create new readings. Existing readings at the same time for a given channel will be overwritten.
     *
     * @param body Readings to be imported
     */
    createEsaReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaReading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Post, path, requestOptions);
    }
    /**
     * Deletes existing channel readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body
     */
    deleteEsaReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaReading/delete';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Post, path, requestOptions);
    }
    /**
     * Deletes existing summarized readings.  Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.  If the summarized reading is system-generated, the endpoint will return an error indicating that it cannot be deleted.
     *
     * @param body
     */
    deleteEsaSummarizedReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/esaReading/summarized/delete';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Post, path, requestOptions);
    }
    /**
     * Retrieves all raw and processed ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaReading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Get, path, requestOptions);
    }
    /**
     * Retrieves all summarized ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaSummarizedReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/esaReading/summarized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Get, path, requestOptions);
    }
    /**
     * Retrieves all summarized ESA readings and exports them as a CSV file. File contents can be filtered and ordered.
     *
     * @param filter
     * @param orderBy
     */
    getEsaSummarizedReadingsAsCSVWithHttpInfo(filter, orderBy, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/esaReading/summarized/csv';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Get, path, requestOptions);
    }
    /**
     * Creates and Edits summarized readings for a datapoint and channel
     *
     * @param body
     */
    upsertEsaSummarizedReadingWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/esaReading/summarized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2m.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaReadingService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaReadingService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EsaReadingService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2l = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ExportService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param exportFileName
     * @param body
     */
    exportHistoricalBills(exportFileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportHistoricalBillsWithHttpInfo(exportFileName, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param exportFileName
     * @param body
     */
    exportHistoricalBillsWithHttpInfo(exportFileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generatebillimport';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (exportFileName !== undefined) {
            queryParameters = queryParameters.set('exportFileName', exportFileName);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2l.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExportService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExportService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExportService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2k = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class FileStoreService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get a list of file data types, their supported extensions, and max size
     *
     */
    getFileDataTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFileDataTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Upload a file
     * | File Data Type | File Data Type Id | Supported File Types                                                                                                                                                                                                                                                                             | Maximum Size |  |----------------|-------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------|  | Image          | 16                | jpg, png, svg, gif, heic                                                                                                                                                                                                                                                                               | 100 MB       |  | PDF            | 17                | pdf                                                                                                                                                                                                                                                                                              | 100 MB       |  | Document       | 18                | MS Word (doc, dot, wbk, docx, docm, dotx, dotm, docb)&lt;br /&gt;Excel (xls, xlt, xlm, xlsx, xlsm, xltx, xltm, xlsb, xlw)&lt;br /&gt;PowerPoint (ppt, pot, pps, pptx, pptm, potx, potm, ppsx, ppsm, sldx, sldm)&lt;br /&gt;OpenOffice (odt, ods, odp)&lt;br /&gt;OneNote (one)&lt;br /&gt;Other (rtf, txt, csv, xml)&lt;br /&gt; Zip (zip) | 100 MB       |
     * @param fileDataTypeId The data type of the file. You can retrieve a list of supported data types by calling the GetFileDataTypes API
     * @param fileName The name of the file
     * @param body Binary data containing the file contents
     */
    uploadFile(fileDataTypeId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.uploadFileWithHttpInfo(fileDataTypeId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of file data types, their supported extensions, and max size
     *
     */
    getFileDataTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/fileStore/fileDataType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2k.Get, path, requestOptions);
    }
    /**
     * Upload a file
     * | File Data Type | File Data Type Id | Supported File Types                                                                                                                                                                                                                                                                             | Maximum Size |  |----------------|-------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------|  | Image          | 16                | jpg, png, svg, gif, heic                                                                                                                                                                                                                                                                               | 100 MB       |  | PDF            | 17                | pdf                                                                                                                                                                                                                                                                                              | 100 MB       |  | Document       | 18                | MS Word (doc, dot, wbk, docx, docm, dotx, dotm, docb)&lt;br /&gt;Excel (xls, xlt, xlm, xlsx, xlsm, xltx, xltm, xlsb, xlw)&lt;br /&gt;PowerPoint (ppt, pot, pps, pptx, pptm, potx, potm, ppsx, ppsm, sldx, sldm)&lt;br /&gt;OpenOffice (odt, ods, odp)&lt;br /&gt;OneNote (one)&lt;br /&gt;Other (rtf, txt, csv, xml)&lt;br /&gt; Zip (zip) | 100 MB       |
     * @param fileDataTypeId The data type of the file. You can retrieve a list of supported data types by calling the GetFileDataTypes API
     * @param fileName The name of the file
     * @param body Binary data containing the file contents
     */
    uploadFileWithHttpInfo(fileDataTypeId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/fileStore/fileDataType/${fileDataTypeId}/upload'
            .replace('${' + 'fileDataTypeId' + '}', String(fileDataTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'fileDataTypeId' is not null or undefined
        if (fileDataTypeId === null || fileDataTypeId === undefined) {
            throw new Error('Required parameter fileDataTypeId was null or undefined when calling uploadFile.');
        }
        if (fileName !== undefined) {
            queryParameters = queryParameters.set('fileName', fileName);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/octet-stream'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2k.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileStoreService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileStoreService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileStoreService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2j = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class FilterService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves list of values for data filter
     *
     * @param dataFieldId
     * @param search
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getFilterData(dataFieldId, search, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFilterDataWithHttpInfo(dataFieldId, search, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves list of values for data filter
     *
     * @param dataFieldId
     * @param search
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getFilterDataWithHttpInfo(dataFieldId, search, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/filterData/${dataFieldId}'
            .replace('${' + 'dataFieldId' + '}', String(dataFieldId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataFieldId' is not null or undefined
        if (dataFieldId === null || dataFieldId === undefined) {
            throw new Error('Required parameter dataFieldId was null or undefined when calling getFilterData.');
        }
        if (search !== undefined) {
            queryParameters = queryParameters.set('search', search);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2j.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FilterService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FilterService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FilterService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2i = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class FlagService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccount(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billFlagSummaryByAccountWithHttpInfo(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeter(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billFlagSummaryByMeterWithHttpInfo(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createFlagTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagType(flagTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteFlagTypeWithHttpInfo(flagTypeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit flag data for a specified entity
     * This API supports a wide variety of Flag-related actions. Below are summaries of expected outcomes for possible combinations of property values.      Create Flag(the entity is not yet flagged, therefore there is no \&quot;modified\&quot; info)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                                                                                   Action                                                                                                                    |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                                                                                                                     |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                                                                                                                                       |  | null                     | null                     | null                     | null                     | null                     | null                 | null                 | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                                                                                                           |  | null                     | **not null**             | **not null**             | **not null**             | **not null**             | false                | false                | Exception, must have a type                                                                                                                                                                                                                 |  | **not null**             | null                     | null                     | null                     | null                     | false                | false                | Flagged, unresolved, specified type                                                                                                                                                                                                         |  | **not null**             | **not null**             | null                     | null                     | null                     | false                | false                | Flagged, unresolved(ignoring specified status), specified type                                                                                                                                                                              |  | **not null**             | null                     | **not null**             | null                     | null                     | false                | false                | Flagged, unresolved, specified type, cost recovery                                                                                                                                                                                          |  | **not null**             | null                     | null                     | **not null**&lt;sup&gt;1&lt;/sup&gt; | null                     | false                | false                | Flagged, unresolved, specified type&lt;br /&gt;&lt;sup&gt;1&lt;/sup&gt;If assignees not empty, assigned                                                                                                                                                       |  | **not null**             | null                     | null                     | null                     | **not null**             | false                | false                | Flagged, unresolved, specified type, comment                                                                                                                                                                                                |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment                                                            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;3&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;No action; will not release a newly flagged bill for export |    Edit Unresolved Flag (the entity is already flagged)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    | ReleaseExportHold |                                                                       Action                                                                        |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**          | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                             |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**      | Exception, must have at least one set                                                                                                               |  | null                     | null                     | null                     | null                     | null                     | false                | false             | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                   |  | **system or user type**  | null                     | null                     | null                     | null                     | false                | false             | Flag type updated                                                                                                                                   |  | null                     | **resolved**             | null                     | null                     | null                     | false                | false             | Resolved                                                                                                                                            |  | null                     | **resolved**             | null                     | null                     | null                     | false                | **true**          | Resolved, released for export                                                                                                                       |  | null                     | null                     | **not null**             | null                     | null                     | false                | false             | Updated, cost recovery                                                                                                                              |  | null                     | null                     | null                     | **not null**             | null                     | false                | false             | Assigned                                                                                                                                            |  | null                     | null                     | null                     | null                     | **not null**             | false                | false             | Updated, comment                                                                                                                                    |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment                   |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |    Edit Resolved Flag (the entity is already flagged)    |        FlagTypeId        |        FlagStatusId        |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                              Action                                                               |  | ------------------------ | -------------------------- | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | --------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                       | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                           |  | null                     | null                       | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                             |  | null                     | null                       | null                     | null                     | null                     | false                | false                | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                 |  | **system or user type**  | null                       | null                     | null                     | null                     | false                | false                | Updated, specified type                                                                                                           |  | null                     | **non-null**               | null                     | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | **not null**             | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | **not null**             | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | null                     | **not null**             | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false                | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;      |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, released from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param body The flag edit request
     */
    editFlag(entityType, entityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editFlagWithHttpInfo(entityType, entityId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param flagResolveComment Optional comment that will be recorded in the flag event when resolving the issue
     * @param body The flag issue edit request
     */
    editFlagIssues(entityType, entityId, flagResolveComment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editFlagIssuesWithHttpInfo(entityType, entityId, flagResolveComment, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates flags for a given list of entities. If the entity does not currently have a flag, one will be created.
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param body The changes to be made to the flags
     */
    flagAction(entityType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagActionWithHttpInfo(entityType, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchy(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInAccountHierarchyWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchy(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInCostCenterHierarchyWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchy(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInMeterHierarchyWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchy(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInPlaceHierarchyWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates flag issues for a given list of flag issue ids
     *
     * @param body The changes to be made to the flag issues
     */
    flagIssueAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagIssueActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlag(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFlagWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssues(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFlagIssuesWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFlagTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccountWithHttpInfo(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/costcenter/${costCenterId}/billFlagSummary'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling billFlagSummaryByAccount.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeterWithHttpInfo(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/place/${placeId}/billFlagSummary'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling billFlagSummaryByMeter.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/flagType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Post, path, requestOptions);
    }
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagTypeWithHttpInfo(flagTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/flagType/${flagTypeId}'
            .replace('${' + 'flagTypeId' + '}', String(flagTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'flagTypeId' is not null or undefined
        if (flagTypeId === null || flagTypeId === undefined) {
            throw new Error('Required parameter flagTypeId was null or undefined when calling deleteFlagType.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Delete, path, requestOptions);
    }
    /**
     * Edit flag data for a specified entity
     * This API supports a wide variety of Flag-related actions. Below are summaries of expected outcomes for possible combinations of property values.      Create Flag(the entity is not yet flagged, therefore there is no \&quot;modified\&quot; info)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                                                                                   Action                                                                                                                    |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                                                                                                                     |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                                                                                                                                       |  | null                     | null                     | null                     | null                     | null                     | null                 | null                 | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                                                                                                           |  | null                     | **not null**             | **not null**             | **not null**             | **not null**             | false                | false                | Exception, must have a type                                                                                                                                                                                                                 |  | **not null**             | null                     | null                     | null                     | null                     | false                | false                | Flagged, unresolved, specified type                                                                                                                                                                                                         |  | **not null**             | **not null**             | null                     | null                     | null                     | false                | false                | Flagged, unresolved(ignoring specified status), specified type                                                                                                                                                                              |  | **not null**             | null                     | **not null**             | null                     | null                     | false                | false                | Flagged, unresolved, specified type, cost recovery                                                                                                                                                                                          |  | **not null**             | null                     | null                     | **not null**&lt;sup&gt;1&lt;/sup&gt; | null                     | false                | false                | Flagged, unresolved, specified type&lt;br /&gt;&lt;sup&gt;1&lt;/sup&gt;If assignees not empty, assigned                                                                                                                                                       |  | **not null**             | null                     | null                     | null                     | **not null**             | false                | false                | Flagged, unresolved, specified type, comment                                                                                                                                                                                                |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment                                                            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;3&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;No action; will not release a newly flagged bill for export |    Edit Unresolved Flag (the entity is already flagged)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    | ReleaseExportHold |                                                                       Action                                                                        |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**          | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                             |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**      | Exception, must have at least one set                                                                                                               |  | null                     | null                     | null                     | null                     | null                     | false                | false             | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                   |  | **system or user type**  | null                     | null                     | null                     | null                     | false                | false             | Flag type updated                                                                                                                                   |  | null                     | **resolved**             | null                     | null                     | null                     | false                | false             | Resolved                                                                                                                                            |  | null                     | **resolved**             | null                     | null                     | null                     | false                | **true**          | Resolved, released for export                                                                                                                       |  | null                     | null                     | **not null**             | null                     | null                     | false                | false             | Updated, cost recovery                                                                                                                              |  | null                     | null                     | null                     | **not null**             | null                     | false                | false             | Assigned                                                                                                                                            |  | null                     | null                     | null                     | null                     | **not null**             | false                | false             | Updated, comment                                                                                                                                    |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment                   |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |    Edit Resolved Flag (the entity is already flagged)    |        FlagTypeId        |        FlagStatusId        |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                              Action                                                               |  | ------------------------ | -------------------------- | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | --------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                       | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                           |  | null                     | null                       | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                             |  | null                     | null                       | null                     | null                     | null                     | false                | false                | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                 |  | **system or user type**  | null                       | null                     | null                     | null                     | false                | false                | Updated, specified type                                                                                                           |  | null                     | **non-null**               | null                     | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | **not null**             | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | **not null**             | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | null                     | **not null**             | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false                | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;      |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, released from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param body The flag edit request
     */
    editFlagWithHttpInfo(entityType, entityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling editFlag.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling editFlag.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param flagResolveComment Optional comment that will be recorded in the flag event when resolving the issue
     * @param body The flag issue edit request
     */
    editFlagIssuesWithHttpInfo(entityType, entityId, flagResolveComment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/flag/flagIssue/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling editFlagIssues.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling editFlagIssues.');
        }
        if (flagResolveComment !== undefined) {
            queryParameters = queryParameters.set('flagResolveComment', flagResolveComment);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Put, path, requestOptions);
    }
    /**
     * Updates flags for a given list of entities. If the entity does not currently have a flag, one will be created.
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param body The changes to be made to the flags
     */
    flagActionWithHttpInfo(entityType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/${entityType}/flagAction'
            .replace('${' + 'entityType' + '}', String(entityType));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling flagAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Put, path, requestOptions);
    }
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchyWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/account/${accountId}/hierarchy'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling flagInAccountHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchyWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/costCenter/${costCenterId}/hierarchy'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling flagInCostCenterHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchyWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/meter/${meterId}/hierarchy'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling flagInMeterHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchyWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/place/${placeId}/hierarchy'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling flagInPlaceHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Updates flag issues for a given list of flag issue ids
     *
     * @param body The changes to be made to the flag issues
     */
    flagIssueActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/flag/flagIssueAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Put, path, requestOptions);
    }
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling getFlag.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling getFlag.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssuesWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/flag/flagIssue/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling getFlagIssues.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling getFlagIssues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/flagType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2i.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FlagService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FlagService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FlagService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2h = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class FormulaService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Check if a formula is valid in the context of the provided datapoint.  A formula is valid if the following are all true:  &lt;list type&#x3D;\&quot;bullet\&quot;&gt;&lt;item&gt;&lt;description&gt;          It is syntactically correct      &lt;/description&gt;&lt;/item&gt;&lt;item&gt;&lt;description&gt;          It only calls allowed functions (including the custom function &#x60;channel()&#x60;\&quot;)      &lt;/description&gt;&lt;/item&gt;&lt;item&gt;&lt;description&gt;          All channels referenced (using the &#x60;channel()&#x60; function) belong to this datapoint          and are real (not calculated) channels.      &lt;/description&gt;&lt;/item&gt;&lt;/list&gt;
     *
     * @param body Formula to validate
     */
    validateFormula(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.validateFormulaWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Check if a formula is valid in the context of the provided datapoint.  A formula is valid if the following are all true:  &lt;list type&#x3D;\&quot;bullet\&quot;&gt;&lt;item&gt;&lt;description&gt;          It is syntactically correct      &lt;/description&gt;&lt;/item&gt;&lt;item&gt;&lt;description&gt;          It only calls allowed functions (including the custom function &#x60;channel()&#x60;\&quot;)      &lt;/description&gt;&lt;/item&gt;&lt;item&gt;&lt;description&gt;          All channels referenced (using the &#x60;channel()&#x60; function) belong to this datapoint          and are real (not calculated) channels.      &lt;/description&gt;&lt;/item&gt;&lt;/list&gt;
     *
     * @param body Formula to validate
     */
    validateFormulaWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/formula/validate';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2h.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormulaService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormulaService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormulaService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2g = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class GHGService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create emission sources for existing meters.
     *
     * @param body The ids of the meters for which to create emission sources
     */
    createEmissionSourceForMeter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionSourceForMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the default GHG scopes and factors that are applied to new meters.  Only included CommodityIds will be updated.  If a CommodityId is not included in the list the currently assigned value will remain.  To remove a default for a particular CommodityId set its ScopeCategoryId and DefaultFactor to null.
     *
     * @param body The default GHG scope and factor to be applied
     */
    editDefaultGHGSettingsMultiFactor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDefaultGHGSettingsMultiFactorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the default GHG scopes and factors that are applied to new meters  GHG License is required to call this endpoint
     *
     */
    getDefaultGHGSettingsMultiFactor(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDefaultGHGSettingsMultiFactorWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the ghg factor categories
     *
     */
    getGHGFactorCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGFactorCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the ghg factor regions
     *
     */
    getGHGFactorRegions(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGFactorRegionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the version history of a specific GHG factor
     *
     * @param factorId The GHG factor to retrieve history for
     */
    getGHGFactorVersionHistory(factorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGFactorVersionHistoryWithHttpInfo(factorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the ghg factors
     *
     * @param filter The api filters&gt;
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGHGFactors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all GHG scope categories and scopes  GHG License is required to call this endpoint
     *
     */
    getGHGScopesWithCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGScopesWithCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettings(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGHGSettingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create emission sources for existing meters.
     *
     * @param body The ids of the meters for which to create emission sources
     */
    createEmissionSourceForMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202502/meter/emissionsource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Post, path, requestOptions);
    }
    /**
     * Edit the default GHG scopes and factors that are applied to new meters.  Only included CommodityIds will be updated.  If a CommodityId is not included in the list the currently assigned value will remain.  To remove a default for a particular CommodityId set its ScopeCategoryId and DefaultFactor to null.
     *
     * @param body The default GHG scope and factor to be applied
     */
    editDefaultGHGSettingsMultiFactorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202502/ghg/default';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Put, path, requestOptions);
    }
    /**
     * Get the default GHG scopes and factors that are applied to new meters  GHG License is required to call this endpoint
     *
     */
    getDefaultGHGSettingsMultiFactorWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202502/ghg/default';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    /**
     * Retrieves all the ghg factor categories
     *
     */
    getGHGFactorCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/ghg/factorCategory';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    /**
     * Retrieves all the ghg factor regions
     *
     */
    getGHGFactorRegionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/ghg/factorRegion';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    /**
     * Get the version history of a specific GHG factor
     *
     * @param factorId The GHG factor to retrieve history for
     */
    getGHGFactorVersionHistoryWithHttpInfo(factorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202210/ghg/factor/${factorId}/version'
            .replace('${' + 'factorId' + '}', String(factorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'factorId' is not null or undefined
        if (factorId === null || factorId === undefined) {
            throw new Error('Required parameter factorId was null or undefined when calling getGHGFactorVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    /**
     * Retrieves all the ghg factors
     *
     * @param filter The api filters&gt;
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGHGFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/ghg/factor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    /**
     * Get all GHG scope categories and scopes  GHG License is required to call this endpoint
     *
     */
    getGHGScopesWithCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202210/ghg/scope/scopeCategory';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202210/meter/${meterId}/ghgsetting'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterGHGSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2g.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GHGService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GHGService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GHGService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2f = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class GeneralLedgerService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a General Ledger
     *
     * @param body Data representing the general ledger being created
     */
    createGeneralLedger(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createGeneralLedgerWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit General Ledger Subcode definitions - update name, type and if \&quot;list\&quot; type edit (add/delete/edit) pick list values.   One or more subcodes can be edited.
     *
     * @param body Provide the subcode definition
     */
    editGLSubCodes(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editGLSubCodesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedger(generalLedgerId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editGeneralLedgerWithHttpInfo(generalLedgerId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCode(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGLSubCodeWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValues(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGLSubCodeValuesWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGLSubCodesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedger(generalLedgerId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGeneralLedgerWithHttpInfo(generalLedgerId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgers(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGeneralLedgersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a General Ledger
     *
     * @param body Data representing the general ledger being created
     */
    createGeneralLedgerWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Post, path, requestOptions);
    }
    /**
     * Edit General Ledger Subcode definitions - update name, type and if \&quot;list\&quot; type edit (add/delete/edit) pick list values.   One or more subcodes can be edited.
     *
     * @param body Provide the subcode definition
     */
    editGLSubCodesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Post, path, requestOptions);
    }
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedgerWithHttpInfo(generalLedgerId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger/${generalLedgerId}'
            .replace('${' + 'generalLedgerId' + '}', String(generalLedgerId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'generalLedgerId' is not null or undefined
        if (generalLedgerId === null || generalLedgerId === undefined) {
            throw new Error('Required parameter generalLedgerId was null or undefined when calling editGeneralLedger.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Put, path, requestOptions);
    }
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCodeWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode/${subCodeIndex}'
            .replace('${' + 'subCodeIndex' + '}', String(subCodeIndex));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'subCodeIndex' is not null or undefined
        if (subCodeIndex === null || subCodeIndex === undefined) {
            throw new Error('Required parameter subCodeIndex was null or undefined when calling getGLSubCode.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Get, path, requestOptions);
    }
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValuesWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode/${subCodeIndex}/savedValues'
            .replace('${' + 'subCodeIndex' + '}', String(subCodeIndex));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'subCodeIndex' is not null or undefined
        if (subCodeIndex === null || subCodeIndex === undefined) {
            throw new Error('Required parameter subCodeIndex was null or undefined when calling getGLSubCodeValues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Get, path, requestOptions);
    }
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Get, path, requestOptions);
    }
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedgerWithHttpInfo(generalLedgerId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger/${generalLedgerId}'
            .replace('${' + 'generalLedgerId' + '}', String(generalLedgerId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'generalLedgerId' is not null or undefined
        if (generalLedgerId === null || generalLedgerId === undefined) {
            throw new Error('Required parameter generalLedgerId was null or undefined when calling getGeneralLedger.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Get, path, requestOptions);
    }
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2f.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GeneralLedgerService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GeneralLedgerService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GeneralLedgerService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2e = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class HierarchyService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlaces(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.availableCostCentersForTopmostPlacesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCenters(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.availablePlacesForTopmostCostCentersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccounts(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryAccountsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollections(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryCollectionsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCenters(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryCostCentersWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPoints(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryDataPointsWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSources(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryEmissionSourcesWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMeters(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryMetersWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlaces(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryPlacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpaces(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestrySpacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollection(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenter(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalSpaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlacesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/place/availableCostCenters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Post, path, requestOptions);
    }
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCentersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/costCenter/availablePlaces';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Post, path, requestOptions);
    }
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccountsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling hierarchicalAncestryAccounts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollectionsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/hierarchy/ancestry/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling hierarchicalAncestryCollections.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCentersWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/costCenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling hierarchicalAncestryCostCenters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPointsWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/hierarchy/ancestry/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling hierarchicalAncestryDataPoints.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSourcesWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/hierarchy/ancestry/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling hierarchicalAncestryEmissionSources.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMetersWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling hierarchicalAncestryMeters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalAncestryPlaces.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/hierarchy/ancestry/space/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalAncestrySpaces.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/hierarchy/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling hierarchicalCollection.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/costCenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling hierarchicalCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/hierarchy/space/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalSpace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2e.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HierarchyService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HierarchyService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HierarchyService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2d = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ImportService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImport(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an emission record import profile
     *
     * @param body Object containing settings for the new profile
     */
    createRecordImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRecordImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an ESA reading import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteEsaReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an emission record import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteRecordImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an emission record import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings to change
     */
    editRecordImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRecordImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetails(taskGuid, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportKickoutDetailsWithHttpInfo(taskGuid, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFile(taskGuid, filename, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportKickoutDetailsByFileWithHttpInfo(taskGuid, filename, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRecordImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummary(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTaskKickoutSummaryWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFile(taskGuid, filename, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTaskKickoutSummaryByFileWithHttpInfo(taskGuid, filename, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickouts(taskGuid, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importBillImportTaskKickoutsWithHttpInfo(taskGuid, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of a emission records import file.  The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEmissionRecordsWithProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importEmissionRecordsWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importEsaReadingWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImport(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.readingImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.writeBillImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * Creates an emission record import profile
     *
     * @param body Object containing settings for the new profile
     */
    createRecordImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteBillImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Delete, path, requestOptions);
    }
    /**
     * Deletes an ESA reading import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteEsaReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Delete, path, requestOptions);
    }
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Delete, path, requestOptions);
    }
    /**
     * Deletes an emission record import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteRecordImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Delete, path, requestOptions);
    }
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editBillImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Put, path, requestOptions);
    }
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editEsaReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Put, path, requestOptions);
    }
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Put, path, requestOptions);
    }
    /**
     * Edits an emission record import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings to change
     */
    editRecordImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editRecordImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Put, path, requestOptions);
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsWithHttpInfo(taskGuid, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/detail'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getBillImportKickoutDetails.');
        }
        if (kickoutMessage !== undefined) {
            queryParameters = queryParameters.set('kickoutMessage', kickoutMessage);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFileWithHttpInfo(taskGuid, filename, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/${filename}/detail'
            .replace('${' + 'taskGuid' + '}', String(taskGuid))
            .replace('${' + 'filename' + '}', String(filename));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getBillImportKickoutDetailsByFile.');
        }
        // verify required parameter 'filename' is not null or undefined
        if (filename === null || filename === undefined) {
            throw new Error('Required parameter filename was null or undefined when calling getBillImportKickoutDetailsByFile.');
        }
        if (kickoutMessage !== undefined) {
            queryParameters = queryParameters.set('kickoutMessage', kickoutMessage);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getBillImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getEsaReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getRecordImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummaryWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/summary'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getTaskKickoutSummary.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFileWithHttpInfo(taskGuid, filename, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/${filename}/summary'
            .replace('${' + 'taskGuid' + '}', String(taskGuid))
            .replace('${' + 'filename' + '}', String(filename));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getTaskKickoutSummaryByFile.');
        }
        // verify required parameter 'filename' is not null or undefined
        if (filename === null || filename === undefined) {
            throw new Error('Required parameter filename was null or undefined when calling getTaskKickoutSummaryByFile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Get, path, requestOptions);
    }
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickoutsWithHttpInfo(taskGuid, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling importBillImportTaskKickouts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * This endpoint allows the import of a emission records import file.  The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEmissionRecordsWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2d.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ImportService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ImportService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ImportService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2c = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ListService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Approve/unapprove account bills
     *
     * @param accountId The account to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    accountBillListApprove(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListApproveWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomAction(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListCustomActionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills for account
     *
     * @param accountId The account to delete all bills from
     */
    accountBillListDeleteBills(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListDeleteBillsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExport(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListExcelExportWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExport(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListExportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Hold/release account bills for export
     *
     * @param accountId The account to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    accountBillListExportHold(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListExportHoldWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexport(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListUnexportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoid(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListVoidWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillList(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountExportHistoricalBillListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountList(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountListWithHttpInfo(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Approve/unapprove bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing approve flag
     */
    approveBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.approveBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomAction(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billListCustomActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordList(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.collectionRecordListWithHttpInfo(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExport(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.collectionRecordListExcelExportWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new list as a copy of an existing list
     *
     * @param listId The list identifier of the existing list
     * @param body The list create properties
     */
    createAndCopyList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAndCopyListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new list with default list settings
     *
     * @param body The list create properties
     */
    createDefaultList(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createDefaultListWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills in a bill list
     *
     * @param listId The list identifier
     */
    deleteBillsInBillList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBillsInBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a list.  For a list to be deleted you must have created the list or have Manage permission and the list is shared with anyone.
     *
     * @param listId The id of the list to delete
     */
    deleteList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeAccountChargesToMetersForBillsInListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a list
     *
     * @param listId The list identifier of the existing list
     * @param body The list edit properties
     */
    editList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the column definition for the list.  For list columns to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body
     */
    editListColumns(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editListColumnsWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Set list filters  If a filter exists in the database, but is not passed in it will be deleted.  For list filters to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body List of filters being set
     */
    editListFilters(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editListFiltersWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the shared users and user groups for a list.  To remove sharing completely set SharedWithEveryone to false, SharedUserIds to [], and SharedUserGroupIds to [].  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     * @param body Users and user groups to share the list with
     */
    editListShare(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editListShareWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the visibility of a list for the current user.  You must have created the list or have access to it.
     *
     * @param listId The shared list identifier
     * @param body Set shared list visibility
     */
    editListShareVisibility(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editListShareVisibilityWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordList(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.emissionSourceRecordListWithHttpInfo(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExport(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.emissionSourceRecordListExcelExportWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportHistoricalBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Hold/release bill list for export
     *
     * @param listId The list identifier
     * @param body Boolean representing exportHold flag
     */
    exportHoldBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportHoldBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create and/or update flags for all bills in a list
     *
     * @param listId Bill list containing a list of bills that will have flags created or updated
     * @param body DTO containing the new state of the flags on each bill in the list
     */
    flagBillListAction(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update flag issuess for all issues in a list
     *
     * @param listId Flag Issue list containing a list of flag issues to be updated
     * @param body DTO containing the new state of the flag Issue on each flag issue in the list
     */
    flagIssueBillListAction(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagIssueBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the definition and data for a list type
     *
     * @param listTypeId The list type for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body DTO containing the list of initial filters to apply and a flag indicating whether to reset the current columns.  Only one list of the specified list type exists, so columns and filters are shared for every dynamic list of the list type.  Filters provided will be saved to the database.
     */
    getDynamicListWithData(listTypeId, pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDynamicListWithDataWithHttpInfo(listTypeId, pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the filters for a list
     *
     * @param listId The list for which the filters are to be retrieved
     */
    getListFilters(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getListFiltersWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the shared users and user groups for a list.  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     */
    getListShare(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getListShareWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the definition and data for a list.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listId The list for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getListWithData(listId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getListWithDataWithHttpInfo(listId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get lists.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listTypeId Type of list
     */
    getLists(listTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getListsWithHttpInfo(listTypeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountList(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPossibleDestinationAccountsForAccountListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPossibleDestinationAccountsForListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param listId The list identifier
     */
    listExport(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.listExportWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillList(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListWithHttpInfo(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Approve/unapprove meter bills
     *
     * @param meterId The meter to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    meterBillListApprove(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListApproveWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomAction(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListCustomActionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills for meter
     *
     * @param meterId The meter to delete all bills from
     */
    meterBillListDeleteBills(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListDeleteBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExport(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListExcelExportWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExport(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListExportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Hold/release meter bills for export
     *
     * @param meterId The meter to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    meterBillListExportHold(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListExportHoldWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexport(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListUnexportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoid(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListVoidWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillList(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterExportHistoricalBillListWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountList(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveBillsToAccountFromAccountListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveBillsToAccountFromListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reset a list to its default columns and filters.  For a list to be reset you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     */
    resetList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.resetListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillList(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseAccountBillListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillList(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseMeterBillListWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param accountId The account whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setAccountBillListAccrualExclusion(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setAccountBillListAccrualExclusionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param listId The list whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the provided list should be excluded from accruals or should have exclusion undone
     */
    setBillListAccrualExclusion(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setBillListAccrualExclusionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param meterId The meter whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setMeterBillListAccrualExclusion(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setMeterBillListAccrualExclusionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.splitBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unexportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeaders(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountBillListHeadersWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeaders(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateBillListHeadersWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeaders(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateMeterBillListHeadersWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Approve/unapprove account bills
     *
     * @param accountId The account to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    accountBillListApproveWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/approve'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListApprove.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomActionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/customAction'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListCustomAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Delete all bills for account
     *
     * @param accountId The account to delete all bills from
     */
    accountBillListDeleteBillsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/data'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListDeleteBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Delete, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExportWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/excelexport'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/export'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Hold/release account bills for export
     *
     * @param accountId The account to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    accountBillListExportHoldWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/exporthold'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListExportHold.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/unexport'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListUnexport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoidWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/void'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListVoid.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/generateimport'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountExportHistoricalBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountListWithHttpInfo(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Approve/unapprove bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing approve flag
     */
    approveBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/approve'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling approveBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/customAction'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling billListCustomAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordListWithHttpInfo(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/collection/${collectionId}/list/record'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling collectionRecordList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExportWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/collection/${collectionId}/list/record/excelexport'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling collectionRecordListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Create a new list as a copy of an existing list
     *
     * @param listId The list identifier of the existing list
     * @param body The list create properties
     */
    createAndCopyListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling createAndCopyList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Create a new list with default list settings
     *
     * @param body The list create properties
     */
    createDefaultListWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Delete all bills in a bill list
     *
     * @param listId The list identifier
     */
    deleteBillsInBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/data'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling deleteBillsInBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Delete, path, requestOptions);
    }
    /**
     * Delete a list.  For a list to be deleted you must have created the list or have Manage permission and the list is shared with anyone.
     *
     * @param listId The id of the list to delete
     */
    deleteListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling deleteList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Delete, path, requestOptions);
    }
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/list/${listId}/distributeAccountCharges'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling distributeAccountChargesToMetersForBillsInList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Edit a list
     *
     * @param listId The list identifier of the existing list
     * @param body The list edit properties
     */
    editListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling editList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Edit the column definition for the list.  For list columns to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body
     */
    editListColumnsWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/column'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling editListColumns.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Set list filters  If a filter exists in the database, but is not passed in it will be deleted.  For list filters to be edited you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     * @param body List of filters being set
     */
    editListFiltersWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/filter'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling editListFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Update the shared users and user groups for a list.  To remove sharing completely set SharedWithEveryone to false, SharedUserIds to [], and SharedUserGroupIds to [].  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     * @param body Users and user groups to share the list with
     */
    editListShareWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/share'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling editListShare.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Update the visibility of a list for the current user.  You must have created the list or have access to it.
     *
     * @param listId The shared list identifier
     * @param body Set shared list visibility
     */
    editListShareVisibilityWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/visible'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling editListShareVisibility.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordListWithHttpInfo(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/emissionSource/${emissionSourceId}/list/record'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling emissionSourceRecordList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExportWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/emissionSource/${emissionSourceId}/list/record/excelexport'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling emissionSourceRecordListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/export'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling exportBillList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/bill/generateimport'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling exportHistoricalBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Hold/release bill list for export
     *
     * @param listId The list identifier
     * @param body Boolean representing exportHold flag
     */
    exportHoldBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/exporthold'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling exportHoldBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Create and/or update flags for all bills in a list
     *
     * @param listId Bill list containing a list of bills that will have flags created or updated
     * @param body DTO containing the new state of the flags on each bill in the list
     */
    flagBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/flagAction'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling flagBillListAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Update flag issuess for all issues in a list
     *
     * @param listId Flag Issue list containing a list of flag issues to be updated
     * @param body DTO containing the new state of the flag Issue on each flag issue in the list
     */
    flagIssueBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/V202502/list/${listId}/flagIssueAction'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling flagIssueBillListAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Get the definition and data for a list type
     *
     * @param listTypeId The list type for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body DTO containing the list of initial filters to apply and a flag indicating whether to reset the current columns.  Only one list of the specified list type exists, so columns and filters are shared for every dynamic list of the list type.  Filters provided will be saved to the database.
     */
    getDynamicListWithDataWithHttpInfo(listTypeId, pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dynamiclist/${listTypeId}'
            .replace('${' + 'listTypeId' + '}', String(listTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listTypeId' is not null or undefined
        if (listTypeId === null || listTypeId === undefined) {
            throw new Error('Required parameter listTypeId was null or undefined when calling getDynamicListWithData.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Get the filters for a list
     *
     * @param listId The list for which the filters are to be retrieved
     */
    getListFiltersWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/filter'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling getListFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Get the shared users and user groups for a list.  You must have created the list and have SharedBillLists Create permission or have BillListAdministrator Manage permission  or must have created the list and have SharedRecordsLists Create permission or have RecordsListAdministrator Manage permission
     *
     * @param listId The list identifier
     */
    getListShareWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/share'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling getListShare.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Get the definition and data for a list.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listId The list for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getListWithDataWithHttpInfo(listId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/data'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling getListWithData.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Get lists.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listTypeId Type of list
     */
    getListsWithHttpInfo(listTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (listTypeId !== undefined) {
            queryParameters = queryParameters.set('listTypeId', listTypeId);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/possibleDestinationAccounts'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getPossibleDestinationAccountsForAccountList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/possibleDestinationAccounts'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling getPossibleDestinationAccountsForList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param listId The list identifier
     */
    listExportWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/data/excelexport'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling listExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillListWithHttpInfo(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Approve/unapprove meter bills
     *
     * @param meterId The meter to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    meterBillListApproveWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/approve'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListApprove.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomActionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/customAction'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListCustomAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Delete all bills for meter
     *
     * @param meterId The meter to delete all bills from
     */
    meterBillListDeleteBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/data'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListDeleteBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Delete, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExportWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/excelexport'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Get, path, requestOptions);
    }
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/export'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Hold/release meter bills for export
     *
     * @param meterId The meter to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    meterBillListExportHoldWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/exporthold'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListExportHold.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/unexport'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListUnexport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoidWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/void'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListVoid.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillListWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/generateimport'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterExportHistoricalBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/moveBills'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling moveBillsToAccountFromAccountList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/moveBills'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling moveBillsToAccountFromList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Reset a list to its default columns and filters.  For a list to be reset you must have created the list  or have BillListAdministrator Manage permission and the list is shared with anyone  or have SharedBillList Edit permission and the list is shared with you.
     *
     * @param listId The list identifier
     */
    resetListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/reset'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling resetList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/reverse'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling reverseAccountBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/reverse'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling reverseBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillListWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/reverse'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling reverseMeterBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param accountId The account whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setAccountBillListAccrualExclusionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/accrualExclusion'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling setAccountBillListAccrualExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param listId The list whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the provided list should be excluded from accruals or should have exclusion undone
     */
    setBillListAccrualExclusionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/accrualExclusion'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling setBillListAccrualExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param meterId The meter whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setMeterBillListAccrualExclusionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/accrualExclusion'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling setMeterBillListAccrualExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/split'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling splitBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Post, path, requestOptions);
    }
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/unexport'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling unexportBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeadersWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/billHeaders'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling updateAccountBillListHeaders.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeadersWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/billHeaders'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling updateBillListHeaders.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeadersWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/billHeaders'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling updateMeterBillListHeaders.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/void'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling voidBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2c.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ListService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ListService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ListService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2b = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class MeService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Initial session starting point. Support authorization via a api key, bearer token, or session cookie
     *
     */
    me(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    updateMe(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateMeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run all actions that happen before login such as system upgrades and report installation by default to provide maximum compatibility with   the latest application code.
     *
     * @param upgradesOnly Set to true to limit to only system data upgrades which improves performance   but may not guarantee maximum compatibility with the latest application logic.
     */
    upgrade(upgradesOnly, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.upgradeWithHttpInfo(upgradesOnly, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Initial session starting point. Support authorization via a api key, bearer token, or session cookie
     *
     */
    meWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/me';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2b.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param body
     */
    updateMeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/me';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2b.Put, path, requestOptions);
    }
    /**
     * Run all actions that happen before login such as system upgrades and report installation by default to provide maximum compatibility with   the latest application code.
     *
     * @param upgradesOnly Set to true to limit to only system data upgrades which improves performance   but may not guarantee maximum compatibility with the latest application logic.
     */
    upgradeWithHttpInfo(upgradesOnly, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/me/upgrade';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (upgradesOnly !== undefined) {
            queryParameters = queryParameters.set('upgradesOnly', upgradesOnly);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2b.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2a = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class MeterService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a meter
     *
     * @param meterId The identifier for the meter being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteMeter(meterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterWithHttpInfo(meterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFile(meterId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadMeterCustomFieldFileWithHttpInfo(meterId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLink(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a meter&#39;s group memberships.   Note that all groups a meter should belong to must be passed in. Passing in one group means that the meter will belong to one group only,   even if it previously belonged to several.  Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param meterId The meter identifier whose group memberships are being edited
     * @param body The groups the meter will belong to
     */
    editMeterGroupMembership(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterGroupMembershipWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersion(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterSerialNumberVersionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFs(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterUDFsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnits(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterWithUnitsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLink(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWatticsDataPointLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherData(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalendarizedUseVsWeatherDataWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactors(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGMeterFactorsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeter(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBills(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroups(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRates(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterRatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplates(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterTemplatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfs(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterUdfsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMetersUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMeters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUnplacedMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeter(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveMeterWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processMeterCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Post, path, requestOptions);
    }
    /**
     * Deletes a meter
     *
     * @param meterId The identifier for the meter being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteMeterWithHttpInfo(meterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteMeter.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Delete, path, requestOptions);
    }
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFileWithHttpInfo(meterId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/meter/${meterId}/udf/${udfId}/download'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling downloadMeterCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadMeterCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/meter/${meterId}/emissionSource'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editEmissionSourceLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     * Edits a meter&#39;s group memberships.   Note that all groups a meter should belong to must be passed in. Passing in one group means that the meter will belong to one group only,   even if it previously belonged to several.  Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param meterId The meter identifier whose group memberships are being edited
     * @param body The groups the meter will belong to
     */
    editMeterGroupMembershipWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/group'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterGroupMembership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/serialnumberversion'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterSerialNumberVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/udf'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnitsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterWithUnits.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/meter/${meterId}/watticsDataPoint'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editWatticsDataPointLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherDataWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/usevsweather/calendarized'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalendarizedUseVsWeatherData.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactorsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/ghg/factor'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getGHGMeterFactors.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeterWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroupsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/group'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterGroups.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/rate'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterRates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/template'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterTemplates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/udf'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/meter/unplacedMeters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Get, path, requestOptions);
    }
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeterWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentPlace/${parentPlaceId}/meter'
            .replace('${' + 'parentPlaceId' + '}', String(parentPlaceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentPlaceId' is not null or undefined
        if (parentPlaceId === null || parentPlaceId === undefined) {
            throw new Error('Required parameter parentPlaceId was null or undefined when calling moveMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202211/meter/customAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2a.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$29 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class MeterDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrend(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedTrendWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/actual/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/actual/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/calendarized/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterCalendarizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/calendarized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrendWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/calendarized/trend'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterCalendarizedTrend.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/calendarized/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterCalendarizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/calendarized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/normalized/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterNormalizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/normalized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/normalized/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterNormalizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/normalized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/savings/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterSavingsMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/savings/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/savings/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterSavingsYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/savings/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$29.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$28 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class MeterGroupService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a meter group category
     *
     * @param body Data representing the meter group category being created
     */
    createMeterCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a meter group
     *
     * @param body Data representing the meter group being created
     */
    createMeterGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a meter group category
     *
     * @param categoryId Id of the category to delete
     */
    deleteMeterCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a user-created meter group
     *
     * @param meterGroupId
     */
    deleteMeterGroup(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a meter group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the meter group category
     */
    editMeterCategory(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a meter group
     *
     * @param meterGroupId Id of the group to edit
     * @param body Data representing the meter group being edited
     */
    editMeterGroup(meterGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterGroupWithHttpInfo(meterGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroups(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllMeterGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroup(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembers(groupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupMembersWithHttpInfo(groupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFilters(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserDefinedAutoMeterGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Include all group members in charts
     *
     * @param meterGroupId
     */
    includeAllMeterGroupMemberInCharts(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.includeAllMeterGroupMemberInChartsWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserMeterAutoGroupsMembership(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateAllUserMeterAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param meterGroupId The meter group to refresh
     */
    recalculateUserMeterAutoGroupMemebership(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateUserMeterAutoGroupMemebershipWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param meterGroupId
     * @param meterId
     * @param body
     */
    updateMeterGroupMember(meterGroupId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateMeterGroupMemberWithHttpInfo(meterGroupId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a meter group category
     *
     * @param body Data representing the meter group category being created
     */
    createMeterCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Post, path, requestOptions);
    }
    /**
     * Create a meter group
     *
     * @param body Data representing the meter group being created
     */
    createMeterGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Post, path, requestOptions);
    }
    /**
     * Delete a meter group category
     *
     * @param categoryId Id of the category to delete
     */
    deleteMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling deleteMeterCategory.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Delete, path, requestOptions);
    }
    /**
     * Delete a user-created meter group
     *
     * @param meterGroupId
     */
    deleteMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling deleteMeterGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Delete, path, requestOptions);
    }
    /**
     * Update a meter group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the meter group category
     */
    editMeterCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling editMeterCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Put, path, requestOptions);
    }
    /**
     * Edit a meter group
     *
     * @param meterGroupId Id of the group to edit
     * @param body Data representing the meter group being edited
     */
    editMeterGroupWithHttpInfo(meterGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling editMeterGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Put, path, requestOptions);
    }
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Get, path, requestOptions);
    }
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Get, path, requestOptions);
    }
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling getMeterCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Get, path, requestOptions);
    }
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling getMeterGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Get, path, requestOptions);
    }
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembersWithHttpInfo(groupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${groupId}/member'
            .replace('${' + 'groupId' + '}', String(groupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'groupId' is not null or undefined
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling getMeterGroupMembers.');
        }
        if (alwaysLimitByTopmost !== undefined) {
            queryParameters = queryParameters.set('alwaysLimitByTopmost', alwaysLimitByTopmost);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Get, path, requestOptions);
    }
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/filters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Get, path, requestOptions);
    }
    /**
     * Include all group members in charts
     *
     * @param meterGroupId
     */
    includeAllMeterGroupMemberInChartsWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}/member/includeInCharts'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling includeAllMeterGroupMemberInCharts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserMeterAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/updateUserAutoGroups';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param meterGroupId The meter group to refresh
     */
    recalculateUserMeterAutoGroupMemebershipWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}/updateUserAutoGroup'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling recalculateUserMeterAutoGroupMemebership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Post, path, requestOptions);
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param meterGroupId
     * @param meterId
     * @param body
     */
    updateMeterGroupMemberWithHttpInfo(meterGroupId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}/member/${meterId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling updateMeterGroupMember.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling updateMeterGroupMember.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$28.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterGroupService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterGroupService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterGroupService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$27 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class MeterGroupDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRanking(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${groupId}/digest/${dataView}/${chart}'
            .replace('${' + 'groupId' + '}', String(groupId))
            .replace('${' + 'dataView' + '}', String(dataView))
            .replace('${' + 'chart' + '}', String(chart));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'groupId' is not null or undefined
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling getMeterGroupRanking.');
        }
        // verify required parameter 'dataView' is not null or undefined
        if (dataView === null || dataView === undefined) {
            throw new Error('Required parameter dataView was null or undefined when calling getMeterGroupRanking.');
        }
        // verify required parameter 'chart' is not null or undefined
        if (chart === null || chart === undefined) {
            throw new Error('Required parameter chart was null or undefined when calling getMeterGroupRanking.');
        }
        if (billingPeriodOption !== undefined) {
            queryParameters = queryParameters.set('billingPeriodOption', billingPeriodOption);
        }
        if (startPeriod !== undefined) {
            queryParameters = queryParameters.set('startPeriod', startPeriod);
        }
        if (endPeriod !== undefined) {
            queryParameters = queryParameters.set('endPeriod', endPeriod);
        }
        if (commodityId !== undefined) {
            queryParameters = queryParameters.set('commodityId', commodityId);
        }
        if (commodityCategoryId !== undefined) {
            queryParameters = queryParameters.set('commodityCategoryId', commodityCategoryId);
        }
        if (highToLowRanking !== undefined) {
            queryParameters = queryParameters.set('highToLowRanking', highToLowRanking);
        }
        if (showExcludedMembers !== undefined) {
            queryParameters = queryParameters.set('showExcludedMembers', showExcludedMembers);
        }
        if (showZeroAverages !== undefined) {
            queryParameters = queryParameters.set('showZeroAverages', showZeroAverages);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$27.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterGroupDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterGroupDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MeterGroupDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$26 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class NotificationService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get a specific notification for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotification(notificationId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationWithHttpInfo(notificationId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get total number of notifications that are unread and unarchived for the current user.  Use lastCheckDateTimeUtc to get the number of new notifications since the passed in date and time.  By default, only the latest 250 notifications will be taken into account. Use the &#39;noLimit&#39; query parameter to override this behavior.
     *
     * @param lastCheckDateTimeUtc Used when calculating the number of new notifications. Must be a UTC DateTime in the format yyyy-MM-ddTHH:mm:ssZ. If not passed the TotalNotifications and NewNotifications will be equal.
     * @param noLimit If true, will return the badge totals for all of the user&#39;s notifications, not just the 250 most recent ones
     */
    getNotificationBadgeTotals(lastCheckDateTimeUtc, noLimit, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationBadgeTotalsWithHttpInfo(lastCheckDateTimeUtc, noLimit, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a specific notification&#39;s details for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotificationDetails(notificationId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationDetailsWithHttpInfo(notificationId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * The default notification settings assigned to new users
     *
     */
    getNotificationSystemSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationSystemSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of notification types
     *
     */
    getNotificationTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * The notification settings for the current user
     *
     */
    getNotificationUserSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationUserSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all notifications for the current user
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getNotifications(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a list of notifications based on the notification ids and action passed in  Only notifications for the current user can be updated
     *
     * @param body List of notification ids and action to perform
     */
    updateListOfNotifications(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateListOfNotificationsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateNotificationSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the notification settings for the current user
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationUserSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateNotificationUserSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a specific notification for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotificationWithHttpInfo(notificationId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/${notificationId}'
            .replace('${' + 'notificationId' + '}', String(notificationId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'notificationId' is not null or undefined
        if (notificationId === null || notificationId === undefined) {
            throw new Error('Required parameter notificationId was null or undefined when calling getNotification.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * Get total number of notifications that are unread and unarchived for the current user.  Use lastCheckDateTimeUtc to get the number of new notifications since the passed in date and time.  By default, only the latest 250 notifications will be taken into account. Use the &#39;noLimit&#39; query parameter to override this behavior.
     *
     * @param lastCheckDateTimeUtc Used when calculating the number of new notifications. Must be a UTC DateTime in the format yyyy-MM-ddTHH:mm:ssZ. If not passed the TotalNotifications and NewNotifications will be equal.
     * @param noLimit If true, will return the badge totals for all of the user&#39;s notifications, not just the 250 most recent ones
     */
    getNotificationBadgeTotalsWithHttpInfo(lastCheckDateTimeUtc, noLimit, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/badge';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (lastCheckDateTimeUtc !== undefined) {
            queryParameters = queryParameters.set('lastCheckDateTimeUtc', lastCheckDateTimeUtc.toISOString());
        }
        if (noLimit !== undefined) {
            queryParameters = queryParameters.set('noLimit', noLimit);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * Get a specific notification&#39;s details for the current user
     *
     * @param notificationId Id of the notification to get
     */
    getNotificationDetailsWithHttpInfo(notificationId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/${notificationId}/detail'
            .replace('${' + 'notificationId' + '}', String(notificationId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'notificationId' is not null or undefined
        if (notificationId === null || notificationId === undefined) {
            throw new Error('Required parameter notificationId was null or undefined when calling getNotificationDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * The default notification settings assigned to new users
     *
     */
    getNotificationSystemSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/systemsetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * Get a list of notification types
     *
     */
    getNotificationTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/type';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * The notification settings for the current user
     *
     */
    getNotificationUserSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/usersetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * Get all notifications for the current user
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getNotificationsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Get, path, requestOptions);
    }
    /**
     * Update a list of notifications based on the notification ids and action passed in  Only notifications for the current user can be updated
     *
     * @param body List of notification ids and action to perform
     */
    updateListOfNotificationsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Put, path, requestOptions);
    }
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/systemsetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Put, path, requestOptions);
    }
    /**
     * Update the notification settings for the current user
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationUserSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/usersetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$26.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NotificationService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NotificationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NotificationService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$25 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ObservationService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReading(readingId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteSingleReadingWithHttpInfo(readingId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReading(readingId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSingleReadingWithHttpInfo(readingId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadings(channelId, beginDate, endDate, originalValue, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReadingsWithHttpInfo(channelId, beginDate, endDate, originalValue, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$25.Post, path, requestOptions);
    }
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$25.Delete, path, requestOptions);
    }
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReadingWithHttpInfo(readingId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading/${readingId}'
            .replace('${' + 'readingId' + '}', String(readingId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'readingId' is not null or undefined
        if (readingId === null || readingId === undefined) {
            throw new Error('Required parameter readingId was null or undefined when calling deleteSingleReading.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$25.Delete, path, requestOptions);
    }
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReadingWithHttpInfo(readingId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading/${readingId}'
            .replace('${' + 'readingId' + '}', String(readingId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'readingId' is not null or undefined
        if (readingId === null || readingId === undefined) {
            throw new Error('Required parameter readingId was null or undefined when calling editSingleReading.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$25.Put, path, requestOptions);
    }
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadingsWithHttpInfo(channelId, beginDate, endDate, originalValue, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/channel/${channelId}/reading'
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling getReadings.');
        }
        if (beginDate !== undefined) {
            queryParameters = queryParameters.set('beginDate', beginDate.toISOString());
        }
        if (endDate !== undefined) {
            queryParameters = queryParameters.set('endDate', endDate.toISOString());
        }
        if (originalValue !== undefined) {
            queryParameters = queryParameters.set('originalValue', originalValue);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$25.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ObservationService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ObservationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ObservationService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$24 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ObservationTypeService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get the observation types for a given noun class code and/or noun code.
     *
     * @param filter
     */
    getObservationTypes(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getObservationTypesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the observation types for a given noun class code and/or noun code.
     *
     * @param filter
     */
    getObservationTypesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/observationtype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$24.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ObservationTypeService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ObservationTypeService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ObservationTypeService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$23 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PlaceService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a place
     *
     * @param body Data representing the place being created
     */
    createPlace(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSize(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceSizeWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a place
     *
     * @param placeId The identifier for the place being deleted
     */
    deletePlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSize(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceType(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceTypeWithHttpInfo(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFile(placeId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadPlaceCustomFieldFileWithHttpInfo(placeId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLink(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyStarPlaceLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlace(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a place&#39;s group memberships.   Note that all groups a place should belong to must be passed in. Passing in one group means that the place will belong to one group only,   even if it previously belonged to several.   Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param placeId The place identifier whose group memberships are being edited
     * @param body The groups the place will belong to
     */
    editPlaceGroupMembership(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceGroupMembershipWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeList(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceSizeListWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceType(placeTypeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceTypeWithHttpInfo(placeTypeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFs(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceUDFsWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLink(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWatticsSiteLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectsForPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlace(placeId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceWithHttpInfo(placeId, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchy(placeId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceHierarchyWithHttpInfo(placeId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLink(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceLinkWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetrics(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceMetricsWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroups(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSize(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizes(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    getPlaceType(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceTypeWithHttpInfo(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all place types
     *
     * @param filter
     */
    getPlaceTypes(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceTypesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfs(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceUdfsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaces(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlacesUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlace(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.movePlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStar(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkPlacesAndChildMetersFromEnergyStarWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateEnergyStarSubmissionTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place
     *
     * @param body Data representing the place being created
     */
    createPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Post, path, requestOptions);
    }
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSizeWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling createPlaceSize.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Post, path, requestOptions);
    }
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Post, path, requestOptions);
    }
    /**
     * Deletes a place
     *
     * @param placeId The identifier for the place being deleted
     */
    deletePlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deletePlace.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Delete, path, requestOptions);
    }
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size/${placeSizeId}'
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeSizeId' + '}', String(placeSizeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deletePlaceSize.');
        }
        // verify required parameter 'placeSizeId' is not null or undefined
        if (placeSizeId === null || placeSizeId === undefined) {
            throw new Error('Required parameter placeSizeId was null or undefined when calling deletePlaceSize.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Delete, path, requestOptions);
    }
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceTypeWithHttpInfo(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype/${placeTypeId}'
            .replace('${' + 'placeTypeId' + '}', String(placeTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeTypeId' is not null or undefined
        if (placeTypeId === null || placeTypeId === undefined) {
            throw new Error('Required parameter placeTypeId was null or undefined when calling deletePlaceType.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Delete, path, requestOptions);
    }
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFileWithHttpInfo(placeId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/place/${placeId}/udf/${udfId}/download'
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling downloadPlaceCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadPlaceCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/link'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEnergyStarPlaceLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Edits a place&#39;s group memberships.   Note that all groups a place should belong to must be passed in. Passing in one group means that the place will belong to one group only,   even if it previously belonged to several.   Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param placeId The place identifier whose group memberships are being edited
     * @param body The groups the place will belong to
     */
    editPlaceGroupMembershipWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/group'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceGroupMembership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeListWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceSizeList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceTypeWithHttpInfo(placeTypeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype/${placeTypeId}'
            .replace('${' + 'placeTypeId' + '}', String(placeTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeTypeId' is not null or undefined
        if (placeTypeId === null || placeTypeId === undefined) {
            throw new Error('Required parameter placeTypeId was null or undefined when calling editPlaceType.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFsWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/udf'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/place/${placeId}/watticsSite'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editWatticsSiteLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/project'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyProjectsForPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlaceWithHttpInfo(placeId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlace.');
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchyWithHttpInfo(placeId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/hierarchy'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlaceHierarchy.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLinkWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/link'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlaceLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetricsWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/metrics'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlaceMetrics.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroupsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/group'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceGroups.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size/${placeSizeId}'
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeSizeId' + '}', String(placeSizeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSize.');
        }
        // verify required parameter 'placeSizeId' is not null or undefined
        if (placeSizeId === null || placeSizeId === undefined) {
            throw new Error('Required parameter placeSizeId was null or undefined when calling getPlaceSize.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSizes.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves one place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    getPlaceTypeWithHttpInfo(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype/${placeTypeId}'
            .replace('${' + 'placeTypeId' + '}', String(placeTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeTypeId' is not null or undefined
        if (placeTypeId === null || placeTypeId === undefined) {
            throw new Error('Required parameter placeTypeId was null or undefined when calling getPlaceType.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves all place types
     *
     * @param filter
     */
    getPlaceTypesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/udf'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Get, path, requestOptions);
    }
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentPlace/${parentPlaceId}/place'
            .replace('${' + 'parentPlaceId' + '}', String(parentPlaceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentPlaceId' is not null or undefined
        if (parentPlaceId === null || parentPlaceId === undefined) {
            throw new Error('Required parameter parentPlaceId was null or undefined when calling movePlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStarWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/place/energyStar/unlink';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/place/energyStar/submissionType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$23.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$22 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PlaceBenchmarkService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValue(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValue(benchmarkIndicator, placeId, placeBenchmarkId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSetting(benchmarkIndicator, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceBenchmarkSettingWithHttpInfo(benchmarkIndicator, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceBenchmarkSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValues(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValues(benchmarkIndicator, placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all place benchmark categories in the database
     *
     */
    getPlaceBenchmarkCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceBenchmarkCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all the place benchmark names and categories for the owner
     *
     */
    getPlaceBenchmarkSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceBenchmarkSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValue(benchmarkIndicator, placeId, placeBenchmarkId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updatePlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling createPlaceBenchmarkValue.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling createPlaceBenchmarkValue.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Post, path, requestOptions);
    }
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue/${placeBenchmarkId}'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeBenchmarkId' + '}', String(placeBenchmarkId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling deleteBenchmarkValue.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deleteBenchmarkValue.');
        }
        // verify required parameter 'placeBenchmarkId' is not null or undefined
        if (placeBenchmarkId === null || placeBenchmarkId === undefined) {
            throw new Error('Required parameter placeBenchmarkId was null or undefined when calling deleteBenchmarkValue.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Delete, path, requestOptions);
    }
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSettingWithHttpInfo(benchmarkIndicator, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/setting'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling deletePlaceBenchmarkSetting.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Delete, path, requestOptions);
    }
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Put, path, requestOptions);
    }
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling editPlaceBenchmarkValues.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceBenchmarkValues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Put, path, requestOptions);
    }
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling getBenchmarkValues.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getBenchmarkValues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Get, path, requestOptions);
    }
    /**
     * Get all place benchmark categories in the database
     *
     */
    getPlaceBenchmarkCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Get, path, requestOptions);
    }
    /**
     * Get all the place benchmark names and categories for the owner
     *
     */
    getPlaceBenchmarkSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Get, path, requestOptions);
    }
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue/${placeBenchmarkId}'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeBenchmarkId' + '}', String(placeBenchmarkId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling updatePlaceBenchmarkValue.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling updatePlaceBenchmarkValue.');
        }
        // verify required parameter 'placeBenchmarkId' is not null or undefined
        if (placeBenchmarkId === null || placeBenchmarkId === undefined) {
            throw new Error('Required parameter placeBenchmarkId was null or undefined when calling updatePlaceBenchmarkValue.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$22.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceBenchmarkService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceBenchmarkService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceBenchmarkService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$21 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PlaceDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartData(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEuiChartDataWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparison(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedCostComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparison(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedGhgComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNomalizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparison(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedUseComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartDataWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/energyUseIntensity'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEuiChartData.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/actual/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/actual/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/place/${placeId}/digest/calendarized/cost/comparison'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedCostComparison.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        if (comparisonYearsAgo !== undefined) {
            queryParameters = queryParameters.set('comparisonYearsAgo', comparisonYearsAgo);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/place/${placeId}/digest/calendarized/ghg/comparison'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedGhgComparison.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        if (comparisonYearsAgo !== undefined) {
            queryParameters = queryParameters.set('comparisonYearsAgo', comparisonYearsAgo);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/calendarized/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/calendarized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/calendarized/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/calendarized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/normalized/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceNomalizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/normalized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/place/${placeId}/digest/normalized/use/comparison'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceNormalizedUseComparison.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        if (comparisonYearsAgo !== undefined) {
            queryParameters = queryParameters.set('comparisonYearsAgo', comparisonYearsAgo);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/normalized/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceNormalizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/normalized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/savings/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSavingsMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/savings/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/savings/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSavingsYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/savings/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$21.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$20 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PlaceGroupService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a place group category
     *
     * @param body Data representing the place group category being created
     */
    createPlaceCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a place group
     *
     * @param body Data representing the place group being created
     */
    createPlaceGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a place group category
     *
     * @param categoryId Id of the category to delete
     */
    deletePlaceCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a user-created place group
     *
     * @param placeGroupId
     */
    deletePlaceGroup(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a place group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the place group category
     */
    editPlaceCategory(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a place group
     *
     * @param placeGroupId Id of the group to edit
     * @param body Data representing the place group being edited
     */
    editPlaceGroup(placeGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceGroupWithHttpInfo(placeGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroups(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllPlaceGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroup(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembers(placeGroupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupMembersWithHttpInfo(placeGroupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFilters(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserDefinedAutoPlaceGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Include all group members in charts
     *
     * @param placeGroupId
     */
    includeAllPlaceGroupMemberInCharts(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.includeAllPlaceGroupMemberInChartsWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserPlaceAutoGroupsMembership(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateAllUserPlaceAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param placeGroupId The place group to refresh
     */
    recalculateUserPlaceAutoGroupMemebership(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateUserPlaceAutoGroupMemebershipWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param placeGroupId
     * @param placeId
     * @param body
     */
    updatePlaceGroupMember(placeGroupId, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updatePlaceGroupMemberWithHttpInfo(placeGroupId, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place group category
     *
     * @param body Data representing the place group category being created
     */
    createPlaceCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Post, path, requestOptions);
    }
    /**
     * Create a place group
     *
     * @param body Data representing the place group being created
     */
    createPlaceGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Post, path, requestOptions);
    }
    /**
     * Delete a place group category
     *
     * @param categoryId Id of the category to delete
     */
    deletePlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling deletePlaceCategory.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Delete, path, requestOptions);
    }
    /**
     * Delete a user-created place group
     *
     * @param placeGroupId
     */
    deletePlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling deletePlaceGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Delete, path, requestOptions);
    }
    /**
     * Update a place group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the place group category
     */
    editPlaceCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling editPlaceCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Put, path, requestOptions);
    }
    /**
     * Edit a place group
     *
     * @param placeGroupId Id of the group to edit
     * @param body Data representing the place group being edited
     */
    editPlaceGroupWithHttpInfo(placeGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling editPlaceGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Put, path, requestOptions);
    }
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Get, path, requestOptions);
    }
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Get, path, requestOptions);
    }
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling getPlaceCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Get, path, requestOptions);
    }
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling getPlaceGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Get, path, requestOptions);
    }
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembersWithHttpInfo(placeGroupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/member'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling getPlaceGroupMembers.');
        }
        if (alwaysLimitByTopmost !== undefined) {
            queryParameters = queryParameters.set('alwaysLimitByTopmost', alwaysLimitByTopmost);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Get, path, requestOptions);
    }
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/filters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Get, path, requestOptions);
    }
    /**
     * Include all group members in charts
     *
     * @param placeGroupId
     */
    includeAllPlaceGroupMemberInChartsWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/member/includeInCharts'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling includeAllPlaceGroupMemberInCharts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserPlaceAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/updateUserAutoGroups';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param placeGroupId The place group to refresh
     */
    recalculateUserPlaceAutoGroupMemebershipWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/updateUserAutoGroup'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling recalculateUserPlaceAutoGroupMemebership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Post, path, requestOptions);
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param placeGroupId
     * @param placeId
     * @param body
     */
    updatePlaceGroupMemberWithHttpInfo(placeGroupId, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/member/${placeId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling updatePlaceGroupMember.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling updatePlaceGroupMember.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$20.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceGroupService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceGroupService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceGroupService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1$ = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PlaceGroupDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRanking(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${groupId}/digest/${dataView}/${chart}'
            .replace('${' + 'groupId' + '}', String(groupId))
            .replace('${' + 'dataView' + '}', String(dataView))
            .replace('${' + 'chart' + '}', String(chart));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'groupId' is not null or undefined
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling getPlaceGroupRanking.');
        }
        // verify required parameter 'dataView' is not null or undefined
        if (dataView === null || dataView === undefined) {
            throw new Error('Required parameter dataView was null or undefined when calling getPlaceGroupRanking.');
        }
        // verify required parameter 'chart' is not null or undefined
        if (chart === null || chart === undefined) {
            throw new Error('Required parameter chart was null or undefined when calling getPlaceGroupRanking.');
        }
        if (billingPeriodOption !== undefined) {
            queryParameters = queryParameters.set('billingPeriodOption', billingPeriodOption);
        }
        if (startPeriod !== undefined) {
            queryParameters = queryParameters.set('startPeriod', startPeriod);
        }
        if (endPeriod !== undefined) {
            queryParameters = queryParameters.set('endPeriod', endPeriod);
        }
        if (commodityId !== undefined) {
            queryParameters = queryParameters.set('commodityId', commodityId);
        }
        if (commodityCategoryId !== undefined) {
            queryParameters = queryParameters.set('commodityCategoryId', commodityCategoryId);
        }
        if (highToLowRanking !== undefined) {
            queryParameters = queryParameters.set('highToLowRanking', highToLowRanking);
        }
        if (showExcludedMembers !== undefined) {
            queryParameters = queryParameters.set('showExcludedMembers', showExcludedMembers);
        }
        if (showZeroAverages !== undefined) {
            queryParameters = queryParameters.set('showZeroAverages', showZeroAverages);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1$.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceGroupDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceGroupDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PlaceGroupDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1_ = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PostalCodeService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves the city, state, country, and weather station for a postal code
     *
     * @param postalCode
     */
    getPostalCode(postalCode, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPostalCodeWithHttpInfo(postalCode, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the city, state, country, and weather station for a postal code
     *
     * @param postalCode
     */
    getPostalCodeWithHttpInfo(postalCode, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/postalcode/${postalCode}'
            .replace('${' + 'postalCode' + '}', String(postalCode));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'postalCode' is not null or undefined
        if (postalCode === null || postalCode === undefined) {
            throw new Error('Required parameter postalCode was null or undefined when calling getPostalCode.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1_.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PostalCodeService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PostalCodeService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PostalCodeService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1Z = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class PrimaryUseService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a Primary Use
     *
     * @param body Data representing the Primary Use being created
     */
    createPrimaryUse(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPrimaryUseWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a primary use
     *
     * @param primaryUseId The identifier for the primary use being deleted
     */
    deletePrimaryUse(primaryUseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePrimaryUseWithHttpInfo(primaryUseId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Primary Uses. The array of Primary Uses can be filtered by Primary Use type. Possible values for this filter include: \&quot;meter\&quot;, \&quot;place\&quot;. See the filter property for more details
     *
     * @param filter
     */
    getPrimaryUses(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPrimaryUsesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a Primary Use
     *
     * @param body Data representing the Primary Use being created
     */
    createPrimaryUseWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/primaryuse';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Z.Post, path, requestOptions);
    }
    /**
     * Deletes a primary use
     *
     * @param primaryUseId The identifier for the primary use being deleted
     */
    deletePrimaryUseWithHttpInfo(primaryUseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/primaryuse/${primaryUseId}'
            .replace('${' + 'primaryUseId' + '}', String(primaryUseId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'primaryUseId' is not null or undefined
        if (primaryUseId === null || primaryUseId === undefined) {
            throw new Error('Required parameter primaryUseId was null or undefined when calling deletePrimaryUse.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Z.Delete, path, requestOptions);
    }
    /**
     * Retrieves all Primary Uses. The array of Primary Uses can be filtered by Primary Use type. Possible values for this filter include: \&quot;meter\&quot;, \&quot;place\&quot;. See the filter property for more details
     *
     * @param filter
     */
    getPrimaryUsesWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/primaryuse';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Z.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PrimaryUseService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PrimaryUseService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PrimaryUseService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1Y = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class RateService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a rate schedule
     *
     * @param body The properties of the rate schedule to be created
     */
    createRate(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRateWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a rate schedule version
     * Allows the user to create a new version for a rate schedule for use in chargeback scenarios where use or demand cost for calculated bills must be created from a predefined unit cost.            ### Validation          * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Inserting a rate version before an existing version will set the new version&#39;s end date to the effective date of the subsequent version.  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule to receive the new version
     * @param body The properties of the rate schedule version to be created
     */
    createRateVersion(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRateVersionWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a rate schedule
     *
     * @param rateId Unique identifier of the rate schedule to be deleted
     */
    deleteRate(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a version of a rate schedule
     * ### Validation  * The last remaining rate version may not be deleted    ### Other Remarks  * When a rate version is deleted, if there is a preceding rate version, then its end date will be reset to the end date of the deleted rate version.
     * @param rateId Unique identifier of the rate schedule to which the version being deleted belongs
     * @param versionId Unique identifier of the rate schedule version to delete
     */
    deleteRateVersion(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a rate custom field
     *
     * @param rateId
     * @param versionId
     * @param udfId
     */
    downloadRateCustomFieldFile(rateId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadRateCustomFieldFileWithHttpInfo(rateId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a rate
     *
     * @param rateId Unique identifier of the rate schedule to be edited
     * @param body Updated properties of the rate schedule to be edited
     */
    editRate(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRateWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a rate schedule version
     * ### Validation  * Effective date of the edited version      * Must be after the effective date of the previous version      * Must be prior to the effective date of the next version  * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule whose version will be edited
     * @param versionId Unique identifier of the rate schedule version to be edited
     * @param body Updated properties of the rate schedule version to be edited
     */
    editRateVersion(rateId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRateVersionWithHttpInfo(rateId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a rate schedule
     *
     * @param rateId Unique ID of the rate schedule
     */
    getRate(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the unit used by a rate. The unit is determined by the usage unit on the most recent template assigned to a meter with the given rate.
     *
     * @param rateId Unique identifier of the rate schedule for which the unit will be retrieved
     */
    getRateUnit(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateUnitWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a rate version with its details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     * @param versionId ID of the rate schedule version to retrieve
     */
    getRateVersion(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all versions for a rate schedule with their details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     */
    getRateVersions(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateVersionsWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRates(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a rate schedule
     *
     * @param body The properties of the rate schedule to be created
     */
    createRateWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Post, path, requestOptions);
    }
    /**
     * Create a rate schedule version
     * Allows the user to create a new version for a rate schedule for use in chargeback scenarios where use or demand cost for calculated bills must be created from a predefined unit cost.            ### Validation          * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Inserting a rate version before an existing version will set the new version&#39;s end date to the effective date of the subsequent version.  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule to receive the new version
     * @param body The properties of the rate schedule version to be created
     */
    createRateVersionWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling createRateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Post, path, requestOptions);
    }
    /**
     * Delete a rate schedule
     *
     * @param rateId Unique identifier of the rate schedule to be deleted
     */
    deleteRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling deleteRate.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Delete, path, requestOptions);
    }
    /**
     * Delete a version of a rate schedule
     * ### Validation  * The last remaining rate version may not be deleted    ### Other Remarks  * When a rate version is deleted, if there is a preceding rate version, then its end date will be reset to the end date of the deleted rate version.
     * @param rateId Unique identifier of the rate schedule to which the version being deleted belongs
     * @param versionId Unique identifier of the rate schedule version to delete
     */
    deleteRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version/${versionId}'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling deleteRateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling deleteRateVersion.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Delete, path, requestOptions);
    }
    /**
     * Download file for a rate custom field
     *
     * @param rateId
     * @param versionId
     * @param udfId
     */
    downloadRateCustomFieldFileWithHttpInfo(rateId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/rate/${rateId}/version/${versionId}/udf/${udfId}/download'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling downloadRateCustomFieldFile.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling downloadRateCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadRateCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Get, path, requestOptions);
    }
    /**
     * Edit a rate
     *
     * @param rateId Unique identifier of the rate schedule to be edited
     * @param body Updated properties of the rate schedule to be edited
     */
    editRateWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling editRate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Put, path, requestOptions);
    }
    /**
     * Edit a rate schedule version
     * ### Validation  * Effective date of the edited version      * Must be after the effective date of the previous version      * Must be prior to the effective date of the next version  * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule whose version will be edited
     * @param versionId Unique identifier of the rate schedule version to be edited
     * @param body Updated properties of the rate schedule version to be edited
     */
    editRateVersionWithHttpInfo(rateId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version/${versionId}'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling editRateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editRateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Put, path, requestOptions);
    }
    /**
     * Get a rate schedule
     *
     * @param rateId Unique ID of the rate schedule
     */
    getRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Get, path, requestOptions);
    }
    /**
     * Get the unit used by a rate. The unit is determined by the usage unit on the most recent template assigned to a meter with the given rate.
     *
     * @param rateId Unique identifier of the rate schedule for which the unit will be retrieved
     */
    getRateUnitWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/unit'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateUnit.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Get, path, requestOptions);
    }
    /**
     * Get a rate version with its details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     * @param versionId ID of the rate schedule version to retrieve
     */
    getRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version/${versionId}'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getRateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Get, path, requestOptions);
    }
    /**
     * Get a list of all versions for a rate schedule with their details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     */
    getRateVersionsWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Get, path, requestOptions);
    }
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Y.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RateService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RateService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RateService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1X = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class RateDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves rolled up actual billing data by rate for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param rateId The rate to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getRateActualYearly(rateId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateActualYearlyWithHttpInfo(rateId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by rate for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param rateId The rate to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getRateActualYearlyWithHttpInfo(rateId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/digest/actual/yearly'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1X.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RateDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RateDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RateDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1W = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ReportService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param body
     */
    createReportGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReportGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Subscribe to a report and receive scheduled emails  This must be a saved report that belongs to or is shared with the current user  Only SSRS reports are supported
     *
     * @param specificReportId
     * @param body
     */
    createReportSubscription(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReportSubscriptionWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Save a specific report to Saved Reports
     *
     * @param specificReportId The specific report to save
     * @param body The specific report create properties
     */
    createSpecificReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a Report Group
     *
     * @param reportGroupId
     */
    deleteReportGroup(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportGroupWithHttpInfo(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     */
    deleteReportSubscription(specificReportId, reportSubscriptionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param specificReportId
     */
    deleteSpecificReport(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Execute a report, save it in a given format, and email it to a list of recipients.   If distributing reports, returns a 204 No Content if onlySendIfData is set to True and the report generated no data;   returns a 200 and the generated report for download or an empty body if onlySendIfData is set to True
     *
     * @param specificReportId The ID of the specific report to run
     * @param body Allows the user to run one report and optionally email it to one or more recipients. They can optionally specify whether or not the report(s) should be sent if they contain no data.
     */
    distributeReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be edited
     * @param body The list of filters to apply
     */
    editReportFilters(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportFiltersWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param reportGroupId
     * @param body
     */
    editReportGroup(reportGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportGroupWithHttpInfo(reportGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     * @param body
     */
    editReportSubscription(specificReportId, reportSubscriptionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a specific report
     *
     * @param specificReportId The specific report to edit
     * @param body The specific report edit properties
     */
    editSpecificReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be retrieved
     */
    getReportFilters(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportFiltersWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param reportGroupId
     */
    getReportGroup(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportGroupWithHttpInfo(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    getReportGroups(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportGroupsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get sharing information for a report
     * Only the user who created the report or a report administrator is permitted to get sharing details for a report.
     * @param specificReportId The specific report for which to retrieve sharing information
     */
    getReportSharingDetails(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportSharingDetailsWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all available report subscription schedule types, and their day indicator values
     *
     */
    getReportSubscriptionScheduleTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportSubscriptionScheduleTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a report by its specificReportID.
     *
     * @param specificReportId
     */
    getSpecificReport(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a filterable list of installed, saved, and shared reports available to the current user.
     *
     * @param filter
     */
    getSpecificReports(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecificReportsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    installReports(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.installReportsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Execute and email report subscriptions that are ready to be run
     *
     */
    processReportSubscriptions(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processReportSubscriptionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generates a \&quot;quick report\&quot; in the specified export format (or in its preferred export format if not specified) as identified by the provided report code and applying ONLY the filters supplied.
     *
     * @param body
     */
    runQuickReport(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.runQuickReportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run a report and download in the provided format
     *
     * @param specificReportId The ID of the specific report to run
     * @param format The format in which the generated report should be downloaded. Supported options are [\&quot;excel\&quot;, \&quot;csv\&quot;, \&quot;pdf\&quot;, \&quot;word\&quot;]
     */
    runReport(specificReportId, format, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.runReportWithHttpInfo(specificReportId, format, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Share a saved report with other users
     *
     * @param specificReportId ID of the saved report to share
     * @param body Updated sharing details for the report
     */
    shareSavedReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.shareSavedReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the visibility of a report for the current user  This must be a report you can see  Which means you must have created the report  or have ReportAdministrator Manage permission and the report is shared at all  or have SharedReports View permission and the report is shared with you
     *
     * @param specificReportId Specific dashboard
     * @param body Set Visibility
     */
    toggleSharedReportVisibility(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.toggleSharedReportVisibilityWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    createReportGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Subscribe to a report and receive scheduled emails  This must be a saved report that belongs to or is shared with the current user  Only SSRS reports are supported
     *
     * @param specificReportId
     * @param body
     */
    createReportSubscriptionWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/subscription'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling createReportSubscription.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Save a specific report to Saved Reports
     *
     * @param specificReportId The specific report to save
     * @param body The specific report create properties
     */
    createSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/copy'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling createSpecificReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Deletes a Report Group
     *
     * @param reportGroupId
     */
    deleteReportGroupWithHttpInfo(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup/${reportGroupId}'
            .replace('${' + 'reportGroupId' + '}', String(reportGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportGroupId' is not null or undefined
        if (reportGroupId === null || reportGroupId === undefined) {
            throw new Error('Required parameter reportGroupId was null or undefined when calling deleteReportGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Delete, path, requestOptions);
    }
    /**
     * Delete a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     */
    deleteReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/subscription/${reportSubscriptionId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId))
            .replace('${' + 'reportSubscriptionId' + '}', String(reportSubscriptionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling deleteReportSubscription.');
        }
        // verify required parameter 'reportSubscriptionId' is not null or undefined
        if (reportSubscriptionId === null || reportSubscriptionId === undefined) {
            throw new Error('Required parameter reportSubscriptionId was null or undefined when calling deleteReportSubscription.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Delete, path, requestOptions);
    }
    /**
     *
     *
     * @param specificReportId
     */
    deleteSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling deleteSpecificReport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Delete, path, requestOptions);
    }
    /**
     * Execute a report, save it in a given format, and email it to a list of recipients.   If distributing reports, returns a 204 No Content if onlySendIfData is set to True and the report generated no data;   returns a 200 and the generated report for download or an empty body if onlySendIfData is set to True
     *
     * @param specificReportId The ID of the specific report to run
     * @param body Allows the user to run one report and optionally email it to one or more recipients. They can optionally specify whether or not the report(s) should be sent if they contain no data.
     */
    distributeReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/exec/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling distributeReport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Edit the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be edited
     * @param body The list of filters to apply
     */
    editReportFiltersWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/filter'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling editReportFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param reportGroupId
     * @param body
     */
    editReportGroupWithHttpInfo(reportGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup/${reportGroupId}'
            .replace('${' + 'reportGroupId' + '}', String(reportGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportGroupId' is not null or undefined
        if (reportGroupId === null || reportGroupId === undefined) {
            throw new Error('Required parameter reportGroupId was null or undefined when calling editReportGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Put, path, requestOptions);
    }
    /**
     * Edit a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     * @param body
     */
    editReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/subscription/${reportSubscriptionId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId))
            .replace('${' + 'reportSubscriptionId' + '}', String(reportSubscriptionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling editReportSubscription.');
        }
        // verify required parameter 'reportSubscriptionId' is not null or undefined
        if (reportSubscriptionId === null || reportSubscriptionId === undefined) {
            throw new Error('Required parameter reportSubscriptionId was null or undefined when calling editReportSubscription.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Put, path, requestOptions);
    }
    /**
     * Edit a specific report
     *
     * @param specificReportId The specific report to edit
     * @param body The specific report edit properties
     */
    editSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling editSpecificReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Put, path, requestOptions);
    }
    /**
     * Get the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be retrieved
     */
    getReportFiltersWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/filter'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling getReportFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param reportGroupId
     */
    getReportGroupWithHttpInfo(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup/${reportGroupId}'
            .replace('${' + 'reportGroupId' + '}', String(reportGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportGroupId' is not null or undefined
        if (reportGroupId === null || reportGroupId === undefined) {
            throw new Error('Required parameter reportGroupId was null or undefined when calling getReportGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     *
     *
     */
    getReportGroupsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     * Get sharing information for a report
     * Only the user who created the report or a report administrator is permitted to get sharing details for a report.
     * @param specificReportId The specific report for which to retrieve sharing information
     */
    getReportSharingDetailsWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/share'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling getReportSharingDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     * Get a list of all available report subscription schedule types, and their day indicator values
     *
     */
    getReportSubscriptionScheduleTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/subscription/scheduletype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     * Get a report by its specificReportID.
     *
     * @param specificReportId
     */
    getSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling getSpecificReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     * Get a filterable list of installed, saved, and shared reports available to the current user.
     *
     * @param filter
     */
    getSpecificReportsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     *
     *
     */
    installReportsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/install/latest';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Execute and email report subscriptions that are ready to be run
     *
     */
    processReportSubscriptionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/exec/subscription';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Generates a \&quot;quick report\&quot; in the specified export format (or in its preferred export format if not specified) as identified by the provided report code and applying ONLY the filters supplied.
     *
     * @param body
     */
    runQuickReportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/quick';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Post, path, requestOptions);
    }
    /**
     * Run a report and download in the provided format
     *
     * @param specificReportId The ID of the specific report to run
     * @param format The format in which the generated report should be downloaded. Supported options are [\&quot;excel\&quot;, \&quot;csv\&quot;, \&quot;pdf\&quot;, \&quot;word\&quot;]
     */
    runReportWithHttpInfo(specificReportId, format, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/exec/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling runReport.');
        }
        if (format !== undefined) {
            queryParameters = queryParameters.set('format', format);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Get, path, requestOptions);
    }
    /**
     * Share a saved report with other users
     *
     * @param specificReportId ID of the saved report to share
     * @param body Updated sharing details for the report
     */
    shareSavedReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/share'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling shareSavedReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Put, path, requestOptions);
    }
    /**
     * Update the visibility of a report for the current user  This must be a report you can see  Which means you must have created the report  or have ReportAdministrator Manage permission and the report is shared at all  or have SharedReports View permission and the report is shared with you
     *
     * @param specificReportId Specific dashboard
     * @param body Set Visibility
     */
    toggleSharedReportVisibilityWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/visible'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling toggleSharedReportVisibility.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1W.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1V = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ReportBuilderService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param kql
     * @param offset
     */
    query(kql, offset, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.queryWithHttpInfo(kql, offset, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param kql
     * @param offset
     */
    queryWithHttpInfo(kql, offset, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/reportbuilder/query';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (kql !== undefined) {
            queryParameters = queryParameters.set('kql', kql);
        }
        if (offset !== undefined) {
            queryParameters = queryParameters.set('offset', offset);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1V.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportBuilderService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportBuilderService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportBuilderService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1U = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ReportDistributionService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a Report Distribution
     *
     * @param body Data representing the report distribution being created
     */
    createReportDistribution(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReportDistributionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to delete
     */
    deleteReportDistribution(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete report distribution logs older than the number of days provided only if  the number of logs per distribution is in excess of 100.  100 latest logs per distribution will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteReportDistributionLogsOlderThan(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportDistributionLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to edit
     * @param body Data representing the report distribution being edited
     */
    editReportDistribution(reportDistributionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportDistributionWithHttpInfo(reportDistributionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run a report distribution and send the report out immediately  This does not affect the current distribution schedule
     *
     * @param reportDistributionId Id of the report distribution to run
     * @param overrideUserIds List of systemuserIds to send the distribution to. If not provided the currently configured recipients will receive the report.  If this is provided it is used in place of the currently configured recipients
     */
    executeReportDistribution(reportDistributionId, overrideUserIds, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeReportDistributionWithHttpInfo(reportDistributionId, overrideUserIds, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistribution(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a Report Distribution Filters
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionFilters(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionFiltersWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the details for a report distribution log
     *
     * @param reportDistributionLogId Id of the report distribution log to get the details for
     */
    getReportDistributionLogDetails(reportDistributionLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionLogDetailsWithHttpInfo(reportDistributionLogId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of report distribution logs
     *
     * @param includeInProgress Option to include in progress distributions.  False by default
     */
    getReportDistributionLogs(includeInProgress, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionLogsWithHttpInfo(includeInProgress, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all Report Distributions
     *
     * @param filter
     */
    getReportDistributions(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run all report distributions  Sends reports based on configured schedule  DistributedReportSettings - Manage permission required.
     *
     */
    runReportDistributions(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.runReportDistributionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a Report Distribution
     *
     * @param body Data representing the report distribution being created
     */
    createReportDistributionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Post, path, requestOptions);
    }
    /**
     * Deletes a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to delete
     */
    deleteReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling deleteReportDistribution.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Delete, path, requestOptions);
    }
    /**
     * Delete report distribution logs older than the number of days provided only if  the number of logs per distribution is in excess of 100.  100 latest logs per distribution will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteReportDistributionLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/log';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (olderThanDays !== undefined) {
            queryParameters = queryParameters.set('olderThanDays', olderThanDays);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Delete, path, requestOptions);
    }
    /**
     * Edit a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to edit
     * @param body Data representing the report distribution being edited
     */
    editReportDistributionWithHttpInfo(reportDistributionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling editReportDistribution.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Put, path, requestOptions);
    }
    /**
     * Run a report distribution and send the report out immediately  This does not affect the current distribution schedule
     *
     * @param reportDistributionId Id of the report distribution to run
     * @param overrideUserIds List of systemuserIds to send the distribution to. If not provided the currently configured recipients will receive the report.  If this is provided it is used in place of the currently configured recipients
     */
    executeReportDistributionWithHttpInfo(reportDistributionId, overrideUserIds, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}/exec'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling executeReportDistribution.');
        }
        if (overrideUserIds) {
            queryParameters = queryParameters.set('overrideUserIds', overrideUserIds.join(COLLECTION_FORMATS['csv']));
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Post, path, requestOptions);
    }
    /**
     * Get a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling getReportDistribution.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Get, path, requestOptions);
    }
    /**
     * Get a Report Distribution Filters
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionFiltersWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}/filter'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling getReportDistributionFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Get, path, requestOptions);
    }
    /**
     * Get the details for a report distribution log
     *
     * @param reportDistributionLogId Id of the report distribution log to get the details for
     */
    getReportDistributionLogDetailsWithHttpInfo(reportDistributionLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/log/${reportDistributionLogId}/detail'
            .replace('${' + 'reportDistributionLogId' + '}', String(reportDistributionLogId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionLogId' is not null or undefined
        if (reportDistributionLogId === null || reportDistributionLogId === undefined) {
            throw new Error('Required parameter reportDistributionLogId was null or undefined when calling getReportDistributionLogDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Get, path, requestOptions);
    }
    /**
     * Get a list of report distribution logs
     *
     * @param includeInProgress Option to include in progress distributions.  False by default
     */
    getReportDistributionLogsWithHttpInfo(includeInProgress, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/log';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (includeInProgress !== undefined) {
            queryParameters = queryParameters.set('includeInProgress', includeInProgress);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Get, path, requestOptions);
    }
    /**
     * Get all Report Distributions
     *
     * @param filter
     */
    getReportDistributionsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Get, path, requestOptions);
    }
    /**
     * Run all report distributions  Sends reports based on configured schedule  DistributedReportSettings - Manage permission required.
     *
     */
    runReportDistributionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1U.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportDistributionService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportDistributionService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ReportDistributionService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1T = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class RouteService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeter(routeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.addMeterWithHttpInfo(routeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRoute(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRouteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a route
     *
     * @param id The identifier for the route being deleted
     */
    deleteRoute(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRoute(id, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRouteWithHttpInfo(id, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRoute(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetails(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRouteDetailsWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all routes
     *
     */
    getRoutes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRoutesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReading(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRoutesWithMetersChannelsLatestReadingWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeter(routeId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.removeMeterWithHttpInfo(routeId, meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeterWithHttpInfo(routeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${routeId}/meter'
            .replace('${' + 'routeId' + '}', String(routeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'routeId' is not null or undefined
        if (routeId === null || routeId === undefined) {
            throw new Error('Required parameter routeId was null or undefined when calling addMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Post, path, requestOptions);
    }
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRouteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Post, path, requestOptions);
    }
    /**
     * Deletes a route
     *
     * @param id The identifier for the route being deleted
     */
    deleteRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteRoute.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Delete, path, requestOptions);
    }
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRouteWithHttpInfo(id, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling editRoute.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Put, path, requestOptions);
    }
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getRoute.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Get, path, requestOptions);
    }
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetailsWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}/details'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getRouteDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Get, path, requestOptions);
    }
    /**
     * Retrieves all routes
     *
     */
    getRoutesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReadingWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/meter/channel/latestReading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Get, path, requestOptions);
    }
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeterWithHttpInfo(routeId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${routeId}/meter/${meterId}'
            .replace('${' + 'routeId' + '}', String(routeId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'routeId' is not null or undefined
        if (routeId === null || routeId === undefined) {
            throw new Error('Required parameter routeId was null or undefined when calling removeMeter.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling removeMeter.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1T.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RouteService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RouteService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RouteService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1S = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SavingsService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Mass update certain cost avoidance settings for meters that match the filter conditions  Baseline and Savings will be reprocessed for affected meters
     *
     * @param body Filters and new cost avoidance setting values
     */
    bulkEditMeterCostAvoidanceSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.bulkEditMeterCostAvoidanceSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Regenerate cost avoidance baseline for the meters that match the filter conditions and then reprocess their savings
     *
     * @param body Settings and filter conditions for baseline processing
     */
    bulkGenerateBaseline(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.bulkGenerateBaselineWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Calculate savings for the meters that match the filter conditions, using the provided settings
     *
     * @param body Settings and filter conditions for savings processing
     */
    calculateSavings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.calculateSavingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavings(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createOtherSavingsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createOtherSavingsCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustment(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createSpecialAdjustmentWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavings(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentById(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteSpecialAdjustmentByIdWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for one or more commodities  Cost Avoidance Savings will be re-calculated for all bills for meters having the affected commodities
     *
     * @param body Data representing one or more average unit cost ranges to edit
     */
    editAucRanges(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAucRangesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    editCostAvoidanceSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCostAvoidanceSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavings(meterId, otherSavingsId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editOtherSavingsWithHttpInfo(meterId, otherSavingsId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustment(meterId, specialAdjustmentId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Executes the baseline and cost avoidance processors with provided baseline and cost avoidance settings for the provided meter.   Results are not saved unless the \&quot;save\&quot; flag is set to true.  If \&quot;save\&quot; is true, MeterSavingsSettings-Manage permission is also required
     *
     * @param meterId ID of the meter for which baseline will be reprocessed
     * @param save If true, the baseline results will be saved to the database
     * @param body Provided baseline and avoidance settings
     */
    generateBaseline(meterId, save, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.generateBaselineWithHttpInfo(meterId, save, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Executes the baseline processor with stored baseline settings for the provided meter
     *
     * @param meterId ID of the meter for which baseline data will be returned
     */
    generateBaselineGet(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.generateBaselineGetWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     */
    getAllOtherSavings(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllOtherSavingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for each commodity
     *
     */
    getAucRanges(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAucRangesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return available filters for Cost Avoidance processors  Filters:  - Commodity ID  - Commodity Name  - Meter Group Name  - Building Group Name  - Topmost Place Code  - Topmost Place Name
     *
     */
    getCostAvoidanceFilters(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostAvoidanceFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Count the number of meters that match the filter conditions for cost avoidance bulk actions
     *
     * @param onlyMetersInCAP Whether or not to only include meters in the count which are already participating in cost avoidance
     * @param body The filters used when counting the meters
     */
    getCostAvoidanceMeterCount(onlyMetersInCAP, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostAvoidanceMeterCountWithHttpInfo(onlyMetersInCAP, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    getCostAvoidanceSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostAvoidanceSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get one other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     * @param otherSavingsId The identifier for the other savings record which is being retrieved
     */
    getOneOtherSavings(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getOneOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get other savings categories
     *
     */
    getOtherSavingsCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getOtherSavingsCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeList(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsAdjustedCostTypeListWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBill(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsMeterBillWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDaily(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsMeterBillDailyWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillList(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsMeterBillListWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single special adjustment by its unique ID
     *
     * @param meterId The meter for which to return the special adjustment
     * @param specialAdjustmentId Unique ID of the special adjustment to return
     */
    getSpecialAdjustment(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethods(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all the special adjustments for the meter
     *
     * @param meterId The meter for which to return special adjustment
     */
    getSpecialAdjustments(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates or removes manual adjustments to savings for a provided meter and bill
     *
     * @param meterId The meter for which the manual adjustment is being made
     * @param billId The bill for which the manual adjustment is being made
     * @param body
     */
    manualAdjustment(meterId, billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manualAdjustmentWithHttpInfo(meterId, billId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Mass update certain cost avoidance settings for meters that match the filter conditions  Baseline and Savings will be reprocessed for affected meters
     *
     * @param body Filters and new cost avoidance setting values
     */
    bulkEditMeterCostAvoidanceSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Put, path, requestOptions);
    }
    /**
     * Regenerate cost avoidance baseline for the meters that match the filter conditions and then reprocess their savings
     *
     * @param body Settings and filter conditions for baseline processing
     */
    bulkGenerateBaselineWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/baseline/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     * Calculate savings for the meters that match the filter conditions, using the provided settings
     *
     * @param body Settings and filter conditions for savings processing
     */
    calculateSavingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavingsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/othersavings/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustmentWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createSpecialAdjustment.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings/${otherSavingsId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'otherSavingsId' + '}', String(otherSavingsId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteOtherSavings.');
        }
        // verify required parameter 'otherSavingsId' is not null or undefined
        if (otherSavingsId === null || otherSavingsId === undefined) {
            throw new Error('Required parameter otherSavingsId was null or undefined when calling deleteOtherSavings.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Delete, path, requestOptions);
    }
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentByIdWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special/${specialAdjustmentId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'specialAdjustmentId' + '}', String(specialAdjustmentId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteSpecialAdjustmentById.');
        }
        // verify required parameter 'specialAdjustmentId' is not null or undefined
        if (specialAdjustmentId === null || specialAdjustmentId === undefined) {
            throw new Error('Required parameter specialAdjustmentId was null or undefined when calling deleteSpecialAdjustmentById.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Delete, path, requestOptions);
    }
    /**
     * Edit the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for one or more commodities  Cost Avoidance Savings will be re-calculated for all bills for meters having the affected commodities
     *
     * @param body Data representing one or more average unit cost ranges to edit
     */
    editAucRangesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/auc';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Put, path, requestOptions);
    }
    /**
     *
     *
     */
    editCostAvoidanceSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/settings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Put, path, requestOptions);
    }
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavingsWithHttpInfo(meterId, otherSavingsId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings/${otherSavingsId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'otherSavingsId' + '}', String(otherSavingsId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editOtherSavings.');
        }
        // verify required parameter 'otherSavingsId' is not null or undefined
        if (otherSavingsId === null || otherSavingsId === undefined) {
            throw new Error('Required parameter otherSavingsId was null or undefined when calling editOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Put, path, requestOptions);
    }
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special/${specialAdjustmentId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'specialAdjustmentId' + '}', String(specialAdjustmentId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editSpecialAdjustment.');
        }
        // verify required parameter 'specialAdjustmentId' is not null or undefined
        if (specialAdjustmentId === null || specialAdjustmentId === undefined) {
            throw new Error('Required parameter specialAdjustmentId was null or undefined when calling editSpecialAdjustment.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Put, path, requestOptions);
    }
    /**
     * Executes the baseline and cost avoidance processors with provided baseline and cost avoidance settings for the provided meter.   Results are not saved unless the \&quot;save\&quot; flag is set to true.  If \&quot;save\&quot; is true, MeterSavingsSettings-Manage permission is also required
     *
     * @param meterId ID of the meter for which baseline will be reprocessed
     * @param save If true, the baseline results will be saved to the database
     * @param body Provided baseline and avoidance settings
     */
    generateBaselineWithHttpInfo(meterId, save, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/baseline'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling generateBaseline.');
        }
        if (save !== undefined) {
            queryParameters = queryParameters.set('save', save);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     * Executes the baseline processor with stored baseline settings for the provided meter
     *
     * @param meterId ID of the meter for which baseline data will be returned
     */
    generateBaselineGetWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/baseline'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling generateBaselineGet.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get a other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     */
    getAllOtherSavingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getAllOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for each commodity
     *
     */
    getAucRangesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/auc';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Return available filters for Cost Avoidance processors  Filters:  - Commodity ID  - Commodity Name  - Meter Group Name  - Building Group Name  - Topmost Place Code  - Topmost Place Name
     *
     */
    getCostAvoidanceFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/filters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Count the number of meters that match the filter conditions for cost avoidance bulk actions
     *
     * @param onlyMetersInCAP Whether or not to only include meters in the count which are already participating in cost avoidance
     * @param body The filters used when counting the meters
     */
    getCostAvoidanceMeterCountWithHttpInfo(onlyMetersInCAP, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/count';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (onlyMetersInCAP !== undefined) {
            queryParameters = queryParameters.set('onlyMetersInCAP', onlyMetersInCAP);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    /**
     *
     *
     */
    getCostAvoidanceSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/settings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get one other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     * @param otherSavingsId The identifier for the other savings record which is being retrieved
     */
    getOneOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings/${otherSavingsId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'otherSavingsId' + '}', String(otherSavingsId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getOneOtherSavings.');
        }
        // verify required parameter 'otherSavingsId' is not null or undefined
        if (otherSavingsId === null || otherSavingsId === undefined) {
            throw new Error('Required parameter otherSavingsId was null or undefined when calling getOneOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get other savings categories
     *
     */
    getOtherSavingsCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/othersavings/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeListWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustedCostType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill/${billId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSavingsMeterBill.');
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getSavingsMeterBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDailyWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill/${billId}/daily'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSavingsMeterBillDaily.');
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getSavingsMeterBillDaily.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillListWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSavingsMeterBillList.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/task/${taskId}'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling getSavingsTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get a single special adjustment by its unique ID
     *
     * @param meterId The meter for which to return the special adjustment
     * @param specialAdjustmentId Unique ID of the special adjustment to return
     */
    getSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special/${specialAdjustmentId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'specialAdjustmentId' + '}', String(specialAdjustmentId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSpecialAdjustment.');
        }
        // verify required parameter 'specialAdjustmentId' is not null or undefined
        if (specialAdjustmentId === null || specialAdjustmentId === undefined) {
            throw new Error('Required parameter specialAdjustmentId was null or undefined when calling getSpecialAdjustment.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/special/method';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/special/type';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Get all the special adjustments for the meter
     *
     * @param meterId The meter for which to return special adjustment
     */
    getSpecialAdjustmentsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSpecialAdjustments.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Get, path, requestOptions);
    }
    /**
     * Creates or removes manual adjustments to savings for a provided meter and bill
     *
     * @param meterId The meter for which the manual adjustment is being made
     * @param billId The bill for which the manual adjustment is being made
     * @param body
     */
    manualAdjustmentWithHttpInfo(meterId, billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill/${billId}/manualadjustment'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manualAdjustment.');
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling manualAdjustment.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1S.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SavingsService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SavingsService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SavingsService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1R = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class ScheduleService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createSchedule(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createScheduleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteSchedule(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editSchedule(scheduleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editScheduleWithHttpInfo(scheduleId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getSchedule(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all schedules
     *
     */
    getSchedules(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSchedulesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createScheduleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1R.Post, path, requestOptions);
    }
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule/${scheduleId}'
            .replace('${' + 'scheduleId' + '}', String(scheduleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'scheduleId' is not null or undefined
        if (scheduleId === null || scheduleId === undefined) {
            throw new Error('Required parameter scheduleId was null or undefined when calling deleteSchedule.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1R.Delete, path, requestOptions);
    }
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editScheduleWithHttpInfo(scheduleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule/${scheduleId}'
            .replace('${' + 'scheduleId' + '}', String(scheduleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'scheduleId' is not null or undefined
        if (scheduleId === null || scheduleId === undefined) {
            throw new Error('Required parameter scheduleId was null or undefined when calling editSchedule.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1R.Put, path, requestOptions);
    }
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule/${scheduleId}'
            .replace('${' + 'scheduleId' + '}', String(scheduleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'scheduleId' is not null or undefined
        if (scheduleId === null || scheduleId === undefined) {
            throw new Error('Required parameter scheduleId was null or undefined when calling getSchedule.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1R.Get, path, requestOptions);
    }
    /**
     * Retrieves all schedules
     *
     */
    getSchedulesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1R.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ScheduleService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ScheduleService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ScheduleService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1Q = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SearchService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Searches for Accounts, Meters, Cost Centers, Places, Place Groups, Emissions Sources, and Collections that match the provided query text
     * Unless searching by id, not all properties on child objects are set in the response DTO, this is for performance reasons
     * @param query The text to search
     * @param limit The maximum number of items to return per entity type. Defaults to 10, valid range of 0 to 100.               0 is treated as default for backwards compatibility reasons.
     */
    getSearchResult(query, limit, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSearchResultWithHttpInfo(query, limit, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Searches for Accounts, Meters, Cost Centers, Places, Place Groups, Emissions Sources, and Collections that match the provided query text
     * Unless searching by id, not all properties on child objects are set in the response DTO, this is for performance reasons
     * @param query The text to search
     * @param limit The maximum number of items to return per entity type. Defaults to 10, valid range of 0 to 100.               0 is treated as default for backwards compatibility reasons.
     */
    getSearchResultWithHttpInfo(query, limit, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (query !== undefined) {
            queryParameters = queryParameters.set('query', query);
        }
        if (limit !== undefined) {
            queryParameters = queryParameters.set('limit', limit);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1Q.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SearchService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SearchService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SearchService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1P = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SentinelService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves all sentinel predictions for a given ESA channel within a specified local date/time range.
     *
     * @param esaChannelId The ID of the ESA channel to retrieve predictions for.
     * @param startLocalDate The start local date/time of the range for which predictions are requested.  If equal to endLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions since this date and time (exclusive).
     * @param endLocalDate The end local date/time of the range for which predictions are requested  If equal to startLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions up to (and including) this date and time.
     */
    getSentinelPredictions(esaChannelId, startLocalDate, endLocalDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSentinelPredictionsWithHttpInfo(esaChannelId, startLocalDate, endLocalDate, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all sentinel predictions for a given ESA channel within a specified local date/time range.
     *
     * @param esaChannelId The ID of the ESA channel to retrieve predictions for.
     * @param startLocalDate The start local date/time of the range for which predictions are requested.  If equal to endLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions since this date and time (exclusive).
     * @param endLocalDate The end local date/time of the range for which predictions are requested  If equal to startLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions up to (and including) this date and time.
     */
    getSentinelPredictionsWithHttpInfo(esaChannelId, startLocalDate, endLocalDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/sentinel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getSentinelPredictions.');
        }
        if (startLocalDate !== undefined) {
            queryParameters = queryParameters.set('StartLocalDate', startLocalDate.toISOString());
        }
        if (endLocalDate !== undefined) {
            queryParameters = queryParameters.set('EndLocalDate', endLocalDate.toISOString());
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1P.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SentinelService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SentinelService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SentinelService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1O = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SetupService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Returns an Excel file used within SetupSheets
     *
     * @param type
     * @param filter
     */
    getSetupSheet(type, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSetupSheetWithHttpInfo(type, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the applicable filters for a given type to filter down SetupSheet Templates
     *
     * @param type
     */
    getSetupSheetFilters(type, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSetupSheetFiltersWithHttpInfo(type, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Import a budget setup sheet
     *
     * @param budgetId The budget identifier
     * @param versionId The budget version identifier
     * @param body The budget sheet file contents
     */
    postBudgetSetupSheet(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.postBudgetSetupSheetWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Processes a SetupSheet Excel file  Accepts a base64 string representation of an xlsx file  File must be Microsoft Excel 2007 or later.
     *
     * @param body
     */
    postSetupSheet(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.postSetupSheetWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns an Excel file used within SetupSheets
     *
     * @param type
     * @param filter
     */
    getSetupSheetWithHttpInfo(type, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/setup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (type !== undefined) {
            queryParameters = queryParameters.set('type', type);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1O.Get, path, requestOptions);
    }
    /**
     * Returns the applicable filters for a given type to filter down SetupSheet Templates
     *
     * @param type
     */
    getSetupSheetFiltersWithHttpInfo(type, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/setup/filter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (type !== undefined) {
            queryParameters = queryParameters.set('type', type);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1O.Get, path, requestOptions);
    }
    /**
     * Import a budget setup sheet
     *
     * @param budgetId The budget identifier
     * @param versionId The budget version identifier
     * @param body The budget sheet file contents
     */
    postBudgetSetupSheetWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202311/setup/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling postBudgetSetupSheet.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling postBudgetSetupSheet.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/vnd.ms-excel'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1O.Post, path, requestOptions);
    }
    /**
     * Processes a SetupSheet Excel file  Accepts a base64 string representation of an xlsx file  File must be Microsoft Excel 2007 or later.
     *
     * @param body
     */
    postSetupSheetWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/setup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/vnd.ms-excel'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1O.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SetupService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SetupService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SetupService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1N = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SparkService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param billId
     */
    executeSparkAudit(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeSparkAuditWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param billId
     */
    executeSparkAuditWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/V202504/spark/bill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling executeSparkAudit.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1N.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SparkService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SparkService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SparkService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1M = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SummaryAccountService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccounts(summaryAccountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.linkSubAccountsWithHttpInfo(summaryAccountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccount(summaryAccountId, subAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkSubAccountWithHttpInfo(summaryAccountId, subAccountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccounts(summaryAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkSubAccountsWithHttpInfo(summaryAccountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccountsWithHttpInfo(summaryAccountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/summaryAccount/${summaryAccountId}/subAccount'
            .replace('${' + 'summaryAccountId' + '}', String(summaryAccountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'summaryAccountId' is not null or undefined
        if (summaryAccountId === null || summaryAccountId === undefined) {
            throw new Error('Required parameter summaryAccountId was null or undefined when calling linkSubAccounts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1M.Post, path, requestOptions);
    }
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccountWithHttpInfo(summaryAccountId, subAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/summaryAccount/${summaryAccountId}/subAccount/${subAccountId}'
            .replace('${' + 'summaryAccountId' + '}', String(summaryAccountId))
            .replace('${' + 'subAccountId' + '}', String(subAccountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'summaryAccountId' is not null or undefined
        if (summaryAccountId === null || summaryAccountId === undefined) {
            throw new Error('Required parameter summaryAccountId was null or undefined when calling unlinkSubAccount.');
        }
        // verify required parameter 'subAccountId' is not null or undefined
        if (subAccountId === null || subAccountId === undefined) {
            throw new Error('Required parameter subAccountId was null or undefined when calling unlinkSubAccount.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1M.Delete, path, requestOptions);
    }
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccountsWithHttpInfo(summaryAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/summaryAccount/${summaryAccountId}/subAccount'
            .replace('${' + 'summaryAccountId' + '}', String(summaryAccountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'summaryAccountId' is not null or undefined
        if (summaryAccountId === null || summaryAccountId === undefined) {
            throw new Error('Required parameter summaryAccountId was null or undefined when calling unlinkSubAccounts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1M.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SummaryAccountService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SummaryAccountService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SummaryAccountService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1L = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SystemUserService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUser(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUserWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRole(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSystemUsersRoleWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUser(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUserWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return a specific user and its properties. Requires View permission for Users &amp; Roles
     *
     * @param userId The ID of the user to return
     */
    getUser(userId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserWithHttpInfo(userId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of users.  Requires View permission for Users &amp; Roles.   If this permission is not available, restricted set of properties are returned.
     *
     * @param filter
     */
    getUsers(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUsersWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUserWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/user';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1L.Post, path, requestOptions);
    }
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRoleWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/systemUser/${userId}/role'
            .replace('${' + 'userId' + '}', String(userId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userId' is not null or undefined
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling editSystemUsersRole.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1L.Put, path, requestOptions);
    }
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUserWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/user/${userId}'
            .replace('${' + 'userId' + '}', String(userId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userId' is not null or undefined
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling editUser.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1L.Put, path, requestOptions);
    }
    /**
     * Return a specific user and its properties. Requires View permission for Users &amp; Roles
     *
     * @param userId The ID of the user to return
     */
    getUserWithHttpInfo(userId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/user/${userId}'
            .replace('${' + 'userId' + '}', String(userId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userId' is not null or undefined
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling getUser.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1L.Get, path, requestOptions);
    }
    /**
     * Gets a list of users.  Requires View permission for Users &amp; Roles.   If this permission is not available, restricted set of properties are returned.
     *
     * @param filter
     */
    getUsersWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/user';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1L.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SystemUserService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SystemUserService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SystemUserService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1K = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class TagService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get a list of tags within a tag category. Report tags are the only supported category at this time.
     *
     * @param filter Currently only supports the &#39;tagCategory&#39; filter with a value of &#39;report&#39;, may be expanded in the future
     */
    getTags(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTagsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of tags within a tag category. Report tags are the only supported category at this time.
     *
     * @param filter Currently only supports the &#39;tagCategory&#39; filter with a value of &#39;report&#39;, may be expanded in the future
     */
    getTagsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/tag';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1K.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TagService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TagService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TagService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1J = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class TaskService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits the note/comment associated with a task
     *
     * @param taskId The identifier for the task being edited
     * @param body Data representing the note
     */
    editTask(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editTaskWithHttpInfo(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a task by its GUID. The output property could potentially contain a large amount of data. If response time or size becomes an issue, use field reduction to eliminate the output field.
     *
     * @param taskGuid The GUID of the task
     */
    getTask(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTaskWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a task&#39;s error log as an EXCEL file by its GUID.  At this time error logs can be downloaded for \&quot;ReadingImport\&quot; task type only
     *
     * @param taskGuid The GUID of the task
     */
    getTaskOutputFile(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTaskOutputFileWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of tasks
     *
     * @param taskTypeCode Task type code. Acceptable values are:       AuditGroup,       CostAvoidance,      Report,      Chargeback,      SetupSheet,      UnitsOfMeasure,      Accrual,      BillImport,       EnergyStar,      BillExport,      ReadingImport,      SummarizeReading,      BillUnexport,      V7CostAvoidance,      V7Accrual,      Budget      CostUnitUpdate,      RecordImportPfl,      EsaReadingImpPfl,      RecordImport  *This combines record import setup sheet tasks and record import with a profile tasks,      EsaReadingImport  *This combines Esa readings import setup sheet tasks and Esa Reading import with a profile tasks
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTasks(taskTypeCode, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTasksWithHttpInfo(taskTypeCode, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits the note/comment associated with a task
     *
     * @param taskId The identifier for the task being edited
     * @param body Data representing the note
     */
    editTaskWithHttpInfo(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/task/${taskId}'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling editTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1J.Put, path, requestOptions);
    }
    /**
     * Retrieves a task by its GUID. The output property could potentially contain a large amount of data. If response time or size becomes an issue, use field reduction to eliminate the output field.
     *
     * @param taskGuid The GUID of the task
     */
    getTaskWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/task/${taskGuid}'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1J.Get, path, requestOptions);
    }
    /**
     * Retrieves a task&#39;s error log as an EXCEL file by its GUID.  At this time error logs can be downloaded for \&quot;ReadingImport\&quot; task type only
     *
     * @param taskGuid The GUID of the task
     */
    getTaskOutputFileWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/task/${taskGuid}/errorOutput'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getTaskOutputFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1J.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of tasks
     *
     * @param taskTypeCode Task type code. Acceptable values are:       AuditGroup,       CostAvoidance,      Report,      Chargeback,      SetupSheet,      UnitsOfMeasure,      Accrual,      BillImport,       EnergyStar,      BillExport,      ReadingImport,      SummarizeReading,      BillUnexport,      V7CostAvoidance,      V7Accrual,      Budget      CostUnitUpdate,      RecordImportPfl,      EsaReadingImpPfl,      RecordImport  *This combines record import setup sheet tasks and record import with a profile tasks,      EsaReadingImport  *This combines Esa readings import setup sheet tasks and Esa Reading import with a profile tasks
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTasksWithHttpInfo(taskTypeCode, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (taskTypeCode !== undefined) {
            queryParameters = queryParameters.set('taskTypeCode', taskTypeCode);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1J.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1I = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class TemplateService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBill(billId, accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountTemplateFromBillWithHttpInfo(billId, accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBill(billId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createTemplateFromBillWithHttpInfo(billId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one template
     *
     * @param templateId The template identifier for the template being retrieved
     */
    getTemplate(templateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTemplateWithHttpInfo(templateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one template version for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     * @param versionId The identifier for the template version being retrieved
     */
    getTemplateVersion(templateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTemplateVersionWithHttpInfo(templateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all template versions for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     */
    getTemplateVersions(templateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTemplateVersionsWithHttpInfo(templateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all templates
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTemplates(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTemplatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplate(templateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountMetersLatestTemplateWithHttpInfo(templateId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBillWithHttpInfo(billId, accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/bill/${billId}/account/${accountId}/template'
            .replace('${' + 'billId' + '}', String(billId))
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling createAccountTemplateFromBill.');
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling createAccountTemplateFromBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Post, path, requestOptions);
    }
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBillWithHttpInfo(billId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/meter/${meterId}/template'
            .replace('${' + 'billId' + '}', String(billId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling createTemplateFromBill.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createTemplateFromBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Post, path, requestOptions);
    }
    /**
     * Retrieves one template
     *
     * @param templateId The template identifier for the template being retrieved
     */
    getTemplateWithHttpInfo(templateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template/${templateId}'
            .replace('${' + 'templateId' + '}', String(templateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'templateId' is not null or undefined
        if (templateId === null || templateId === undefined) {
            throw new Error('Required parameter templateId was null or undefined when calling getTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Get, path, requestOptions);
    }
    /**
     * Retrieves one template version for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     * @param versionId The identifier for the template version being retrieved
     */
    getTemplateVersionWithHttpInfo(templateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template/${templateId}/version/${versionId}'
            .replace('${' + 'templateId' + '}', String(templateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'templateId' is not null or undefined
        if (templateId === null || templateId === undefined) {
            throw new Error('Required parameter templateId was null or undefined when calling getTemplateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getTemplateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Get, path, requestOptions);
    }
    /**
     * Retrieves all template versions for a given template
     *
     * @param templateId The template identifier for the template version being retrieved
     */
    getTemplateVersionsWithHttpInfo(templateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template/${templateId}/version'
            .replace('${' + 'templateId' + '}', String(templateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'templateId' is not null or undefined
        if (templateId === null || templateId === undefined) {
            throw new Error('Required parameter templateId was null or undefined when calling getTemplateVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Get, path, requestOptions);
    }
    /**
     * Retrieves all templates
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTemplatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Get, path, requestOptions);
    }
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplateWithHttpInfo(templateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template/${templateId}/accountMeter'
            .replace('${' + 'templateId' + '}', String(templateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'templateId' is not null or undefined
        if (templateId === null || templateId === undefined) {
            throw new Error('Required parameter templateId was null or undefined when calling updateAccountMetersLatestTemplate.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1I.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TemplateService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TemplateService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TemplateService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1H = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class TimeZoneService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves the list of Time Zones
     *
     */
    getTimeZones(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTimeZonesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the list of Time Zones
     *
     */
    getTimeZonesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/timezone';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1H.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TimeZoneService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TimeZoneService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TimeZoneService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1G = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class UDFService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDF(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUDFWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDF(udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteUDFWithHttpInfo(udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFields(udfType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCustomFieldsWithHttpInfo(udfType, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDF(udfId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUDFWithHttpInfo(udfId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one user defined field / custom field
     *
     * @param udfId The user defined field / custom field identifier
     */
    getUDF(udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUDFWithHttpInfo(udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all User defined fields/custom fields.   The array of UDFs can be filtered by UDF type.   Possible values for this filter include: \&quot;Account\&quot;, \&quot;Meter\&quot;, \&quot;Place\&quot;, \&quot;Vendor\&quot;, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;.  See the filter property for more details
     *
     * @param filter
     */
    getUDFs(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUDFsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDFWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1G.Post, path, requestOptions);
    }
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDFWithHttpInfo(udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/${udfId}'
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling deleteUDF.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1G.Delete, path, requestOptions);
    }
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFieldsWithHttpInfo(udfType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/list/${udfType}'
            .replace('${' + 'udfType' + '}', String(udfType));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfType' is not null or undefined
        if (udfType === null || udfType === undefined) {
            throw new Error('Required parameter udfType was null or undefined when calling editCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1G.Put, path, requestOptions);
    }
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDFWithHttpInfo(udfId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/${udfId}'
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling editUDF.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1G.Put, path, requestOptions);
    }
    /**
     * Retrieves one user defined field / custom field
     *
     * @param udfId The user defined field / custom field identifier
     */
    getUDFWithHttpInfo(udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/${udfId}'
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling getUDF.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1G.Get, path, requestOptions);
    }
    /**
     * Retrieves all User defined fields/custom fields.   The array of UDFs can be filtered by UDF type.   Possible values for this filter include: \&quot;Account\&quot;, \&quot;Meter\&quot;, \&quot;Place\&quot;, \&quot;Vendor\&quot;, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;.  See the filter property for more details
     *
     * @param filter
     */
    getUDFsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1G.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UDFService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UDFService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UDFService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1F = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class UnitService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves all units
     *
     * @param filter
     */
    getUnits(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUnitsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update common and global use units
     *
     * @param body
     */
    updateUseRollupUnits(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateUseRollupUnitsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all units
     *
     * @param filter
     */
    getUnitsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202305/unit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1F.Get, path, requestOptions);
    }
    /**
     * Update common and global use units
     *
     * @param body
     */
    updateUseRollupUnitsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/unit/rollup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1F.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UnitService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UnitService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UnitService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1E = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class UserGroupService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUserGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroup(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteUserGroupWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroup(userGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUserGroupWithHttpInfo(userGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a user group
     *
     * @param userGroupId Id of the user group to return
     */
    getUserGroup(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserGroupWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of user group members
     *
     * @param userGroupId Id of the user group to get the list of members
     */
    getUserGroupMembers(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserGroupMembersWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of user groups
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUserGroups(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserGroupsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1E.Post, path, requestOptions);
    }
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroupWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling deleteUserGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1E.Delete, path, requestOptions);
    }
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroupWithHttpInfo(userGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling editUserGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1E.Put, path, requestOptions);
    }
    /**
     * Gets a user group
     *
     * @param userGroupId Id of the user group to return
     */
    getUserGroupWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling getUserGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1E.Get, path, requestOptions);
    }
    /**
     * Gets a list of user group members
     *
     * @param userGroupId Id of the user group to get the list of members
     */
    getUserGroupMembersWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}/member'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling getUserGroupMembers.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1E.Get, path, requestOptions);
    }
    /**
     * Gets a list of user groups
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUserGroupsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1E.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UserGroupService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UserGroupService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UserGroupService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1D = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class UserRoleService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param body
     */
    createUserRole(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUserRoleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a user role
     *
     * @param userRoleId The identifier for the role being deleted
     */
    deleteUserRole(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteUserRoleWithHttpInfo(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    editUserRole(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUserRoleWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a specific user role and its permissions  You need Roles.Manage or UsersAndUserGroups.View for this API
     *
     * @param userRoleId The userRoleId to get
     */
    getUserRole(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserRoleWithHttpInfo(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets user roles and their permissions  You need Roles.Manage or UsersAndUserGroups.View for this API
     *
     */
    getUserRoles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserRolesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    setUserRoleHidden(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setUserRoleHiddenWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    createUserRoleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/userrole';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1D.Post, path, requestOptions);
    }
    /**
     * Deletes a user role
     *
     * @param userRoleId The identifier for the role being deleted
     */
    deleteUserRoleWithHttpInfo(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userrole/${userRoleId}'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling deleteUserRole.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1D.Delete, path, requestOptions);
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    editUserRoleWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/userrole/${userRoleId}'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling editUserRole.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1D.Put, path, requestOptions);
    }
    /**
     * Gets a specific user role and its permissions  You need Roles.Manage or UsersAndUserGroups.View for this API
     *
     * @param userRoleId The userRoleId to get
     */
    getUserRoleWithHttpInfo(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userrole/${userRoleId}'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling getUserRole.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1D.Get, path, requestOptions);
    }
    /**
     * Gets user roles and their permissions  You need Roles.Manage or UsersAndUserGroups.View for this API
     *
     */
    getUserRolesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userrole';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1D.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    setUserRoleHiddenWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/userrole/${userRoleId}/hidden'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling setUserRoleHidden.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1D.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UserRoleService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UserRoleService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UserRoleService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1C = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class UtilityPlatformService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Apply a release to a meter
     *
     * @param meterId The id of the meter
     * @param body
     */
    assignDataAccessRelease(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.assignDataAccessReleaseWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlace(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUtilityPlatformMetersByPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregations(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeProcessorAggregationsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetails(dataAccessReleaseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataAccessReleaseDetailsWithHttpInfo(dataAccessReleaseId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the status of a meter&#39;s data access release
     *
     * @param meterId The meter to get release state for
     */
    getDataAccessReleaseState(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataAccessReleaseStateWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUtilityPlatformMetersByPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Release all account and meters to a specific place
     *
     * @param placeId The id of the place for the released meters
     * @param body
     */
    releaseAccountAndAllMeterToABuilding(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.releaseAccountAndAllMeterToABuildingWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMeters(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchUtilityPlatformMetersWithHttpInfo(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddresses(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchUtilityPlatformServiceAddressesWithHttpInfo(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmail(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.sendDataAccessReleaseRequestEmailWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeter(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.upsertAggregateMeterWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Apply a release to a meter
     *
     * @param meterId The id of the meter
     * @param body
     */
    assignDataAccessReleaseWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/${meterId}/release'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling assignDataAccessRelease.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/meter'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling createUtilityPlatformMetersByPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregationsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/aggregations/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetailsWithHttpInfo(dataAccessReleaseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/dataAccessRelease/${dataAccessReleaseId}'
            .replace('${' + 'dataAccessReleaseId' + '}', String(dataAccessReleaseId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataAccessReleaseId' is not null or undefined
        if (dataAccessReleaseId === null || dataAccessReleaseId === undefined) {
            throw new Error('Required parameter dataAccessReleaseId was null or undefined when calling getDataAccessReleaseDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Get, path, requestOptions);
    }
    /**
     * Get the status of a meter&#39;s data access release
     *
     * @param meterId The meter to get release state for
     */
    getDataAccessReleaseStateWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/${meterId}/dataAccessReleaseState'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getDataAccessReleaseState.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Get, path, requestOptions);
    }
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/meter'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getUtilityPlatformMetersByPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Get, path, requestOptions);
    }
    /**
     * Release all account and meters to a specific place
     *
     * @param placeId The id of the place for the released meters
     * @param body
     */
    releaseAccountAndAllMeterToABuildingWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/release'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling releaseAccountAndAllMeterToABuilding.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMetersWithHttpInfo(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddressesWithHttpInfo(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/address/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (address !== undefined) {
            queryParameters = queryParameters.set('address', address);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmailWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/${meterId}/sendDataAccessReleaseRequest'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling sendDataAccessReleaseRequestEmail.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Post, path, requestOptions);
    }
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeterWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/aggregateMeter'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling upsertAggregateMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1C.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UtilityPlatformService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UtilityPlatformService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UtilityPlatformService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1B = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class VendorService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Add accounts to a vendor
     *
     * @param vendorId The identifier for the vendor to which accounts are being added
     * @param body List of accountIds to move a new vendor
     */
    addAccounts(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.addAccountsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplate(sourceVendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.copyVendorTemplateWithHttpInfo(sourceVendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a vendor
     *
     * @param body Data representing the vendor being created
     */
    createVendor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createVendorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a vendor
     *
     * @param vendorId The identifier for the vendor being deleted
     */
    deleteVendor(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFile(vendorId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadVendorCustomFieldFileWithHttpInfo(vendorId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendor(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editVendorWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFs(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editVendorUDFsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendor(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContracts(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorContractsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplate(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorTemplateWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfs(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorUdfsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplate(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.putVendorTemplateWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Enable or disable all accounts assigned to a vendor from audits
     *
     * @param vendorId The identifier for the vendor to act upon
     * @param body
     */
    setVendorAccountsAuditExclusion(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setVendorAccountsAuditExclusionWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Add accounts to a vendor
     *
     * @param vendorId The identifier for the vendor to which accounts are being added
     * @param body List of accountIds to move a new vendor
     */
    addAccountsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/account'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling addAccounts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Put, path, requestOptions);
    }
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplateWithHttpInfo(sourceVendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/vendor/${sourceVendorId}/template/copy'
            .replace('${' + 'sourceVendorId' + '}', String(sourceVendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'sourceVendorId' is not null or undefined
        if (sourceVendorId === null || sourceVendorId === undefined) {
            throw new Error('Required parameter sourceVendorId was null or undefined when calling copyVendorTemplate.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Post, path, requestOptions);
    }
    /**
     * Creates a vendor
     *
     * @param body Data representing the vendor being created
     */
    createVendorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Post, path, requestOptions);
    }
    /**
     * Deletes a vendor
     *
     * @param vendorId The identifier for the vendor being deleted
     */
    deleteVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling deleteVendor.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Delete, path, requestOptions);
    }
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFileWithHttpInfo(vendorId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/vendor/${vendorId}/udf/${udfId}/download'
            .replace('${' + 'vendorId' + '}', String(vendorId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling downloadVendorCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadVendorCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendorWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling editVendor.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/udf'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling editVendorUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Put, path, requestOptions);
    }
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendor.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContractsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/contract'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorContracts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplateWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/vendor/${vendorId}/template'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/udf'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Get, path, requestOptions);
    }
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplateWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/vendor/${vendorId}/template'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling putVendorTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Put, path, requestOptions);
    }
    /**
     * Enable or disable all accounts assigned to a vendor from audits
     *
     * @param vendorId The identifier for the vendor to act upon
     * @param body
     */
    setVendorAccountsAuditExclusionWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/vendor/${vendorId}/auditEnabled'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling setVendorAccountsAuditExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1B.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VendorService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VendorService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VendorService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1A = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class VendorDigestService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves rolled up actual billing data by vendor for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param vendorId The vendor to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getVendorActualYearly(vendorId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorActualYearlyWithHttpInfo(vendorId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by vendor for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param vendorId The vendor to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getVendorActualYearlyWithHttpInfo(vendorId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/digest/actual/yearly'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1A.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VendorDigestService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VendorDigestService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VendorDigestService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1z = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class WeatherStationService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get weather stations. Includes custom-created weather stations
     *
     */
    getWeatherStations(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWeatherStationsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Import mean daily temperature readings for weather stations which are connected to EnergyCAP weather services
     * ### Other Remarks  By default, this endpoint may be called without parameters to import weather for all \&quot;used\&quot; weather stations (at least one building is assigned to it) beginning from the current date minus 31 days.          By providing a begin date, API users may go further back in history to backfill missing weather data.     If a weather station has no readings at all, then the begin date will be set to 1899-12-31 so we can import history    However the begin date is ascertained, readings will be imported from that date through today&#39;s date, overwriting any existing readings or filling in any missing readings.    The API user may also provide a list of weather station codes. Even if the provided stations are not yet used, weather readings will be imported for them.
     * @param body
     */
    importWeatherData(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importWeatherDataWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get weather stations. Includes custom-created weather stations
     *
     */
    getWeatherStationsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/weatherstation';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1z.Get, path, requestOptions);
    }
    /**
     * Import mean daily temperature readings for weather stations which are connected to EnergyCAP weather services
     * ### Other Remarks  By default, this endpoint may be called without parameters to import weather for all \&quot;used\&quot; weather stations (at least one building is assigned to it) beginning from the current date minus 31 days.          By providing a begin date, API users may go further back in history to backfill missing weather data.     If a weather station has no readings at all, then the begin date will be set to 1899-12-31 so we can import history    However the begin date is ascertained, readings will be imported from that date through today&#39;s date, overwriting any existing readings or filling in any missing readings.    The API user may also provide a list of weather station codes. Even if the provided stations are not yet used, weather readings will be imported for them.
     * @param body
     */
    importWeatherDataWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/weatherstation/import';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1z.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WeatherStationService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WeatherStationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WeatherStationService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1y = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class WebhookService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhook(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createWebhookWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhook(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteWebhookWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThan(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteWebhookLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhook(webhookId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWebhookWithHttpInfo(webhookId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single webhook
     *
     * @param webhookId
     */
    getWebhook(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get webhook event types
     *
     */
    getWebhookEventTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookEventTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get details for a webhook log
     *
     * @param webhookId
     * @param webhookLogId
     */
    getWebhookLogDetails(webhookId, webhookLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookLogDetailsWithHttpInfo(webhookId, webhookLogId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogs(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookLogsWithHttpInfo(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all webhooks
     *
     * @param filter
     */
    getWebhooks(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhooksWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhookWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Post, path, requestOptions);
    }
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhookWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling deleteWebhook.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Delete, path, requestOptions);
    }
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/webhook/log';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (olderThanDays !== undefined) {
            queryParameters = queryParameters.set('olderThanDays', olderThanDays);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Delete, path, requestOptions);
    }
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhookWithHttpInfo(webhookId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling editWebhook.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Put, path, requestOptions);
    }
    /**
     * Get a single webhook
     *
     * @param webhookId
     */
    getWebhookWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling getWebhook.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Get, path, requestOptions);
    }
    /**
     * Get webhook event types
     *
     */
    getWebhookEventTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/eventType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Get, path, requestOptions);
    }
    /**
     * Get details for a webhook log
     *
     * @param webhookId
     * @param webhookLogId
     */
    getWebhookLogDetailsWithHttpInfo(webhookId, webhookLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}/log/${webhookLogId}/detail'
            .replace('${' + 'webhookId' + '}', String(webhookId))
            .replace('${' + 'webhookLogId' + '}', String(webhookLogId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling getWebhookLogDetails.');
        }
        // verify required parameter 'webhookLogId' is not null or undefined
        if (webhookLogId === null || webhookLogId === undefined) {
            throw new Error('Required parameter webhookLogId was null or undefined when calling getWebhookLogDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Get, path, requestOptions);
    }
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogsWithHttpInfo(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}/log'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling getWebhookLogs.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Get, path, requestOptions);
    }
    /**
     * Get a list of all webhooks
     *
     * @param filter
     */
    getWebhooksWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1y.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WebhookService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WebhookService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WebhookService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1x = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class WidgetService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves data for cost avoidance by commodity dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    costAvoidanceByCommodity(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.costAvoidanceByCommodityWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param specificWidgetId
     * @param filter
     */
    executeSprocWidget(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeSprocWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns counts of bills Held from Export, bills Waiting for Export to AP, bills Waiting for Export to GL, bills which are Not Approved, bills with unresolved flags,   and bills created in the past seven days.
     *
     * @param specificWidgetId Identifier for a specific Bill Status widget on a dashboard
     * @param filter Filter string which may add to or override saved filter values during this request
     */
    getActionableBillCounts(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getActionableBillCountsWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the actual vs budget widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getActualVsBudget(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getActualVsBudgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves data about bills that have not yet been received from vendors.  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsOverdueFromVendor(specificWidgetId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillsOverdueFromVendorWithHttpInfo(specificWidgetId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the carbon footprint data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprint(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCarbonFootprintWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves yearly Carbon Emissions data that is split by year, then by Gas Type and one of the following group types:  ( Scope, Scope Category, Commodity ). Also includes target data, if target comparisons are enabled and set.
     *
     * @param specificWidgetId Specific Widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprintData(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCarbonFootprintDataWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves data for commodity cost dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCommodityCost(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommodityCostWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns Cost Avoidance Savings Program-to-date. The user can set the topmost place and/or commodity filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCostAvoidanceProgramSavings(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostAvoidanceProgramSavingsWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of buildings for the Multiple ENERGY STAR Buildings widget.  The widget is expecting zero, one, or many buildings, and alters its layout based on how many results it receives.    Validation:  - The provided specific widget must exist  - The provided specific widget must be an Multiple ENERGY STAR Buildings widget
     *
     * @param specificWidgetId Identifier for a specific ENERGY STAR widget on a dashboard
     * @param numberOfYears Only used when a single building is returned. The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     * @param filter Filter string which may add to or override saved filter values during this request
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarMultipleBuildings(specificWidgetId, numberOfYears, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarMultipleBuildingsWithHttpInfo(specificWidgetId, numberOfYears, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves ENERGY STAR place score history for a building    Validation:  - The provided specific widget must exist  - The provided specific widget must be an ENERGY STAR Single Building widget
     *
     * @param specificWidgetId Identifier for a specific Single ENERGY STAR Building widget on a dashboard
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarSingleBuilding(specificWidgetId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarSingleBuildingWithHttpInfo(specificWidgetId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns data for the ESA demand interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaDemandIntervalDataWidget(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaDemandIntervalDataWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns data for the esa interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaIntervalDataWidget(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaIntervalDataWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve Trend Insights (previously \&quot;ESA Sentinel\&quot;) readings and predictions for a Channel.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getEsaSentinelWidget(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaSentinelWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves energy use intensity data for a specific widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter API filters
     */
    getEuiChartWidgetData(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEuiChartWidgetDataWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get building rank by GHG emissions or intensity.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGBuildingRank(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGBuildingRankWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the greenhouse gas performance by commodity, scope or scope category.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGPerformance(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGPerformanceWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get ranking by GHG emissions.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGRanking(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGRankingWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves interval data for a specific widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     */
    getIntervalData(specificWidgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getIntervalDataWithHttpInfo(specificWidgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the bar rank and tree map widgets.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getItemRank(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getItemRankWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves map data for a specific map widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     */
    getMapWidget(specificWidgetId, chartMonthsToExclude, numMonths, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMapWidgetWithHttpInfo(specificWidgetId, chartMonthsToExclude, numMonths, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns gaps in billing data for a date range specified by the  Bill Date Range filter.   A gap is defined as at least one day that falls within the account&#39;s service dates and   not included in any bill for that account meter.  The Allowable Gap Days filter specifies the number of days that must be in the gap  before it will be included in the results.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMissingBills(specificWidgetId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMissingBillsWithHttpInfo(specificWidgetId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets data for the Monthly Cost Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyCostTrend(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMonthlyCostTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns data for the monthly trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getMonthlyTrend(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMonthlyTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets data for the Monthly Use Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyUseTrend(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMonthlyUseTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the most expensive building data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveBuildings(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMostExpensiveBuildingsWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the most expensive meters data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveMeters(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMostExpensiveMetersWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves data for the Rolling Monthly Comparison Widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getRollingComparison(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRollingComparisonWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of widgets.
     *
     */
    getWidgets(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWidgetsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns data for the monthly savings trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    monthlyCAPTrend(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.monthlyCAPTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves data for cost avoidance by commodity dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    costAvoidanceByCommodityWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/costavoidancebycommodity/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling costAvoidanceByCommodity.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param specificWidgetId
     * @param filter
     */
    executeSprocWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/exec/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling executeSprocWidget.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns counts of bills Held from Export, bills Waiting for Export to AP, bills Waiting for Export to GL, bills which are Not Approved, bills with unresolved flags,   and bills created in the past seven days.
     *
     * @param specificWidgetId Identifier for a specific Bill Status widget on a dashboard
     * @param filter Filter string which may add to or override saved filter values during this request
     */
    getActionableBillCountsWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/actionablebillcounts/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getActionableBillCounts.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Gets the actual vs budget widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getActualVsBudgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202311/widget/actualvsbudget/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getActualVsBudget.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves data about bills that have not yet been received from vendors.  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsOverdueFromVendorWithHttpInfo(specificWidgetId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/billsoverduefromvendor/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getBillsOverdueFromVendor.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves the carbon footprint data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprintWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/carbonfootprint/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getCarbonFootprint.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves yearly Carbon Emissions data that is split by year, then by Gas Type and one of the following group types:  ( Scope, Scope Category, Commodity ). Also includes target data, if target comparisons are enabled and set.
     *
     * @param specificWidgetId Specific Widget identifier to get the data for
     * @param filter
     */
    getCarbonFootprintDataWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202211/widget/carbonfootprint/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getCarbonFootprintData.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves data for commodity cost dashboard widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCommodityCostWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/commoditycost/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getCommodityCost.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns Cost Avoidance Savings Program-to-date. The user can set the topmost place and/or commodity filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getCostAvoidanceProgramSavingsWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/programsavings/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getCostAvoidanceProgramSavings.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of buildings for the Multiple ENERGY STAR Buildings widget.  The widget is expecting zero, one, or many buildings, and alters its layout based on how many results it receives.    Validation:  - The provided specific widget must exist  - The provided specific widget must be an Multiple ENERGY STAR Buildings widget
     *
     * @param specificWidgetId Identifier for a specific ENERGY STAR widget on a dashboard
     * @param numberOfYears Only used when a single building is returned. The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     * @param filter Filter string which may add to or override saved filter values during this request
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarMultipleBuildingsWithHttpInfo(specificWidgetId, numberOfYears, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/multipleenergystarbuildings/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEnergyStarMultipleBuildings.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves ENERGY STAR place score history for a building    Validation:  - The provided specific widget must exist  - The provided specific widget must be an ENERGY STAR Single Building widget
     *
     * @param specificWidgetId Identifier for a specific Single ENERGY STAR Building widget on a dashboard
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarSingleBuildingWithHttpInfo(specificWidgetId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/singleenergystarbuilding/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEnergyStarSingleBuilding.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns data for the ESA demand interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaDemandIntervalDataWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/V202502/widget/esademandintervaldata/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEsaDemandIntervalDataWidget.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns data for the esa interval data widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getEsaIntervalDataWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/widget/esaintervaldata/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEsaIntervalDataWidget.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieve Trend Insights (previously \&quot;ESA Sentinel\&quot;) readings and predictions for a Channel.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getEsaSentinelWidgetWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/widget/trendinsights/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEsaSentinelWidget.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves energy use intensity data for a specific widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter API filters
     */
    getEuiChartWidgetDataWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/eui/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEuiChartWidgetData.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Get building rank by GHG emissions or intensity.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGBuildingRankWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202212/widget/ghgbuildingrank/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getGHGBuildingRank.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Gets the greenhouse gas performance by commodity, scope or scope category.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGPerformanceWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202212/widget/ghgperformance/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getGHGPerformance.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Get ranking by GHG emissions.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getGHGRankingWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202212/widget/ghgscopecategoryrank/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getGHGRanking.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves interval data for a specific widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     */
    getIntervalDataWithHttpInfo(specificWidgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/intervaldata/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getIntervalData.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Gets the bar rank and tree map widgets.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getItemRankWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/itemrank/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getItemRank.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves map data for a specific map widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     */
    getMapWidgetWithHttpInfo(specificWidgetId, chartMonthsToExclude, numMonths, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202209/widget/map/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMapWidget.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns gaps in billing data for a date range specified by the  Bill Date Range filter.   A gap is defined as at least one day that falls within the account&#39;s service dates and   not included in any bill for that account meter.  The Allowable Gap Days filter specifies the number of days that must be in the gap  before it will be included in the results.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMissingBillsWithHttpInfo(specificWidgetId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/missingbills/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMissingBills.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Gets data for the Monthly Cost Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyCostTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/monthlycosttrend/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMonthlyCostTrend.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns data for the monthly trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    getMonthlyTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/monthlytrend/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMonthlyTrend.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Gets data for the Monthly Use Trend widget.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter Filters to apply to the widget
     */
    getMonthlyUseTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/monthlyusetrend/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMonthlyUseTrend.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves the most expensive building data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveBuildingsWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/mostexpensivebuildings/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMostExpensiveBuildings.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves the most expensive meters data for a specific widget
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     */
    getMostExpensiveMetersWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/mostexpensivemeters/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMostExpensiveMeters.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves data for the Rolling Monthly Comparison Widget.
     *
     * @param specificWidgetId The specific widget id
     * @param filter The widget filters
     */
    getRollingComparisonWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202301/widget/rollingmonthlycomparison/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getRollingComparison.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of widgets.
     *
     */
    getWidgetsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    /**
     * Returns data for the monthly savings trend widget
     *
     * @param specificWidgetId Specific widget identifier
     * @param filter Optional filters
     */
    monthlyCAPTrendWithHttpInfo(specificWidgetId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/widget/monthlysavingstrend/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling monthlyCAPTrend.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1x.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1w = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class WorkflowService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Update bill workflow settings
     *
     * @param body All workflow settings
     */
    editWorkflow(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflow(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApprovalWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflow(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflow(exportMode, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getExportWorkflowWithHttpInfo(exportMode, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill workflow settings
     *
     */
    getWorkflow(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update bill workflow settings
     *
     * @param body All workflow settings
     */
    editWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/workflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Put, path, requestOptions);
    }
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/approval';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Get, path, requestOptions);
    }
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Get, path, requestOptions);
    }
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/billImport';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Get, path, requestOptions);
    }
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/chargeback';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Get, path, requestOptions);
    }
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflowWithHttpInfo(exportMode, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/export';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (exportMode !== undefined) {
            queryParameters = queryParameters.set('exportMode', exportMode);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Get, path, requestOptions);
    }
    /**
     * Get bill workflow settings
     *
     */
    getWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1w.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1v = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPaginatedPaginatedspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountList(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountListWithHttpInfo(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccount(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billFlagSummaryByAccountWithHttpInfo(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeter(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billFlagSummaryByMeterWithHttpInfo(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordList(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.collectionRecordListWithHttpInfo(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordList(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.emissionSourceRecordListWithHttpInfo(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccounts(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylines(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllBillsBodylinesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatches(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettings(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountChargeSplitSettingsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActual(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersActualWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarized(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersCalendarizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalized(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersNormalizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatistics(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersStatisticsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersions(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBills(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves data about bills that have not yet been received from vendors.  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsOverdueFromVendor(specificWidgetId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillsOverdueFromVendorWithHttpInfo(specificWidgetId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersions(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all chargeback tasks with details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getChargebackTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollections(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearly(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualYearlyWithHttpInfo(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCentersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPoints(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataPointsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the definition and data for a list type
     *
     * @param listTypeId The list type for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body DTO containing the list of initial filters to apply and a flag indicating whether to reset the current columns.  Only one list of the specified list type exists, so columns and filters are shared for every dynamic list of the list type.  Filters provided will be saved to the database.
     */
    getDynamicListWithData(listTypeId, pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDynamicListWithDataWithHttpInfo(listTypeId, pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecords(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionRecordsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSources(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourcesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourcesWithMultiFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of buildings for the Multiple ENERGY STAR Buildings widget.  The widget is expecting zero, one, or many buildings, and alters its layout based on how many results it receives.    Validation:  - The provided specific widget must exist  - The provided specific widget must be an Multiple ENERGY STAR Buildings widget
     *
     * @param specificWidgetId Identifier for a specific ENERGY STAR widget on a dashboard
     * @param numberOfYears Only used when a single building is returned. The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     * @param filter Filter string which may add to or override saved filter values during this request
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarMultipleBuildings(specificWidgetId, numberOfYears, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarMultipleBuildingsWithHttpInfo(specificWidgetId, numberOfYears, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannels(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlaces(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all raw and processed ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaReadings(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all summarized ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaSummarizedReadings(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaSummarizedReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves list of values for data filter
     *
     * @param dataFieldId
     * @param search
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getFilterData(dataFieldId, search, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFilterDataWithHttpInfo(dataFieldId, search, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the ghg factors
     *
     * @param filter The api filters&gt;
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGHGFactors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgers(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGeneralLedgersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the definition and data for a list.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listId The list for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getListWithData(listId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getListWithDataWithHttpInfo(listId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMetersUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns gaps in billing data for a date range specified by the  Bill Date Range filter.   A gap is defined as at least one day that falls within the account&#39;s service dates and   not included in any bill for that account meter.  The Allowable Gap Days filter specifies the number of days that must be in the gap  before it will be included in the results.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMissingBills(specificWidgetId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMissingBillsWithHttpInfo(specificWidgetId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all notifications for the current user
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getNotifications(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaces(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlacesUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRates(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of tasks
     *
     * @param taskTypeCode Task type code. Acceptable values are:       AuditGroup,       CostAvoidance,      Report,      Chargeback,      SetupSheet,      UnitsOfMeasure,      Accrual,      BillImport,       EnergyStar,      BillExport,      ReadingImport,      SummarizeReading,      BillUnexport,      V7CostAvoidance,      V7Accrual,      Budget      CostUnitUpdate,      RecordImportPfl,      EsaReadingImpPfl,      RecordImport  *This combines record import setup sheet tasks and record import with a profile tasks,      EsaReadingImport  *This combines Esa readings import setup sheet tasks and Esa Reading import with a profile tasks
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTasks(taskTypeCode, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTasksWithHttpInfo(taskTypeCode, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all templates
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTemplates(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTemplatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMeters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUnplacedMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of user groups
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUserGroups(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserGroupsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogs(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookLogsWithHttpInfo(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillList(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListWithHttpInfo(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMeters(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchUtilityPlatformMetersWithHttpInfo(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddresses(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchUtilityPlatformServiceAddressesWithHttpInfo(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountListWithHttpInfo(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccountWithHttpInfo(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/costcenter/${costCenterId}/billFlagSummary'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling billFlagSummaryByAccount.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeterWithHttpInfo(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/place/${placeId}/billFlagSummary'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling billFlagSummaryByMeter.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordListWithHttpInfo(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/collection/${collectionId}/list/record'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling collectionRecordList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordListWithHttpInfo(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/emissionSource/${emissionSourceId}/list/record'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling emissionSourceRecordList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylinesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/bodyline';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatchesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettingsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActualWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/actual';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/calendarized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/normalized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatisticsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/statistics';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billSplit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves data about bills that have not yet been received from vendors.  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsOverdueFromVendorWithHttpInfo(specificWidgetId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/billsoverduefromvendor/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getBillsOverdueFromVendor.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/calculatedBill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get all chargeback tasks with details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getChargebackTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollectionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyWithHttpInfo(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/${costCenterId}/digest/actual/yearly'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenterActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCentersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPointsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get the definition and data for a list type
     *
     * @param listTypeId The list type for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body DTO containing the list of initial filters to apply and a flag indicating whether to reset the current columns.  Only one list of the specified list type exists, so columns and filters are shared for every dynamic list of the list type.  Filters provided will be saved to the database.
     */
    getDynamicListWithDataWithHttpInfo(listTypeId, pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dynamiclist/${listTypeId}'
            .replace('${' + 'listTypeId' + '}', String(listTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listTypeId' is not null or undefined
        if (listTypeId === null || listTypeId === undefined) {
            throw new Error('Required parameter listTypeId was null or undefined when calling getDynamicListWithData.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Post, path, requestOptions);
    }
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecordsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of buildings for the Multiple ENERGY STAR Buildings widget.  The widget is expecting zero, one, or many buildings, and alters its layout based on how many results it receives.    Validation:  - The provided specific widget must exist  - The provided specific widget must be an Multiple ENERGY STAR Buildings widget
     *
     * @param specificWidgetId Identifier for a specific ENERGY STAR widget on a dashboard
     * @param numberOfYears Only used when a single building is returned. The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     * @param filter Filter string which may add to or override saved filter values during this request
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarMultipleBuildingsWithHttpInfo(specificWidgetId, numberOfYears, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/multipleenergystarbuildings/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getEnergyStarMultipleBuildings.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannelsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all raw and processed ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaReading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all summarized ESA readings
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaSummarizedReadingsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/esaReading/summarized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves list of values for data filter
     *
     * @param dataFieldId
     * @param search
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getFilterDataWithHttpInfo(dataFieldId, search, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/filterData/${dataFieldId}'
            .replace('${' + 'dataFieldId' + '}', String(dataFieldId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataFieldId' is not null or undefined
        if (dataFieldId === null || dataFieldId === undefined) {
            throw new Error('Required parameter dataFieldId was null or undefined when calling getFilterData.');
        }
        if (search !== undefined) {
            queryParameters = queryParameters.set('search', search);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all the ghg factors
     *
     * @param filter The api filters&gt;
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGHGFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/ghg/factor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get the definition and data for a list.  For a list to be returned you must have created the list or have access to it.
     *
     * @param listId The list for which the definition and data are to be retrieved
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getListWithDataWithHttpInfo(listId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/data'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling getListWithData.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/calendarized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/calendarized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/normalized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/normalized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/savings/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/savings/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Returns gaps in billing data for a date range specified by the  Bill Date Range filter.   A gap is defined as at least one day that falls within the account&#39;s service dates and   not included in any bill for that account meter.  The Allowable Gap Days filter specifies the number of days that must be in the gap  before it will be included in the results.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMissingBillsWithHttpInfo(specificWidgetId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/missingbills/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getMissingBills.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get all notifications for the current user
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getNotificationsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/calendarized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/calendarized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/normalized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/normalized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/savings/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/savings/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of tasks
     *
     * @param taskTypeCode Task type code. Acceptable values are:       AuditGroup,       CostAvoidance,      Report,      Chargeback,      SetupSheet,      UnitsOfMeasure,      Accrual,      BillImport,       EnergyStar,      BillExport,      ReadingImport,      SummarizeReading,      BillUnexport,      V7CostAvoidance,      V7Accrual,      Budget      CostUnitUpdate,      RecordImportPfl,      EsaReadingImpPfl,      RecordImport  *This combines record import setup sheet tasks and record import with a profile tasks,      EsaReadingImport  *This combines Esa readings import setup sheet tasks and Esa Reading import with a profile tasks
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTasksWithHttpInfo(taskTypeCode, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (taskTypeCode !== undefined) {
            queryParameters = queryParameters.set('taskTypeCode', taskTypeCode);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all templates
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getTemplatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/meter/unplacedMeters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Gets a list of user groups
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUserGroupsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogsWithHttpInfo(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}/log'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling getWebhookLogs.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillListWithHttpInfo(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Get, path, requestOptions);
    }
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMetersWithHttpInfo(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Post, path, requestOptions);
    }
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddressesWithHttpInfo(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/address/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (address !== undefined) {
            queryParameters = queryParameters.set('address', address);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1v.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPaginatedPaginatedspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPaginatedPaginatedspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPaginatedPaginatedspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1u = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edit accounting settings
     *
     * @param body
     */
    editAccountingSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit General Ledger Subcode definitions - update name, type and if \&quot;list\&quot; type edit (add/delete/edit) pick list values.   One or more subcodes can be edited.
     *
     * @param body Provide the subcode definition
     */
    editGLSubCodes(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editGLSubCodesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit accounting settings
     *
     * @param body
     */
    editAccountingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/accounting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1u.Put, path, requestOptions);
    }
    /**
     * Edit General Ledger Subcode definitions - update name, type and if \&quot;list\&quot; type edit (add/delete/edit) pick list values.   One or more subcodes can be edited.
     *
     * @param body Provide the subcode definition
     */
    editGLSubCodesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1u.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1t = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an account
     *
     * @param body Data representing the account being created
     */
    createAccount(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a General Ledger
     *
     * @param body Data representing the general ledger being created
     */
    createGeneralLedger(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createGeneralLedgerWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an account
     *
     * @param body Data representing the account being created
     */
    createAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1t.Post, path, requestOptions);
    }
    /**
     * Creates a General Ledger
     *
     * @param body Data representing the general ledger being created
     */
    createGeneralLedgerWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1t.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1s = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes an account. Currently NO confirmation is required
     *
     * @param accountId The identifier for the account being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteAccount(accountId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountWithHttpInfo(accountId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an account. Currently NO confirmation is required
     *
     * @param accountId The identifier for the account being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteAccountWithHttpInfo(accountId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling deleteAccount.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1s.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1r = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlert(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountAlertWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRate(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountRateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBill(billId, accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createAccountTemplateFromBillWithHttpInfo(billId, accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplate(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createFormTemplateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBill(billId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createTemplateFromBillWithHttpInfo(billId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlert(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeter(accountMeterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountMeterWithHttpInfo(accountMeterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignment(accountMeterId, formTemplateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteTemplateAssignmentWithHttpInfo(accountMeterId, formTemplateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccount(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersion(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountCodeVersionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeter(accountMeterId, deleteBills, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountMeterWithHttpInfo(accountMeterId, deleteBills, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateList(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountRateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFs(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountUDFsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateList(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editFormTemplateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedger(generalLedgerId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editGeneralLedgerWithHttpInfo(generalLedgerId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccounts(summaryAccountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.linkSubAccountsWithHttpInfo(summaryAccountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccount(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveAccountWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processAccountCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccount(summaryAccountId, subAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkSubAccountWithHttpInfo(summaryAccountId, subAccountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccounts(summaryAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkSubAccountsWithHttpInfo(summaryAccountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlert(accountId, alertId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountAlertWithHttpInfo(accountId, alertId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplate(templateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountMetersLatestTemplateWithHttpInfo(templateId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an account alert
     *
     * @param accountId The identifier for the account to create alert is on
     * @param body Data representing the account alert being created
     */
    createAccountAlertWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling createAccountAlert.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Links an account and meter together  Meters must be linked to an active account to be usable in EnergyCAP  Once an account and meter are created individually, they must be linked with this API
     *
     * @param body Data representing the account and meter being linked
     */
    createAccountMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Creates an AccountRate Relationship.  Linking AccountMeter and Rate
     *
     * @param accountMeterId
     * @param body
     */
    createAccountRateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/rate'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling createAccountRate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Creates a new Template from an existing Bill&#39;s cost-only line items belonging to the provided Account (lines which came from a vendor template will be dropped).
     *
     * @param billId Id of Bill from which to create the Template
     * @param accountId Id of Account whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createAccountTemplateFromBillWithHttpInfo(billId, accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/bill/${billId}/account/${accountId}/template'
            .replace('${' + 'billId' + '}', String(billId))
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling createAccountTemplateFromBill.');
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling createAccountTemplateFromBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Assigns a new template to an account meter.   The new template&#39;s begin date must be after the begin date of all existing template assignments
     *
     * @param accountMeterId
     * @param body
     */
    createFormTemplateWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/template'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling createFormTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Creates a new Template from an existing Bill&#39;s line items belonging to the provided Meter
     *
     * @param billId Id of Bill from which to create the Template
     * @param meterId Id of Meter whose bodylines from source bill will be used to create the Template
     * @param body Additional information about new Template
     */
    createTemplateFromBillWithHttpInfo(billId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/meter/${meterId}/template'
            .replace('${' + 'billId' + '}', String(billId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling createTemplateFromBill.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createTemplateFromBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Deletes an account alert.
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to delete
     */
    deleteAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert/${alertId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'alertId' + '}', String(alertId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling deleteAccountAlert.');
        }
        // verify required parameter 'alertId' is not null or undefined
        if (alertId === null || alertId === undefined) {
            throw new Error('Required parameter alertId was null or undefined when calling deleteAccountAlert.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Delete, path, requestOptions);
    }
    /**
     * Delete an account meter
     *
     * @param accountMeterId
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter              WARNING: Bills for this account include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              There is a single relationship between the specified account and meter
     */
    deleteAccountMeterWithHttpInfo(accountMeterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling deleteAccountMeter.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Delete, path, requestOptions);
    }
    /**
     * Delete an template assignment from an account meter  If we are deleting a template assignment in the middle of two other template assignments, then we will move back the next template&#39;s start date  If we are deleting the last template(current template), the extend second last template&#39;s end date to match the account meter&#39;s end date  If we are deleting the first template pull the second template&#39;s begin date to match account meter&#39;s begin date
     *
     * @param accountMeterId
     * @param formTemplateId
     */
    deleteTemplateAssignmentWithHttpInfo(accountMeterId, formTemplateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/template/${formTemplateId}'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId))
            .replace('${' + 'formTemplateId' + '}', String(formTemplateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling deleteTemplateAssignment.');
        }
        // verify required parameter 'formTemplateId' is not null or undefined
        if (formTemplateId === null || formTemplateId === undefined) {
            throw new Error('Required parameter formTemplateId was null or undefined when calling deleteTemplateAssignment.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Delete, path, requestOptions);
    }
    /**
     * Edits an account
     *
     * @param accountId The identifier for the account being edited
     * @param body Data representing the account being edited
     */
    editAccountWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccount.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param accountId
     * @param body
     */
    editAccountCodeVersionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/codeversion'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccountCodeVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Edit an account meter relationship
     *
     * @param accountMeterId The id of the account meter record to edit
     * @param deleteBills A true value means delete all bills that have at least 1 line for this account and meter and a bill start date greater than or equal to the new account and meter relationship end date.              WARNING: Bills for this account may include other meters.  The ENTIRE bill is deleted.              This flag can only be true when:              Editing the most recent relationship between this account and meter              The end date has been changed but not the begin date
     * @param body Data used to update the account and meter
     */
    editAccountMeterWithHttpInfo(accountMeterId, deleteBills, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling editAccountMeter.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Edit all AccountRate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editAccountRateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/rate'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling editAccountRateList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular account
     *
     * @param accountId The identifier for the account
     * @param body Data representing the account user defined fields / custom fields being edited
     */
    editAccountUDFsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/udf'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccountUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Edit all FormTemplate relationships
     *
     * @param accountMeterId
     * @param body
     */
    editFormTemplateListWithHttpInfo(accountMeterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accountmeter/${accountMeterId}/template'
            .replace('${' + 'accountMeterId' + '}', String(accountMeterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountMeterId' is not null or undefined
        if (accountMeterId === null || accountMeterId === undefined) {
            throw new Error('Required parameter accountMeterId was null or undefined when calling editFormTemplateList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Updates a General Ledger
     *
     * @param generalLedgerId General Ledger ID to update
     * @param body Data representing the general ledger to update
     */
    editGeneralLedgerWithHttpInfo(generalLedgerId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger/${generalLedgerId}'
            .replace('${' + 'generalLedgerId' + '}', String(generalLedgerId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'generalLedgerId' is not null or undefined
        if (generalLedgerId === null || generalLedgerId === undefined) {
            throw new Error('Required parameter generalLedgerId was null or undefined when calling editGeneralLedger.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Link sub accounts to a summary account  This only adds sub accounts to a summary account.  It will not remove any links.  Use the Delete to remove accounts.  Because the number of linked sub accounts can be large we just return the total number of accounts linked  To get the list of all sub accounts linked to a summary account call the Get All Accounts API with the summaryAccountID filter.
     *
     * @param summaryAccountId
     * @param body
     */
    linkSubAccountsWithHttpInfo(summaryAccountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/summaryAccount/${summaryAccountId}/subAccount'
            .replace('${' + 'summaryAccountId' + '}', String(summaryAccountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'summaryAccountId' is not null or undefined
        if (summaryAccountId === null || summaryAccountId === undefined) {
            throw new Error('Required parameter summaryAccountId was null or undefined when calling linkSubAccounts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Post, path, requestOptions);
    }
    /**
     * Move list of accounts to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of accountIds to move under the parentCostCenterId
     */
    moveAccountWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentCostCenter/${parentCostCenterId}/account'
            .replace('${' + 'parentCostCenterId' + '}', String(parentCostCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCostCenterId' is not null or undefined
        if (parentCostCenterId === null || parentCostCenterId === undefined) {
            throw new Error('Required parameter parentCostCenterId was null or undefined when calling moveAccount.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Fires a custom account action. Custom account actions are setup as webhooks
     *
     * @param body
     */
    processAccountCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202211/account/customAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Unlink a sub account from a summary account
     *
     * @param summaryAccountId
     * @param subAccountId
     */
    unlinkSubAccountWithHttpInfo(summaryAccountId, subAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/summaryAccount/${summaryAccountId}/subAccount/${subAccountId}'
            .replace('${' + 'summaryAccountId' + '}', String(summaryAccountId))
            .replace('${' + 'subAccountId' + '}', String(subAccountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'summaryAccountId' is not null or undefined
        if (summaryAccountId === null || summaryAccountId === undefined) {
            throw new Error('Required parameter summaryAccountId was null or undefined when calling unlinkSubAccount.');
        }
        // verify required parameter 'subAccountId' is not null or undefined
        if (subAccountId === null || subAccountId === undefined) {
            throw new Error('Required parameter subAccountId was null or undefined when calling unlinkSubAccount.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Delete, path, requestOptions);
    }
    /**
     * Unlink all sub accounts from a summary account
     *
     * @param summaryAccountId
     */
    unlinkSubAccountsWithHttpInfo(summaryAccountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/summaryAccount/${summaryAccountId}/subAccount'
            .replace('${' + 'summaryAccountId' + '}', String(summaryAccountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'summaryAccountId' is not null or undefined
        if (summaryAccountId === null || summaryAccountId === undefined) {
            throw new Error('Required parameter summaryAccountId was null or undefined when calling unlinkSubAccounts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Delete, path, requestOptions);
    }
    /**
     * Updates an account alert
     *
     * @param accountId The identifier for the account the alert to update is on
     * @param alertId The identifier for the account alert to update
     * @param body Data representing the account alert being created
     */
    updateAccountAlertWithHttpInfo(accountId, alertId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert/${alertId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'alertId' + '}', String(alertId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling updateAccountAlert.');
        }
        // verify required parameter 'alertId' is not null or undefined
        if (alertId === null || alertId === undefined) {
            throw new Error('Required parameter alertId was null or undefined when calling updateAccountAlert.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    /**
     * Update current template for all passed in accountMeterIds  If the accountMeter is an account only record the template must be for the &#39;Money&#39; commodity or an error will be thrown  If the accountMeter has no template assigned one will be created  If the accountMeter&#39;s latest template assignment is end dated, a new assignment will be created starting from the latest end date  All must be successfully updated otherwise none are updated and an error is returned
     *
     * @param templateId The template to apply to the provided accountMeterIds
     * @param body List of accountMeterIds whose template will be updated
     */
    updateAccountMetersLatestTemplateWithHttpInfo(templateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/template/${templateId}/accountMeter'
            .replace('${' + 'templateId' + '}', String(templateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'templateId' is not null or undefined
        if (templateId === null || templateId === undefined) {
            throw new Error('Required parameter templateId was null or undefined when calling updateAccountMetersLatestTemplate.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1r.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1q = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFile(accountId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadAccountCustomFieldFileWithHttpInfo(accountId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccount(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthly(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualMonthlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearly(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualYearlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlert(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlerts(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountAlertsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetails(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountBillSplitParentDetailsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRates(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountRatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplates(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountTemplatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfs(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountUdfsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccounts(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetails(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistory(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplits(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCode(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGLSubCodeWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValues(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGLSubCodeValuesWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGLSubCodesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedger(generalLedgerId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGeneralLedgerWithHttpInfo(generalLedgerId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgers(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGeneralLedgersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccounts(query, includeInactiveAccounts, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchAccountsWithHttpInfo(query, includeInactiveAccounts, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for an account custom field
     *
     * @param accountId
     * @param udfId
     */
    downloadAccountCustomFieldFileWithHttpInfo(accountId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/account/${accountId}/udf/${udfId}/download'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling downloadAccountCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadAccountCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves one account
     *
     * @param accountId The account identifier for the account being retrieved
     */
    getAccountWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccount.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getAccountActualMonthlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/digest/actual/monthly'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param accountId The account to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getAccountActualYearlyWithHttpInfo(accountId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/digest/actual/yearly'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by account for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves an alert for an account
     *
     * @param accountId The identifier for the account the alert is on
     * @param alertId The identifier for the alert to return
     */
    getAccountAlertWithHttpInfo(accountId, alertId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert/${alertId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'alertId' + '}', String(alertId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountAlert.');
        }
        // verify required parameter 'alertId' is not null or undefined
        if (alertId === null || alertId === undefined) {
            throw new Error('Required parameter alertId was null or undefined when calling getAccountAlert.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all alerts for an account
     *
     * @param accountId The identifier for the account
     */
    getAccountAlertsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/alert'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountAlerts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Get bill split parent information for an account
     *
     * @param accountId ID of the account
     */
    getAccountBillSplitParentDetailsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billSplit/parent'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountBillSplitParentDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all rates for a particular account
     *
     * @param accountId The account identifier for which rate values are being retrieved
     */
    getAccountRatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/rate'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountRates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all templates for a particular account
     *
     * @param accountId The account identifier for which template values are being retrieved
     */
    getAccountTemplatesWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/template'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountTemplates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular account
     *
     * @param accountId The account identifier for which user defined field / custom field values are being retrieved
     */
    getAccountUdfsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/udf'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all accounts
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAccountsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Get details for a bill split distribution
     *
     * @param accountId ID of the account
     * @param meterId ID of the meter
     * @param versionId ID of the distribution version
     */
    getBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit/${versionId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplitDetails.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getBillSplitDetails.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBillSplitDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Get a list of bill split versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned bill split versions
     * @param meterId ID of the meter to get all assigned bill split versions
     */
    getBillSplitVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplitVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getBillSplitVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Get a list of bill split versions on an account
     *
     * @param accountId ID of the account to get all assigned bill split versions
     */
    getBillSplitsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billSplit'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillSplits.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves specific General Ledger Subcode definition
     *
     * @param subCodeIndex The index of the subCode being retrieved
     */
    getGLSubCodeWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode/${subCodeIndex}'
            .replace('${' + 'subCodeIndex' + '}', String(subCodeIndex));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'subCodeIndex' is not null or undefined
        if (subCodeIndex === null || subCodeIndex === undefined) {
            throw new Error('Required parameter subCodeIndex was null or undefined when calling getGLSubCode.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves unique General Ledger Subcode values
     *
     * @param subCodeIndex The index of the subCode whose values are being retrieved
     */
    getGLSubCodeValuesWithHttpInfo(subCodeIndex, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode/${subCodeIndex}/savedValues'
            .replace('${' + 'subCodeIndex' + '}', String(subCodeIndex));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'subCodeIndex' is not null or undefined
        if (subCodeIndex === null || subCodeIndex === undefined) {
            throw new Error('Required parameter subCodeIndex was null or undefined when calling getGLSubCodeValues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all General Ledger SubCode definitions
     *
     */
    getGLSubCodesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/glsubcode';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves a specific General Ledger
     *
     * @param generalLedgerId General Ledger ID to return
     */
    getGeneralLedgerWithHttpInfo(generalLedgerId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger/${generalLedgerId}'
            .replace('${' + 'generalLedgerId' + '}', String(generalLedgerId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'generalLedgerId' is not null or undefined
        if (generalLedgerId === null || generalLedgerId === undefined) {
            throw new Error('Required parameter generalLedgerId was null or undefined when calling getGeneralLedger.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Retrieves all General Ledgers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getGeneralLedgersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generalledger';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    /**
     * Search for accounts  Search for accounts whose account code, address, old account code, meter serial number, or meter address contains \&quot;query\&quot;
     *
     * @param query The string to search for
     * @param includeInactiveAccounts Flag to determine if inactive accounts should be included in the search results
     */
    searchAccountsWithHttpInfo(query, includeInactiveAccounts, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (query !== undefined) {
            queryParameters = queryParameters.set('query', query);
        }
        if (includeInactiveAccounts !== undefined) {
            queryParameters = queryParameters.set('includeInactiveAccounts', includeInactiveAccounts);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1q.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1p = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param accountId The account whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setAccountBillListAccrualExclusion(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setAccountBillListAccrualExclusionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param body
     */
    setBillAccrualExclusion(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setBillAccrualExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param listId The list whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the provided list should be excluded from accruals or should have exclusion undone
     */
    setBillListAccrualExclusion(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setBillListAccrualExclusionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param meterId The meter whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setMeterBillListAccrualExclusion(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setMeterBillListAccrualExclusionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param accountId The account whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setAccountBillListAccrualExclusionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/accrualExclusion'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling setAccountBillListAccrualExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1p.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param body
     */
    setBillAccrualExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/accrualExclusion';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1p.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param listId The list whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the provided list should be excluded from accruals or should have exclusion undone
     */
    setBillListAccrualExclusionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/accrualExclusion'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling setBillListAccrualExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1p.Put, path, requestOptions);
    }
    /**
     * Excludes or undoes exclusion of bills from accruals
     *
     * @param meterId The meter whose bills will be excluded or have exclusion undone
     * @param body Indicates whether or not the bills should be excluded from accruals or should have exclusion undone
     */
    setMeterBillListAccrualExclusionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/accrualExclusion'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling setMeterBillListAccrualExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1p.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1o = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete all bills created by the Accrual task   If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the accrual task
     */
    deleteAccrualTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run the accrual processor engine using the supplied settings to generate accrual bills
     *
     * @param filter Accrual data selection filters
     * @param body Accrual processor settings
     */
    processAccruals(filter, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processAccrualsWithHttpInfo(filter, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void all bills created by the Accrual task  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the accrual task
     */
    voidAccrualTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills created by the Accrual task   If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the accrual task
     */
    deleteAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual/${taskId}/delete'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling deleteAccrualTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1o.Post, path, requestOptions);
    }
    /**
     * Run the accrual processor engine using the supplied settings to generate accrual bills
     *
     * @param filter Accrual data selection filters
     * @param body Accrual processor settings
     */
    processAccrualsWithHttpInfo(filter, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1o.Post, path, requestOptions);
    }
    /**
     * Void all bills created by the Accrual task  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the accrual task
     */
    voidAccrualTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual/${taskId}/void'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling voidAccrualTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1o.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1n = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get Accrual settings
     *
     */
    getAccrualSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccrualSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Accrual settings
     *
     */
    getAccrualSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/accrual/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1n.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1m = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDF(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUDFWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhook(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createWebhookWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKey(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSetting(benchmarkIndicator, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceBenchmarkSettingWithHttpInfo(benchmarkIndicator, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDF(udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteUDFWithHttpInfo(udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhook(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteWebhookWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThan(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteWebhookLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKey(apiKeyId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editApiKeyWithHttpInfo(apiKeyId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a cost category
     *
     * @param costCategoryId The identifier of the cost category to edit
     * @param body Object containing settings to change
     */
    editCostCategory(costCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCostCategoryWithHttpInfo(costCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFields(udfType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCustomFieldsWithHttpInfo(udfType, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceBenchmarkSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDF(udfId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUDFWithHttpInfo(udfId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhook(webhookId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWebhookWithHttpInfo(webhookId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppAction(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processCustomAppActionWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setReportingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update common and global use units
     *
     * @param body
     */
    updateUseRollupUnits(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateUseRollupUnitsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a user defined field / custom field
     *
     * @param body Data representing the user defined field / custom field being created
     */
    createUDFWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Post, path, requestOptions);
    }
    /**
     * Create a new webhook
     *
     * @param body
     */
    createWebhookWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Post, path, requestOptions);
    }
    /**
     * Delete an API key
     *
     * @param apiKeyId
     */
    deleteApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey/${apiKeyId}'
            .replace('${' + 'apiKeyId' + '}', String(apiKeyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiKeyId' is not null or undefined
        if (apiKeyId === null || apiKeyId === undefined) {
            throw new Error('Required parameter apiKeyId was null or undefined when calling deleteApiKey.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Delete, path, requestOptions);
    }
    /**
     * Delete the settings for the place benchmark defined by the benchmarkIndicator.  Deletes all corresponding place benchmark values that were defined for that indicator.  Updates user-defined autogroup membership for groups that contained filters for that indicator.
     *
     * @param benchmarkIndicator Indicator for the benchmark
     */
    deletePlaceBenchmarkSettingWithHttpInfo(benchmarkIndicator, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/setting'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling deletePlaceBenchmarkSetting.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Delete, path, requestOptions);
    }
    /**
     * Deletes a user defined field / custom field. Currently NO confirmation is required
     *
     * @param udfId The identifier for the user defined field / custom field being deleted
     */
    deleteUDFWithHttpInfo(udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/${udfId}'
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling deleteUDF.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Delete, path, requestOptions);
    }
    /**
     * Delete a webhook
     *
     * @param webhookId
     */
    deleteWebhookWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling deleteWebhook.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Delete, path, requestOptions);
    }
    /**
     * Delete webhook logs older than the number of days provided only if  the number of logs per webhook is in excess of 100.  100 latest logs per webhook will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteWebhookLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/webhook/log';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (olderThanDays !== undefined) {
            queryParameters = queryParameters.set('olderThanDays', olderThanDays);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Delete, path, requestOptions);
    }
    /**
     * Edit the name and description of an api key
     *
     * @param apiKeyId
     * @param body
     */
    editApiKeyWithHttpInfo(apiKeyId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey/${apiKeyId}'
            .replace('${' + 'apiKeyId' + '}', String(apiKeyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiKeyId' is not null or undefined
        if (apiKeyId === null || apiKeyId === undefined) {
            throw new Error('Required parameter apiKeyId was null or undefined when calling editApiKey.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Edits a cost category
     *
     * @param costCategoryId The identifier of the cost category to edit
     * @param body Object containing settings to change
     */
    editCostCategoryWithHttpInfo(costCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/costCategory/${costCategoryId}'
            .replace('${' + 'costCategoryId' + '}', String(costCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCategoryId' is not null or undefined
        if (costCategoryId === null || costCategoryId === undefined) {
            throw new Error('Required parameter costCategoryId was null or undefined when calling editCostCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Edits a list of user defined fields / custom fields
     *
     * @param udfType Valid udfTypes include \&quot;Account\&quot;, \&quot;Vendor\&quot;, \&quot;Place\&quot;, \&quot;Meter, \&quot;ChannelVersion\&quot;, \&quot;Rate\&quot;, \&quot;Bill\&quot;, \&quot;EnergyProject\&quot;, \&quot;Collection\&quot;, and \&quot;EmissionSource\&quot;
     * @param body
     */
    editCustomFieldsWithHttpInfo(udfType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/list/${udfType}'
            .replace('${' + 'udfType' + '}', String(udfType));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfType' is not null or undefined
        if (udfType === null || udfType === undefined) {
            throw new Error('Required parameter udfType was null or undefined when calling editCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * The user can edit the category and name for each benchmark  If a benchmark has not been configured, it is configured  User cannot delete a benchmark from this endpoint  If the benchmark dto is null or not passed the API will ignore it  If the benchmark dto is not null, the category and name are required
     *
     * @param body Dto containing what to edit on benchmark
     */
    editPlaceBenchmarkSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Edit system settings
     *
     * @param body
     */
    editSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/admin/systemSettings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Edits a user defined field / custom field
     *
     * @param udfId
     * @param body Data representing the UDF being edited
     */
    editUDFWithHttpInfo(udfId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/udf/${udfId}'
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling editUDF.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Edit an existing webhook
     *
     * @param webhookId
     * @param body
     */
    editWebhookWithHttpInfo(webhookId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling editWebhook.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Fire a custom application action webhook
     *
     * @param webhookId The identifier for the webhook being fired
     */
    processCustomAppActionWithHttpInfo(webhookId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/customapplicationaction/${webhookId}'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling processCustomAppAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Set the system reporting settings
     *
     * @param body
     */
    setReportingSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202305/admin/reportingSettings';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    /**
     * Update common and global use units
     *
     * @param body
     */
    updateUseRollupUnitsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/unit/rollup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1m.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1l = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a new API key
     *
     * @param body
     */
    createApiKey(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createApiKeyWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the license details.
     *
     * @param body
     */
    editLicenseDetails(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editLicenseDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an API key
     *
     * @param apiKeyId
     */
    getApiKey(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all available API keys
     *
     * @param filter
     */
    getApiKeys(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApiKeysWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get license details.
     *
     */
    getLicenseDetails(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getLicenseDetailsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get webhook event types
     *
     */
    getWebhookEventTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookEventTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get details for a webhook log
     *
     * @param webhookId
     * @param webhookLogId
     */
    getWebhookLogDetails(webhookId, webhookLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookLogDetailsWithHttpInfo(webhookId, webhookLogId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogs(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWebhookLogsWithHttpInfo(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new API key
     *
     * @param body
     */
    createApiKeyWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Post, path, requestOptions);
    }
    /**
     * Edit the license details.
     *
     * @param body
     */
    editLicenseDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/license';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Put, path, requestOptions);
    }
    /**
     * Get an API key
     *
     * @param apiKeyId
     */
    getApiKeyWithHttpInfo(apiKeyId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey/${apiKeyId}'
            .replace('${' + 'apiKeyId' + '}', String(apiKeyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'apiKeyId' is not null or undefined
        if (apiKeyId === null || apiKeyId === undefined) {
            throw new Error('Required parameter apiKeyId was null or undefined when calling getApiKey.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Get, path, requestOptions);
    }
    /**
     * Get a list of all available API keys
     *
     * @param filter
     */
    getApiKeysWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/apiKey';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Get, path, requestOptions);
    }
    /**
     * Get license details.
     *
     */
    getLicenseDetailsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/admin/license';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Get, path, requestOptions);
    }
    /**
     * Get webhook event types
     *
     */
    getWebhookEventTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/eventType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Get, path, requestOptions);
    }
    /**
     * Get details for a webhook log
     *
     * @param webhookId
     * @param webhookLogId
     */
    getWebhookLogDetailsWithHttpInfo(webhookId, webhookLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}/log/${webhookLogId}/detail'
            .replace('${' + 'webhookId' + '}', String(webhookId))
            .replace('${' + 'webhookLogId' + '}', String(webhookLogId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling getWebhookLogDetails.');
        }
        // verify required parameter 'webhookLogId' is not null or undefined
        if (webhookLogId === null || webhookLogId === undefined) {
            throw new Error('Required parameter webhookLogId was null or undefined when calling getWebhookLogDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Get, path, requestOptions);
    }
    /**
     * Get a list of webhook event logs
     *
     * @param webhookId
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getWebhookLogsWithHttpInfo(webhookId, filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/webhook/${webhookId}/log'
            .replace('${' + 'webhookId' + '}', String(webhookId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'webhookId' is not null or undefined
        if (webhookId === null || webhookId === undefined) {
            throw new Error('Required parameter webhookId was null or undefined when calling getWebhookLogs.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1l.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1k = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Approve/unapprove account bills
     *
     * @param accountId The account to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    accountBillListApprove(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListApproveWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Approve/unapprove bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing approve flag
     */
    approveBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.approveBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update approved flag for the given billIDs
     *
     * @param body approve action
     */
    billActionApprove(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionApproveWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Approve/unapprove meter bills
     *
     * @param meterId The meter to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    meterBillListApprove(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListApproveWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Approve/unapprove account bills
     *
     * @param accountId The account to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    accountBillListApproveWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/approve'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListApprove.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1k.Put, path, requestOptions);
    }
    /**
     * Approve/unapprove bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing approve flag
     */
    approveBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/approve'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling approveBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1k.Put, path, requestOptions);
    }
    /**
     * Update approved flag for the given billIDs
     *
     * @param body approve action
     */
    billActionApproveWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/approve';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1k.Put, path, requestOptions);
    }
    /**
     * Approve/unapprove meter bills
     *
     * @param meterId The meter to approve/unapprove all bills
     * @param body Boolean representing approve flag
     */
    meterBillListApproveWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/approve'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListApprove.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1k.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1j = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Regenerate cost avoidance baseline for the meters that match the filter conditions and then reprocess their savings
     *
     * @param body Settings and filter conditions for baseline processing
     */
    bulkGenerateBaseline(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.bulkGenerateBaselineWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Regenerate cost avoidance baseline for the meters that match the filter conditions and then reprocess their savings
     *
     * @param body Settings and filter conditions for baseline processing
     */
    bulkGenerateBaselineWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/baseline/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1j.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1i = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves a list of bill line type mappings
     *
     */
    getBillLineTypeMappings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillLineTypeMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of bill line type mappings
     *
     */
    getBillLineTypeMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/bill/billLineTypeMapping';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1i.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1h = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a specific account&#39;s setting to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    deleteAccountBillAccountChargeSplitSettings(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a specific vendor&#39;s setting to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    deleteVendorBillAccountChargeSplitSettings(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a specific account&#39;s setting to split account charges on bill import  If a rule does not currently exist for this account it is created otherwise it is updated
     *
     * @param accountId Account identifier
     * @param body
     */
    editAccountBillAccountChargeSplitSettings(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the method used to split account charges on bill import
     *
     * @param body Method used to split account charges on bill import
     */
    editBillAccountChargeSplitMethod(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillAccountChargeSplitMethodWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a specific vendor&#39;s setting to split account charges on bill import  If a rule does not currently exist for this vendor it is created otherwise it is updated
     *
     * @param vendorId Vendor identifier
     * @param body
     */
    editVendorBillAccountChargeSplitSettings(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update bill workflow settings
     *
     * @param body All workflow settings
     */
    editWorkflow(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update audit settings
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param body The new state of the audit settings
     */
    updateAuditSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAuditSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a specific account&#39;s setting to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    deleteAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling deleteAccountBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Delete, path, requestOptions);
    }
    /**
     * Deletes a specific vendor&#39;s setting to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    deleteVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling deleteVendorBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Delete, path, requestOptions);
    }
    /**
     * Edits a specific account&#39;s setting to split account charges on bill import  If a rule does not currently exist for this account it is created otherwise it is updated
     *
     * @param accountId Account identifier
     * @param body
     */
    editAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling editAccountBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Put, path, requestOptions);
    }
    /**
     * Edit the method used to split account charges on bill import
     *
     * @param body Method used to split account charges on bill import
     */
    editBillAccountChargeSplitMethodWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/method';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Put, path, requestOptions);
    }
    /**
     * Edits a specific vendor&#39;s setting to split account charges on bill import  If a rule does not currently exist for this vendor it is created otherwise it is updated
     *
     * @param vendorId Vendor identifier
     * @param body
     */
    editVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling editVendorBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Put, path, requestOptions);
    }
    /**
     * Update bill workflow settings
     *
     * @param body All workflow settings
     */
    editWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/workflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Put, path, requestOptions);
    }
    /**
     * Update audit settings
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param body The new state of the audit settings
     */
    updateAuditSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/audit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1h.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1g = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves a specific account&#39;s settings to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    getAccountBillAccountChargeSplitSettings(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the method used to split account charges on bill import
     *
     */
    getBillAccountChargeSplitMethod(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountChargeSplitMethodWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettings(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountChargeSplitSettingsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific vendor&#39;s settings to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    getVendorBillAccountChargeSplitSettings(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill workflow settings
     *
     */
    getWorkflow(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific account&#39;s settings to split account charges on bill import
     *
     * @param accountId Account identifier
     */
    getAccountBillAccountChargeSplitSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1g.Get, path, requestOptions);
    }
    /**
     * Retrieves the method used to split account charges on bill import
     *
     */
    getBillAccountChargeSplitMethodWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/method';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1g.Get, path, requestOptions);
    }
    /**
     * Retrieves all settings used to split account charges on bill import  Note: When filtering by vendor, only settings that apply to all vendor accounts (account null) will be returned
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountChargeSplitSettingsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1g.Get, path, requestOptions);
    }
    /**
     * Retrieves a specific vendor&#39;s settings to split account charges on bill import
     *
     * @param vendorId Vendor identifier
     */
    getVendorBillAccountChargeSplitSettingsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/billAccountChargeSplit/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorBillAccountChargeSplitSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1g.Get, path, requestOptions);
    }
    /**
     * Get bill workflow settings
     *
     */
    getWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1g.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1f = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImport(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     */
    closeBatch(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.closeBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBill(saveAsResolved, comment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBillWithHttpInfo(saveAsResolved, comment, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatch(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryData(accountId, beginDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillEntryDataWithHttpInfo(accountId, beginDate, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickouts(taskGuid, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importBillImportTaskKickoutsWithHttpInfo(taskGuid, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    openBatch(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.openBatchWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.writeBillImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of an EnergyCAP Advanced or a profile mapped file. The file can be comma separated file (CSV/DAT/TXT) or EXCEL (XLSX) or a collection of files (ZIP). The file should be base64 encoded with a UTF8 character set.
     *
     * @param body DTO containing the data to import, filename with extension, optional profileCode to map input file to advanced format, optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    billImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Post, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     */
    closeBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/close/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling closeBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Put, path, requestOptions);
    }
    /**
     * Create a new bill
     * Creates a bill.  The created bill gets audited.  If any audits fail, the bill will get flagged.  If the audit setting for any of the failed audits is set to Fail and Hold, the bill will be set as \&quot;Hold from Accounting Export\&quot;  If saveAsResolved property is set to true, the flagged bill will be automatically resolved and Released for Accounting Export
     * @param saveAsResolved Controls whether or not any failed audits automatically get marked as resolved
     * @param comment Optional comment to explain why the audit is being auto resolved
     * @param body
     */
    createBillWithHttpInfo(saveAsResolved, comment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (saveAsResolved !== undefined) {
            queryParameters = queryParameters.set('saveAsResolved', saveAsResolved);
        }
        if (comment !== undefined) {
            queryParameters = queryParameters.set('comment', comment);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Post, path, requestOptions);
    }
    /**
     * Deletes a bill import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteBillImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Delete, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     * @param body
     */
    editBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling editBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Put, path, requestOptions);
    }
    /**
     * Edit a bill import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editBillImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editBillImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Put, path, requestOptions);
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param accountId
     * @param beginDate
     */
    getBillEntryDataWithHttpInfo(accountId, beginDate, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billEntry'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getBillEntryData.');
        }
        if (beginDate !== undefined) {
            queryParameters = queryParameters.set('beginDate', beginDate.toISOString());
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Get, path, requestOptions);
    }
    /**
     * Get a bill import profile
     *
     * @param profileId The identifier for the profile to get
     */
    getBillImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getBillImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Get, path, requestOptions);
    }
    /**
     * Get all bill import profiles
     *
     */
    getBillImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Get, path, requestOptions);
    }
    /**
     * This endpoint allows the reimport of an EnergyCAP.  All kickout files generated from the import will be zipped and reimported as a single task.
     *
     * @param taskGuid The taskGuid should be a bill import task with a status of completed with kickouts.
     * @param body DTO containing optional batch settings, optional import note/comment, and optional properties to automatically resolve audit failures and reason for resolution
     */
    importBillImportTaskKickoutsWithHttpInfo(taskGuid, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling importBillImportTaskKickouts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Post, path, requestOptions);
    }
    /**
     *
     *
     * @param body
     */
    openBatchWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Post, path, requestOptions);
    }
    /**
     * Creates a bill import profile
     *
     * @param body The details about the profile being created
     */
    writeBillImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/bill/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1f.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1e = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete all bills for account
     *
     * @param accountId The account to delete all bills from
     */
    accountBillListDeleteBills(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListDeleteBillsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete given billIDs
     *
     * @param body
     */
    billActionDelete(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionDeleteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     */
    deleteBatch(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills in a bill list
     *
     * @param listId The list identifier
     */
    deleteBillsInBillList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBillsInBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills for meter
     *
     * @param meterId The meter to delete all bills from
     */
    meterBillListDeleteBills(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListDeleteBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills for account
     *
     * @param accountId The account to delete all bills from
     */
    accountBillListDeleteBillsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/data'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListDeleteBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1e.Delete, path, requestOptions);
    }
    /**
     * Delete given billIDs
     *
     * @param body
     */
    billActionDeleteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/delete';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1e.Post, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     */
    deleteBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling deleteBatch.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1e.Delete, path, requestOptions);
    }
    /**
     * Delete all bills in a bill list
     *
     * @param listId The list identifier
     */
    deleteBillsInBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/data'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling deleteBillsInBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1e.Delete, path, requestOptions);
    }
    /**
     * Delete all bills for meter
     *
     * @param meterId The meter to delete all bills from
     */
    meterBillListDeleteBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/data'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListDeleteBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1e.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1d = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomAction(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListCustomActionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoid(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListVoidWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeaders(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionUpdateHeadersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoid(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionVoidWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomAction(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billListCustomActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetails(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billPaymentDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billPaymentDetailsFileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABill(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.cleanABillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBills(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.cleanDirtyBillsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEvent(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBillPaymentEventWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMeters(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeAccountChargesToMetersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatch(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeAccountChargesToMetersForBillsInBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeAccountChargesToMetersForBillsInListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBill(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFields(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBillCustomFieldsWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomAction(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListCustomActionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoid(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListVoidWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processBillCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillList(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseAccountBillListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBills(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillList(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.reverseMeterBillListWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeaders(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountBillListHeadersWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeaders(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateBillListHeadersWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeaders(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateMeterBillListHeadersWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImage(billId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.uploadBillImageWithHttpInfo(billId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom bill action on an account bill list. Custom bill actions are setup as webhooks.
     *
     * @param accountId The account against which all of its bills will have the custom action performed
     * @param body
     */
    accountBillListCustomActionWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/customAction'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListCustomAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Void/unvoid account bills
     *
     * @param accountId The account to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    accountBillListVoidWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/void'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListVoid.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Update all headers for a given list of bills  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bill audits won&#39;t be fired
     *
     * @param body Bill header update action
     */
    billActionUpdateHeadersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billHeaders';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Update void flag for the given billIDs
     *
     * @param body Void action
     */
    billActionVoidWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/void';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action on a bill list
     *
     * @param listId The bill list against which all of its bills will have the custom action performed
     * @param body
     */
    billListCustomActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/customAction'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling billListCustomAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * For each record in the request body, update the bill payment details.
     *
     * @param body List of Bill payment details
     */
    billPaymentDetailsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/bill/billPaymentDetails';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * For each bill in the import file, update the bill payment details.
     * The import file needs to be a comma separated file.    All lines are data lines (No header line allowed).    The file structure is as follows-  Bill Id (required), Check Number (required), Check Date YYYYMMDD format (required), Pay Status (upto 10 characters- do not use commas) (required), Cleared Date YYYYMMDD format (optional), Accounting Period YYYYMM (optional), comment (optional) - comment will be ignored.  Example data:12345,7098,20210801,Procesed,20210806,202107,July bill paid via AP     For this request, please use application/octet-stream as Content-Type and include your file as binary in the body of the request.  ///
     * @param body Binary data containing the file contents
     */
    billPaymentDetailsFileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/bill/billPaymentDetailsFile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/octet-stream'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Cleans a single bill. The dirty flag of the bill is not taken into account.
     *
     * @param billId
     */
    cleanABillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/cleanBill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling cleanABill.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Cleans all dirty bills, and any bills created outside of version 7.
     *
     */
    cleanDirtyBillsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/cleanBill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Persist an payment event for several bills
     *
     * @param body Payment event creation payload
     */
    createBillPaymentEventWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202504/bill/paymentEvent';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Post, path, requestOptions);
    }
    /**
     * For each bill in the request body which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param body Distribution information
     */
    distributeAccountChargesToMetersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/bill/distributeAccountCharges';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * For each bill in the provided batch which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param batchId ID for the batch containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInBatchWithHttpInfo(batchId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/batch/${batchId}/distributeAccountCharges'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling distributeAccountChargesToMetersForBillsInBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * For each bill in the provided list which has account-level charges, distribute these account charges amongst the meters on the bill.  This is done proportionally by meter use or cost, depending on the split basis.  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId ID for the list containing bills for which account charges will be distributed to meters
     * @param body Distribution information
     */
    distributeAccountChargesToMetersForBillsInListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/list/${listId}/distributeAccountCharges'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling distributeAccountChargesToMetersForBillsInList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Edit an existing bill
     * If enabled, audits will be processed for the edited bill.    Below are some clarifications regarding the rules for editing an existing bill:  * Bills which are marked as \&quot;void\&quot; may not be edited  * Users without UpdateApprovedBills.Edit permission may not edit bills marked as \&quot;Approved\&quot;  * Users without ExportBills.Edit permission may not edit bills exported to AP or GL  * Bills must have at least one line item  * If configured, required bill headers will be enforced
     * @param billId
     * @param body
     */
    editBillWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling editBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a bill
     *
     * @param billId The id of the bill
     * @param body The list of udf values being edited
     */
    editBillCustomFieldsWithHttpInfo(billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202202/bill/${billId}/udf'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling editBillCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action on a meter bill list. Custom bill actions are setup as webhooks
     *
     * @param meterId The meter against which all of its bills will have the custom action performed
     * @param body
     */
    meterBillListCustomActionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/customAction'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListCustomAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Void/unvoid meter bills
     *
     * @param meterId The meter to void/unvoid all bills
     * @param body Boolean representing void flag
     */
    meterBillListVoidWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/void'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListVoid.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Fires a custom bill action. Custom bill actions are setup as webhooks
     *
     * @param body
     */
    processBillCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/customAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Reverses all bills on an account bill list
     *
     * @param accountId The account that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseAccountBillListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/reverse'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling reverseAccountBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Reverses all bills on a bill list
     *
     * @param listId The bill list that all bills will be reversed on
     * @param body Batch settings for the reversed bill. If not provided, bills will be placed in the currently open batch.
     */
    reverseBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/reverse'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling reverseBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Creates reversal bills for the given bill ids
     *
     * @param body
     */
    reverseBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/reverse';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Reverses all bills on a meter bill list
     *
     * @param meterId The meter that all bills will be reversed on
     * @param body Batch settings for the reversed bills. If not provided, bills will be placed in the currently open batch.
     */
    reverseMeterBillListWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/reverse'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling reverseMeterBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Updates bill headers for the bills for an account&#39;s bill list  Audits won&#39;t be fired
     *
     * @param accountId The account whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateAccountBillListHeadersWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/billHeaders'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling updateAccountBillListHeaders.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Update all headers for a bill list  If a new begin date or end date is being set, bills that would have end dates on or before their begin date will not be updated  If the user does not have permission to edit exported or approved bills, those bills will not be updated  Bills audits won&#39;t be fired
     *
     * @param listId The list identifier
     * @param body Bill list header update action
     */
    updateBillListHeadersWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/billHeaders'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling updateBillListHeaders.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Updates bill headers for all bills on a meter bill list  Audits won&#39;t be fired
     *
     * @param meterId The meter whose bills will have header updates applied
     * @param body Indicates which headers need to be updated
     */
    updateMeterBillListHeadersWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/billHeaders'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling updateMeterBillListHeaders.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    /**
     * Upload a file representing a bill image.  The bill image file extension must match the settings in system data &#39;webbillimageext&#39;.
     *
     * @param billId The Bill ID associated with the file being uploaded.
     * @param fileName The name of the file containing the bill image
     * @param body Binary data containing the bill image
     */
    uploadBillImageWithHttpInfo(billId, fileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/bill/${billId}/billImage'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling uploadBillImage.');
        }
        if (fileName !== undefined) {
            queryParameters = queryParameters.set('fileName', fileName);
        }
        // to determine the Accept header
        let produces = [
            'application/json',
            'text/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/octet-stream'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Post, path, requestOptions);
    }
    /**
     * Void/unvoid bill list
     *
     * @param listId The list identifier
     * @param body Boolean representing void flag
     */
    voidBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/void'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling voidBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1d.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1c = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExport(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListExcelExportWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillList(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountExportHistoricalBillListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountList(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountListWithHttpInfo(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFile(billId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadBillCustomFieldFileWithHttpInfo(billId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJson(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillsAsJsonWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportHistoricalBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param exportFileName
     * @param body
     */
    exportHistoricalBills(exportFileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportHistoricalBillsWithHttpInfo(exportFileName, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistory(accountId, billingPeriod, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountBillHistoryWithHttpInfo(accountId, billingPeriod, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylines(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllBillsBodylinesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflow(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getApprovalWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets all audit settings
     *
     */
    getAuditSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAuditSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param batchId
     */
    getBatch(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflow(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatches(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBatchesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBill(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterActualByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterCalendarizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterNormalizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMeterStatisticsByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActual(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersActualWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarized(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersCalendarizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalized(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersNormalizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatistics(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillAccountMetersStatisticsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * List of a bill IDs that were created or modified since the given date.
     *
     * @param date Created or modified datetime; Defaults to yesterday at the current time
     */
    getBillActivity(date, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillActivityWithHttpInfo(date, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylines(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillBodylinesWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFields(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillCustomFieldsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillId(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillEntryDataByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistory(billId, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillHistoryWithHttpInfo(billId, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetails(taskGuid, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportKickoutDetailsWithHttpInfo(taskGuid, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFile(taskGuid, filename, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportKickoutDetailsByFileWithHttpInfo(taskGuid, filename, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillImportWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEvents(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillPaymentEventsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves properties for bill view
     *
     * @param billId The bill identifier
     */
    getBillView(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillViewWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBills(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflow(exportMode, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getExportWorkflowWithHttpInfo(exportMode, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBills(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummary(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTaskKickoutSummaryWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFile(taskGuid, filename, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getTaskKickoutSummaryByFileWithHttpInfo(taskGuid, filename, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillList(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListWithHttpInfo(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExport(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListExcelExportWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillList(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterExportHistoricalBillListWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param accountId The account to export bills
     */
    accountBillListExcelExportWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/excelexport'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Generate a bill import file from all bills in an account bill list.
     *
     * @param accountId The account from which to get all bills
     */
    accountExportHistoricalBillListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/generateimport'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountExportHistoricalBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Post, path, requestOptions);
    }
    /**
     * Get the account bills list
     *
     * @param accountId The account identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    accountListWithHttpInfo(accountId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Download file for a bill custom field
     *
     * @param billId The id of the bill
     * @param udfId The id of the custom field
     */
    downloadBillCustomFieldFileWithHttpInfo(billId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202202/bill/${billId}/udf/${udfId}/download'
            .replace('${' + 'billId' + '}', String(billId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling downloadBillCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadBillCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves a JSON array of bill details.
     *
     * @param body List of bill IDs
     */
    exportBillsAsJsonWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/bill/export/json';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Post, path, requestOptions);
    }
    /**
     * Generate a bill import file from bills in a list.
     *
     * @param listId The id of the list to get bills from
     */
    exportHistoricalBillListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/bill/generateimport'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling exportHistoricalBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Post, path, requestOptions);
    }
    /**
     *
     *
     * @param exportFileName
     * @param body
     */
    exportHistoricalBillsWithHttpInfo(exportFileName, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/generatebillimport';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (exportFileName !== undefined) {
            queryParameters = queryParameters.set('exportFileName', exportFileName);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Post, path, requestOptions);
    }
    /**
     * Retrieves bill history for an account
     *
     * @param accountId accountId to get bill history for
     * @param billingPeriod required: billingPeriod in yyyymm format to return history from
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getAccountBillHistoryWithHttpInfo(accountId, billingPeriod, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/billHistory'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountBillHistory.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (includeVoid !== undefined) {
            queryParameters = queryParameters.set('includeVoid', includeVoid);
        }
        if (includeAccrual !== undefined) {
            queryParameters = queryParameters.set('includeAccrual', includeAccrual);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves all bill&#39;s bodylines
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getAllBillsBodylinesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/bodyline';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Get approval workflow settings
     *
     */
    getApprovalWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/approval';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Gets all audit settings
     *
     */
    getAuditSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/audit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param batchId
     */
    getBatchWithHttpInfo(batchId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch/${batchId}'
            .replace('${' + 'batchId' + '}', String(batchId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'batchId' is not null or undefined
        if (batchId === null || batchId === undefined) {
            throw new Error('Required parameter batchId was null or undefined when calling getBatch.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Get batch workflow settings
     *
     */
    getBatchWorkflowWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBatchesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/batch';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves one bill
     *
     * @param billId The bill identifier
     */
    getBillWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterActualByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/actual'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterActualByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter calendarized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterCalendarizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/calendarized'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterCalendarizedByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter normalized record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterNormalizedByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/normalized'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterNormalizedByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter statistics record for a specific billId
     *
     * @param billId The bill identifier
     */
    getBillAccountMeterStatisticsByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billaccountmeter/statistics'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillAccountMeterStatisticsByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersActualWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/actual';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter calendarized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersCalendarizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/calendarized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter normalized records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersNormalizedWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/normalized';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill account meter statistics records
     *
     * @param filter Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillAccountMetersStatisticsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/billaccountmeter/statistics';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * List of a bill IDs that were created or modified since the given date.
     *
     * @param date Created or modified datetime; Defaults to yesterday at the current time
     */
    getBillActivityWithHttpInfo(date, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/activity/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (date !== undefined) {
            queryParameters = queryParameters.set('date', date.toISOString());
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves one bill&#39;s bodylines
     *
     * @param billId The bill identifier
     */
    getBillBodylinesWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/bill/${billId}/bodyline'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillBodylines.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Get custom field values for a bill
     *
     * @param billId The id of the bill
     */
    getBillCustomFieldsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202202/bill/${billId}/udf'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves all data necessary to load the bill entry screen
     *
     * @param billId
     */
    getBillEntryDataByBillIdWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billEntry'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillEntryDataByBillId.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves bill history from starting at the billId billing period
     *
     * @param billId billId to get bill history for
     * @param numberOfYears optional: Number of years of history to return.  Defaults to 5
     * @param includeVoid optional: Should voided bills be included.  Defaults to false
     * @param includeAccrual optional: Should accrual bills be included.  Defaults to false
     */
    getBillHistoryWithHttpInfo(billId, numberOfYears, includeVoid, includeAccrual, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/${billId}/billHistory'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillHistory.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (includeVoid !== undefined) {
            queryParameters = queryParameters.set('includeVoid', includeVoid);
        }
        if (includeAccrual !== undefined) {
            queryParameters = queryParameters.set('includeAccrual', includeAccrual);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsWithHttpInfo(taskGuid, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/detail'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getBillImportKickoutDetails.');
        }
        if (kickoutMessage !== undefined) {
            queryParameters = queryParameters.set('kickoutMessage', kickoutMessage);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves the kickout details associated with a specified bill import task, file and an optional kickout message.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     * @param kickoutMessage The optional kickout message to search for.
     */
    getBillImportKickoutDetailsByFileWithHttpInfo(taskGuid, filename, kickoutMessage, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/${filename}/detail'
            .replace('${' + 'taskGuid' + '}', String(taskGuid))
            .replace('${' + 'filename' + '}', String(filename));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getBillImportKickoutDetailsByFile.');
        }
        // verify required parameter 'filename' is not null or undefined
        if (filename === null || filename === undefined) {
            throw new Error('Required parameter filename was null or undefined when calling getBillImportKickoutDetailsByFile.');
        }
        if (kickoutMessage !== undefined) {
            queryParameters = queryParameters.set('kickoutMessage', kickoutMessage);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Get bill import workflow settings
     *
     */
    getBillImportWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/billImport';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves the payment events for a bill
     *
     * @param billId Identifier for the bill
     */
    getBillPaymentEventsWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202504/bill/${billId}/paymentEvent'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillPaymentEvents.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves properties for bill view
     *
     * @param billId The bill identifier
     */
    getBillViewWithHttpInfo(billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billView/${billId}'
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getBillView.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of bills. The array of bills can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Get export workflow settings
     *
     * @param exportMode The export mode to get settings for, can be &#39;AP&#39;, &#39;GL&#39; or &#39;Payment&#39;
     */
    getExportWorkflowWithHttpInfo(exportMode, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/export';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (exportMode !== undefined) {
            queryParameters = queryParameters.set('exportMode', exportMode);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves all bills for a particular meter
     *
     * @param meterId The meter identifier for which bill values are being retrieved
     */
    getMeterBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     */
    getTaskKickoutSummaryWithHttpInfo(taskGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/summary'
            .replace('${' + 'taskGuid' + '}', String(taskGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getTaskKickoutSummary.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of kickout messages associated with a specified bill import task and file.
     *
     * @param taskGuid The task GUID to search for. The task must be of type Bill Import.
     * @param filename The kickout file name to search for.
     */
    getTaskKickoutSummaryByFileWithHttpInfo(taskGuid, filename, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202401/import/bill/task/${taskGuid}/kickout/${filename}/summary'
            .replace('${' + 'taskGuid' + '}', String(taskGuid))
            .replace('${' + 'filename' + '}', String(filename));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskGuid' is not null or undefined
        if (taskGuid === null || taskGuid === undefined) {
            throw new Error('Required parameter taskGuid was null or undefined when calling getTaskKickoutSummaryByFile.');
        }
        // verify required parameter 'filename' is not null or undefined
        if (filename === null || filename === undefined) {
            throw new Error('Required parameter filename was null or undefined when calling getTaskKickoutSummaryByFile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Get the meter bills list
     *
     * @param meterId The meter identifier to retrieve bills list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    meterBillListWithHttpInfo(meterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param meterId The meter to export bills from
     */
    meterBillListExcelExportWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/excelexport'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Get, path, requestOptions);
    }
    /**
     * Generate a bill import file from all bills in a meter bill list.
     *
     * @param meterId The meter from which to get all bills
     */
    meterExportHistoricalBillListWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/generateimport'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterExportHistoricalBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1c.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1b = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a budget
     *
     * @param body Data representing the budget being created
     */
    createBudget(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBudgetWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a budget version
     *
     * @param budgetId The identifier for the budget to create the version on
     * @param body Data representing the budgetVersion being created
     */
    createBudgetVersion(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createBudgetVersionWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a budget
     *
     * @param body Data representing the budget being created
     */
    createBudgetWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1b.Post, path, requestOptions);
    }
    /**
     * Creates a budget version
     *
     * @param budgetId The identifier for the budget to create the version on
     * @param body Data representing the budgetVersion being created
     */
    createBudgetVersionWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling createBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1b.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1a = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a budget
     *
     * @param budgetId The identifier for the budget being deleted
     */
    deleteBudget(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being deleted
     */
    deleteBudgetVersion(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a budget
     *
     * @param budgetId The identifier for the budget being deleted
     */
    deleteBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling deleteBudget.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1a.Delete, path, requestOptions);
    }
    /**
     * Deletes a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being deleted
     */
    deleteBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling deleteBudgetVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling deleteBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1a.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$19 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits a budget
     *
     * @param budgetId The identifier for the budget being edited
     * @param body Data representing the budget being edited
     */
    editBudget(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBudgetWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param body Data representing the budgetVersion being edited
     */
    editBudgetVersion(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editBudgetVersionWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Import a budget setup sheet
     *
     * @param budgetId The budget identifier
     * @param versionId The budget version identifier
     * @param body The budget sheet file contents
     */
    postBudgetSetupSheet(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.postBudgetSetupSheetWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Sets a budget version as active, and all other versions as inactive.
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version to set as active
     */
    setBudgetVersionActive(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setBudgetVersionActiveWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a budget
     *
     * @param budgetId The identifier for the budget being edited
     * @param body Data representing the budget being edited
     */
    editBudgetWithHttpInfo(budgetId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling editBudget.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$19.Put, path, requestOptions);
    }
    /**
     * Edits a budget version
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param body Data representing the budgetVersion being edited
     */
    editBudgetVersionWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling editBudgetVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$19.Put, path, requestOptions);
    }
    /**
     * Import a budget setup sheet
     *
     * @param budgetId The budget identifier
     * @param versionId The budget version identifier
     * @param body The budget sheet file contents
     */
    postBudgetSetupSheetWithHttpInfo(budgetId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202311/setup/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling postBudgetSetupSheet.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling postBudgetSetupSheet.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/vnd.ms-excel'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$19.Post, path, requestOptions);
    }
    /**
     * Sets a budget version as active, and all other versions as inactive.
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version to set as active
     */
    setBudgetVersionActiveWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}/active'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling setBudgetVersionActive.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling setBudgetVersionActive.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$19.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$18 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves the budget by ID
     *
     * @param budgetId The identifier for the budget being retrieved
     */
    getBudget(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of available budget data types
     *
     */
    getBudgetDataTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetDataTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of budget period types
     *
     */
    getBudgetPeriodTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetPeriodTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of available budget usage methods
     *
     */
    getBudgetUsageMethods(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetUsageMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a specific version for a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     */
    getBudgetVersion(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the summary for a specific version on a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param commodityId The optional commodity filter
     */
    getBudgetVersionSummary(budgetId, versionId, commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetVersionSummaryWithHttpInfo(budgetId, versionId, commodityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the versions for a specified budget
     *
     * @param budgetId The identifier for the budget to retrieve all versions
     */
    getBudgetVersions(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetVersionsWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the budgets
     *
     */
    getBudgets(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBudgetsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the budget by ID
     *
     * @param budgetId The identifier for the budget being retrieved
     */
    getBudgetWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudget.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of available budget data types
     *
     */
    getBudgetDataTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/dataType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of budget period types
     *
     */
    getBudgetPeriodTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/periodType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of available budget usage methods
     *
     */
    getBudgetUsageMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/usageMethod';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves a specific version for a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     */
    getBudgetVersionWithHttpInfo(budgetId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudgetVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBudgetVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves the summary for a specific version on a budget
     *
     * @param budgetId The identifier for the budget
     * @param versionId The identifier for the version being retrieved
     * @param commodityId The optional commodity filter
     */
    getBudgetVersionSummaryWithHttpInfo(budgetId, versionId, commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version/${versionId}/summary'
            .replace('${' + 'budgetId' + '}', String(budgetId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudgetVersionSummary.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getBudgetVersionSummary.');
        }
        if (commodityId !== undefined) {
            queryParameters = queryParameters.set('commodityId', commodityId);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves all the versions for a specified budget
     *
     * @param budgetId The identifier for the budget to retrieve all versions
     */
    getBudgetVersionsWithHttpInfo(budgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget/${budgetId}/version'
            .replace('${' + 'budgetId' + '}', String(budgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'budgetId' is not null or undefined
        if (budgetId === null || budgetId === undefined) {
            throw new Error('Required parameter budgetId was null or undefined when calling getBudgetVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    /**
     * Retrieves all the budgets
     *
     */
    getBudgetsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202310/budget';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$18.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$17 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a meter group category
     *
     * @param body Data representing the meter group category being created
     */
    createMeterCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a meter group
     *
     * @param body Data representing the meter group being created
     */
    createMeterGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place group category
     *
     * @param body Data representing the place group category being created
     */
    createPlaceCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a place group
     *
     * @param body Data representing the place group being created
     */
    createPlaceGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a meter group
     *
     * @param meterGroupId Id of the group to edit
     * @param body Data representing the meter group being edited
     */
    editMeterGroup(meterGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterGroupWithHttpInfo(meterGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a place group
     *
     * @param placeGroupId Id of the group to edit
     * @param body Data representing the place group being edited
     */
    editPlaceGroup(placeGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceGroupWithHttpInfo(placeGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a meter group category
     *
     * @param body Data representing the meter group category being created
     */
    createMeterCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$17.Post, path, requestOptions);
    }
    /**
     * Create a meter group
     *
     * @param body Data representing the meter group being created
     */
    createMeterGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$17.Post, path, requestOptions);
    }
    /**
     * Creates a place group category
     *
     * @param body Data representing the place group category being created
     */
    createPlaceCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$17.Post, path, requestOptions);
    }
    /**
     * Create a place group
     *
     * @param body Data representing the place group being created
     */
    createPlaceGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$17.Post, path, requestOptions);
    }
    /**
     * Edit a meter group
     *
     * @param meterGroupId Id of the group to edit
     * @param body Data representing the meter group being edited
     */
    editMeterGroupWithHttpInfo(meterGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling editMeterGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$17.Put, path, requestOptions);
    }
    /**
     * Edit a place group
     *
     * @param placeGroupId Id of the group to edit
     * @param body Data representing the place group being edited
     */
    editPlaceGroupWithHttpInfo(placeGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling editPlaceGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$17.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$16 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete a meter group category
     *
     * @param categoryId Id of the category to delete
     */
    deleteMeterCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a user-created meter group
     *
     * @param meterGroupId
     */
    deleteMeterGroup(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a place group category
     *
     * @param categoryId Id of the category to delete
     */
    deletePlaceCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a user-created place group
     *
     * @param placeGroupId
     */
    deletePlaceGroup(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a meter group category
     *
     * @param categoryId Id of the category to delete
     */
    deleteMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling deleteMeterCategory.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$16.Delete, path, requestOptions);
    }
    /**
     * Delete a user-created meter group
     *
     * @param meterGroupId
     */
    deleteMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling deleteMeterGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$16.Delete, path, requestOptions);
    }
    /**
     * Delete a place group category
     *
     * @param categoryId Id of the category to delete
     */
    deletePlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling deletePlaceCategory.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$16.Delete, path, requestOptions);
    }
    /**
     * Delete a user-created place group
     *
     * @param placeGroupId
     */
    deletePlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling deletePlaceGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$16.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$15 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Update a meter group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the meter group category
     */
    editMeterCategory(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a meter&#39;s group memberships.   Note that all groups a meter should belong to must be passed in. Passing in one group means that the meter will belong to one group only,   even if it previously belonged to several.  Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param meterId The meter identifier whose group memberships are being edited
     * @param body The groups the meter will belong to
     */
    editMeterGroupMembership(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterGroupMembershipWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a place group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the place group category
     */
    editPlaceCategory(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a place&#39;s group memberships.   Note that all groups a place should belong to must be passed in. Passing in one group means that the place will belong to one group only,   even if it previously belonged to several.   Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param placeId The place identifier whose group memberships are being edited
     * @param body The groups the place will belong to
     */
    editPlaceGroupMembership(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceGroupMembershipWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Include all group members in charts
     *
     * @param meterGroupId
     */
    includeAllMeterGroupMemberInCharts(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.includeAllMeterGroupMemberInChartsWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Include all group members in charts
     *
     * @param placeGroupId
     */
    includeAllPlaceGroupMemberInCharts(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.includeAllPlaceGroupMemberInChartsWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserMeterAutoGroupsMembership(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateAllUserMeterAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserPlaceAutoGroupsMembership(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateAllUserPlaceAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param meterGroupId The meter group to refresh
     */
    recalculateUserMeterAutoGroupMemebership(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateUserMeterAutoGroupMemebershipWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param placeGroupId The place group to refresh
     */
    recalculateUserPlaceAutoGroupMemebership(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.recalculateUserPlaceAutoGroupMemebershipWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param meterGroupId
     * @param meterId
     * @param body
     */
    updateMeterGroupMember(meterGroupId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateMeterGroupMemberWithHttpInfo(meterGroupId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param placeGroupId
     * @param placeId
     * @param body
     */
    updatePlaceGroupMember(placeGroupId, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updatePlaceGroupMemberWithHttpInfo(placeGroupId, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a meter group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the meter group category
     */
    editMeterCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling editMeterCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Put, path, requestOptions);
    }
    /**
     * Edits a meter&#39;s group memberships.   Note that all groups a meter should belong to must be passed in. Passing in one group means that the meter will belong to one group only,   even if it previously belonged to several.  Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param meterId The meter identifier whose group memberships are being edited
     * @param body The groups the meter will belong to
     */
    editMeterGroupMembershipWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/group'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterGroupMembership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Put, path, requestOptions);
    }
    /**
     * Update a place group category
     *
     * @param categoryId Id of the category to update
     * @param body Data to update the place group category
     */
    editPlaceCategoryWithHttpInfo(categoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling editPlaceCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Put, path, requestOptions);
    }
    /**
     * Edits a place&#39;s group memberships.   Note that all groups a place should belong to must be passed in. Passing in one group means that the place will belong to one group only,   even if it previously belonged to several.   Only manual groups assignments can be changed; auto groups are unaffected.
     *
     * @param placeId The place identifier whose group memberships are being edited
     * @param body The groups the place will belong to
     */
    editPlaceGroupMembershipWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/group'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceGroupMembership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Put, path, requestOptions);
    }
    /**
     * Include all group members in charts
     *
     * @param meterGroupId
     */
    includeAllMeterGroupMemberInChartsWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}/member/includeInCharts'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling includeAllMeterGroupMemberInCharts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Post, path, requestOptions);
    }
    /**
     * Include all group members in charts
     *
     * @param placeGroupId
     */
    includeAllPlaceGroupMemberInChartsWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/member/includeInCharts'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling includeAllPlaceGroupMemberInCharts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserMeterAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/updateUserAutoGroups';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for all user defined auto groups
     *
     */
    recalculateAllUserPlaceAutoGroupsMembershipWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/updateUserAutoGroups';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param meterGroupId The meter group to refresh
     */
    recalculateUserMeterAutoGroupMemebershipWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}/updateUserAutoGroup'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling recalculateUserMeterAutoGroupMemebership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Post, path, requestOptions);
    }
    /**
     * Refreshes group membership for a user defined auto group
     *
     * @param placeGroupId The place group to refresh
     */
    recalculateUserPlaceAutoGroupMemebershipWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/updateUserAutoGroup'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling recalculateUserPlaceAutoGroupMemebership.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Post, path, requestOptions);
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param meterGroupId
     * @param meterId
     * @param body
     */
    updateMeterGroupMemberWithHttpInfo(meterGroupId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}/member/${meterId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling updateMeterGroupMember.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling updateMeterGroupMember.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Put, path, requestOptions);
    }
    /**
     * Update a group member&#39;s include in charts flag
     *
     * @param placeGroupId
     * @param placeId
     * @param body
     */
    updatePlaceGroupMemberWithHttpInfo(placeGroupId, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/member/${placeId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling updatePlaceGroupMember.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling updatePlaceGroupMember.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$15.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$14 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an ESA place
     *
     * @param body Data representing the ESA place being created
     */
    createEsaPlace(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place
     *
     * @param body Data representing the place being created
     */
    createPlace(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a Primary Use
     *
     * @param body Data representing the Primary Use being created
     */
    createPrimaryUse(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPrimaryUseWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA place
     *
     * @param body Data representing the ESA place being created
     */
    createEsaPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$14.Post, path, requestOptions);
    }
    /**
     * Creates a place
     *
     * @param body Data representing the place being created
     */
    createPlaceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$14.Post, path, requestOptions);
    }
    /**
     * Creates a Primary Use
     *
     * @param body Data representing the Primary Use being created
     */
    createPrimaryUseWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/primaryuse';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$14.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$13 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes an ESA place
     *
     * @param placeId The identifier for the ESA place being deleted
     */
    deleteEsaPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a place
     *
     * @param placeId The identifier for the place being deleted
     */
    deletePlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a primary use
     *
     * @param primaryUseId The identifier for the primary use being deleted
     */
    deletePrimaryUse(primaryUseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePrimaryUseWithHttpInfo(primaryUseId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an ESA place
     *
     * @param placeId The identifier for the ESA place being deleted
     */
    deleteEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deleteEsaPlace.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$13.Delete, path, requestOptions);
    }
    /**
     * Deletes a place
     *
     * @param placeId The identifier for the place being deleted
     */
    deletePlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deletePlace.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$13.Delete, path, requestOptions);
    }
    /**
     * Deletes a primary use
     *
     * @param primaryUseId The identifier for the primary use being deleted
     */
    deletePrimaryUseWithHttpInfo(primaryUseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/primaryuse/${primaryUseId}'
            .replace('${' + 'primaryUseId' + '}', String(primaryUseId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'primaryUseId' is not null or undefined
        if (primaryUseId === null || primaryUseId === undefined) {
            throw new Error('Required parameter primaryUseId was null or undefined when calling deletePrimaryUse.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$13.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$12 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequests(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.acceptPropertyAndMeterSharingRequestsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.bulkEditDataRollupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValue(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSize(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceSizeWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createPlaceTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createSchedule(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createScheduleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValue(benchmarkIndicator, placeId, placeBenchmarkId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSize(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceType(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deletePlaceTypeWithHttpInfo(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteSchedule(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLink(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyStarPlaceLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlace(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedules(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaPlaceSchedulesWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistory(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaPlaceSizeHistoryWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlace(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValues(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeList(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceSizeListWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceType(placeTypeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceTypeWithHttpInfo(placeTypeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFs(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editPlaceUDFsWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editSchedule(scheduleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editScheduleWithHttpInfo(scheduleId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLink(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWatticsSiteLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlace(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveEsaPlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlace(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.movePlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStar(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkPlacesAndChildMetersFromEnergyStarWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateEnergyStarSubmissionTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValue(benchmarkIndicator, placeId, placeBenchmarkId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updatePlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Accept any pending property and meter share requests from ENERGY STAR Portfolio Manager
     *
     */
    acceptPropertyAndMeterSharingRequestsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/acceptShares';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Set and Reset the data Rollup from esa place
     *
     * @param body The list of placeIds and If the Rollup is true or false
     */
    bulkEditDataRollupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/dataRollup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Creates a place benchmark value  If a preceding benchmark value exists, the preceding record&#39;s end date will be changed to match the created records begin date  If a succeeding benchmark value exists, the created record&#39;s end date will match the succeeding benchmarks begin date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param body The new begin date and value for the benchmark
     */
    createPlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling createPlaceBenchmarkValue.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling createPlaceBenchmarkValue.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Post, path, requestOptions);
    }
    /**
     * Creates a place size version  If a preceding place size version exists, the preceding record&#39;s end date will be changed to match the created record&#39;s begin date  If a succeeding place size version exists the created records end date will match the succeeding version&#39;s begin date
     *
     * @param placeId The identifier of the place to add a place size to
     * @param body Data representing the place size being created
     */
    createPlaceSizeWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling createPlaceSize.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Post, path, requestOptions);
    }
    /**
     * Create a place type
     * New place types will not be considered structures
     * @param body Definition of new place type
     */
    createPlaceTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Post, path, requestOptions);
    }
    /**
     * Creates a schedule
     *
     * @param body Data representing the schedule being created
     */
    createScheduleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Post, path, requestOptions);
    }
    /**
     * Delete a single benchmark value.  If a preceding benchmark value exists, the preceding record’s end date will be changed to prevent any gaps in benchmark values
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Indicator for the place
     * @param placeBenchmarkId Indicator for the individual benchmark value
     */
    deleteBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue/${placeBenchmarkId}'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeBenchmarkId' + '}', String(placeBenchmarkId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling deleteBenchmarkValue.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deleteBenchmarkValue.');
        }
        // verify required parameter 'placeBenchmarkId' is not null or undefined
        if (placeBenchmarkId === null || placeBenchmarkId === undefined) {
            throw new Error('Required parameter placeBenchmarkId was null or undefined when calling deleteBenchmarkValue.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Delete, path, requestOptions);
    }
    /**
     * Delete a place size version  The preceding version&#39;s end date will be shifted to the deleted record&#39;s end date to prevent any gaps
     *
     * @param placeId The identifier of the place
     * @param placeSizeId The identifier of the place size
     */
    deletePlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size/${placeSizeId}'
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeSizeId' + '}', String(placeSizeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling deletePlaceSize.');
        }
        // verify required parameter 'placeSizeId' is not null or undefined
        if (placeSizeId === null || placeSizeId === undefined) {
            throw new Error('Required parameter placeSizeId was null or undefined when calling deletePlaceSize.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Delete, path, requestOptions);
    }
    /**
     * Deletes the place type
     *
     * @param placeTypeId Unique identifier for the place type
     */
    deletePlaceTypeWithHttpInfo(placeTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype/${placeTypeId}'
            .replace('${' + 'placeTypeId' + '}', String(placeTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeTypeId' is not null or undefined
        if (placeTypeId === null || placeTypeId === undefined) {
            throw new Error('Required parameter placeTypeId was null or undefined when calling deletePlaceType.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Delete, path, requestOptions);
    }
    /**
     * Deletes a schedule
     *
     * @param scheduleId The schedule identifier
     */
    deleteScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule/${scheduleId}'
            .replace('${' + 'scheduleId' + '}', String(scheduleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'scheduleId' is not null or undefined
        if (scheduleId === null || scheduleId === undefined) {
            throw new Error('Required parameter scheduleId was null or undefined when calling deleteSchedule.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Delete, path, requestOptions);
    }
    /**
     * Edit the ENERGY STAR linking information for this place and its meters.  Set PmPropertyId/PmMeterId to null to unlink a property/meter.  Set PmMeterId to -1 to auto-create a new meter.
     *
     * @param placeId The place identifier
     * @param body Data representing the place link being edited
     */
    editEnergyStarPlaceLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/link'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEnergyStarPlaceLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edits an ESA place
     *
     * @param placeId The identifier for the ESA place being edited
     * @param body Data representing the ESA place being edited
     */
    editEsaPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEsaPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Manages the schedules of a place
     *
     * @param placeId The place identifier
     * @param body A list of schedule identifiers to assign
     */
    editEsaPlaceSchedulesWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaplace/${placeId}/schedule'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEsaPlaceSchedules.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Manages the version history for a single ESA place.   This endpoint handles Creating, Editing, and Deleting place sizes for ESA places in bulk.
     *
     * @param placeId
     * @param body
     */
    editEsaPlaceSizeHistoryWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}/placeSize'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editEsaPlaceSizeHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edits a place
     *
     * @param placeId The identifier for the place being edited
     * @param body Data representing the place being edited
     */
    editPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edit all values for a benchmark factor on a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId
     * @param body
     */
    editPlaceBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling editPlaceBenchmarkValues.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceBenchmarkValues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * API endpoint which takes care of Create, Edit and Delete of new place sizes in bulk
     *
     * @param placeId The identifier of the place
     * @param body Data representing the place size being created
     */
    editPlaceSizeListWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceSizeList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edit a current place type
     *
     * @param placeTypeId Unique identifier for the place type
     * @param body Definition of new place type
     */
    editPlaceTypeWithHttpInfo(placeTypeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/placetype/${placeTypeId}'
            .replace('${' + 'placeTypeId' + '}', String(placeTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeTypeId' is not null or undefined
        if (placeTypeId === null || placeTypeId === undefined) {
            throw new Error('Required parameter placeTypeId was null or undefined when calling editPlaceType.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular place
     *
     * @param placeId The identifier for the place
     * @param body Data representing the place user defined fields / custom fields being edited
     */
    editPlaceUDFsWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/udf'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editPlaceUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edits a schedule
     *
     * @param scheduleId The schedule identifier
     * @param body Data representing the schedule being edited
     */
    editScheduleWithHttpInfo(scheduleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule/${scheduleId}'
            .replace('${' + 'scheduleId' + '}', String(scheduleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'scheduleId' is not null or undefined
        if (scheduleId === null || scheduleId === undefined) {
            throw new Error('Required parameter scheduleId was null or undefined when calling editSchedule.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a place
     *
     * @param placeId The place identifier for the place to edit
     * @param body Identifier for the SmartAnalytics (Wattics) site to assign to the place
     */
    editWatticsSiteLinkWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/place/${placeId}/watticsSite'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling editWatticsSiteLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Move list of places to be under a parent place
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of place identifiers to move
     */
    moveEsaPlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/parentPlace/${parentPlaceId}/place'
            .replace('${' + 'parentPlaceId' + '}', String(parentPlaceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentPlaceId' is not null or undefined
        if (parentPlaceId === null || parentPlaceId === undefined) {
            throw new Error('Required parameter parentPlaceId was null or undefined when calling moveEsaPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Move list of places to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of placeIds to move under the parentPlaceId
     */
    movePlaceWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentPlace/${parentPlaceId}/place'
            .replace('${' + 'parentPlaceId' + '}', String(parentPlaceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentPlaceId' is not null or undefined
        if (parentPlaceId === null || parentPlaceId === undefined) {
            throw new Error('Required parameter parentPlaceId was null or undefined when calling movePlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Unlink a list of places and their child meters from ENERGY STAR
     *
     * @param body List of place identifiers to unlink from ENERGY STAR
     */
    unlinkPlacesAndChildMetersFromEnergyStarWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/place/energyStar/unlink';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Update a list of places to be submitted to ENERGY STAR manually or automatically
     *
     * @param body The list of places to update, as well as the submission type to set
     */
    updateEnergyStarSubmissionTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/place/energyStar/submissionType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    /**
     * Updates a place benchmark value  If the begin date is being modified, the following will happen:  * Records that now precede and previously preceded this benchmark will have their end dates modified to prevent gaps in benchmarks  * If a succeeding benchmark value exists for the new begin date, the end date will be modified to match the succeeding benchmarks end date
     *
     * @param benchmarkIndicator Indicator for the benchmark, can be 1, 2, or 3
     * @param placeId The place that the benchmark is on
     * @param placeBenchmarkId The identifier for the benchmark being updated
     * @param body The new begin date and value for the benchmark
     */
    updatePlaceBenchmarkValueWithHttpInfo(benchmarkIndicator, placeId, placeBenchmarkId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue/${placeBenchmarkId}'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeBenchmarkId' + '}', String(placeBenchmarkId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling updatePlaceBenchmarkValue.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling updatePlaceBenchmarkValue.');
        }
        // verify required parameter 'placeBenchmarkId' is not null or undefined
        if (placeBenchmarkId === null || placeBenchmarkId === undefined) {
            throw new Error('Required parameter placeBenchmarkId was null or undefined when calling updatePlaceBenchmarkValue.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$12.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$11 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlaces(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.availableCostCentersForTopmostPlacesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFields(energyProjectId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFile(placeId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadPlaceCustomFieldFileWithHttpInfo(placeId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValues(benchmarkIndicator, placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProject(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFields(energyProjectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManager(query, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectManagerWithHttpInfo(query, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyProjectsForPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarCommodityMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlace(placeId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceWithHttpInfo(placeId, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchy(placeId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceHierarchyWithHttpInfo(placeId, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLink(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceLinkWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetrics(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarPlaceMetricsWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizes(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceChildrenSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedules(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceSchedulesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistory(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlaceSizeHistoryWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlaces(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartData(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEuiChartDataWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparison(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedCostComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparison(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedGhgComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroups(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNomalizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparison(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedUseComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearly(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSize(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizes(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfs(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceUdfsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaces(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlacesUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperties(includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPortfolioManagerPropertiesWithHttpInfo(includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerProperty(pmPropertyId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPortfolioManagerPropertyWithHttpInfo(pmPropertyId, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMeters(pmPropertyId, includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPortfolioManagerPropertyMetersWithHttpInfo(pmPropertyId, includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getSchedule(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all schedules
     *
     */
    getSchedules(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSchedulesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPoints(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryDataPointsWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMeters(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryMetersWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlaces(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryPlacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpaces(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestrySpacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalSpaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For a list of topmost places, get associated topmost cost centers.
     *
     * @param body List of placeIds to get associated topmost cost centers.
     */
    availableCostCentersForTopmostPlacesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/place/availableCostCenters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Post, path, requestOptions);
    }
    /**
     * Download file for a energy project custom field
     *
     * @param energyProjectId The id of the energy project
     * @param udfId The id of the custom field
     */
    downloadEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/energyproject/${energyProjectId}/udf/${udfId}/download'
            .replace('${' + 'energyProjectId' + '}', String(energyProjectId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyProjectId' is not null or undefined
        if (energyProjectId === null || energyProjectId === undefined) {
            throw new Error('Required parameter energyProjectId was null or undefined when calling downloadEnergyProjectCustomFields.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadEnergyProjectCustomFields.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Download file for a place custom field
     *
     * @param placeId
     * @param udfId
     */
    downloadPlaceCustomFieldFileWithHttpInfo(placeId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/place/${placeId}/udf/${udfId}/download'
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling downloadPlaceCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadPlaceCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves benchmark values for a place
     *
     * @param benchmarkIndicator Indicator for the benchmark
     * @param placeId Identifier for the place
     */
    getBenchmarkValuesWithHttpInfo(benchmarkIndicator, placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeBenchmark/${benchmarkIndicator}/place/${placeId}/benchmarkValue'
            .replace('${' + 'benchmarkIndicator' + '}', String(benchmarkIndicator))
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'benchmarkIndicator' is not null or undefined
        if (benchmarkIndicator === null || benchmarkIndicator === undefined) {
            throw new Error('Required parameter benchmarkIndicator was null or undefined when calling getBenchmarkValues.');
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getBenchmarkValues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get an energy project
     *
     * @param projectId The identifier for the energy project to retrieve
     */
    getEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/${projectId}'
            .replace('${' + 'projectId' + '}', String(projectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'projectId' is not null or undefined
        if (projectId === null || projectId === undefined) {
            throw new Error('Required parameter projectId was null or undefined when calling getEnergyProject.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get custom field values for a energy project
     *
     * @param energyProjectId The id of the energy project
     */
    getEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/energyproject/${energyProjectId}/udf'
            .replace('${' + 'energyProjectId' + '}', String(energyProjectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyProjectId' is not null or undefined
        if (energyProjectId === null || energyProjectId === undefined) {
            throw new Error('Required parameter energyProjectId was null or undefined when calling getEnergyProjectCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get the energy project managers
     *
     * @param query
     */
    getEnergyProjectManagerWithHttpInfo(query, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/projectmanager';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (query !== undefined) {
            queryParameters = queryParameters.set('query', query);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get all the energy project types
     *
     */
    getEnergyProjectTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/energyprojecttype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all Energy Projects for a particular place by placeId. For organizations it will be the rollup of its children&#39;s energy projects
     *
     * @param placeId The place identifier for which energy projects are being retrieved
     */
    getEnergyProjectsForPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/project'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyProjectsForPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get a list of all commodities and, if configured, their mappings in ENERGY STAR
     *
     */
    getEnergyStarCommodityMappingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202109/energyStar/commodity';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get the ENERGY STAR info for a place.
     *
     * @param placeId The place identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getEnergyStarPlaceWithHttpInfo(placeId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlace.');
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get this place&#39;s ENERGY STAR child places
     *
     * @param placeId The place identifier
     * @param filter
     */
    getEnergyStarPlaceHierarchyWithHttpInfo(placeId, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/hierarchy'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlaceHierarchy.');
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get the ENERGY STAR linking information for this place and its meters.   PmPropertyId and PmMeterId will be null if no link yet exists.
     *
     * @param placeId The place identifier
     */
    getEnergyStarPlaceLinkWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/link'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlaceLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get the ENERGY STAR metrics for a place.
     *
     * @param placeId The place identifier
     * @param numberOfYears The number of years to go back from most recent score. Defaults to 2 years. If 0 is provided, will only include current score.
     */
    getEnergyStarPlaceMetricsWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/energyStar/metrics'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEnergyStarPlaceMetrics.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get settings for ENERGY STAR submissions
     *
     */
    getEnergyStarSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves an ESA place by place ID
     *
     * @param placeId The identifier for the ESA place being retrieved
     */
    getEsaPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves the current sizes of all of an ESA place&#39;s children.   If a place has no children, nothing is returned.
     *
     * @param placeId
     */
    getEsaPlaceChildrenSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}/placeSize/child'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlaceChildrenSizes.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Gets the schedules of a place
     *
     * @param placeId The place identifier
     */
    getEsaPlaceSchedulesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/esaplace/${placeId}/schedule'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlaceSchedules.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves the entire size history of an ESA place by ID
     *
     * @param placeId
     */
    getEsaPlaceSizeHistoryWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace/${placeId}/placeSize/history'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEsaPlaceSizeHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esaplace';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves energy use intensity data for a place.   If data is requested for an organization, then all the places under the organization will be rolled up.
     *
     * @param placeId The place to retrieve data for
     */
    getEuiChartDataWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/energyUseIntensity'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getEuiChartData.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves one place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceActualMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/actual/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceActualYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/actual/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Return the total cost and cost for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedCostComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/place/${placeId}/digest/calendarized/cost/comparison'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedCostComparison.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        if (comparisonYearsAgo !== undefined) {
            queryParameters = queryParameters.set('comparisonYearsAgo', comparisonYearsAgo);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Return the total ghg and ghg for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceCalendarizedGhgComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/place/${placeId}/digest/calendarized/ghg/comparison'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedGhgComparison.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        if (comparisonYearsAgo !== undefined) {
            queryParameters = queryParameters.set('comparisonYearsAgo', comparisonYearsAgo);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceCalendarizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/calendarized/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for calendarized and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/calendarized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceCalendarizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/calendarized/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceCalendarizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/calendarized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all Place Groups for a particular place by placeId
     *
     * @param placeId The place identifier for which group values are being retrieved
     */
    getPlaceGroupsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/group'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceGroups.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     */
    getPlaceNomalizedMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/normalized/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceNomalizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes use on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for normalized and savings, and 24 or 26 (if 13 accounting periods) for normalized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNomalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/normalized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Return the total use and use for each commodity under a place for comparison  Example calculating the current and previous ranges:   Today is 2022-10-06  chartMonthsToExclude &#x3D; 2, numMonths &#x3D; 6, comparisonYearsAgo &#x3D; 3  CurrentPeriodRange is 202203 - 202208 and PreviousPeriodRange is 201903 - 201908
     *
     * @param placeId Id of the place to lookup
     * @param chartMonthsToExclude Optional, the number of months to exclude from intensity data, 0 includes all months including the current one. Defaults to the system setting otherwise 0.
     * @param numMonths Optional, the number of months of intensity data to include, the end month is respective of chartMonthsToExclude. Defaults to 12.
     * @param comparisonYearsAgo The comparisonYearsAgo is the number of years to go back to do the comparison. Defaults to 1.
     */
    getPlaceNormalizedUseComparisonWithHttpInfo(placeId, chartMonthsToExclude, numMonths, comparisonYearsAgo, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/place/${placeId}/digest/normalized/use/comparison'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceNormalizedUseComparison.');
        }
        if (chartMonthsToExclude !== undefined) {
            queryParameters = queryParameters.set('chartMonthsToExclude', chartMonthsToExclude);
        }
        if (numMonths !== undefined) {
            queryParameters = queryParameters.set('numMonths', numMonths);
        }
        if (comparisonYearsAgo !== undefined) {
            queryParameters = queryParameters.set('comparisonYearsAgo', comparisonYearsAgo);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getPlaceNormalizedYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/normalized/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceNormalizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by building/organization for a given number of years- Result include use on an yearly basis. It also includes target comparison data and commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/normalized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes target comparison data and commodity level break up.
     *
     * @param placeId The place to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getPlaceSavingsMonthlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/savings/monthly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSavingsMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings data by building/organization for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/savings/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     *
     *
     * @param placeId
     * @param numberOfYears
     */
    getPlaceSavingsYearlyWithHttpInfo(placeId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/digest/savings/yearly'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSavingsYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data by building/organization for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes a commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlaceSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/digest/savings/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves a place size record for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     * @param placeSizeId The identifier for the place size being retrieved
     */
    getPlaceSizeWithHttpInfo(placeId, placeSizeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size/${placeSizeId}'
            .replace('${' + 'placeId' + '}', String(placeId))
            .replace('${' + 'placeSizeId' + '}', String(placeSizeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSize.');
        }
        // verify required parameter 'placeSizeId' is not null or undefined
        if (placeSizeId === null || placeSizeId === undefined) {
            throw new Error('Required parameter placeSizeId was null or undefined when calling getPlaceSize.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all place size records for a particular place
     *
     * @param placeId The identifier for the place being retrieved
     */
    getPlaceSizesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/size'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceSizes.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular place
     *
     * @param placeId The place identifier for which user defined field / custom field values are being retrieved
     */
    getPlaceUdfsWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/${placeId}/udf'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getPlaceUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all places
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getPlacesUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/place/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get list of Portfolio Manager properties
     *
     * @param includeOnlyUnlinked Include only unlinked properties
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertiesWithHttpInfo(includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/pmProperty';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (includeOnlyUnlinked !== undefined) {
            queryParameters = queryParameters.set('includeOnlyUnlinked', includeOnlyUnlinked);
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get a Portfolio Manager property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmPropertyId and PmPropertyName from Portfolio Manager.              PmPropertyUseType, PmFloorArea, PmFloorAreaUnits will be null.
     */
    getPortfolioManagerPropertyWithHttpInfo(pmPropertyId, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/pmProperty/${pmPropertyId}'
            .replace('${' + 'pmPropertyId' + '}', String(pmPropertyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'pmPropertyId' is not null or undefined
        if (pmPropertyId === null || pmPropertyId === undefined) {
            throw new Error('Required parameter pmPropertyId was null or undefined when calling getPortfolioManagerProperty.');
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Get list of Portfolio Manager meters for a property
     *
     * @param pmPropertyId Portfolio Manager property identifier
     * @param includeOnlyUnlinked Include only unlinked meters
     * @param verbose true by default.                When set to false the API will perform faster but will only retrieve PmMeterId and PmMeterName from Portfolio Manager.              PmCommodityCode and PmUnitCode will be null.
     */
    getPortfolioManagerPropertyMetersWithHttpInfo(pmPropertyId, includeOnlyUnlinked, verbose, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/pmProperty/${pmPropertyId}/pmMeter'
            .replace('${' + 'pmPropertyId' + '}', String(pmPropertyId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'pmPropertyId' is not null or undefined
        if (pmPropertyId === null || pmPropertyId === undefined) {
            throw new Error('Required parameter pmPropertyId was null or undefined when calling getPortfolioManagerPropertyMeters.');
        }
        if (includeOnlyUnlinked !== undefined) {
            queryParameters = queryParameters.set('includeOnlyUnlinked', includeOnlyUnlinked);
        }
        if (verbose !== undefined) {
            queryParameters = queryParameters.set('verbose', verbose);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves the specified schedule
     *
     * @param scheduleId The schedule identifier
     */
    getScheduleWithHttpInfo(scheduleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule/${scheduleId}'
            .replace('${' + 'scheduleId' + '}', String(scheduleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'scheduleId' is not null or undefined
        if (scheduleId === null || scheduleId === undefined) {
            throw new Error('Required parameter scheduleId was null or undefined when calling getSchedule.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Retrieves all schedules
     *
     */
    getSchedulesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/schedule';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Returns the data point ancestry information, useful for populating a tree of spaces
     *
     * @param dataPointId Data point Id
     */
    hierarchicalAncestryDataPointsWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/hierarchy/ancestry/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling hierarchicalAncestryDataPoints.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Returns meter ancestry information, useful for populating a tree of places
     *
     * @param meterId Meter ID
     */
    hierarchicalAncestryMetersWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling hierarchicalAncestryMeters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Returns place ancestry information, useful for populating a tree of places
     *
     * @param placeId Place ID
     */
    hierarchicalAncestryPlacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalAncestryPlaces.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Returns the space ancestry information, useful for populating a tree of spaces
     *
     * @param placeId Place Id
     */
    hierarchicalAncestrySpacesWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/hierarchy/ancestry/space/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalAncestrySpaces.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Returns place descendant information, useful for expanding a place node
     *
     * @param placeId Place ID
     */
    hierarchicalPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/place/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    /**
     * Returns the space descendant information, useful for expanding a space node
     *
     * @param placeId Place Id
     */
    hierarchicalSpaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202405/hierarchy/space/${placeId}'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling hierarchicalSpace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$11.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$10 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the chargeback task
     */
    deleteChargebackTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills created by a chargeback workflow step  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    deleteChargebackWorkflowSteps(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the chargeback task
     */
    voidChargebackTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Void all bills created by a chargeback workflow step for a particular billing period  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    voidChargebackWorkflowSteps(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.voidChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param taskId Identifier for the chargeback task
     */
    deleteChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}/delete'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling deleteChargebackTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$10.Post, path, requestOptions);
    }
    /**
     * Delete all bills created by a chargeback workflow step  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be deleted
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    deleteChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/delete'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling deleteChargebackWorkflowSteps.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$10.Post, path, requestOptions);
    }
    /**
     * Void all bills created by the chargeback task  If this is a split task, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param taskId Identifier for the chargeback task
     */
    voidChargebackTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}/void'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling voidChargebackTask.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$10.Post, path, requestOptions);
    }
    /**
     * Void all bills created by a chargeback workflow step for a particular billing period  If this workflow step was run multiple times, all bills created across all runs for the billing period will be voided  If this is a split step, any source bills will be reset to has not been split  If any bills have already been exported they will still be voided
     *
     * @param chargebackWorkflowStepId Chargeback Workflow Step ID
     * @param billingPeriod Billing period to undo
     */
    voidChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/void'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling voidChargebackWorkflowSteps.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$10.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$$ = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStep(chargebackWorkflowStepId, billingPeriod, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.assignVersionsToStepWithHttpInfo(chargebackWorkflowStepId, billingPeriod, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflow(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createChargebackWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflow(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflow(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editChargebackWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItems(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageAccountLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetails(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistory(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageBillSplitVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCost(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculateBillCostWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemand(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUse(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculateBillUseWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistory(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItems(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manageMeterLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Assign a list of bill split or calculate bill versions to a chargeback workflow step of the same type
     *
     * @param chargebackWorkflowStepId ID of the chargeback workflow step to which the versions will be assigned
     * @param billingPeriod The billing period to validate that the provided versions are effective
     * @param body The chargeback versions to assign to the provided chargeback workflow step
     */
    assignVersionsToStepWithHttpInfo(chargebackWorkflowStepId, billingPeriod, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/billingPeriod/${billingPeriod}/version'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId))
            .replace('${' + 'billingPeriod' + '}', String(billingPeriod));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling assignVersionsToStep.');
        }
        // verify required parameter 'billingPeriod' is not null or undefined
        if (billingPeriod === null || billingPeriod === undefined) {
            throw new Error('Required parameter billingPeriod was null or undefined when calling assignVersionsToStep.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Create a chargeback workflow
     *
     * @param body Definition for chargeback workflow
     */
    createChargebackWorkflowWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Post, path, requestOptions);
    }
    /**
     * Delete a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    deleteChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowId}'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling deleteChargebackWorkflow.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Delete, path, requestOptions);
    }
    /**
     * Edit a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     * @param body Definition for chargeback workflow
     */
    editChargebackWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowId}'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling editChargebackWorkflow.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill account line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the account line items.
     */
    manageAccountLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/accountLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageAccountLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageAccountLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageAccountLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage details for a bill split distribution
     *
     * @param accountId ID of the master account
     * @param meterId ID of the master meter
     * @param versionId ID of the version to update bill split details
     * @param body Definition of details for bill split
     */
    manageBillSplitDetailsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit/${versionId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageBillSplitDetails.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageBillSplitDetails.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageBillSplitDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage a bill split&#39;s version history  All bill split versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a bill split version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account whose bill split versions will be updated
     * @param meterId ID of the meter whose bill split versions will be updated
     * @param body List of bill split distribution versions to add or edit
     */
    manageBillSplitVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/billSplit'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageBillSplitVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageBillSplitVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill&#39;s cost  If cost does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  Since cost is required for the calculated bill distribution to work.  One option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its cost
     */
    manageCalculateBillCostWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/cost'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculateBillCost.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculateBillCost.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageCalculateBillCost.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill&#39;s demand  If demand does not exist on the distribution it will be added  If one exists it will be saved as the option sent in  If the dto sends null for both (channel and fixed), then demand will get cleared
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its demand
     */
    manageCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/demand'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculateBillDemand.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculateBillDemand.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageCalculateBillDemand.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill&#39;s use  * If use does not exist on the distribution it will be added  * If use already exists it will be saved as the option sent in and any existing inputs will be deleted  * Since use is required for the calculated bill distribution to work, one option is always required and cannot be deleted
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of how the meter will calculate its use
     */
    manageCalculateBillUseWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/use'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculateBillUse.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculateBillUse.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageCalculateBillUse.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage a calculated bill&#39;s version history  All calculated bill versions to save on this account and meter relationship should be passed  If versionId is passed, this version will be updated to the request body values  If copyVersionId is passed, a new version will be created and all instructions and inputs on the copyVersionId will be copied  If versionId and copyVersionId are null a new version will be created  Versions cannot overlap  If a calculated bill version currently exists in the database, but is not passed in it will be deleted  Only versions that are not currently associated with any bills can be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param body List of calculated bill distribution versions to add or edit
     */
    manageCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageCalculatedBillVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageCalculatedBillVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    /**
     * Manage calculated bill meter line items  The order of items in the list defines the calculation order  All line items to save should be passed  If a line currently exists and is not passed in it will be deleted  If any part of the create, update, or delete process fails, the entire process is rolled back
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     * @param body Definition of the meter line items
     */
    manageMeterLineItemsWithHttpInfo(accountId, meterId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/meterLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling manageMeterLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manageMeterLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling manageMeterLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$$.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$_ = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersions(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getBillSplitVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersions(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflow(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigest(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowDigestWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStep(chargebackWorkflowStepId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowStepWithHttpInfo(chargebackWorkflowStepId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowSteps(chargebackWorkflowType, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowType, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflows(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getChargebackWorkflowsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of customers.
     *
     * @param filter
     */
    getCustomers(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCustomersWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of bill split versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getBillSplitVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billSplit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions which match the provided filter conditions
     *
     * @param filter API filter string containing conditions
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCalculatedBillVersionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/calculatedBill';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get a chargeback workflow
     *
     * @param chargebackWorkflowId Chargeback workflow id
     */
    getChargebackWorkflowWithHttpInfo(chargebackWorkflowId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowId}'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling getChargebackWorkflow.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get a digest of all bills by meter for all meters involved in a chargeback workflow step for a given billing period.
     *
     * @param chargebackWorkflowStepId The id of the chargeback workflow step.
     * @param billingPeriod The billing period of the digest.
     */
    getChargebackWorkflowDigestWithHttpInfo(chargebackWorkflowStepId, billingPeriod, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow/${chargebackWorkflowStepId}/digest'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling getChargebackWorkflowDigest.');
        }
        if (billingPeriod !== undefined) {
            queryParameters = queryParameters.set('billingPeriod', billingPeriod);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get chargeback workflow settings
     *
     */
    getChargebackWorkflowSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/workflow/chargeback';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get a single chargeback workflow step
     *
     * @param chargebackWorkflowStepId Workflow step ID
     */
    getChargebackWorkflowStepWithHttpInfo(chargebackWorkflowStepId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling getChargebackWorkflowStep.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get a list of chargeback workflow steps
     *
     * @param chargebackWorkflowType Pass either \&quot;split\&quot; or \&quot;calculation\&quot; to filter workflow steps
     */
    getChargebackWorkflowStepsWithHttpInfo(chargebackWorkflowType, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (chargebackWorkflowType !== undefined) {
            queryParameters = queryParameters.set('chargebackWorkflowType', chargebackWorkflowType);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Get a list of chargeback workflows
     *
     */
    getChargebackWorkflowsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflow';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of customers.
     *
     * @param filter
     */
    getCustomersWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/customer';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$_.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$Z = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplit(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionSplitWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeBillSplitProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeCalculateBillProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregations(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeProcessorAggregationsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflow(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeProcessorByWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStep(chargebackWorkflowStepId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeProcessorByWorkflowStepWithHttpInfo(chargebackWorkflowStepId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.splitBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTask(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateChargebackTaskWithHttpInfo(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run the bill split processor on the given list of bills.  Optional note can be provided.  Optional batch settings can be provided that will allow custom batchcode and bill headers for the destination bills
     *
     * @param body
     */
    billActionSplitWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/split';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Process one or more Bill Split distributions for a specific billing period
     *
     * @param body
     */
    executeBillSplitProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/billSplit/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Process one or more Calculated Bill distributions for a specific billing period
     *
     * @param body
     */
    executeCalculateBillProcessorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/calculatedBill/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Process one or more Calculated Bill aggregations within a billing period range ending with the specified billing period.  If billing period is not supplied, the current period will be assumed.
     *
     * @param body
     */
    executeProcessorAggregationsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/aggregations/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Process distributions assigned to a chargeback workflow for a specific billing period.  If settings are not provided, the last month will be processed.
     *
     * @param chargebackWorkflowId The chargeback workflow id
     * @param body The processor settings
     */
    executeProcessorByWorkflowWithHttpInfo(chargebackWorkflowId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/chargebackWorkflow/${chargebackWorkflowId}/exec'
            .replace('${' + 'chargebackWorkflowId' + '}', String(chargebackWorkflowId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowId' is not null or undefined
        if (chargebackWorkflowId === null || chargebackWorkflowId === undefined) {
            throw new Error('Required parameter chargebackWorkflowId was null or undefined when calling executeProcessorByWorkflow.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Process distributions assigned to a chargeback workflow step for a specific billing period
     *
     * @param chargebackWorkflowStepId The chargeback workflow step id.
     * @param body The other processor settings.
     */
    executeProcessorByWorkflowStepWithHttpInfo(chargebackWorkflowStepId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackWorkflowStep/${chargebackWorkflowStepId}/exec'
            .replace('${' + 'chargebackWorkflowStepId' + '}', String(chargebackWorkflowStepId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'chargebackWorkflowStepId' is not null or undefined
        if (chargebackWorkflowStepId === null || chargebackWorkflowStepId === undefined) {
            throw new Error('Required parameter chargebackWorkflowStepId was null or undefined when calling executeProcessorByWorkflowStep.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Split all bills eligible to be split in a bill list
     *
     * @param listId The list identifier
     * @param body Optional note and batch settings can be provided. Batch Settings will allow custom batchcode and bill headers for the destination bills
     */
    splitBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/split'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling splitBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Post, path, requestOptions);
    }
    /**
     * Update a chargeback task&#39;s comment
     *
     * @param taskId Identifier for the chargeback task to update
     * @param body Data representing the comment
     */
    updateChargebackTaskWithHttpInfo(taskId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/chargebackTask/${taskId}'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling updateChargebackTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Z.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$Y = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a collection
     *
     * @param body Data representing the collection being created
     */
    createCollection(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCollectionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a collection
     *
     * @param body Data representing the collection being created
     */
    createCollectionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Y.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$X = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a collection
     *
     * @param collectionId The identifier for the collection being deleted
     */
    deleteCollection(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a collection
     *
     * @param collectionId The identifier for the collection being deleted
     */
    deleteCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling deleteCollection.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$X.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$W = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits a collection
     *
     * @param collectionId The identifier for the collection being edited
     * @param body Data representing the collection being edited
     */
    editCollection(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCollectionWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a collection
     *
     * @param collectionId The id of the collection
     * @param body The list of udf values being edited
     */
    editCollectionCustomFields(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCollectionCustomFieldsWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveCollections(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveCollectionsWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a collection
     *
     * @param collectionId The identifier for the collection being edited
     * @param body Data representing the collection being edited
     */
    editCollectionWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling editCollection.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$W.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a collection
     *
     * @param collectionId The id of the collection
     * @param body The list of udf values being edited
     */
    editCollectionCustomFieldsWithHttpInfo(collectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/collection/${collectionId}/udf'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling editCollectionCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$W.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveCollectionsWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202309/parentCollection/${parentCollectionId}/collection'
            .replace('${' + 'parentCollectionId' + '}', String(parentCollectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCollectionId' is not null or undefined
        if (parentCollectionId === null || parentCollectionId === undefined) {
            throw new Error('Required parameter parentCollectionId was null or undefined when calling moveCollections.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$W.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$V = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFields(collectionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadCollectionCustomFieldsWithHttpInfo(collectionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollection(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFields(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionCustomFieldsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollections(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCollectionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollections(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryCollectionsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSources(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryEmissionSourcesWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollection(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a collection custom field
     *
     * @param collectionId The id of the collection
     * @param udfId The id of the custom field
     */
    downloadCollectionCustomFieldsWithHttpInfo(collectionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/collection/${collectionId}/udf/${udfId}/download'
            .replace('${' + 'collectionId' + '}', String(collectionId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling downloadCollectionCustomFields.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadCollectionCustomFields.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    /**
     * Retrieves the collection by ID
     *
     * @param collectionId The identifier for the collection being retrieved
     */
    getCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling getCollection.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    /**
     * Get custom field values for a collection
     *
     * @param collectionId The id of the collection
     */
    getCollectionCustomFieldsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/collection/${collectionId}/udf'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling getCollectionCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    /**
     * Retrieves all the collections
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCollectionsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/collection';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    /**
     * Returns collection ancestry information, useful for populating a tree of collections
     *
     * @param collectionId Collection ID
     */
    hierarchicalAncestryCollectionsWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/hierarchy/ancestry/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling hierarchicalAncestryCollections.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    /**
     * Returns emission source ancestry information, useful for populating a tree of collections
     *
     * @param emissionSourceId Emission Source ID
     */
    hierarchicalAncestryEmissionSourcesWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/hierarchy/ancestry/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling hierarchicalAncestryEmissionSources.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    /**
     * Returns collection descendant information, useful for expanding a collection node
     *
     * @param collectionId Collection ID
     */
    hierarchicalCollectionWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/hierarchy/collection/${collectionId}'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling hierarchicalCollection.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$V.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$U = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a Cost Center
     *
     * @param body Data representing the cost center being created
     */
    createCostCenter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCostCenterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a Cost Center
     *
     * @param body Data representing the cost center being created
     */
    createCostCenterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$U.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$T = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a cost center
     *
     * @param costCenterId The identifier for the cost center being deleted
     */
    deleteCostCenter(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a cost center
     *
     * @param costCenterId The identifier for the cost center being deleted
     */
    deleteCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling deleteCostCenter.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$T.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$S = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits a cost center
     *
     * @param costCenterId The identifier for the cost center being edited
     * @param body Data representing the cost center being edited
     */
    editCostCenter(costCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCostCenterWithHttpInfo(costCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of costCenters to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of costCenterIds to move under the parentCostCenterId
     */
    moveCostCenter(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveCostCenterWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a cost center
     *
     * @param costCenterId The identifier for the cost center being edited
     * @param body Data representing the cost center being edited
     */
    editCostCenterWithHttpInfo(costCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling editCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$S.Put, path, requestOptions);
    }
    /**
     * Move list of costCenters to be under parentCostCenterId
     *
     * @param parentCostCenterId The identifier for the new parent costCenter
     * @param body List of costCenterIds to move under the parentCostCenterId
     */
    moveCostCenterWithHttpInfo(parentCostCenterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentCostCenter/${parentCostCenterId}/costCenter'
            .replace('${' + 'parentCostCenterId' + '}', String(parentCostCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCostCenterId' is not null or undefined
        if (parentCostCenterId === null || parentCostCenterId === undefined) {
            throw new Error('Required parameter parentCostCenterId was null or undefined when calling moveCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$S.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$R = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCenters(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.availablePlacesForTopmostCostCentersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenter(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthly(costCenterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualMonthlyWithHttpInfo(costCenterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearly(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualYearlyWithHttpInfo(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCenterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostCentersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccounts(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryAccountsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCenters(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalAncestryCostCentersWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenter(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.hierarchicalCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * For a list of topmost cost centers, get associated topmost places.
     *
     * @param body List of costCenterIds to get associated topmost places.
     */
    availablePlacesForTopmostCostCentersWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/costCenter/availablePlaces';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Post, path, requestOptions);
    }
    /**
     * Retrieves the cost center by ID
     *
     * @param costCenterId The identifier for the cost center being retrieved
     */
    getCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     */
    getCostCenterActualMonthlyWithHttpInfo(costCenterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/${costCenterId}/digest/actual/monthly'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenterActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on a monthly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param costCenterId The costCenter to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyWithHttpInfo(costCenterId, numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/${costCenterId}/digest/actual/yearly'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling getCostCenterActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by costCenter for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCenterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costCenter/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Retrieves all the cost centers
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getCostCentersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/costcenter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Returns account ancestry information, useful for populating a tree of costCenters
     *
     * @param accountId Account ID
     */
    hierarchicalAncestryAccountsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/account/${accountId}'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling hierarchicalAncestryAccounts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Returns cost center ancestry information, useful for populating a tree of cost centers
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalAncestryCostCentersWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/ancestry/costCenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling hierarchicalAncestryCostCenters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    /**
     * Returns costCenter descendant information, useful for expanding a costCenter node
     *
     * @param costCenterId CostCenter ID
     */
    hierarchicalCostCenterWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/hierarchy/costCenter/${costCenterId}'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling hierarchicalCostCenter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$R.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$Q = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Add a widget to a dashboard  To add widgets to a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    addWidget(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.addWidgetWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Copy a dashboard  To copy a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Request object
     */
    copyDashboard(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.copyDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a dashboard
     *
     * @param body
     */
    createDashboard(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createDashboardWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the visibility of a dashboard for the current user  This must be a dashboard you can see  Which means you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Set Visibility
     */
    dashboardActionVisible(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.dashboardActionVisibleWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a dashboard  To delete a dashboard you must have created it  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Specific dashboard
     */
    deleteDashboard(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteDashboardWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a dashboard  To edit a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId
     * @param body
     */
    editDashboard(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Reorder, edit, and delete specific widgets on a dashboard.  To edit dashboard widgets you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    editDashboardWidgets(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardWidgetsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Applies display settings and filters to a map dashboard. These settings are specific to map dashboards, and cannot be applied to standard dashboards.  To apply these settings, You must also have either:  Created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier of the dashboard to apply these settings to
     * @param body Object containing the settings to be applied.
     */
    editMapDashboardSettings(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMapDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets the current display settings and filters for a specific map dashboard. Cannot be used to retreive settings for a standard dashboard.
     *
     * @param dashboardId The identifier of the dashboard to get the settings of
     */
    getMapDashboardSettings(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMapDashboardSettingsWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Add a widget to a dashboard  To add widgets to a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    addWidgetWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/widget'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling addWidget.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Post, path, requestOptions);
    }
    /**
     * Copy a dashboard  To copy a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Request object
     */
    copyDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/copy'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling copyDashboard.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Post, path, requestOptions);
    }
    /**
     * Creates a dashboard
     *
     * @param body
     */
    createDashboardWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Post, path, requestOptions);
    }
    /**
     * Update the visibility of a dashboard for the current user  This must be a dashboard you can see  Which means you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps View permission and the dashboard is shared with you
     *
     * @param dashboardId Specific dashboard
     * @param body Set Visibility
     */
    dashboardActionVisibleWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}/visible'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling dashboardActionVisible.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Put, path, requestOptions);
    }
    /**
     * Delete a dashboard  To delete a dashboard you must have created it  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public
     *
     * @param dashboardId Specific dashboard
     */
    deleteDashboardWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling deleteDashboard.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Delete, path, requestOptions);
    }
    /**
     * Edit a dashboard  To edit a dashboard you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId
     * @param body
     */
    editDashboardWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/dashboard/${dashboardId}'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboard.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Put, path, requestOptions);
    }
    /**
     * Reorder, edit, and delete specific widgets on a dashboard.  To edit dashboard widgets you must have created the dashboard  or have DashboardAdministrator Manage permission and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId dashboard
     * @param body Request object
     */
    editDashboardWidgetsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/widget'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboardWidgets.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Put, path, requestOptions);
    }
    /**
     * Applies display settings and filters to a map dashboard. These settings are specific to map dashboards, and cannot be applied to standard dashboards.  To apply these settings, You must also have either:  Created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier of the dashboard to apply these settings to
     * @param body Object containing the settings to be applied.
     */
    editMapDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/mapsetting'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editMapDashboardSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Put, path, requestOptions);
    }
    /**
     * Gets the current display settings and filters for a specific map dashboard. Cannot be used to retreive settings for a standard dashboard.
     *
     * @param dashboardId The identifier of the dashboard to get the settings of
     */
    getMapDashboardSettingsWithHttpInfo(dashboardId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/mapsetting'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling getMapDashboardSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$Q.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$P = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a Report Distribution
     *
     * @param body Data representing the report distribution being created
     */
    createReportDistribution(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReportDistributionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to delete
     */
    deleteReportDistribution(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete report distribution logs older than the number of days provided only if  the number of logs per distribution is in excess of 100.  100 latest logs per distribution will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteReportDistributionLogsOlderThan(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportDistributionLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to edit
     * @param body Data representing the report distribution being edited
     */
    editReportDistribution(reportDistributionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportDistributionWithHttpInfo(reportDistributionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run a report distribution and send the report out immediately  This does not affect the current distribution schedule
     *
     * @param reportDistributionId Id of the report distribution to run
     * @param overrideUserIds List of systemuserIds to send the distribution to. If not provided the currently configured recipients will receive the report.  If this is provided it is used in place of the currently configured recipients
     */
    executeReportDistribution(reportDistributionId, overrideUserIds, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.executeReportDistributionWithHttpInfo(reportDistributionId, overrideUserIds, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistribution(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a Report Distribution Filters
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionFilters(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionFiltersWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the details for a report distribution log
     *
     * @param reportDistributionLogId Id of the report distribution log to get the details for
     */
    getReportDistributionLogDetails(reportDistributionLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionLogDetailsWithHttpInfo(reportDistributionLogId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of report distribution logs
     *
     * @param includeInProgress Option to include in progress distributions.  False by default
     */
    getReportDistributionLogs(includeInProgress, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionLogsWithHttpInfo(includeInProgress, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all Report Distributions
     *
     * @param filter
     */
    getReportDistributions(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportDistributionsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a Report Distribution
     *
     * @param body Data representing the report distribution being created
     */
    createReportDistributionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Post, path, requestOptions);
    }
    /**
     * Deletes a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to delete
     */
    deleteReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling deleteReportDistribution.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Delete, path, requestOptions);
    }
    /**
     * Delete report distribution logs older than the number of days provided only if  the number of logs per distribution is in excess of 100.  100 latest logs per distribution will always be maintained
     *
     * @param olderThanDays Defaults to 3
     */
    deleteReportDistributionLogsOlderThanWithHttpInfo(olderThanDays, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/log';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (olderThanDays !== undefined) {
            queryParameters = queryParameters.set('olderThanDays', olderThanDays);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Delete, path, requestOptions);
    }
    /**
     * Edit a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to edit
     * @param body Data representing the report distribution being edited
     */
    editReportDistributionWithHttpInfo(reportDistributionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling editReportDistribution.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Put, path, requestOptions);
    }
    /**
     * Run a report distribution and send the report out immediately  This does not affect the current distribution schedule
     *
     * @param reportDistributionId Id of the report distribution to run
     * @param overrideUserIds List of systemuserIds to send the distribution to. If not provided the currently configured recipients will receive the report.  If this is provided it is used in place of the currently configured recipients
     */
    executeReportDistributionWithHttpInfo(reportDistributionId, overrideUserIds, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}/exec'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling executeReportDistribution.');
        }
        if (overrideUserIds) {
            queryParameters = queryParameters.set('overrideUserIds', overrideUserIds.join(COLLECTION_FORMATS['csv']));
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Post, path, requestOptions);
    }
    /**
     * Get a Report Distribution
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling getReportDistribution.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Get, path, requestOptions);
    }
    /**
     * Get a Report Distribution Filters
     *
     * @param reportDistributionId Id of the report distribution to get
     */
    getReportDistributionFiltersWithHttpInfo(reportDistributionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/${reportDistributionId}/filter'
            .replace('${' + 'reportDistributionId' + '}', String(reportDistributionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionId' is not null or undefined
        if (reportDistributionId === null || reportDistributionId === undefined) {
            throw new Error('Required parameter reportDistributionId was null or undefined when calling getReportDistributionFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Get, path, requestOptions);
    }
    /**
     * Get the details for a report distribution log
     *
     * @param reportDistributionLogId Id of the report distribution log to get the details for
     */
    getReportDistributionLogDetailsWithHttpInfo(reportDistributionLogId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/log/${reportDistributionLogId}/detail'
            .replace('${' + 'reportDistributionLogId' + '}', String(reportDistributionLogId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportDistributionLogId' is not null or undefined
        if (reportDistributionLogId === null || reportDistributionLogId === undefined) {
            throw new Error('Required parameter reportDistributionLogId was null or undefined when calling getReportDistributionLogDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Get, path, requestOptions);
    }
    /**
     * Get a list of report distribution logs
     *
     * @param includeInProgress Option to include in progress distributions.  False by default
     */
    getReportDistributionLogsWithHttpInfo(includeInProgress, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution/log';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (includeInProgress !== undefined) {
            queryParameters = queryParameters.set('includeInProgress', includeInProgress);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Get, path, requestOptions);
    }
    /**
     * Get all Report Distributions
     *
     * @param filter
     */
    getReportDistributionsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202106/reportdistribution';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$P.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$O = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edit settings for ENERGY STAR submissions
     *
     * @param body ENERGY STAR settings
     */
    editEnergyStarSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyStarSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the connection status for a Portfolio Manager account and database
     *
     * @param pmUserName User name used to log in to Portfolio Manager
     */
    getPMConnectionStatus(pmUserName, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPMConnectionStatusWithHttpInfo(pmUserName, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unlink owner from portfolio manager account
     *
     * @param deleteData If true, delete EnergyStar metrics and score. False by default
     */
    unlinkOwnerFromPortfolioManager(deleteData, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unlinkOwnerFromPortfolioManagerWithHttpInfo(deleteData, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit settings for ENERGY STAR submissions
     *
     * @param body ENERGY STAR settings
     */
    editEnergyStarSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/setting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$O.Put, path, requestOptions);
    }
    /**
     * Get the connection status for a Portfolio Manager account and database
     *
     * @param pmUserName User name used to log in to Portfolio Manager
     */
    getPMConnectionStatusWithHttpInfo(pmUserName, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/connectionstatus';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (pmUserName !== undefined) {
            queryParameters = queryParameters.set('pmUserName', pmUserName);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$O.Get, path, requestOptions);
    }
    /**
     * Unlink owner from portfolio manager account
     *
     * @param deleteData If true, delete EnergyStar metrics and score. False by default
     */
    unlinkOwnerFromPortfolioManagerWithHttpInfo(deleteData, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/unlink';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (deleteData !== undefined) {
            queryParameters = queryParameters.set('deleteData', deleteData);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$O.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$N = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Automatically submit billing data to ENERGY STAR  By default calendarized bill data for a 13-month period (excludes current and last month) in the \&quot;Ready\&quot; state for all buildings setup to automatically submit to ENERGY STAR will be submitted  If 13 months is not preferred, set up the owner&#39;s systemdata key called \&quot;EnergyStarAutoSubmitNumOfMonths\&quot; with an integer value representing the preferred number of months   For example - Today is 25th Nov 2021 - all calendarized data for Sep 2020 through Sep 2021 will be submitted  The buildings submitted will be within the user&#39;s topmost place  No data prior to the earliest period to submit set up in ENERGY STAR settings will ever be submitted
     *
     */
    autoSubmitToEnergyStar(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.autoSubmitToEnergyStarWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Initiate (create) a submission of place data to ENERGY STAR
     *
     * @param body
     */
    createEnergyStarSubmission(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEnergyStarSubmissionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the submission status for places by submission period.   Places that do not match the filter criteria will not be returned.    NOTE: Deleting/voiding bills that have already been submitted will not cause submission status to change from \&quot;submitted\&quot;.
     * Returned submission status:      Submitted  - submission has been made for this place and submission period and no bills have been created or modified since the last submission      No Data    - no submission has been made for this place and submission period and current submission period has no billing data      Incomplete - no submission has been made for this place and submission period and current billing data is incomplete (some meters may not have data or some days in submission period may not have data)      Ready      - no submission has been made for this place and submission period and current billing data is complete (every meter has data for every day of this period), or submission has been made but billing data has been added or modified since the last submission
     * @param submissionBeginPeriod The beginning submission period to select
     * @param submissionEndPeriod The ending submission period to select; set equal to beginning submission period get one period
     * @param filter API filter string containing conditions
     */
    getEnergyStarSubmissionStatusList(submissionBeginPeriod, submissionEndPeriod, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarSubmissionStatusListWithHttpInfo(submissionBeginPeriod, submissionEndPeriod, filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an ENERGY STAR task with its details
     *
     * @param energyStarTaskId
     */
    getEnergyStarTask(energyStarTaskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarTaskWithHttpInfo(energyStarTaskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEnergyStarTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update ENERGY STAR metrics for the places matching the request criteria.
     *
     * @param body Periods and list of place identifiers for which to update metrics
     */
    updateEnergyStarMetrics(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateEnergyStarMetricsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Automatically submit billing data to ENERGY STAR  By default calendarized bill data for a 13-month period (excludes current and last month) in the \&quot;Ready\&quot; state for all buildings setup to automatically submit to ENERGY STAR will be submitted  If 13 months is not preferred, set up the owner&#39;s systemdata key called \&quot;EnergyStarAutoSubmitNumOfMonths\&quot; with an integer value representing the preferred number of months   For example - Today is 25th Nov 2021 - all calendarized data for Sep 2020 through Sep 2021 will be submitted  The buildings submitted will be within the user&#39;s topmost place  No data prior to the earliest period to submit set up in ENERGY STAR settings will ever be submitted
     *
     */
    autoSubmitToEnergyStarWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202110/energyStar/autosubmit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$N.Post, path, requestOptions);
    }
    /**
     * Initiate (create) a submission of place data to ENERGY STAR
     *
     * @param body
     */
    createEnergyStarSubmissionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/submit';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$N.Post, path, requestOptions);
    }
    /**
     * Get the submission status for places by submission period.   Places that do not match the filter criteria will not be returned.    NOTE: Deleting/voiding bills that have already been submitted will not cause submission status to change from \&quot;submitted\&quot;.
     * Returned submission status:      Submitted  - submission has been made for this place and submission period and no bills have been created or modified since the last submission      No Data    - no submission has been made for this place and submission period and current submission period has no billing data      Incomplete - no submission has been made for this place and submission period and current billing data is incomplete (some meters may not have data or some days in submission period may not have data)      Ready      - no submission has been made for this place and submission period and current billing data is complete (every meter has data for every day of this period), or submission has been made but billing data has been added or modified since the last submission
     * @param submissionBeginPeriod The beginning submission period to select
     * @param submissionEndPeriod The ending submission period to select; set equal to beginning submission period get one period
     * @param filter API filter string containing conditions
     */
    getEnergyStarSubmissionStatusListWithHttpInfo(submissionBeginPeriod, submissionEndPeriod, filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/submissionStatus';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'submissionBeginPeriod' is not null or undefined
        if (submissionBeginPeriod === null || submissionBeginPeriod === undefined) {
            throw new Error('Required parameter submissionBeginPeriod was null or undefined when calling getEnergyStarSubmissionStatusList.');
        }
        // verify required parameter 'submissionEndPeriod' is not null or undefined
        if (submissionEndPeriod === null || submissionEndPeriod === undefined) {
            throw new Error('Required parameter submissionEndPeriod was null or undefined when calling getEnergyStarSubmissionStatusList.');
        }
        if (submissionBeginPeriod !== undefined) {
            queryParameters = queryParameters.set('submissionBeginPeriod', submissionBeginPeriod);
        }
        if (submissionEndPeriod !== undefined) {
            queryParameters = queryParameters.set('submissionEndPeriod', submissionEndPeriod);
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$N.Get, path, requestOptions);
    }
    /**
     * Get an ENERGY STAR task with its details
     *
     * @param energyStarTaskId
     */
    getEnergyStarTaskWithHttpInfo(energyStarTaskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/task/${energyStarTaskId}'
            .replace('${' + 'energyStarTaskId' + '}', String(energyStarTaskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyStarTaskId' is not null or undefined
        if (energyStarTaskId === null || energyStarTaskId === undefined) {
            throw new Error('Required parameter energyStarTaskId was null or undefined when calling getEnergyStarTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$N.Get, path, requestOptions);
    }
    /**
     * Get a list of ENERGY STAR tasks with their details
     *
     * @param filter Filters to apply
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEnergyStarTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$N.Get, path, requestOptions);
    }
    /**
     * Update ENERGY STAR metrics for the places matching the request criteria.
     *
     * @param body Periods and list of place identifiers for which to update metrics
     */
    updateEnergyStarMetricsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyStar/metrics';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$N.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$M = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an emissions source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSource(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionSourceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create emission sources for existing meters.
     *
     * @param body The ids of the meters for which to create emission sources
     */
    createEmissionSourceForMeter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionSourceForMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an emission source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithMultiFactors(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionSourceWithMultiFactorsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an emissions source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$M.Post, path, requestOptions);
    }
    /**
     * Create emission sources for existing meters.
     *
     * @param body The ids of the meters for which to create emission sources
     */
    createEmissionSourceForMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202502/meter/emissionsource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$M.Post, path, requestOptions);
    }
    /**
     * Creates an emission source
     *
     * @param body Data representing the emission source being created
     */
    createEmissionSourceWithMultiFactorsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$M.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$L = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being deleted
     * @param deleteRecords Should this cascade to delete any records associated with this emissions source
     */
    deleteEmissionSource(emissionSourceId, deleteRecords, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEmissionSourceWithHttpInfo(emissionSourceId, deleteRecords, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being deleted
     * @param deleteRecords Should this cascade to delete any records associated with this emissions source
     */
    deleteEmissionSourceWithHttpInfo(emissionSourceId, deleteRecords, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling deleteEmissionSource.');
        }
        if (deleteRecords !== undefined) {
            queryParameters = queryParameters.set('deleteRecords', deleteRecords);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$L.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$K = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSource(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a emissions source
     *
     * @param emissionSourceId The id of the emissions source
     * @param body The list of udf values being edited
     */
    editEmissionSourceCustomFields(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Assigns the specified scope category and factor pairings to the specified emission sources.  If one or more of the factors provided cannot be applied to the emission source, that emission source will be skipped.
     *
     * @param body
     */
    editEmissionSourceFactorCategoriesBulk(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an emission source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithMultiFactors(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit meter data in an Emission Source
     *
     * @param emissionSourceId The Emission Source identifier
     * @param body Meter data to assign to the Emission Source
     */
    editMeterLink(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterLinkWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveEmissionSources(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveEmissionSourcesWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Resets the scope category and factor pairings of the specified emission sources to their commodity default.  If no default exists for an emission source&#39;s commodity, that emission source will be skipped.
     *
     * @param body
     */
    resetEmissionSourceFactorCategoriesBulk(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.resetEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an emissions source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editEmissionSource.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a emissions source
     *
     * @param emissionSourceId The id of the emissions source
     * @param body The list of udf values being edited
     */
    editEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/${emissionSourceId}/udf'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editEmissionSourceCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    /**
     * Assigns the specified scope category and factor pairings to the specified emission sources.  If one or more of the factors provided cannot be applied to the emission source, that emission source will be skipped.
     *
     * @param body
     */
    editEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/factorCategory/update';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    /**
     * Edits an emission source
     *
     * @param emissionSourceId The identifier for the emission source being edited
     * @param body Data representing the emission source being edited
     */
    editEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editEmissionSourceWithMultiFactors.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    /**
     * Edit meter data in an Emission Source
     *
     * @param emissionSourceId The Emission Source identifier
     * @param body Meter data to assign to the Emission Source
     */
    editMeterLinkWithHttpInfo(emissionSourceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/emissionSource/${emissionSourceId}/meter'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling editMeterLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param parentCollectionId
     * @param body
     */
    moveEmissionSourcesWithHttpInfo(parentCollectionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202309/parentCollection/${parentCollectionId}/emissionSource'
            .replace('${' + 'parentCollectionId' + '}', String(parentCollectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentCollectionId' is not null or undefined
        if (parentCollectionId === null || parentCollectionId === undefined) {
            throw new Error('Required parameter parentCollectionId was null or undefined when calling moveEmissionSources.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    /**
     * Resets the scope category and factor pairings of the specified emission sources to their commodity default.  If no default exists for an emission source&#39;s commodity, that emission source will be skipped.
     *
     * @param body
     */
    resetEmissionSourceFactorCategoriesBulkWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/factorCategory/reset';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$K.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$J = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFields(emissionSourceId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSource(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourceWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFields(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactors(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSources(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourcesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionSourcesWithMultiFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a emissions source custom field
     *
     * @param emissionSourceId The id of the emissions source
     * @param udfId The id of the custom field
     */
    downloadEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/${emissionSourceId}/udf/${udfId}/download'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling downloadEmissionSourceCustomFields.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadEmissionSourceCustomFields.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$J.Get, path, requestOptions);
    }
    /**
     * Retrieves the emissions source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling getEmissionSource.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$J.Get, path, requestOptions);
    }
    /**
     * Get custom field values for an emissions source
     *
     * @param emissionSourceId The id of the emissions source
     */
    getEmissionSourceCustomFieldsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/emissionSource/${emissionSourceId}/udf'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling getEmissionSourceCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$J.Get, path, requestOptions);
    }
    /**
     * Retrieves an emission source by ID
     *
     * @param emissionSourceId The identifier for the emission source being retrieved
     */
    getEmissionSourceWithMultiFactorsWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource/${emissionSourceId}'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling getEmissionSourceWithMultiFactors.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$J.Get, path, requestOptions);
    }
    /**
     * Retrieves all the emissions sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$J.Get, path, requestOptions);
    }
    /**
     * Retrieves all emission sources
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionSourcesWithMultiFactorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202411/emissionSource';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$J.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$I = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExport(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListExportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexport(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListUnexportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBills(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExport(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListExportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexport(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListUnexportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unexportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBills(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unexportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuid(billExportGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.unexportBillsByGuidWithHttpInfo(billExportGuid, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export all account bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param accountId The account to export all bills
     * @param body Bill Export Options
     */
    accountBillListExportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/export'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Unexport account bills
     *
     * @param accountId The account for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    accountBillListUnexportWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/unexport'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListUnexport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Export all bills in a list to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param listId The list identifier
     * @param body Bill Export Options
     */
    exportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/export'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling exportBillList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Retrieves text of a standard EnergyCAP bill export file for AP and GL purposes.  Maximum of 10000 bills can be processed at one time.  Only bills with the following conditions are included in the export file:   1) approved bills (if the approval system is enabled in workflow settings)  2) bill is in a closed batch (if after batch or after batch approval is set in the workflow settings)  3) bill is not held for export  4) bill is not void  5) bill is within the user&#39;s topmost setting.  6) bill in not already exported
     *
     * @param body
     */
    exportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/export';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Export all meter bills to ap or gl  Maximum of 10000 bills can be processed at one time.
     *
     * @param meterId The meter to export all bills
     * @param body Bill Export Options
     */
    meterBillListExportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/export'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Unexport meter bills
     *
     * @param meterId The meter for which to unexport all bills
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    meterBillListUnexportWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/unexport'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListUnexport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Unexport bill list
     *
     * @param listId The list identifier
     * @param body Value of \&quot;ap\&quot; for A/P unexport, or \&quot;gl\&quot; for GL unexport
     */
    unexportBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/unexport'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling unexportBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Marks one or more bills as unexported.
     *
     * @param body An array of bill ids to be marked as unexported and export mode
     */
    unexportBillsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/unexport';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    /**
     * Marks one or more bills as unexported. The bills to be unexported are selected based on the guid passed in.   The guid is generated when bills are exported via the bill export end point, and the guid is returned in the header of the response in a field named Ec-Guid.
     *
     * @param billExportGuid The identifier for the bills to be unexported
     */
    unexportBillsByGuidWithHttpInfo(billExportGuid, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/unexport/${billExportGuid}'
            .replace('${' + 'billExportGuid' + '}', String(billExportGuid));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'billExportGuid' is not null or undefined
        if (billExportGuid === null || billExportGuid === undefined) {
            throw new Error('Required parameter billExportGuid was null or undefined when calling unexportBillsByGuid.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$I.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$H = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Hold/release account bills for export
     *
     * @param accountId The account to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    accountBillListExportHold(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.accountBillListExportHoldWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update export hold flag for the given billIDs
     *
     * @param body export hold action
     */
    billActionExportHold(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billActionExportHoldWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Hold/release bill list for export
     *
     * @param listId The list identifier
     * @param body Boolean representing exportHold flag
     */
    exportHoldBillList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.exportHoldBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Hold/release meter bills for export
     *
     * @param meterId The meter to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    meterBillListExportHold(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.meterBillListExportHoldWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Hold/release account bills for export
     *
     * @param accountId The account to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    accountBillListExportHoldWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/exporthold'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling accountBillListExportHold.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$H.Put, path, requestOptions);
    }
    /**
     * Update export hold flag for the given billIDs
     *
     * @param body export hold action
     */
    billActionExportHoldWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/exporthold';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$H.Put, path, requestOptions);
    }
    /**
     * Hold/release bill list for export
     *
     * @param listId The list identifier
     * @param body Boolean representing exportHold flag
     */
    exportHoldBillListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/exporthold'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling exportHoldBillList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$H.Put, path, requestOptions);
    }
    /**
     * Hold/release meter bills for export
     *
     * @param meterId The meter to set the export hold flag on all bills
     * @param body Boolean representing exportHold flag
     */
    meterBillListExportHoldWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/list/bill/exporthold'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling meterBillListExportHold.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$H.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$G = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an Energy Project
     *
     * @param body Data representing the Energy project being created
     */
    createEnergyProject(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEnergyProjectWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a energy project type
     *
     * @param body
     */
    createEnergyProjectType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEnergyProjectTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an Energy Project
     *
     * @param body Data representing the Energy project being created
     */
    createEnergyProjectWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$G.Post, path, requestOptions);
    }
    /**
     * Create a energy project type
     *
     * @param body
     */
    createEnergyProjectTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/energyprojecttype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$G.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$F = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes an Energy Project
     *
     * @param projectId The identifier for the energy project being deleted
     */
    deleteEnergyProject(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an Energy Project
     *
     * @param projectId The identifier for the energy project being deleted
     */
    deleteEnergyProjectWithHttpInfo(projectId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/${projectId}'
            .replace('${' + 'projectId' + '}', String(projectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'projectId' is not null or undefined
        if (projectId === null || projectId === undefined) {
            throw new Error('Required parameter projectId was null or undefined when calling deleteEnergyProject.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$F.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$E = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits an Energy Project
     *
     * @param projectId The identifier for the energy project being edited
     * @param body
     */
    editEnergyProject(projectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyProjectWithHttpInfo(projectId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the custom field values on a energy project
     *
     * @param energyProjectId The id of the energy project
     * @param body The list of udf values being edited
     */
    editEnergyProjectCustomFields(energyProjectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an Energy Project
     *
     * @param projectId The identifier for the energy project being edited
     * @param body
     */
    editEnergyProjectWithHttpInfo(projectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/energyproject/${projectId}'
            .replace('${' + 'projectId' + '}', String(projectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'projectId' is not null or undefined
        if (projectId === null || projectId === undefined) {
            throw new Error('Required parameter projectId was null or undefined when calling editEnergyProject.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$E.Put, path, requestOptions);
    }
    /**
     * Edit the custom field values on a energy project
     *
     * @param energyProjectId The id of the energy project
     * @param body The list of udf values being edited
     */
    editEnergyProjectCustomFieldsWithHttpInfo(energyProjectId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/energyproject/${energyProjectId}/udf'
            .replace('${' + 'energyProjectId' + '}', String(energyProjectId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'energyProjectId' is not null or undefined
        if (energyProjectId === null || energyProjectId === undefined) {
            throw new Error('Required parameter energyProjectId was null or undefined when calling editEnergyProjectCustomFields.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$E.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$D = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edit flag data for a specified entity
     * This API supports a wide variety of Flag-related actions. Below are summaries of expected outcomes for possible combinations of property values.      Create Flag(the entity is not yet flagged, therefore there is no \&quot;modified\&quot; info)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                                                                                   Action                                                                                                                    |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                                                                                                                     |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                                                                                                                                       |  | null                     | null                     | null                     | null                     | null                     | null                 | null                 | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                                                                                                           |  | null                     | **not null**             | **not null**             | **not null**             | **not null**             | false                | false                | Exception, must have a type                                                                                                                                                                                                                 |  | **not null**             | null                     | null                     | null                     | null                     | false                | false                | Flagged, unresolved, specified type                                                                                                                                                                                                         |  | **not null**             | **not null**             | null                     | null                     | null                     | false                | false                | Flagged, unresolved(ignoring specified status), specified type                                                                                                                                                                              |  | **not null**             | null                     | **not null**             | null                     | null                     | false                | false                | Flagged, unresolved, specified type, cost recovery                                                                                                                                                                                          |  | **not null**             | null                     | null                     | **not null**&lt;sup&gt;1&lt;/sup&gt; | null                     | false                | false                | Flagged, unresolved, specified type&lt;br /&gt;&lt;sup&gt;1&lt;/sup&gt;If assignees not empty, assigned                                                                                                                                                       |  | **not null**             | null                     | null                     | null                     | **not null**             | false                | false                | Flagged, unresolved, specified type, comment                                                                                                                                                                                                |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment                                                            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;3&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;No action; will not release a newly flagged bill for export |    Edit Unresolved Flag (the entity is already flagged)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    | ReleaseExportHold |                                                                       Action                                                                        |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**          | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                             |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**      | Exception, must have at least one set                                                                                                               |  | null                     | null                     | null                     | null                     | null                     | false                | false             | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                   |  | **system or user type**  | null                     | null                     | null                     | null                     | false                | false             | Flag type updated                                                                                                                                   |  | null                     | **resolved**             | null                     | null                     | null                     | false                | false             | Resolved                                                                                                                                            |  | null                     | **resolved**             | null                     | null                     | null                     | false                | **true**          | Resolved, released for export                                                                                                                       |  | null                     | null                     | **not null**             | null                     | null                     | false                | false             | Updated, cost recovery                                                                                                                              |  | null                     | null                     | null                     | **not null**             | null                     | false                | false             | Assigned                                                                                                                                            |  | null                     | null                     | null                     | null                     | **not null**             | false                | false             | Updated, comment                                                                                                                                    |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment                   |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |    Edit Resolved Flag (the entity is already flagged)    |        FlagTypeId        |        FlagStatusId        |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                              Action                                                               |  | ------------------------ | -------------------------- | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | --------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                       | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                           |  | null                     | null                       | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                             |  | null                     | null                       | null                     | null                     | null                     | false                | false                | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                 |  | **system or user type**  | null                       | null                     | null                     | null                     | false                | false                | Updated, specified type                                                                                                           |  | null                     | **non-null**               | null                     | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | **not null**             | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | **not null**             | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | null                     | **not null**             | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false                | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;      |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, released from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param body The flag edit request
     */
    editFlag(entityType, entityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editFlagWithHttpInfo(entityType, entityId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param flagResolveComment Optional comment that will be recorded in the flag event when resolving the issue
     * @param body The flag issue edit request
     */
    editFlagIssues(entityType, entityId, flagResolveComment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editFlagIssuesWithHttpInfo(entityType, entityId, flagResolveComment, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates flags for a given list of entities. If the entity does not currently have a flag, one will be created.
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param body The changes to be made to the flags
     */
    flagAction(entityType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagActionWithHttpInfo(entityType, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create and/or update flags for all bills in a list
     *
     * @param listId Bill list containing a list of bills that will have flags created or updated
     * @param body DTO containing the new state of the flags on each bill in the list
     */
    flagBillListAction(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates flag issues for a given list of flag issue ids
     *
     * @param body The changes to be made to the flag issues
     */
    flagIssueAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagIssueActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update flag issuess for all issues in a list
     *
     * @param listId Flag Issue list containing a list of flag issues to be updated
     * @param body DTO containing the new state of the flag Issue on each flag issue in the list
     */
    flagIssueBillListAction(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagIssueBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Enable or disable Accounts from audits
     *
     * @param body
     */
    setAccountAuditExclusion(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setAccountAuditExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Enable or disable all accounts assigned to a vendor from audits
     *
     * @param vendorId The identifier for the vendor to act upon
     * @param body
     */
    setVendorAccountsAuditExclusion(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setVendorAccountsAuditExclusionWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update audit settings for an account.   Every audit must be included but supplying null for its settings will remove them.
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param accountId The account identifier
     * @param body The new state of the audit settings
     */
    updateAccountAuditSettings(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateAccountAuditSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit flag data for a specified entity
     * This API supports a wide variety of Flag-related actions. Below are summaries of expected outcomes for possible combinations of property values.      Create Flag(the entity is not yet flagged, therefore there is no \&quot;modified\&quot; info)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                                                                                   Action                                                                                                                    |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                                                                                                                     |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                                                                                                                                       |  | null                     | null                     | null                     | null                     | null                     | null                 | null                 | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                                                                                                           |  | null                     | **not null**             | **not null**             | **not null**             | **not null**             | false                | false                | Exception, must have a type                                                                                                                                                                                                                 |  | **not null**             | null                     | null                     | null                     | null                     | false                | false                | Flagged, unresolved, specified type                                                                                                                                                                                                         |  | **not null**             | **not null**             | null                     | null                     | null                     | false                | false                | Flagged, unresolved(ignoring specified status), specified type                                                                                                                                                                              |  | **not null**             | null                     | **not null**             | null                     | null                     | false                | false                | Flagged, unresolved, specified type, cost recovery                                                                                                                                                                                          |  | **not null**             | null                     | null                     | **not null**&lt;sup&gt;1&lt;/sup&gt; | null                     | false                | false                | Flagged, unresolved, specified type&lt;br /&gt;&lt;sup&gt;1&lt;/sup&gt;If assignees not empty, assigned                                                                                                                                                       |  | **not null**             | null                     | null                     | null                     | **not null**             | false                | false                | Flagged, unresolved, specified type, comment                                                                                                                                                                                                |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment                                                            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;3&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Flagged, unresolved (ignoring specified status), specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;If assignees not empty, assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;No action; will not release a newly flagged bill for export |    Edit Unresolved Flag (the entity is already flagged)    |        FlagTypeId        |       FlagStatusId       |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    | ReleaseExportHold |                                                                       Action                                                                        |  | ------------------------ | ------------------------ | ------------------------ | ------------------------ | ------------------------ | -------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                     | null                     | null                     | **non-null**             | **true**             | **true**          | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                                             |  | null                     | null                     | null                     | null                     | null                     | **non-null**         | **non-null**      | Exception, must have at least one set                                                                                                               |  | null                     | null                     | null                     | null                     | null                     | false                | false             | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                                   |  | **system or user type**  | null                     | null                     | null                     | null                     | false                | false             | Flag type updated                                                                                                                                   |  | null                     | **resolved**             | null                     | null                     | null                     | false                | false             | Resolved                                                                                                                                            |  | null                     | **resolved**             | null                     | null                     | null                     | false                | **true**          | Resolved, released for export                                                                                                                       |  | null                     | null                     | **not null**             | null                     | null                     | false                | false             | Updated, cost recovery                                                                                                                              |  | null                     | null                     | null                     | **not null**             | null                     | false                | false             | Assigned                                                                                                                                            |  | null                     | null                     | null                     | null                     | **not null**             | false                | false             | Updated, comment                                                                                                                                    |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment                   |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false             | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |    Edit Resolved Flag (the entity is already flagged)    |        FlagTypeId        |        FlagStatusId        |       CostRecovery       |        Assignees         |         Comment          |    HoldFromExport    |  ReleaseExportHold   |                                                              Action                                                               |  | ------------------------ | -------------------------- | ------------------------ | ------------------------ | ------------------------ | -------------------- | -------------------- | --------------------------------------------------------------------------------------------------------------------------------- |  | null                     | null                       | null                     | null                     | **non-null**             | **true**             | **true**             | Exception, cannot set both HoldFromExport and ReleaseExportHold at once                                                           |  | null                     | null                       | null                     | null                     | null                     | **non-null**         | **non-null**         | Exception, must have at least one set                                                                                             |  | null                     | null                       | null                     | null                     | null                     | false                | false                | Exception, must provided a non-null value for HoldFromExport or ReleaseExportHold                                                 |  | **system or user type**  | null                       | null                     | null                     | null                     | false                | false                | Updated, specified type                                                                                                           |  | null                     | **non-null**               | null                     | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | **not null**             | null                     | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | **not null**             | null                     | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | null                     | null                       | null                     | null                     | **not null**             | false                | false                | Exception; must provide flag type (cannot change flag status of a resolved flag; instead must \&quot;re-flag\&quot; it)                       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | false                | &lt;sup&gt;1&lt;/sup&gt;Updated, specified type, cost recovery, comment&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;&lt;sup&gt;3&lt;/sup&gt;Resolved, comment |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, no export hold action&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;      |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **unresolved**&lt;sup&gt;3&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | **true**&lt;sup&gt;1&lt;/sup&gt; | false                | &lt;sup&gt;1&lt;/sup&gt;Flagged, specified type, cost recovery, comment, held from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;            |  | **not null**&lt;sup&gt;1&lt;/sup&gt; | **resolved**&lt;sup&gt;3&lt;/sup&gt;   | **not null**&lt;sup&gt;1&lt;/sup&gt; | **not null**&lt;sup&gt;2&lt;/sup&gt; | **not null**&lt;sup&gt;1&lt;/sup&gt; | false                | **true**&lt;sup&gt;1&lt;/sup&gt; | &lt;sup&gt;1&lt;/sup&gt;Resolved, specified type, cost recovery, comment, released from export&lt;br /&gt;&lt;sup&gt;2&lt;/sup&gt;Assigned, comment&lt;br /&gt;       |
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param body The flag edit request
     */
    editFlagWithHttpInfo(entityType, entityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling editFlag.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling editFlag.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     * @param flagResolveComment Optional comment that will be recorded in the flag event when resolving the issue
     * @param body The flag issue edit request
     */
    editFlagIssuesWithHttpInfo(entityType, entityId, flagResolveComment, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/flag/flagIssue/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling editFlagIssues.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling editFlagIssues.');
        }
        if (flagResolveComment !== undefined) {
            queryParameters = queryParameters.set('flagResolveComment', flagResolveComment);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Updates flags for a given list of entities. If the entity does not currently have a flag, one will be created.
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param body The changes to be made to the flags
     */
    flagActionWithHttpInfo(entityType, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/${entityType}/flagAction'
            .replace('${' + 'entityType' + '}', String(entityType));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling flagAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Create and/or update flags for all bills in a list
     *
     * @param listId Bill list containing a list of bills that will have flags created or updated
     * @param body DTO containing the new state of the flags on each bill in the list
     */
    flagBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/flagAction'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling flagBillListAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Updates flag issues for a given list of flag issue ids
     *
     * @param body The changes to be made to the flag issues
     */
    flagIssueActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/flag/flagIssueAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Update flag issuess for all issues in a list
     *
     * @param listId Flag Issue list containing a list of flag issues to be updated
     * @param body DTO containing the new state of the flag Issue on each flag issue in the list
     */
    flagIssueBillListActionWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/V202502/list/${listId}/flagIssueAction'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling flagIssueBillListAction.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Enable or disable Accounts from audits
     *
     * @param body
     */
    setAccountAuditExclusionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/account/auditEnabled';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Enable or disable all accounts assigned to a vendor from audits
     *
     * @param vendorId The identifier for the vendor to act upon
     * @param body
     */
    setVendorAccountsAuditExclusionWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202104/vendor/${vendorId}/auditEnabled'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling setVendorAccountsAuditExclusion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    /**
     * Update audit settings for an account.   Every audit must be included but supplying null for its settings will remove them.
     *  __Setting Status Descriptions:__    | Setting Status | Description |  | -------------- | ----------- |  | Check          | If this audit fails affected bills are flagged  |  | Hold           | If this audit fails affected bills are flagged and held from export  |  | Skip           | This audit is skipped  |
     * @param accountId The account identifier
     * @param body The new state of the audit settings
     */
    updateAccountAuditSettingsWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/account/${accountId}/auditSetting'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling updateAccountAuditSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$D.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$C = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccount(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billFlagSummaryByAccountWithHttpInfo(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeter(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.billFlagSummaryByMeterWithHttpInfo(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagType(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createFlagTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagType(flagTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteFlagTypeWithHttpInfo(flagTypeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchy(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInAccountHierarchyWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchy(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInCostCenterHierarchyWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchy(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInMeterHierarchyWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchy(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.flagInPlaceHierarchyWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettings(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountAuditSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlag(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFlagWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssues(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFlagIssuesWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getFlagTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns a tabular flag summary by Account for all the accounts under the given cost center
     *
     * @param costCenterId Parent cost center identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByAccountWithHttpInfo(costCenterId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/costcenter/${costCenterId}/billFlagSummary'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling billFlagSummaryByAccount.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Returns a tabular flag summary by Meter for all the meters under the given place
     *
     * @param placeId Parent place identifier
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    billFlagSummaryByMeterWithHttpInfo(placeId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/place/${placeId}/billFlagSummary'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling billFlagSummaryByMeter.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Create a flag type
     *
     * @param body Contains the name of the flag type being created
     */
    createFlagTypeWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/flagType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Post, path, requestOptions);
    }
    /**
     * Delete a flag type. System flag types cannot be deleted.
     *
     * @param flagTypeId The identifier for the flag type being deleted
     */
    deleteFlagTypeWithHttpInfo(flagTypeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/flagType/${flagTypeId}'
            .replace('${' + 'flagTypeId' + '}', String(flagTypeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'flagTypeId' is not null or undefined
        if (flagTypeId === null || flagTypeId === undefined) {
            throw new Error('Required parameter flagTypeId was null or undefined when calling deleteFlagType.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Delete, path, requestOptions);
    }
    /**
     * Checks a given account and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param accountId
     */
    flagInAccountHierarchyWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/account/${accountId}/hierarchy'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling flagInAccountHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Checks a given cost center and it&#39;s child cost centers, accounts, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param costCenterId
     */
    flagInCostCenterHierarchyWithHttpInfo(costCenterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/costCenter/${costCenterId}/hierarchy'
            .replace('${' + 'costCenterId' + '}', String(costCenterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'costCenterId' is not null or undefined
        if (costCenterId === null || costCenterId === undefined) {
            throw new Error('Required parameter costCenterId was null or undefined when calling flagInCostCenterHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Checks a given meter and it&#39;s bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param meterId
     */
    flagInMeterHierarchyWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/meter/${meterId}/hierarchy'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling flagInMeterHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Checks a given place and it&#39;s child places, meters, and bills for the existence of a flag  For bill flags, void bills are excluded
     *
     * @param placeId
     */
    flagInPlaceHierarchyWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/place/${placeId}/hierarchy'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling flagInPlaceHierarchy.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Gets all account audit setting overrides
     *
     * @param accountId
     */
    getAccountAuditSettingsWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202506/account/${accountId}/auditSetting'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountAuditSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Get flag data for a specified entity
     *
     * @param entityType The type of entity the flag is being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling getFlag.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling getFlag.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Get flag issues for a specified entity
     *
     * @param entityType The type of entity the flag issues are being request for. Supported values are: \&quot;Bill\&quot;
     * @param entityId The identifier of the entity
     */
    getFlagIssuesWithHttpInfo(entityType, entityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202501/flag/flagIssue/${entityType}/${entityId}'
            .replace('${' + 'entityType' + '}', String(entityType))
            .replace('${' + 'entityId' + '}', String(entityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'entityType' is not null or undefined
        if (entityType === null || entityType === undefined) {
            throw new Error('Required parameter entityType was null or undefined when calling getFlagIssues.');
        }
        // verify required parameter 'entityId' is not null or undefined
        if (entityId === null || entityId === undefined) {
            throw new Error('Required parameter entityId was null or undefined when calling getFlagIssues.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    /**
     * Get a list of all available flag types
     *
     */
    getFlagTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/flag/flagType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$C.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$B = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edit the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for one or more commodities  Cost Avoidance Savings will be re-calculated for all bills for meters having the affected commodities
     *
     * @param body Data representing one or more average unit cost ranges to edit
     */
    editAucRanges(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editAucRangesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for one or more commodities  Cost Avoidance Savings will be re-calculated for all bills for meters having the affected commodities
     *
     * @param body Data representing one or more average unit cost ranges to edit
     */
    editAucRangesWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/auc';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$B.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$A = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for each commodity
     *
     */
    getAucRanges(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAucRangesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Count the number of meters that match the filter conditions for cost avoidance bulk actions
     *
     * @param onlyMetersInCAP Whether or not to only include meters in the count which are already participating in cost avoidance
     * @param body The filters used when counting the meters
     */
    getCostAvoidanceMeterCount(onlyMetersInCAP, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostAvoidanceMeterCountWithHttpInfo(onlyMetersInCAP, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the average unit cost \&quot;acceptable range\&quot; values for cost avoidance for each commodity
     *
     */
    getAucRangesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/auc';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$A.Get, path, requestOptions);
    }
    /**
     * Count the number of meters that match the filter conditions for cost avoidance bulk actions
     *
     * @param onlyMetersInCAP Whether or not to only include meters in the count which are already participating in cost avoidance
     * @param body The filters used when counting the meters
     */
    getCostAvoidanceMeterCountWithHttpInfo(onlyMetersInCAP, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/count';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (onlyMetersInCAP !== undefined) {
            queryParameters = queryParameters.set('onlyMetersInCAP', onlyMetersInCAP);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$A.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$z = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroups(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllMeterGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroups(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllPlaceGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroup(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembers(groupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupMembersWithHttpInfo(groupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRanking(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategory(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroup(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembers(placeGroupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupMembersWithHttpInfo(placeGroupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRanking(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPlaceGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFilters(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserDefinedAutoMeterGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFilters(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserDefinedAutoPlaceGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of meter groups
     *
     * @param filter
     */
    getAllMeterGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of place groups
     *
     * @param filter
     */
    getAllPlaceGroupsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of meter categories
     *
     */
    getMeterCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Retrieve a meter group category
     *
     * @param categoryId The identifier for the meter group category being retrieved
     */
    getMeterCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling getMeterCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a meter group
     *
     * @param meterGroupId
     */
    getMeterGroupWithHttpInfo(meterGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${meterGroupId}'
            .replace('${' + 'meterGroupId' + '}', String(meterGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterGroupId' is not null or undefined
        if (meterGroupId === null || meterGroupId === undefined) {
            throw new Error('Required parameter meterGroupId was null or undefined when calling getMeterGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of meter group members
     *
     * @param groupId
     * @param alwaysLimitByTopmost
     */
    getMeterGroupMembersWithHttpInfo(groupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${groupId}/member'
            .replace('${' + 'groupId' + '}', String(groupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'groupId' is not null or undefined
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling getMeterGroupMembers.');
        }
        if (alwaysLimitByTopmost !== undefined) {
            queryParameters = queryParameters.set('alwaysLimitByTopmost', alwaysLimitByTopmost);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Retrieves cost, use, unit cost or demand per day ranking data by meter group.
     * Specify values for any query parameters whose database values are to be overridden.                **PLEASE NOTE: As shown in the table below, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    |  Chart   |              Response Type               |  | -------- | ---------------------------------------- |  | cost     | MeterGroupDigestRankingResponseDTO       |  | use      | MeterGroupDigestRankingResponseDTO       |  | unitCost | MeterGroupDigestRankingResponseDTO       |  | demand   | MeterGroupDigestDemandRankingResponseDTO |
     * @param groupId The meter group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - cost, use, unitcost, demand
     * @param billingPeriodOption The billing period option - last12periods, lastyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getMeterGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/${groupId}/digest/${dataView}/${chart}'
            .replace('${' + 'groupId' + '}', String(groupId))
            .replace('${' + 'dataView' + '}', String(dataView))
            .replace('${' + 'chart' + '}', String(chart));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'groupId' is not null or undefined
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling getMeterGroupRanking.');
        }
        // verify required parameter 'dataView' is not null or undefined
        if (dataView === null || dataView === undefined) {
            throw new Error('Required parameter dataView was null or undefined when calling getMeterGroupRanking.');
        }
        // verify required parameter 'chart' is not null or undefined
        if (chart === null || chart === undefined) {
            throw new Error('Required parameter chart was null or undefined when calling getMeterGroupRanking.');
        }
        if (billingPeriodOption !== undefined) {
            queryParameters = queryParameters.set('billingPeriodOption', billingPeriodOption);
        }
        if (startPeriod !== undefined) {
            queryParameters = queryParameters.set('startPeriod', startPeriod);
        }
        if (endPeriod !== undefined) {
            queryParameters = queryParameters.set('endPeriod', endPeriod);
        }
        if (commodityId !== undefined) {
            queryParameters = queryParameters.set('commodityId', commodityId);
        }
        if (commodityCategoryId !== undefined) {
            queryParameters = queryParameters.set('commodityCategoryId', commodityCategoryId);
        }
        if (highToLowRanking !== undefined) {
            queryParameters = queryParameters.set('highToLowRanking', highToLowRanking);
        }
        if (showExcludedMembers !== undefined) {
            queryParameters = queryParameters.set('showExcludedMembers', showExcludedMembers);
        }
        if (showZeroAverages !== undefined) {
            queryParameters = queryParameters.set('showZeroAverages', showZeroAverages);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of place categories
     *
     */
    getPlaceCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Retrieve a Place Group Category
     *
     * @param categoryId The identifier for the place group category being retrieved
     */
    getPlaceCategoryWithHttpInfo(categoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/category/${categoryId}'
            .replace('${' + 'categoryId' + '}', String(categoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'categoryId' is not null or undefined
        if (categoryId === null || categoryId === undefined) {
            throw new Error('Required parameter categoryId was null or undefined when calling getPlaceCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a place group
     *
     * @param placeGroupId
     */
    getPlaceGroupWithHttpInfo(placeGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling getPlaceGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of place group members
     *
     * @param placeGroupId
     * @param alwaysLimitByTopmost
     */
    getPlaceGroupMembersWithHttpInfo(placeGroupId, alwaysLimitByTopmost, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${placeGroupId}/member'
            .replace('${' + 'placeGroupId' + '}', String(placeGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeGroupId' is not null or undefined
        if (placeGroupId === null || placeGroupId === undefined) {
            throw new Error('Required parameter placeGroupId was null or undefined when calling getPlaceGroupMembers.');
        }
        if (alwaysLimitByTopmost !== undefined) {
            queryParameters = queryParameters.set('alwaysLimitByTopmost', alwaysLimitByTopmost);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Retrieves ranking data by place group.
     * Depending on the \&quot;chart\&quot; parameter retrieved ranking data could be cost, use, or demand per area, cost or use per day, heating sensitivity or cooling sensitivity  Specify values for any query parameters whose database values are to be overridden.  For the heating sensitivity and cooling sensitivity charts we sort by weather sensitivity (slope) and exclude non-weather meters            **PLEASE NOTE: As shown in the table above, this API endpoint returns different response types based on the \&quot;chart\&quot; value. Despite what you see below regarding HTTP status codes for each response type, _all_ of these response types will return 200 OK.**    | Chart              | Response Type                                |  | ------------------ | -------------------------------------------- |  | areaCost           | PlaceGroupDigestAreaRankingResponseDTO       |  | areaUse            | PlaceGroupDigestAreaRankingResponseDTO       |  | cost               | PlaceGroupDigestRankingResponseDTO           |  | use                | PlaceGroupDigestRankingResponseDTO           |  | areaDemand         | PlaceGroupDigestAreaDemandRankingResponseDTO |  | coolingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | heatingSensitivity | PlaceGroupDigestWeatherRankingResponseDTO    |  | benchmark1Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Use      | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark1Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark2Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |  | benchmark3Cost     | PlaceGroupDigestBenchmarkRankingResponseDTO  |
     * @param groupId The place group to retrieve data for
     * @param dataView The desired data view - actual, calendarized, normalized
     * @param chart The desired chart - areacost, areause, areademand, cost, use, heatingsensitivity, coolingsensitivity, benchmark1use, benchmark1cost, benchmark2use, benchmark2cost, benchmark3use, benchmark3cost
     * @param billingPeriodOption The billing period option - last12periods, currentyear, lastfiscalyear, custom (optional)
     * @param startPeriod The custom start period (optional)
     * @param endPeriod The custom end period (optional)
     * @param commodityId Id of commodity to filter by (optional)
     * @param commodityCategoryId Id of commodity category to filter by (optional)
     * @param highToLowRanking Ranking from high to low, or low to high? (optional)
     * @param showExcludedMembers Show group members excluded from the group? (optional)
     * @param showZeroAverages Show group members whose ranking averages are zero? (optional)
     */
    getPlaceGroupRankingWithHttpInfo(groupId, dataView, chart, billingPeriodOption, startPeriod, endPeriod, commodityId, commodityCategoryId, highToLowRanking, showExcludedMembers, showZeroAverages, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/${groupId}/digest/${dataView}/${chart}'
            .replace('${' + 'groupId' + '}', String(groupId))
            .replace('${' + 'dataView' + '}', String(dataView))
            .replace('${' + 'chart' + '}', String(chart));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'groupId' is not null or undefined
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling getPlaceGroupRanking.');
        }
        // verify required parameter 'dataView' is not null or undefined
        if (dataView === null || dataView === undefined) {
            throw new Error('Required parameter dataView was null or undefined when calling getPlaceGroupRanking.');
        }
        // verify required parameter 'chart' is not null or undefined
        if (chart === null || chart === undefined) {
            throw new Error('Required parameter chart was null or undefined when calling getPlaceGroupRanking.');
        }
        if (billingPeriodOption !== undefined) {
            queryParameters = queryParameters.set('billingPeriodOption', billingPeriodOption);
        }
        if (startPeriod !== undefined) {
            queryParameters = queryParameters.set('startPeriod', startPeriod);
        }
        if (endPeriod !== undefined) {
            queryParameters = queryParameters.set('endPeriod', endPeriod);
        }
        if (commodityId !== undefined) {
            queryParameters = queryParameters.set('commodityId', commodityId);
        }
        if (commodityCategoryId !== undefined) {
            queryParameters = queryParameters.set('commodityCategoryId', commodityCategoryId);
        }
        if (highToLowRanking !== undefined) {
            queryParameters = queryParameters.set('highToLowRanking', highToLowRanking);
        }
        if (showExcludedMembers !== undefined) {
            queryParameters = queryParameters.set('showExcludedMembers', showExcludedMembers);
        }
        if (showZeroAverages !== undefined) {
            queryParameters = queryParameters.set('showZeroAverages', showZeroAverages);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of filters that can be used to create Meter Groups
     *
     */
    getUserDefinedAutoMeterGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meterGroup/filters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    /**
     * Gets a list of filters that can be used to create Place Groups
     *
     */
    getUserDefinedAutoPlaceGroupFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/placeGroup/filters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$z.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$y = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReading(readingId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteSingleReadingWithHttpInfo(readingId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReading(readingId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSingleReadingWithHttpInfo(readingId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImport(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.readingImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an interval data import profile
     *
     * @param body The details about the profile being created
     */
    createReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Post, path, requestOptions);
    }
    /**
     * Creates new readings
     *
     * @param body Data representing the readings being imported
     */
    createReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Post, path, requestOptions);
    }
    /**
     * Deletes a reading import profile
     *
     * @param profileId The identifier for the profile being deleted
     */
    deleteReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Delete, path, requestOptions);
    }
    /**
     * Deletes one or more sets of meter readings.   Each set of meter readings to be deleted is on one channel and covers a time range signified by a begin and end date and time.  The time range includes all readings greater than the begin time and less than or equal to the end date and time.  To delete only one reading, set the begin and end date and time to the same value.
     *
     * @param body The channel id, begin date and time and end date and time of the set of meter readings to be deleted
     */
    deleteReadingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Delete, path, requestOptions);
    }
    /**
     * Deletes a single interval data reading by its ID
     *
     * @param readingId Unique ID of the reading to delete
     */
    deleteSingleReadingWithHttpInfo(readingId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading/${readingId}'
            .replace('${' + 'readingId' + '}', String(readingId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'readingId' is not null or undefined
        if (readingId === null || readingId === undefined) {
            throw new Error('Required parameter readingId was null or undefined when calling deleteSingleReading.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Delete, path, requestOptions);
    }
    /**
     * Edits an interval data import profile
     *
     * @param profileId The identifier for the profile being edited
     * @param body The details about the profile being edited
     */
    editReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Put, path, requestOptions);
    }
    /**
     * Edits a single interval data reading.  Duplicate timestamps are not allowed for readings on a given channel.  If the reading being edited has the same timestamp as another reading on the same channel, this end point throws an error
     *
     * @param readingId Unique ID of the reading to edit
     * @param body Updated reading properties
     */
    editSingleReadingWithHttpInfo(readingId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/reading/${readingId}'
            .replace('${' + 'readingId' + '}', String(readingId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'readingId' is not null or undefined
        if (readingId === null || readingId === undefined) {
            throw new Error('Required parameter readingId was null or undefined when calling editSingleReading.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Put, path, requestOptions);
    }
    /**
     * Returns one reading import profile
     *
     * @param profileId
     */
    getReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Get, path, requestOptions);
    }
    /**
     * Returns all Reading Import profiles
     *
     */
    getReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Get, path, requestOptions);
    }
    /**
     * This endpoint allows the import of a channel reading (\&quot;interval\&quot;) data import file. The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to export and the profile that defines the structure.
     */
    readingImportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/import/reading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$y.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$x = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves interval data for a specific widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     */
    getIntervalData(specificWidgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getIntervalDataWithHttpInfo(specificWidgetId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves interval data for a specific widget  NOTE: Does not support global dashboard filtering with Topmost Place, Place Group API filters.
     *
     * @param specificWidgetId Specific widget identifier to get the data for
     */
    getIntervalDataWithHttpInfo(specificWidgetId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/widget/intervaldata/${specificWidgetId}'
            .replace('${' + 'specificWidgetId' + '}', String(specificWidgetId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificWidgetId' is not null or undefined
        if (specificWidgetId === null || specificWidgetId === undefined) {
            throw new Error('Required parameter specificWidgetId was null or undefined when calling getIntervalData.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$x.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$w = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates or removes manual adjustments to savings for a provided meter and bill
     *
     * @param meterId The meter for which the manual adjustment is being made
     * @param billId The bill for which the manual adjustment is being made
     * @param body
     */
    manualAdjustment(meterId, billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.manualAdjustmentWithHttpInfo(meterId, billId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates or removes manual adjustments to savings for a provided meter and bill
     *
     * @param meterId The meter for which the manual adjustment is being made
     * @param billId The bill for which the manual adjustment is being made
     * @param body
     */
    manualAdjustmentWithHttpInfo(meterId, billId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill/${billId}/manualadjustment'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling manualAdjustment.');
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling manualAdjustment.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$w.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$v = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Mass update certain cost avoidance settings for meters that match the filter conditions  Baseline and Savings will be reprocessed for affected meters
     *
     * @param body Filters and new cost avoidance setting values
     */
    bulkEditMeterCostAvoidanceSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.bulkEditMeterCostAvoidanceSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Mass update certain cost avoidance settings for meters that match the filter conditions  Baseline and Savings will be reprocessed for affected meters
     *
     * @param body Filters and new cost avoidance setting values
     */
    bulkEditMeterCostAvoidanceSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$v.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$u = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Executes the baseline and cost avoidance processors with provided baseline and cost avoidance settings for the provided meter.   Results are not saved unless the \&quot;save\&quot; flag is set to true.  If \&quot;save\&quot; is true, MeterSavingsSettings-Manage permission is also required
     *
     * @param meterId ID of the meter for which baseline will be reprocessed
     * @param save If true, the baseline results will be saved to the database
     * @param body Provided baseline and avoidance settings
     */
    generateBaseline(meterId, save, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.generateBaselineWithHttpInfo(meterId, save, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Executes the baseline processor with stored baseline settings for the provided meter
     *
     * @param meterId ID of the meter for which baseline data will be returned
     */
    generateBaselineGet(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.generateBaselineGetWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Executes the baseline and cost avoidance processors with provided baseline and cost avoidance settings for the provided meter.   Results are not saved unless the \&quot;save\&quot; flag is set to true.  If \&quot;save\&quot; is true, MeterSavingsSettings-Manage permission is also required
     *
     * @param meterId ID of the meter for which baseline will be reprocessed
     * @param save If true, the baseline results will be saved to the database
     * @param body Provided baseline and avoidance settings
     */
    generateBaselineWithHttpInfo(meterId, save, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/baseline'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling generateBaseline.');
        }
        if (save !== undefined) {
            queryParameters = queryParameters.set('save', save);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$u.Post, path, requestOptions);
    }
    /**
     * Executes the baseline processor with stored baseline settings for the provided meter
     *
     * @param meterId ID of the meter for which baseline data will be returned
     */
    generateBaselineGetWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/baseline'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling generateBaselineGet.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$u.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$t = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPoint(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createDataPointWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannel(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaChannelWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeter(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRoute(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRouteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlace(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUtilityPlatformMetersByPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importEsaReadingWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeter(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.upsertAggregateMeterWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a data point
     *
     * @param body Data representing the data point being created
     */
    createDataPointWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * Creates an ESA channel
     *
     * @param body Data representing the ESA channel being created
     */
    createEsaChannelWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * Creates an ESA reading import profile
     *
     * @param body Object containing settings for the new profile
     */
    createEsaReadingImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * Creates a meter
     *
     * @param body Data representing the meter being created
     */
    createMeterWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * Creates a new route and assigns a group of meters to it
     *
     * @param body Data representing the route being created
     */
    createRouteWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * Create meters on a particular place
     *
     * @param placeId The id of the place
     * @param body The meters to create on the place
     */
    createUtilityPlatformMetersByPlaceWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/meter'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling createUtilityPlatformMetersByPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * This endpoint allows the import of an ESA reading import file.  The file should be a base64-encoded file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEsaReadingWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Post, path, requestOptions);
    }
    /**
     * Create a new aggregate meter, update an existing version, create a new version  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate&#39;s MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated
     *
     * @param placeId The id of the place to insert the aggregate meter
     * @param body The release request details
     */
    upsertAggregateMeterWithHttpInfo(placeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/aggregateMeter'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling upsertAggregateMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$t.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$s = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a data point
     *
     * @param dataPointId The data point identifier
     */
    deleteDataPoint(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    deleteEsaChannel(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an ESA reading import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteEsaReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a meter
     *
     * @param meterId The identifier for the meter being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteMeter(meterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterWithHttpInfo(meterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a route
     *
     * @param id The identifier for the route being deleted
     */
    deleteRoute(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a data point
     *
     * @param dataPointId The data point identifier
     */
    deleteDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling deleteDataPoint.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$s.Delete, path, requestOptions);
    }
    /**
     * Deletes an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    deleteEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling deleteEsaChannel.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$s.Delete, path, requestOptions);
    }
    /**
     * Deletes an ESA reading import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteEsaReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$s.Delete, path, requestOptions);
    }
    /**
     * Deletes a meter
     *
     * @param meterId The identifier for the meter being deleted
     * @param deleteBills Should this cascade to delete any bills associated with this meter
     */
    deleteMeterWithHttpInfo(meterId, deleteBills, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteMeter.');
        }
        if (deleteBills !== undefined) {
            queryParameters = queryParameters.set('deleteBills', deleteBills);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$s.Delete, path, requestOptions);
    }
    /**
     * Deletes a route
     *
     * @param id The identifier for the route being deleted
     */
    deleteRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteRoute.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$s.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$r = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMetersEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeter(routeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.addMeterWithHttpInfo(routeId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersion(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createChannelVersionWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersion(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEsaChannelVersionWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannel(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createMeterChannelWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersion(meterId, channelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteChannelVersionWithHttpInfo(meterId, channelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannel(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersion(meterId, channelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editChannelVersionWithHttpInfo(meterId, channelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPoint(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDataPointWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLink(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionSourceLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannel(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaChannelWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersion(esaChannelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaChannelVersionWithHttpInfo(esaChannelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEsaReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannel(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterChannelWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersion(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterSerialNumberVersionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFs(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterUDFsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnits(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editMeterWithUnitsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRoute(id, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRouteWithHttpInfo(id, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLink(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editWatticsDataPointLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinel(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.enableSentinelWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetails(dataAccessReleaseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataAccessReleaseDetailsWithHttpInfo(dataAccessReleaseId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeter(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveMeterWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomAction(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processMeterCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeter(routeId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.removeMeterWithHttpInfo(routeId, meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMeters(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchUtilityPlatformMetersWithHttpInfo(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddresses(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.searchUtilityPlatformServiceAddressesWithHttpInfo(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmail(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.sendDataAccessReleaseRequestEmailWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Adds a meter to a route
     *
     * @param routeId The identifier for the route to add the meters to
     * @param body Object representing meter to add to the route
     */
    addMeterWithHttpInfo(routeId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${routeId}/meter'
            .replace('${' + 'routeId' + '}', String(routeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'routeId' is not null or undefined
        if (routeId === null || routeId === undefined) {
            throw new Error('Required parameter routeId was null or undefined when calling addMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    /**
     * Create a new channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to add the version to
     * @param body
     */
    createChannelVersionWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}/version'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createChannelVersion.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling createChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    /**
     * Creates an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel version being created
     */
    createEsaChannelVersionWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling createEsaChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    /**
     * Creates and assigns a channel to a meter
     *
     * @param meterId Id of the meter to link the channel to
     * @param body Data representing the channel being created
     */
    createMeterChannelWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createMeterChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    /**
     * Delete a channel version  There must always be one version on a channel  If you try and delete the only version on a channel an exception will occur
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to delete
     */
    deleteChannelVersionWithHttpInfo(meterId, channelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}/version/${versionId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteChannelVersion.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling deleteChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling deleteChannelVersion.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Delete, path, requestOptions);
    }
    /**
     * Deletes a meter&#39;s channel  All readings linked to this channel will also be deleted.  A channel that is part of a distribution cannot be deleted.
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to delete
     */
    deleteMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteMeterChannel.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling deleteMeterChannel.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Delete, path, requestOptions);
    }
    /**
     * Update a channel version
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel the version is linked to
     * @param versionId Id of the channel version to update
     * @param body
     */
    editChannelVersionWithHttpInfo(meterId, channelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}/version/${versionId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editChannelVersion.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling editChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits a data point
     *
     * @param dataPointId The data point identifier
     * @param body Data representing the data point being edited
     */
    editDataPointWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling editDataPoint.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edit emission source data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Emission Source data to assign to the meter
     */
    editEmissionSourceLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/meter/${meterId}/emissionSource'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editEmissionSourceLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param body Data representing the ESA channel being edited
     */
    editEsaChannelWithHttpInfo(esaChannelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling editEsaChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     * @param body Data representing the ESA channel version being edited
     */
    editEsaChannelVersionWithHttpInfo(esaChannelId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version/${versionId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling editEsaChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editEsaChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits an ESA reading import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings for the profile
     */
    editEsaReadingImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editEsaReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Updates a meter&#39;s channel  If a channel version exists and is not passed into the request body it will continue to exist and no data will be changed.  To delete a specific channel version call DELETE meter/{meterId}/channel/{channelId}/version/{versionId}
     *
     * @param meterId Id of the meter the channel is linked to
     * @param channelId Id of the channel to update
     * @param body
     */
    editMeterChannelWithHttpInfo(meterId, channelId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterChannel.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling editMeterChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param meterId
     * @param body
     */
    editMeterSerialNumberVersionWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/serialnumberversion'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterSerialNumberVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular meter
     *
     * @param meterId The identifier for the meter
     * @param body Data representing the meter user defined fields / custom fields being edited
     */
    editMeterUDFsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/udf'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits a meter - unlike the original v3 EditMeter API, the meter use unit will be removed if it is null
     *
     * @param meterId The meter identifier for the meter being edited
     * @param body Data representing the meter being edited
     */
    editMeterWithUnitsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202307/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editMeterWithUnits.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits a route
     *
     * @param id The identifier for the route being edited
     * @param body Data representing the route being edited
     */
    editRouteWithHttpInfo(id, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling editRoute.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edit SmartAnalytics (Wattics) data on a meter
     *
     * @param meterId The meter identifier for the meter to edit
     * @param body Identifier for the SmartAnaltyics data point to assign to the meter
     */
    editWatticsDataPointLinkWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202302/meter/${meterId}/watticsDataPoint'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editWatticsDataPointLink.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Edits the data point sentinel configuration
     *
     * @param dataPointId
     * @param body The data point identifier
     */
    enableSentinelWithHttpInfo(dataPointId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}/sentinel'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling enableSentinel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Get data access release details
     *
     * @param dataAccessReleaseId The id of the data access release
     */
    getDataAccessReleaseDetailsWithHttpInfo(dataAccessReleaseId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/dataAccessRelease/${dataAccessReleaseId}'
            .replace('${' + 'dataAccessReleaseId' + '}', String(dataAccessReleaseId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataAccessReleaseId' is not null or undefined
        if (dataAccessReleaseId === null || dataAccessReleaseId === undefined) {
            throw new Error('Required parameter dataAccessReleaseId was null or undefined when calling getDataAccessReleaseDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Get, path, requestOptions);
    }
    /**
     * Move list of meters to be under parentPlaceId
     *
     * @param parentPlaceId The identifier for the new parent place
     * @param body List of meterIds to move under the parentPlaceId
     */
    moveMeterWithHttpInfo(parentPlaceId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/parentPlace/${parentPlaceId}/meter'
            .replace('${' + 'parentPlaceId' + '}', String(parentPlaceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'parentPlaceId' is not null or undefined
        if (parentPlaceId === null || parentPlaceId === undefined) {
            throw new Error('Required parameter parentPlaceId was null or undefined when calling moveMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Fires a custom meter action. Custom meter actions are setup as webhooks
     *
     * @param body
     */
    processMeterCustomActionWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202211/meter/customAction';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Put, path, requestOptions);
    }
    /**
     * Removes a meter from a route
     *
     * @param routeId The identifier for the route the meter is being remove from
     * @param meterId The identifier for the meter being removed
     */
    removeMeterWithHttpInfo(routeId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${routeId}/meter/${meterId}'
            .replace('${' + 'routeId' + '}', String(routeId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'routeId' is not null or undefined
        if (routeId === null || routeId === undefined) {
            throw new Error('Required parameter routeId was null or undefined when calling removeMeter.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling removeMeter.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Delete, path, requestOptions);
    }
    /**
     * Search utility platform meters
     *
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     * @param body The meter search criteria
     */
    searchUtilityPlatformMetersWithHttpInfo(pageSize, pageNumber, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    /**
     * Search service addresses
     *
     * @param address The address fragment to search for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    searchUtilityPlatformServiceAddressesWithHttpInfo(address, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/address/search';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (address !== undefined) {
            queryParameters = queryParameters.set('address', address);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    /**
     * Email a data access release request
     *
     * @param meterId The meter that the release is for
     * @param body The release request details
     */
    sendDataAccessReleaseRequestEmailWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/meter/${meterId}/sendDataAccessReleaseRequest'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling sendDataAccessReleaseRequestEmail.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$r.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$q = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMetersViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFile(meterId, channelId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadChannelVersionCustomFieldFileWithHttpInfo(meterId, channelId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFile(meterId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadMeterCustomFieldFileWithHttpInfo(meterId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItems(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAccountLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCost(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillCostWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemand(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetails(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUse(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculateBillUseWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistory(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBills(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalculatedBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherData(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCalendarizedUseVsWeatherDataWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPoint(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPoints(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getDataPointsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannel(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersion(esaChannelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelVersionWithHttpInfo(esaChannelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersions(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelVersionsWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannels(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaChannelsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEsaReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactors(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getGHGMeterFactorsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeter(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetails(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterBillSplitParentDetailsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrend(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedTrendWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannel(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannels(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterChannelsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettings(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGHGSettingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroups(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterGroupsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItems(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRates(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterRatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearly(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyList(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplates(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterTemplatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfs(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMeterUdfsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getMetersUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadings(channelId, beginDate, endDate, originalValue, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReadingsWithHttpInfo(channelId, beginDate, endDate, originalValue, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRoute(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetails(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRouteDetailsWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all routes
     *
     */
    getRoutes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRoutesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReading(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRoutesWithMetersChannelsLatestReadingWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeList(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsAdjustedCostTypeListWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBill(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsMeterBillWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDaily(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsMeterBillDailyWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillList(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsMeterBillListWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTask(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasks(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSavingsTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethods(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMeters(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUnplacedMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlace(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUtilityPlatformMetersByPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a channel version custom field
     *
     * @param meterId
     * @param channelId
     * @param versionId
     * @param udfId
     */
    downloadChannelVersionCustomFieldFileWithHttpInfo(meterId, channelId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/meter/${meterId}/channel/${channelId}/version/${versionId}/udf/${udfId}/download'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId))
            .replace('${' + 'versionId' + '}', String(versionId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadChannelVersionCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Download file for a meter custom field
     *
     * @param meterId
     * @param udfId
     */
    downloadMeterCustomFieldFileWithHttpInfo(meterId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/meter/${meterId}/udf/${udfId}/download'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling downloadMeterCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadMeterCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get calculated bill account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getAccountLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/accountLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getAccountLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getAccountLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getAccountLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get calculated cost details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillCostWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/cost'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillCost.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillCost.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillCost.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get calculated demand details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDemandWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/demand'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillDemand.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillDemand.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillDemand.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * All details related to calculated bill setup including use, cost, meter line items, and account line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillDetailsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillDetails.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillDetails.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get calculated use details
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getCalculateBillUseWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/use'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculateBillUse.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculateBillUse.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getCalculateBillUse.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions on this account and meter relationship
     *
     * @param accountId ID of the account to get all assigned calculated bill versions
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillVersionHistoryWithHttpInfo(accountId, meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getCalculatedBillVersionHistory.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculatedBillVersionHistory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get a list of calculated bill versions on a meter
     *
     * @param meterId ID of the meter to get all assigned calculated bill versions
     */
    getCalculatedBillsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/calculatedBill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalculatedBills.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get calendarized Use vs Weather data
     *
     * @param meterId The meter identifier
     */
    getCalendarizedUseVsWeatherDataWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/usevsweather/calendarized'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getCalendarizedUseVsWeatherData.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves a data point
     *
     * @param dataPointId The data point identifier
     */
    getDataPointWithHttpInfo(dataPointId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint/${dataPointId}'
            .replace('${' + 'dataPointId' + '}', String(dataPointId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dataPointId' is not null or undefined
        if (dataPointId === null || dataPointId === undefined) {
            throw new Error('Required parameter dataPointId was null or undefined when calling getDataPoint.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all data points
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getDataPointsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/datapoint';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves an ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     */
    getEsaChannelWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getEsaChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves an ESA channel version for a specified ESA channel
     *
     * @param esaChannelId The ESA channel identifier
     * @param versionId The ESA channel version identifier
     */
    getEsaChannelVersionWithHttpInfo(esaChannelId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version/${versionId}'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getEsaChannelVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getEsaChannelVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA channel version for a specified ESA channel
     *
     * @param esaChannelId
     */
    getEsaChannelVersionsWithHttpInfo(esaChannelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel/${esaChannelId}/version'
            .replace('${' + 'esaChannelId' + '}', String(esaChannelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'esaChannelId' is not null or undefined
        if (esaChannelId === null || esaChannelId === undefined) {
            throw new Error('Required parameter esaChannelId was null or undefined when calling getEsaChannelVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all ESA channels
     *
     * @param filter
     * @param orderBy
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEsaChannelsWithHttpInfo(filter, orderBy, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/esachannel';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (orderBy !== undefined) {
            queryParameters = queryParameters.set('orderBy', orderBy);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Gets an ESA reading import profile
     *
     * @param profileId
     */
    getEsaReadingImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getEsaReadingImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get all ESA reading import profiles
     *
     */
    getEsaReadingImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202407/import/esareading/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get the ghg meter factors
     *
     * @param meterId The meter identifier for ghg factors are being retrieved
     */
    getGHGMeterFactorsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/ghg/factor'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getGHGMeterFactors.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves one meter
     *
     * @param meterId The meter identifier for the meter being retrieved
     */
    getMeterWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeter.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterActualMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/actual/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterActualMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/actual/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterActualYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/actual/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up billing data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterActualYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/actual/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get bill split parent information for a meter
     *
     * @param meterId ID of the meter
     */
    getMeterBillSplitParentDetailsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/billSplit/parent'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterBillSplitParentDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/calendarized/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterCalendarizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/calendarized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterCalendarizedTrendWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/calendarized/trend'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterCalendarizedTrend.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterCalendarizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/calendarized/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterCalendarizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up calendarized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterCalendarizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/calendarized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves a channel and its channel versions linked to a meter
     *
     * @param meterId Id of the linked meter to retrieve the channel information for
     * @param channelId Id of the channel to retrieve information for
     */
    getMeterChannelWithHttpInfo(meterId, channelId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel/${channelId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterChannel.');
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling getMeterChannel.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all channel and channel versions linked to a meter
     *
     * @param meterId Id of the meter to retrieve the channel information for
     */
    getMeterChannelsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202101/meter/${meterId}/channel'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterChannels.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get the configured GHG scope category and factor for a meter.  GHG License is required to call this endpoint.
     *
     * @param meterId The meter to retrieve settings for
     */
    getMeterGHGSettingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202210/meter/${meterId}/ghgsetting'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterGHGSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all Meter Groups for a particular meter
     *
     * @param meterId The meter identifier for which group values are being retrieved
     */
    getMeterGroupsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/group'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterGroups.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get calculated bill meter line items
     *
     * @param accountId ID of the account to receive calculated bill details
     * @param meterId ID of the meter to receive calculated bill details
     * @param versionId ID of the calculated bill distribution version
     */
    getMeterLineItemsWithHttpInfo(accountId, meterId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/meter/${meterId}/calculatedBill/${versionId}/meterLineItem'
            .replace('${' + 'accountId' + '}', String(accountId))
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getMeterLineItems.');
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterLineItems.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getMeterLineItems.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     */
    getMeterNormalizedMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/normalized/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterNormalizedMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data by meter for a given range of months- Result includes cost, use, unit cost on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years of months (24 for actual and savings, and 24 or 26 (if 13 accounting periods) for calendarized and normalized)
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/normalized/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized billing data for a given meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getMeterNormalizedYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/normalized/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterNormalizedYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up normalized data by meter for a given range of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterNormalizedYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/normalized/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all rates for a particular meter
     *
     * @param meterId The meter identifier for which rate values are being retrieved
     */
    getMeterRatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/rate'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterRates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data for a given meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param meterId The identifier for the meter being retrieved
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     */
    getMeterSavingsMonthlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/savings/monthly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterSavingsMonthly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up savings billing data by meter for a given number of years- Result includes cost and use savings on a monthly basis.
     *
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to two years/24 months
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsMonthlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/savings/monthly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves savings data for a single meter for a given number of years.
     *
     * @param meterId The meter for which to return data
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     */
    getMeterSavingsYearlyWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/digest/savings/yearly'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterSavingsYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves savings data by meter for a given number of years.
     *
     * @param numberOfYears Number of years of data to return including the current year - Defaults to 4
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMeterSavingsYearlyListWithHttpInfo(numberOfYears, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/digest/savings/yearly';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all templates for a particular meter
     *
     * @param meterId The meter identifier for which template values are being retrieved
     */
    getMeterTemplatesWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/template'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterTemplates.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular meter
     *
     * @param meterId The meter identifier for which user defined field / custom field values are being retrieved
     */
    getMeterUdfsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/${meterId}/udf'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getMeterUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getMetersUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/meter/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of readings
     *
     * @param channelId Specific Channel ID
     * @param beginDate The starting date of readings to return
     * @param endDate The end date of readings to return
     * @param originalValue If &#39;true&#39;, returns the original observation value. If &#39;false&#39; returns the computed observation value based on the channel type. NOTE: this parameter is no longer used and has been deprecated.
     */
    getReadingsWithHttpInfo(channelId, beginDate, endDate, originalValue, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/channel/${channelId}/reading'
            .replace('${' + 'channelId' + '}', String(channelId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'channelId' is not null or undefined
        if (channelId === null || channelId === undefined) {
            throw new Error('Required parameter channelId was null or undefined when calling getReadings.');
        }
        if (beginDate !== undefined) {
            queryParameters = queryParameters.set('beginDate', beginDate.toISOString());
        }
        if (endDate !== undefined) {
            queryParameters = queryParameters.set('endDate', endDate.toISOString());
        }
        if (originalValue !== undefined) {
            queryParameters = queryParameters.set('originalValue', originalValue);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves one route
     *
     * @param id The identifier for route being retrieved
     */
    getRouteWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getRoute.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves one route and all the meters on that route  The meters are ordered by display order
     *
     * @param id The identifier for route being retrieved
     */
    getRouteDetailsWithHttpInfo(id, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/${id}/details'
            .replace('${' + 'id' + '}', String(id));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getRouteDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves all routes
     *
     */
    getRoutesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Retrieves a list of routes with their list of meters and a list of channels on each meter with the latest reading  Meters are returned in order they appear on a route  If the interval filter is passed and no channels match the filter, the route is not included in the response.
     *
     * @param filter
     */
    getRoutesWithMetersChannelsLatestReadingWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/route/meter/channel/latestReading';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Gets a list of the Adjusted Cost Types
     *
     */
    getSavingsAdjustedCostTypeListWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustedCostType';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get a single Savings Details record of usage and cost avoidance for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill/${billId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSavingsMeterBill.');
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getSavingsMeterBill.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get cost avoidance savings by day for a meter and bill
     *
     * @param meterId The meter for which to retrieve data
     * @param billId The bill for which to retrieve data
     */
    getSavingsMeterBillDailyWithHttpInfo(meterId, billId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill/${billId}/daily'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'billId' + '}', String(billId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSavingsMeterBillDaily.');
        }
        // verify required parameter 'billId' is not null or undefined
        if (billId === null || billId === undefined) {
            throw new Error('Required parameter billId was null or undefined when calling getSavingsMeterBillDaily.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get Savings Details of usage and cost avoidance for a meter&#39;s bills
     *
     * @param meterId The meter for which to retrieve data
     * @param numberOfYears Number of years of data to return; includes the current year - Defaults to 5
     */
    getSavingsMeterBillListWithHttpInfo(meterId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/bill'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSavingsMeterBillList.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get a single cost avoidance task by its unique ID
     *
     * @param taskId
     */
    getSavingsTaskWithHttpInfo(taskId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/task/${taskId}'
            .replace('${' + 'taskId' + '}', String(taskId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'taskId' is not null or undefined
        if (taskId === null || taskId === undefined) {
            throw new Error('Required parameter taskId was null or undefined when calling getSavingsTask.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get a list of cost avoidance tasks  NOTE: does not include cost avoidance tasks created from prior versions of the software
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getSavingsTasksWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/task';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get Special Adjustment Methods
     *
     */
    getSpecialAdjustmentMethodsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/special/method';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get Special Adjustment Types
     *
     */
    getSpecialAdjustmentTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/special/type';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get all unplaced meters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getUnplacedMetersWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/meter/unplacedMeters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    /**
     * Get meters on a particular place
     *
     * @param placeId The id of the place
     */
    getUtilityPlatformMetersByPlaceWithHttpInfo(placeId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202203/utilityPlatform/place/${placeId}/meter'
            .replace('${' + 'placeId' + '}', String(placeId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'placeId' is not null or undefined
        if (placeId === null || placeId === undefined) {
            throw new Error('Required parameter placeId was null or undefined when calling getUtilityPlatformMetersByPlace.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$q.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$p = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Add accounts to a vendor
     *
     * @param vendorId The identifier for the vendor to which accounts are being added
     * @param body List of accountIds to move a new vendor
     */
    addAccounts(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.addAccountsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Add accounts to a vendor
     *
     * @param vendorId The identifier for the vendor to which accounts are being added
     * @param body List of accountIds to move a new vendor
     */
    addAccountsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/account'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling addAccounts.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$p.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$o = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccounts(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPossibleDestinationAccountsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountList(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPossibleDestinationAccountsForAccountListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForList(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getPossibleDestinationAccountsForListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccount(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveBillsToAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountList(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveBillsToAccountFromAccountListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromList(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.moveBillsToAccountFromListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bills
     *
     * @param body List of Bill Ids to be used to determine the commodities to be matched on the destination accounts.
     */
    getPossibleDestinationAccountsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/possibleDestinationAccounts';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$o.Put, path, requestOptions);
    }
    /**
     * Retrieves a list of Accounts that contain meters of ALL of the commodities represented by the given Account&#39;s Bill List
     *
     * @param accountId A specific Account that should be used for finding matching Accounts (uses all Bills on the Account Bill List).
     */
    getPossibleDestinationAccountsForAccountListWithHttpInfo(accountId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/possibleDestinationAccounts'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling getPossibleDestinationAccountsForAccountList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$o.Put, path, requestOptions);
    }
    /**
     * Retrieves a list of accounts that contain meters of ALL of the commodities represented by the given Bill List
     *
     * @param listId A specific Bill List that should be used for finding matching Accounts.
     */
    getPossibleDestinationAccountsForListWithHttpInfo(listId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/possibleDestinationAccounts'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling getPossibleDestinationAccountsForList.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$o.Put, path, requestOptions);
    }
    /**
     * Moves the list of given bills to the specified destination account and meters. Each source Meter will be matched with   a corresponding destination Meter based on commodity.
     *
     * @param body DTO containing a list of Bill Ids, the destination Account Id, the destination AcountMeter Ids, a flag   indicating whether the Account GL information should be updated, a flag indicating whether the Meter GL information  should be updated, and a flag indicating whether linked emissions record scope cateogory and GHG factors should be updated.  WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.
     */
    moveBillsToAccountWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/bill/moveBills';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$o.Put, path, requestOptions);
    }
    /**
     *     Moves the bills from the given Account&#39;s Bill List to the specified destination Account and Meters. Each source Meter       will be matched with a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;accountId\&quot;&gt;      Account for the Bill List containing a list of bills that should be moved. All bills from this Account&#39;s Bill List will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param accountId
     * @param body
     */
    moveBillsToAccountFromAccountListWithHttpInfo(accountId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/account/${accountId}/list/bill/moveBills'
            .replace('${' + 'accountId' + '}', String(accountId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'accountId' is not null or undefined
        if (accountId === null || accountId === undefined) {
            throw new Error('Required parameter accountId was null or undefined when calling moveBillsToAccountFromAccountList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$o.Put, path, requestOptions);
    }
    /**
     *     Moves the bills from the given Bill List to the specified destination Account and Meters. Each source Meter will be matched with       a corresponding destination Meter based on commodity.  &lt;param name&#x3D;\&quot;listId\&quot;&gt;      Bill List containing a list of bills that should be moved. All bills from this list will be moved.  &lt;/param&gt;&lt;param name&#x3D;\&quot;dto\&quot;&gt;      DTO containing the destination Account Id, the destination AcountMeter Ids, a flag indicating whether the Account GL       information should be updated, a flag indicating whether the Meter GL information should be updated,      and a flag indicating whether linked emissions record scope and GHG factors should be updated.      WARNING: If emissions record scope categories and GHG factors are updated, any notes and/or attachments on those emissions records will be lost.  &lt;/param&gt;
     *
     * @param listId
     * @param body
     */
    moveBillsToAccountFromListWithHttpInfo(listId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/list/${listId}/moveBills'
            .replace('${' + 'listId' + '}', String(listId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'listId' is not null or undefined
        if (listId === null || listId === undefined) {
            throw new Error('Required parameter listId was null or undefined when calling moveBillsToAccountFromList.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$o.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$n = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edits the public display settings for a dashboard. Settings can only be applied to public dashboards. Filter settings cannot be applied to Map dashboards.  To apply these settings, you must have the PublicDashboardsOrMaps Manage permission.  You must also have either created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier for the dashboard to apply settings to.
     * @param body An object containing the settings to be applied.
     */
    editDashboardSettings(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits the public display settings for a dashboard. Settings can only be applied to public dashboards. Filter settings cannot be applied to Map dashboards.  To apply these settings, you must have the PublicDashboardsOrMaps Manage permission.  You must also have either created the dashboard  or have DashboardAdministrator Manage and the dashboard is shared at all  or have DashboardAdministrator Manage permission and the dashboard is public  or have SharedDashboardsOrMaps Edit permission and the dashboard is shared with you
     *
     * @param dashboardId The identifier for the dashboard to apply settings to.
     * @param body An object containing the settings to be applied.
     */
    editDashboardSettingsWithHttpInfo(dashboardId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202208/dashboard/${dashboardId}/publicsetting'
            .replace('${' + 'dashboardId' + '}', String(dashboardId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'dashboardId' is not null or undefined
        if (dashboardId === null || dashboardId === undefined) {
            throw new Error('Required parameter dashboardId was null or undefined when calling editDashboardSettings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$n.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$m = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a rate schedule
     *
     * @param body The properties of the rate schedule to be created
     */
    createRate(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRateWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a rate schedule
     *
     * @param body The properties of the rate schedule to be created
     */
    createRateWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$m.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$l = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete a rate schedule
     *
     * @param rateId Unique identifier of the rate schedule to be deleted
     */
    deleteRate(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a rate schedule
     *
     * @param rateId Unique identifier of the rate schedule to be deleted
     */
    deleteRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling deleteRate.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$l.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$k = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a rate schedule version
     * Allows the user to create a new version for a rate schedule for use in chargeback scenarios where use or demand cost for calculated bills must be created from a predefined unit cost.            ### Validation          * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Inserting a rate version before an existing version will set the new version&#39;s end date to the effective date of the subsequent version.  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule to receive the new version
     * @param body The properties of the rate schedule version to be created
     */
    createRateVersion(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRateVersionWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a version of a rate schedule
     * ### Validation  * The last remaining rate version may not be deleted    ### Other Remarks  * When a rate version is deleted, if there is a preceding rate version, then its end date will be reset to the end date of the deleted rate version.
     * @param rateId Unique identifier of the rate schedule to which the version being deleted belongs
     * @param versionId Unique identifier of the rate schedule version to delete
     */
    deleteRateVersion(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a rate
     *
     * @param rateId Unique identifier of the rate schedule to be edited
     * @param body Updated properties of the rate schedule to be edited
     */
    editRate(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRateWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a rate schedule version
     * ### Validation  * Effective date of the edited version      * Must be after the effective date of the previous version      * Must be prior to the effective date of the next version  * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule whose version will be edited
     * @param versionId Unique identifier of the rate schedule version to be edited
     * @param body Updated properties of the rate schedule version to be edited
     */
    editRateVersion(rateId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRateVersionWithHttpInfo(rateId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a rate schedule version
     * Allows the user to create a new version for a rate schedule for use in chargeback scenarios where use or demand cost for calculated bills must be created from a predefined unit cost.            ### Validation          * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Inserting a rate version before an existing version will set the new version&#39;s end date to the effective date of the subsequent version.  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule to receive the new version
     * @param body The properties of the rate schedule version to be created
     */
    createRateVersionWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling createRateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$k.Post, path, requestOptions);
    }
    /**
     * Delete a version of a rate schedule
     * ### Validation  * The last remaining rate version may not be deleted    ### Other Remarks  * When a rate version is deleted, if there is a preceding rate version, then its end date will be reset to the end date of the deleted rate version.
     * @param rateId Unique identifier of the rate schedule to which the version being deleted belongs
     * @param versionId Unique identifier of the rate schedule version to delete
     */
    deleteRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version/${versionId}'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling deleteRateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling deleteRateVersion.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$k.Delete, path, requestOptions);
    }
    /**
     * Edit a rate
     *
     * @param rateId Unique identifier of the rate schedule to be edited
     * @param body Updated properties of the rate schedule to be edited
     */
    editRateWithHttpInfo(rateId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling editRate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$k.Put, path, requestOptions);
    }
    /**
     * Edit a rate schedule version
     * ### Validation  * Effective date of the edited version      * Must be after the effective date of the previous version      * Must be prior to the effective date of the next version  * Account and meter line items      * Subtotal calculation type is not supported    ### Other Remarks  * Null values are acceptable for use and demand unit costs. However, for chargeback bills to calculate correctly, these values must be provided.
     * @param rateId Unique identifier of the rate schedule whose version will be edited
     * @param versionId Unique identifier of the rate schedule version to be edited
     * @param body Updated properties of the rate schedule version to be edited
     */
    editRateVersionWithHttpInfo(rateId, versionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version/${versionId}'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling editRateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling editRateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$k.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$j = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create an emission record
     *
     * @param body Data representing the record being created
     */
    createEmissionRecord(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createEmissionRecordWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates an emission record import profile
     *
     * @param body Object containing settings for the new profile
     */
    createRecordImportProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createRecordImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes an emission record import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteRecordImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits an emission record import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings to change
     */
    editRecordImportProfile(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editRecordImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * This endpoint allows the import of a emission records import file.  The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEmissionRecordsWithProfile(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importEmissionRecordsWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create an emission record
     *
     * @param body Data representing the record being created
     */
    createEmissionRecordWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$j.Post, path, requestOptions);
    }
    /**
     * Creates an emission record import profile
     *
     * @param body Object containing settings for the new profile
     */
    createRecordImportProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$j.Post, path, requestOptions);
    }
    /**
     * Deletes an emission record import profile
     *
     * @param profileId The identifier of the profile to delete
     */
    deleteRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling deleteRecordImportProfile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$j.Delete, path, requestOptions);
    }
    /**
     * Edits an emission record import profile
     *
     * @param profileId The identifier of the profile to edit
     * @param body Object containing settings to change
     */
    editRecordImportProfileWithHttpInfo(profileId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling editRecordImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$j.Put, path, requestOptions);
    }
    /**
     * This endpoint allows the import of a emission records import file.  The file should be a base64-encoded delimited text file with a UTF8 character set.
     *
     * @param body DTO containing the data to import and the profile that defines the structure.
     */
    importEmissionRecordsWithProfileWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$j.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$i = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Delete an emission record
     *
     * @param emissionRecordId The Id of the emission record to delete
     */
    deleteEmissionRecord(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an emission record
     *
     * @param emissionRecordId The Id of the emission record to delete
     */
    deleteEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord/${emissionRecordId}'
            .replace('${' + 'emissionRecordId' + '}', String(emissionRecordId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionRecordId' is not null or undefined
        if (emissionRecordId === null || emissionRecordId === undefined) {
            throw new Error('Required parameter emissionRecordId was null or undefined when calling deleteEmissionRecord.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$i.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$h = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Edit an emission record
     *
     * @param emissionRecordId The Id of the emission record to edit
     * @param body Data representing the emission record being edited
     */
    editEmissionRecord(emissionRecordId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editEmissionRecordWithHttpInfo(emissionRecordId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an emission record
     *
     * @param emissionRecordId The Id of the emission record to edit
     * @param body Data representing the emission record being edited
     */
    editEmissionRecordWithHttpInfo(emissionRecordId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord/${emissionRecordId}'
            .replace('${' + 'emissionRecordId' + '}', String(emissionRecordId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionRecordId' is not null or undefined
        if (emissionRecordId === null || emissionRecordId === undefined) {
            throw new Error('Required parameter emissionRecordId was null or undefined when calling editEmissionRecord.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$h.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$g = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordList(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.collectionRecordListWithHttpInfo(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExport(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.collectionRecordListExcelExportWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordList(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.emissionSourceRecordListWithHttpInfo(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExport(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.emissionSourceRecordListExcelExportWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecord(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecords(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getEmissionRecordsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfile(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfiles(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRecordImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the collection records list
     *
     * @param collectionId The collection identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    collectionRecordListWithHttpInfo(collectionId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/collection/${collectionId}/list/record'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling collectionRecordList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param collectionId The collection to export records
     */
    collectionRecordListExcelExportWithHttpInfo(collectionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/collection/${collectionId}/list/record/excelexport'
            .replace('${' + 'collectionId' + '}', String(collectionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'collectionId' is not null or undefined
        if (collectionId === null || collectionId === undefined) {
            throw new Error('Required parameter collectionId was null or undefined when calling collectionRecordListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Get the emission source records list
     *
     * @param emissionSourceId The emission source identifier to retrieve records list for
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    emissionSourceRecordListWithHttpInfo(emissionSourceId, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/emissionSource/${emissionSourceId}/list/record'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling emissionSourceRecordList.');
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Export list data to excel spreadsheet format
     *
     * @param emissionSourceId The emissionSource to export records
     */
    emissionSourceRecordListExcelExportWithHttpInfo(emissionSourceId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/emissionSource/${emissionSourceId}/list/record/excelexport'
            .replace('${' + 'emissionSourceId' + '}', String(emissionSourceId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionSourceId' is not null or undefined
        if (emissionSourceId === null || emissionSourceId === undefined) {
            throw new Error('Required parameter emissionSourceId was null or undefined when calling emissionSourceRecordListExcelExport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Retrieve an emission record by ID
     *
     * @param emissionRecordId The Id of the emission record to retrieve
     */
    getEmissionRecordWithHttpInfo(emissionRecordId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord/${emissionRecordId}'
            .replace('${' + 'emissionRecordId' + '}', String(emissionRecordId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'emissionRecordId' is not null or undefined
        if (emissionRecordId === null || emissionRecordId === undefined) {
            throw new Error('Required parameter emissionRecordId was null or undefined when calling getEmissionRecord.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Retrieve a list of emission records
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getEmissionRecordsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202306/emissionRecord';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Get an emission record import profile
     *
     * @param profileId The identifier of the profile to get
     */
    getRecordImportProfileWithHttpInfo(profileId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile/${profileId}'
            .replace('${' + 'profileId' + '}', String(profileId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'profileId' is not null or undefined
        if (profileId === null || profileId === undefined) {
            throw new Error('Required parameter profileId was null or undefined when calling getRecordImportProfile.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    /**
     * Get all emission record import profiles
     *
     */
    getRecordImportProfilesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202403/import/record/profile';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$g.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$f = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     */
    installReports(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.installReportsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     */
    installReportsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/install/latest';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$f.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$e = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param body
     */
    createReportGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReportGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a Report Group
     *
     * @param reportGroupId
     */
    deleteReportGroup(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportGroupWithHttpInfo(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param reportGroupId
     * @param body
     */
    editReportGroup(reportGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportGroupWithHttpInfo(reportGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    createReportGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$e.Post, path, requestOptions);
    }
    /**
     * Deletes a Report Group
     *
     * @param reportGroupId
     */
    deleteReportGroupWithHttpInfo(reportGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup/${reportGroupId}'
            .replace('${' + 'reportGroupId' + '}', String(reportGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportGroupId' is not null or undefined
        if (reportGroupId === null || reportGroupId === undefined) {
            throw new Error('Required parameter reportGroupId was null or undefined when calling deleteReportGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$e.Delete, path, requestOptions);
    }
    /**
     *
     *
     * @param reportGroupId
     * @param body
     */
    editReportGroupWithHttpInfo(reportGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/reportgroup/${reportGroupId}'
            .replace('${' + 'reportGroupId' + '}', String(reportGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'reportGroupId' is not null or undefined
        if (reportGroupId === null || reportGroupId === undefined) {
            throw new Error('Required parameter reportGroupId was null or undefined when calling editReportGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$e.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$d = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsReportsRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Subscribe to a report and receive scheduled emails  This must be a saved report that belongs to or is shared with the current user  Only SSRS reports are supported
     *
     * @param specificReportId
     * @param body
     */
    createReportSubscription(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createReportSubscriptionWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Save a specific report to Saved Reports
     *
     * @param specificReportId The specific report to save
     * @param body The specific report create properties
     */
    createSpecificReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     */
    deleteReportSubscription(specificReportId, reportSubscriptionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param specificReportId
     */
    deleteSpecificReport(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Execute a report, save it in a given format, and email it to a list of recipients.   If distributing reports, returns a 204 No Content if onlySendIfData is set to True and the report generated no data;   returns a 200 and the generated report for download or an empty body if onlySendIfData is set to True
     *
     * @param specificReportId The ID of the specific report to run
     * @param body Allows the user to run one report and optionally email it to one or more recipients. They can optionally specify whether or not the report(s) should be sent if they contain no data.
     */
    distributeReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.distributeReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be edited
     * @param body The list of filters to apply
     */
    editReportFilters(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportFiltersWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     * @param body
     */
    editReportSubscription(specificReportId, reportSubscriptionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a specific report
     *
     * @param specificReportId The specific report to edit
     * @param body The specific report edit properties
     */
    editSpecificReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be retrieved
     */
    getReportFilters(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportFiltersWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get sharing information for a report
     * Only the user who created the report or a report administrator is permitted to get sharing details for a report.
     * @param specificReportId The specific report for which to retrieve sharing information
     */
    getReportSharingDetails(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportSharingDetailsWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all available report subscription schedule types, and their day indicator values
     *
     */
    getReportSubscriptionScheduleTypes(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getReportSubscriptionScheduleTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a report by its specificReportID.
     *
     * @param specificReportId
     */
    getSpecificReport(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a filterable list of installed, saved, and shared reports available to the current user.
     *
     * @param filter
     */
    getSpecificReports(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecificReportsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Execute and email report subscriptions that are ready to be run
     *
     */
    processReportSubscriptions(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.processReportSubscriptionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Generates a \&quot;quick report\&quot; in the specified export format (or in its preferred export format if not specified) as identified by the provided report code and applying ONLY the filters supplied.
     *
     * @param body
     */
    runQuickReport(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.runQuickReportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Run a report and download in the provided format
     *
     * @param specificReportId The ID of the specific report to run
     * @param format The format in which the generated report should be downloaded. Supported options are [\&quot;excel\&quot;, \&quot;csv\&quot;, \&quot;pdf\&quot;, \&quot;word\&quot;]
     */
    runReport(specificReportId, format, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.runReportWithHttpInfo(specificReportId, format, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Share a saved report with other users
     *
     * @param specificReportId ID of the saved report to share
     * @param body Updated sharing details for the report
     */
    shareSavedReport(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.shareSavedReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the visibility of a report for the current user  This must be a report you can see  Which means you must have created the report  or have ReportAdministrator Manage permission and the report is shared at all  or have SharedReports View permission and the report is shared with you
     *
     * @param specificReportId Specific dashboard
     * @param body Set Visibility
     */
    toggleSharedReportVisibility(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.toggleSharedReportVisibilityWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Subscribe to a report and receive scheduled emails  This must be a saved report that belongs to or is shared with the current user  Only SSRS reports are supported
     *
     * @param specificReportId
     * @param body
     */
    createReportSubscriptionWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/subscription'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling createReportSubscription.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Post, path, requestOptions);
    }
    /**
     * Save a specific report to Saved Reports
     *
     * @param specificReportId The specific report to save
     * @param body The specific report create properties
     */
    createSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/copy'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling createSpecificReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Post, path, requestOptions);
    }
    /**
     * Delete a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     */
    deleteReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/subscription/${reportSubscriptionId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId))
            .replace('${' + 'reportSubscriptionId' + '}', String(reportSubscriptionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling deleteReportSubscription.');
        }
        // verify required parameter 'reportSubscriptionId' is not null or undefined
        if (reportSubscriptionId === null || reportSubscriptionId === undefined) {
            throw new Error('Required parameter reportSubscriptionId was null or undefined when calling deleteReportSubscription.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Delete, path, requestOptions);
    }
    /**
     *
     *
     * @param specificReportId
     */
    deleteSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling deleteSpecificReport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Delete, path, requestOptions);
    }
    /**
     * Execute a report, save it in a given format, and email it to a list of recipients.   If distributing reports, returns a 204 No Content if onlySendIfData is set to True and the report generated no data;   returns a 200 and the generated report for download or an empty body if onlySendIfData is set to True
     *
     * @param specificReportId The ID of the specific report to run
     * @param body Allows the user to run one report and optionally email it to one or more recipients. They can optionally specify whether or not the report(s) should be sent if they contain no data.
     */
    distributeReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/exec/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling distributeReport.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Post, path, requestOptions);
    }
    /**
     * Edit the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be edited
     * @param body The list of filters to apply
     */
    editReportFiltersWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/filter'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling editReportFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Put, path, requestOptions);
    }
    /**
     * Edit a report subscription  This must be a subscription that belongs to the current user
     *
     * @param specificReportId
     * @param reportSubscriptionId
     * @param body
     */
    editReportSubscriptionWithHttpInfo(specificReportId, reportSubscriptionId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/subscription/${reportSubscriptionId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId))
            .replace('${' + 'reportSubscriptionId' + '}', String(reportSubscriptionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling editReportSubscription.');
        }
        // verify required parameter 'reportSubscriptionId' is not null or undefined
        if (reportSubscriptionId === null || reportSubscriptionId === undefined) {
            throw new Error('Required parameter reportSubscriptionId was null or undefined when calling editReportSubscription.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Put, path, requestOptions);
    }
    /**
     * Edit a specific report
     *
     * @param specificReportId The specific report to edit
     * @param body The specific report edit properties
     */
    editSpecificReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling editSpecificReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Put, path, requestOptions);
    }
    /**
     * Get the filters for a specific report.
     *
     * @param specificReportId The specific report for which the filters are to be retrieved
     */
    getReportFiltersWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/filter'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling getReportFilters.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Get, path, requestOptions);
    }
    /**
     * Get sharing information for a report
     * Only the user who created the report or a report administrator is permitted to get sharing details for a report.
     * @param specificReportId The specific report for which to retrieve sharing information
     */
    getReportSharingDetailsWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/share'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling getReportSharingDetails.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Get, path, requestOptions);
    }
    /**
     * Get a list of all available report subscription schedule types, and their day indicator values
     *
     */
    getReportSubscriptionScheduleTypesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/subscription/scheduletype';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Get, path, requestOptions);
    }
    /**
     * Get a report by its specificReportID.
     *
     * @param specificReportId
     */
    getSpecificReportWithHttpInfo(specificReportId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling getSpecificReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Get, path, requestOptions);
    }
    /**
     * Get a filterable list of installed, saved, and shared reports available to the current user.
     *
     * @param filter
     */
    getSpecificReportsWithHttpInfo(filter, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Get, path, requestOptions);
    }
    /**
     * Execute and email report subscriptions that are ready to be run
     *
     */
    processReportSubscriptionsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/exec/subscription';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Post, path, requestOptions);
    }
    /**
     * Generates a \&quot;quick report\&quot; in the specified export format (or in its preferred export format if not specified) as identified by the provided report code and applying ONLY the filters supplied.
     *
     * @param body
     */
    runQuickReportWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/quick';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Post, path, requestOptions);
    }
    /**
     * Run a report and download in the provided format
     *
     * @param specificReportId The ID of the specific report to run
     * @param format The format in which the generated report should be downloaded. Supported options are [\&quot;excel\&quot;, \&quot;csv\&quot;, \&quot;pdf\&quot;, \&quot;word\&quot;]
     */
    runReportWithHttpInfo(specificReportId, format, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/exec/${specificReportId}'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling runReport.');
        }
        if (format !== undefined) {
            queryParameters = queryParameters.set('format', format);
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Get, path, requestOptions);
    }
    /**
     * Share a saved report with other users
     *
     * @param specificReportId ID of the saved report to share
     * @param body Updated sharing details for the report
     */
    shareSavedReportWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/share'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling shareSavedReport.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Put, path, requestOptions);
    }
    /**
     * Update the visibility of a report for the current user  This must be a report you can see  Which means you must have created the report  or have ReportAdministrator Manage permission and the report is shared at all  or have SharedReports View permission and the report is shared with you
     *
     * @param specificReportId Specific dashboard
     * @param body Set Visibility
     */
    toggleSharedReportVisibilityWithHttpInfo(specificReportId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/report/${specificReportId}/visible'
            .replace('${' + 'specificReportId' + '}', String(specificReportId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'specificReportId' is not null or undefined
        if (specificReportId === null || specificReportId === undefined) {
            throw new Error('Required parameter specificReportId was null or undefined when calling toggleSharedReportVisibility.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$d.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportsRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$c = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsRolesManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     *
     *
     * @param body
     */
    createUserRole(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUserRoleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a user role
     *
     * @param userRoleId The identifier for the role being deleted
     */
    deleteUserRole(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteUserRoleWithHttpInfo(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    editUserRole(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUserRoleWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    setUserRoleHidden(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.setUserRoleHiddenWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     *
     *
     * @param body
     */
    createUserRoleWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/userrole';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$c.Post, path, requestOptions);
    }
    /**
     * Deletes a user role
     *
     * @param userRoleId The identifier for the role being deleted
     */
    deleteUserRoleWithHttpInfo(userRoleId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userrole/${userRoleId}'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling deleteUserRole.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$c.Delete, path, requestOptions);
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    editUserRoleWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/userrole/${userRoleId}'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling editUserRole.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$c.Put, path, requestOptions);
    }
    /**
     *
     *
     * @param userRoleId
     * @param body
     */
    setUserRoleHiddenWithHttpInfo(userRoleId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/userrole/${userRoleId}/hidden'
            .replace('${' + 'userRoleId' + '}', String(userRoleId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userRoleId' is not null or undefined
        if (userRoleId === null || userRoleId === undefined) {
            throw new Error('Required parameter userRoleId was null or undefined when calling setUserRoleHidden.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$c.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRolesManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRolesManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsRolesManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$b = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavings(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createOtherSavingsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createOtherSavingsCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustment(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createSpecialAdjustmentWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavings(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentById(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteSpecialAdjustmentByIdWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavings(meterId, otherSavingsId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editOtherSavingsWithHttpInfo(meterId, otherSavingsId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustment(meterId, specialAdjustmentId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which the other savings is being created
     * @param body Data representing the other savings adjustment being created
     */
    createOtherSavingsWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Post, path, requestOptions);
    }
    /**
     * Create other savings category
     *
     * @param body Data representing the other saving category being created
     */
    createOtherSavingsCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/othersavings/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Post, path, requestOptions);
    }
    /**
     * Create a new special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter for which to create a special adjustment
     * @param body Data representing the special adjustment being created
     */
    createSpecialAdjustmentWithHttpInfo(meterId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling createSpecialAdjustment.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Post, path, requestOptions);
    }
    /**
     * Delete an other savings adjustment
     *
     * @param meterId The meter for which the other savings is being deleted
     * @param otherSavingsId The other saving identifier which is being deleted
     */
    deleteOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings/${otherSavingsId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'otherSavingsId' + '}', String(otherSavingsId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteOtherSavings.');
        }
        // verify required parameter 'otherSavingsId' is not null or undefined
        if (otherSavingsId === null || otherSavingsId === undefined) {
            throw new Error('Required parameter otherSavingsId was null or undefined when calling deleteOtherSavings.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Delete, path, requestOptions);
    }
    /**
     * Delete a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter from which to delete the special adjustment
     * @param specialAdjustmentId The special adjustment to delete
     */
    deleteSpecialAdjustmentByIdWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special/${specialAdjustmentId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'specialAdjustmentId' + '}', String(specialAdjustmentId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling deleteSpecialAdjustmentById.');
        }
        // verify required parameter 'specialAdjustmentId' is not null or undefined
        if (specialAdjustmentId === null || specialAdjustmentId === undefined) {
            throw new Error('Required parameter specialAdjustmentId was null or undefined when calling deleteSpecialAdjustmentById.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Delete, path, requestOptions);
    }
    /**
     * Edit an other savings adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter whose other savings is being edited
     * @param otherSavingsId The other savings to edit
     * @param body Data representing the other savings adjustment being edited
     */
    editOtherSavingsWithHttpInfo(meterId, otherSavingsId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings/${otherSavingsId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'otherSavingsId' + '}', String(otherSavingsId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editOtherSavings.');
        }
        // verify required parameter 'otherSavingsId' is not null or undefined
        if (otherSavingsId === null || otherSavingsId === undefined) {
            throw new Error('Required parameter otherSavingsId was null or undefined when calling editOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Put, path, requestOptions);
    }
    /**
     * Edit a special adjustment  Meter Cost Avoidance Savings will be re-calculated
     *
     * @param meterId The meter with the special adjustment to edit
     * @param specialAdjustmentId The special adjustment to edit
     * @param body Data representing the special adjustment being edited
     */
    editSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special/${specialAdjustmentId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'specialAdjustmentId' + '}', String(specialAdjustmentId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling editSpecialAdjustment.');
        }
        // verify required parameter 'specialAdjustmentId' is not null or undefined
        if (specialAdjustmentId === null || specialAdjustmentId === undefined) {
            throw new Error('Required parameter specialAdjustmentId was null or undefined when calling editSpecialAdjustment.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$b.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$a = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get a other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     */
    getAllOtherSavings(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getAllOtherSavingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get one other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     * @param otherSavingsId The identifier for the other savings record which is being retrieved
     */
    getOneOtherSavings(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getOneOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get other savings categories
     *
     */
    getOtherSavingsCategories(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getOtherSavingsCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a single special adjustment by its unique ID
     *
     * @param meterId The meter for which to return the special adjustment
     * @param specialAdjustmentId Unique ID of the special adjustment to return
     */
    getSpecialAdjustment(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get all the special adjustments for the meter
     *
     * @param meterId The meter for which to return special adjustment
     */
    getSpecialAdjustments(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getSpecialAdjustmentsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     */
    getAllOtherSavingsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getAllOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$a.Get, path, requestOptions);
    }
    /**
     * Get one other savings for a meter
     *
     * @param meterId The meter for which the other savings are being retrieved
     * @param otherSavingsId The identifier for the other savings record which is being retrieved
     */
    getOneOtherSavingsWithHttpInfo(meterId, otherSavingsId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/othersavings/${otherSavingsId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'otherSavingsId' + '}', String(otherSavingsId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getOneOtherSavings.');
        }
        // verify required parameter 'otherSavingsId' is not null or undefined
        if (otherSavingsId === null || otherSavingsId === undefined) {
            throw new Error('Required parameter otherSavingsId was null or undefined when calling getOneOtherSavings.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$a.Get, path, requestOptions);
    }
    /**
     * Get other savings categories
     *
     */
    getOtherSavingsCategoriesWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/adjustment/othersavings/category';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$a.Get, path, requestOptions);
    }
    /**
     * Get a single special adjustment by its unique ID
     *
     * @param meterId The meter for which to return the special adjustment
     * @param specialAdjustmentId Unique ID of the special adjustment to return
     */
    getSpecialAdjustmentWithHttpInfo(meterId, specialAdjustmentId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special/${specialAdjustmentId}'
            .replace('${' + 'meterId' + '}', String(meterId))
            .replace('${' + 'specialAdjustmentId' + '}', String(specialAdjustmentId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSpecialAdjustment.');
        }
        // verify required parameter 'specialAdjustmentId' is not null or undefined
        if (specialAdjustmentId === null || specialAdjustmentId === undefined) {
            throw new Error('Required parameter specialAdjustmentId was null or undefined when calling getSpecialAdjustment.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$a.Get, path, requestOptions);
    }
    /**
     * Get all the special adjustments for the meter
     *
     * @param meterId The meter for which to return special adjustment
     */
    getSpecialAdjustmentsWithHttpInfo(meterId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/meter/${meterId}/adjustment/special'
            .replace('${' + 'meterId' + '}', String(meterId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'meterId' is not null or undefined
        if (meterId === null || meterId === undefined) {
            throw new Error('Required parameter meterId was null or undefined when calling getSpecialAdjustments.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$a.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$9 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Calculate savings for the meters that match the filter conditions, using the provided settings
     *
     * @param body Settings and filter conditions for savings processing
     */
    calculateSavings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.calculateSavingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return available filters for Cost Avoidance processors  Filters:  - Commodity ID  - Commodity Name  - Meter Group Name  - Building Group Name  - Topmost Place Code  - Topmost Place Name
     *
     */
    getCostAvoidanceFilters(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCostAvoidanceFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Calculate savings for the meters that match the filter conditions, using the provided settings
     *
     * @param body Settings and filter conditions for savings processing
     */
    calculateSavingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/exec';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$9.Post, path, requestOptions);
    }
    /**
     * Return available filters for Cost Avoidance processors  Filters:  - Commodity ID  - Commodity Name  - Meter Group Name  - Building Group Name  - Topmost Place Code  - Topmost Place Name
     *
     */
    getCostAvoidanceFiltersWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/savings/filters';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$9.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$8 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a commodity
     *
     * @param body Data representing the commodity being created
     */
    createCommodity(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCommodityWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a commodity category
     *
     * @param body Data representing the commodity category being created
     */
    createCommodityCategory(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createCommodityCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a commodity
     *
     * @param commodityId The commodity Id
     */
    deleteCommodity(commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCommodityWithHttpInfo(commodityId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     */
    deleteCommodityCategory(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteCommodityCategoryWithHttpInfo(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a commodity
     *
     * @param commodityId The commodity Id
     * @param body Data that will be used to update the commodity
     */
    editCommodity(commodityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCommodityWithHttpInfo(commodityId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     * @param body Data representing the commodity category being created
     */
    editCommodityCategory(commodityCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editCommodityCategoryWithHttpInfo(commodityCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a commodity
     *
     * @param body Data representing the commodity being created
     */
    createCommodityWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/commodity';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$8.Post, path, requestOptions);
    }
    /**
     * Creates a commodity category
     *
     * @param body Data representing the commodity category being created
     */
    createCommodityCategoryWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$8.Post, path, requestOptions);
    }
    /**
     * Deletes a commodity
     *
     * @param commodityId The commodity Id
     */
    deleteCommodityWithHttpInfo(commodityId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202304/commodity/${commodityId}'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling deleteCommodity.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$8.Delete, path, requestOptions);
    }
    /**
     * Deletes a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     */
    deleteCommodityCategoryWithHttpInfo(commodityCategoryId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory/${commodityCategoryId}'
            .replace('${' + 'commodityCategoryId' + '}', String(commodityCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityCategoryId' is not null or undefined
        if (commodityCategoryId === null || commodityCategoryId === undefined) {
            throw new Error('Required parameter commodityCategoryId was null or undefined when calling deleteCommodityCategory.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$8.Delete, path, requestOptions);
    }
    /**
     * Edits a commodity
     *
     * @param commodityId The commodity Id
     * @param body Data that will be used to update the commodity
     */
    editCommodityWithHttpInfo(commodityId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202410/commodity/${commodityId}'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling editCommodity.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$8.Put, path, requestOptions);
    }
    /**
     * Edits a commodity category
     *
     * @param commodityCategoryId The commodity category identifier
     * @param body Data representing the commodity category being created
     */
    editCommodityCategoryWithHttpInfo(commodityCategoryId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202402/commodityCategory/${commodityCategoryId}'
            .replace('${' + 'commodityCategoryId' + '}', String(commodityCategoryId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityCategoryId' is not null or undefined
        if (commodityCategoryId === null || commodityCategoryId === undefined) {
            throw new Error('Required parameter commodityCategoryId was null or undefined when calling editCommodityCategory.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$8.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$7 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUser(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUserWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroup(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createUserGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroup(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteUserGroupWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRole(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editSystemUsersRoleWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUser(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUserWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroup(userGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editUserGroupWithHttpInfo(userGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettings(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.updateNotificationSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Create a new user. Requires Manage permission for Users &amp; Roles
     *
     * @param body The object defining the properties for the new user
     */
    createUserWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/user';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Post, path, requestOptions);
    }
    /**
     * Create a user group
     *
     * @param body Data representing the user group being created
     */
    createUserGroupWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Post, path, requestOptions);
    }
    /**
     * Delete a user group
     *
     * @param userGroupId Id of the user group to delete
     */
    deleteUserGroupWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling deleteUserGroup.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Delete, path, requestOptions);
    }
    /**
     * Edit a system user&#39;s role.
     *
     * @param userId
     * @param body
     */
    editSystemUsersRoleWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/systemUser/${userId}/role'
            .replace('${' + 'userId' + '}', String(userId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userId' is not null or undefined
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling editSystemUsersRole.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Put, path, requestOptions);
    }
    /**
     * Edit an existing user. Requires Manage permission for Users &amp; Roles. Please note that password is optional; all other items are required. MaxApprovalAmount may be null; if there is an existing value and null is passed, the existing value will be overwritten.
     *
     * @param userId The ID of the user to edit
     * @param body The object defining the updated properties of the existing user.
     */
    editUserWithHttpInfo(userId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202406/user/${userId}'
            .replace('${' + 'userId' + '}', String(userId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userId' is not null or undefined
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling editUser.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Put, path, requestOptions);
    }
    /**
     * Edit a user group
     *
     * @param userGroupId Id of the user group to edit
     * @param body Data representing the user group being edited
     */
    editUserGroupWithHttpInfo(userGroupId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling editUserGroup.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Put, path, requestOptions);
    }
    /**
     * Update the default notification settings assigned to new users
     *
     * @param body Values to update the system notification settings.  If a setting is not passed it&#39;s value is not updated.
     */
    updateNotificationSystemSettingsWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/systemsetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$7.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$6 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * The default notification settings assigned to new users
     *
     */
    getNotificationSystemSettings(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getNotificationSystemSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Return a specific user and its properties. Requires View permission for Users &amp; Roles
     *
     * @param userId The ID of the user to return
     */
    getUser(userId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserWithHttpInfo(userId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Gets a list of user group members
     *
     * @param userGroupId Id of the user group to get the list of members
     */
    getUserGroupMembers(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getUserGroupMembersWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * The default notification settings assigned to new users
     *
     */
    getNotificationSystemSettingsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202108/notification/systemsetting';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$6.Get, path, requestOptions);
    }
    /**
     * Return a specific user and its properties. Requires View permission for Users &amp; Roles
     *
     * @param userId The ID of the user to return
     */
    getUserWithHttpInfo(userId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/user/${userId}'
            .replace('${' + 'userId' + '}', String(userId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userId' is not null or undefined
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling getUser.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$6.Get, path, requestOptions);
    }
    /**
     * Gets a list of user group members
     *
     * @param userGroupId Id of the user group to get the list of members
     */
    getUserGroupMembersWithHttpInfo(userGroupId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/userGroup/${userGroupId}/member'
            .replace('${' + 'userGroupId' + '}', String(userGroupId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'userGroupId' is not null or undefined
        if (userGroupId === null || userGroupId === undefined) {
            throw new Error('Required parameter userGroupId was null or undefined when calling getUserGroupMembers.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$6.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$5 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Download file for a rate custom field
     *
     * @param rateId
     * @param versionId
     * @param udfId
     */
    downloadRateCustomFieldFile(rateId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadRateCustomFieldFileWithHttpInfo(rateId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFile(vendorId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.downloadVendorCustomFieldFileWithHttpInfo(vendorId, udfId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by commodities for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param commodityId The commodity to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getCommodityActualYearly(commodityId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getCommodityActualYearlyWithHttpInfo(commodityId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a rate schedule
     *
     * @param rateId Unique ID of the rate schedule
     */
    getRate(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by rate for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param rateId The rate to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getRateActualYearly(rateId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateActualYearlyWithHttpInfo(rateId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get the unit used by a rate. The unit is determined by the usage unit on the most recent template assigned to a meter with the given rate.
     *
     * @param rateId Unique identifier of the rate schedule for which the unit will be retrieved
     */
    getRateUnit(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateUnitWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a rate version with its details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     * @param versionId ID of the rate schedule version to retrieve
     */
    getRateVersion(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all versions for a rate schedule with their details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     */
    getRateVersions(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRateVersionsWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRates(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getRatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendor(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves rolled up actual billing data by vendor for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param vendorId The vendor to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getVendorActualYearly(vendorId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorActualYearlyWithHttpInfo(vendorId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContracts(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorContractsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplate(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorTemplateWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfs(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorUdfsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendors(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfs(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getVendorsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Download file for a rate custom field
     *
     * @param rateId
     * @param versionId
     * @param udfId
     */
    downloadRateCustomFieldFileWithHttpInfo(rateId, versionId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/rate/${rateId}/version/${versionId}/udf/${udfId}/download'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling downloadRateCustomFieldFile.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling downloadRateCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadRateCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Download file for a vendor custom field
     *
     * @param vendorId
     * @param udfId
     */
    downloadVendorCustomFieldFileWithHttpInfo(vendorId, udfId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202105/vendor/${vendorId}/udf/${udfId}/download'
            .replace('${' + 'vendorId' + '}', String(vendorId))
            .replace('${' + 'udfId' + '}', String(udfId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling downloadVendorCustomFieldFile.');
        }
        // verify required parameter 'udfId' is not null or undefined
        if (udfId === null || udfId === undefined) {
            throw new Error('Required parameter udfId was null or undefined when calling downloadVendorCustomFieldFile.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by commodities for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param commodityId The commodity to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getCommodityActualYearlyWithHttpInfo(commodityId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/commodity/${commodityId}/digest/actual/yearly'
            .replace('${' + 'commodityId' + '}', String(commodityId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'commodityId' is not null or undefined
        if (commodityId === null || commodityId === undefined) {
            throw new Error('Required parameter commodityId was null or undefined when calling getCommodityActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Get a rate schedule
     *
     * @param rateId Unique ID of the rate schedule
     */
    getRateWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by rate for a given number of years- Result includes cost, use, unit cost on an yearly basis.
     *
     * @param rateId The rate to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getRateActualYearlyWithHttpInfo(rateId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/digest/actual/yearly'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Get the unit used by a rate. The unit is determined by the usage unit on the most recent template assigned to a meter with the given rate.
     *
     * @param rateId Unique identifier of the rate schedule for which the unit will be retrieved
     */
    getRateUnitWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/unit'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateUnit.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Get a rate version with its details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     * @param versionId ID of the rate schedule version to retrieve
     */
    getRateVersionWithHttpInfo(rateId, versionId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version/${versionId}'
            .replace('${' + 'rateId' + '}', String(rateId))
            .replace('${' + 'versionId' + '}', String(versionId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateVersion.');
        }
        // verify required parameter 'versionId' is not null or undefined
        if (versionId === null || versionId === undefined) {
            throw new Error('Required parameter versionId was null or undefined when calling getRateVersion.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Get a list of all versions for a rate schedule with their details including dates, unit cost values, and bodylines
     *
     * @param rateId ID of the rate schedule to retrieve
     */
    getRateVersionsWithHttpInfo(rateId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate/${rateId}/version'
            .replace('${' + 'rateId' + '}', String(rateId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'rateId' is not null or undefined
        if (rateId === null || rateId === undefined) {
            throw new Error('Required parameter rateId was null or undefined when calling getRateVersions.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Get a list of all rate schedules matching the provided filters
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getRatesWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/rate';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves one vendor
     *
     * @param vendorId The identifier for the vendor being retrieved
     */
    getVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendor.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves rolled up actual billing data by vendor for a given number of years- Result includes cost, use, unit cost on an yearly basis. It also includes commodity level break up.
     *
     * @param vendorId The vendor to retrieve data for
     * @param numberOfYears Number of years of data to return includes the current year - Defaults to 4
     */
    getVendorActualYearlyWithHttpInfo(vendorId, numberOfYears, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/digest/actual/yearly'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorActualYearly.');
        }
        if (numberOfYears !== undefined) {
            queryParameters = queryParameters.set('numberOfYears', numberOfYears);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves all Contracts for a particular vendor. &lt;br /&gt;  Contracts are not supported in EnergyCAP Version 7, this API is for reading existing contracts only and may be removed in the future.
     *
     * @param vendorId The vendor identifier for which Contracts are being retrieved
     */
    getVendorContractsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/contract'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorContracts.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves the most recent template from the specified vendor
     *
     * @param vendorId The vendor identifier to search by
     */
    getVendorTemplateWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/vendor/${vendorId}/template'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for a particular vendor
     *
     * @param vendorId The vendor identifier for which user defined field / custom field values are being retrieved
     */
    getVendorUdfsWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/udf'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling getVendorUdfs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves an array of vendors. The array of vendors can be filtered by a number of criteria. See the filter property for more details
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    /**
     * Retrieves all user defined fields / custom fields for all vendors
     *
     * @param filter
     * @param pageSize The number of elements to return in a page
     * @param pageNumber The current page number
     */
    getVendorsUdfsWithHttpInfo(filter, pageSize, pageNumber, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/udf';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        if (filter !== undefined) {
            queryParameters = queryParameters.set('filter', filter);
        }
        if (pageSize !== undefined) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (pageNumber !== undefined) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$5.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$4 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Creates a vendor
     *
     * @param body Data representing the vendor being created
     */
    createVendor(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.createVendorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Creates a vendor
     *
     * @param body Data representing the vendor being created
     */
    createVendorWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$4.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$3 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Deletes a vendor
     *
     * @param vendorId The identifier for the vendor being deleted
     */
    deleteVendor(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.deleteVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Deletes a vendor
     *
     * @param vendorId The identifier for the vendor being deleted
     */
    deleteVendorWithHttpInfo(vendorId, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling deleteVendor.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$3.Delete, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$2 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplate(sourceVendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.copyVendorTemplateWithHttpInfo(sourceVendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendor(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editVendorWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFs(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.editVendorUDFsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplate(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.putVendorTemplateWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Copies any template attached to the provided sourceVendorId to each of the recipientVendorIds specified in the body.  If the recipient vendor has a template defined, it will be replaced with the lines on the source vendor&#39;s template.  If the recipient vendor does not have a template defined, a new template will be created with the lines on the source vendor&#39;s template.
     *
     * @param sourceVendorId Identifier for the \&quot;Source\&quot; vendor, which serves as the source for the template to be copied
     * @param body List of identifiers for the \&quot;Recipient\&quot; vendors, who will each receive a copy of the template attached to the Source vendor
     */
    copyVendorTemplateWithHttpInfo(sourceVendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/vendor/${sourceVendorId}/template/copy'
            .replace('${' + 'sourceVendorId' + '}', String(sourceVendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'sourceVendorId' is not null or undefined
        if (sourceVendorId === null || sourceVendorId === undefined) {
            throw new Error('Required parameter sourceVendorId was null or undefined when calling copyVendorTemplate.');
        }
        // to determine the Accept header
        let produces = [];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2.Post, path, requestOptions);
    }
    /**
     * Edits a vendor
     *
     * @param vendorId The identifier for the vendor being edited
     * @param body Data representing the vendor being edited
     */
    editVendorWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling editVendor.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2.Put, path, requestOptions);
    }
    /**
     * Edits user defined field / custom field values for a particular vendor
     *
     * @param vendorId The identifier for the vendor
     * @param body Data representing the vendor user defined fields / custom fields being edited
     */
    editVendorUDFsWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/vendor/${vendorId}/udf'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling editVendorUDFs.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2.Put, path, requestOptions);
    }
    /**
     * Updates the template for the specified vendor
     *
     * @param vendorId The vendor to apply the template to
     * @param body Definition of the lines to apply to the template. If vendorLines is empty, any existing template will be deleted
     */
    putVendorTemplateWithHttpInfo(vendorId, body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v202206/vendor/${vendorId}/template'
            .replace('${' + 'vendorId' + '}', String(vendorId));
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // verify required parameter 'vendorId' is not null or undefined
        if (vendorId === null || vendorId === undefined) {
            throw new Error('Required parameter vendorId was null or undefined when calling putVendorTemplate.');
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$2.Put, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod$1 = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Import mean daily temperature readings for weather stations which are connected to EnergyCAP weather services
     * ### Other Remarks  By default, this endpoint may be called without parameters to import weather for all \&quot;used\&quot; weather stations (at least one building is assigned to it) beginning from the current date minus 31 days.          By providing a begin date, API users may go further back in history to backfill missing weather data.     If a weather station has no readings at all, then the begin date will be set to 1899-12-31 so we can import history    However the begin date is ascertained, readings will be imported from that date through today&#39;s date, overwriting any existing readings or filling in any missing readings.    The API user may also provide a list of weather station codes. Even if the provided stations are not yet used, weather readings will be imported for them.
     * @param body
     */
    importWeatherData(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.importWeatherDataWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Import mean daily temperature readings for weather stations which are connected to EnergyCAP weather services
     * ### Other Remarks  By default, this endpoint may be called without parameters to import weather for all \&quot;used\&quot; weather stations (at least one building is assigned to it) beginning from the current date minus 31 days.          By providing a begin date, API users may go further back in history to backfill missing weather data.     If a weather station has no readings at all, then the begin date will be set to 1899-12-31 so we can import history    However the begin date is ascertained, readings will be imported from that date through today&#39;s date, overwriting any existing readings or filling in any missing readings.    The API user may also provide a list of weather station codes. Even if the provided stations are not yet used, weather readings will be imported for them.
     * @param body
     */
    importWeatherDataWithHttpInfo(body, extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/weatherstation/import';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [
            'application/json'
        ];
        headers = headers.set('Content-Type', consumes[0]);
        let requestOptions = {
            headers: headers,
            body: body == null ? '' : (consumes[0] == 'application/json' ? JSON.stringify(body) : body), // https://github.com/angular/angular/issues/10612
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod$1.Post, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
const RequestMethod = {
    Get: 'get',
    Post: 'post',
    Put: 'put',
    Delete: 'delete',
    Options: 'options',
    Head: 'head',
    Patch: 'patch'
};
class SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService {
    http;
    basePath = 'https://localhost';
    defaultHeaders = new HttpHeaders();
    configuration = new Configuration();
    constructor(http, basePath, configuration) {
        this.http = http;
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     *
     * Extends object by coping non-existing properties.
     * @param objA object to be extended
     * @param objB source object
     */
    extendObj(objA, objB) {
        for (let key in objB) {
            if (objB.hasOwnProperty(key)) {
                objA[key] = objB[key];
            }
        }
        return objA;
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (let consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * Get weather stations. Includes custom-created weather stations
     *
     */
    getWeatherStations(extraHttpRequestParams, extraHttpRequestHeaders) {
        return this.getWeatherStationsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders)
            .pipe(map((response) => {
            if (response.status === 204) {
                return undefined;
            }
            else {
                return response.body;
            }
        }));
    }
    /**
     * Get weather stations. Includes custom-created weather stations
     *
     */
    getWeatherStationsWithHttpInfo(extraHttpRequestParams, extraHttpRequestHeaders) {
        const path = this.basePath + '/api/v3/weatherstation';
        let queryParameters;
        if (extraHttpRequestParams) {
            if (typeof extraHttpRequestParams.search === 'string') {
                queryParameters = new HttpParams({ fromString: extraHttpRequestParams.search });
            }
            else {
                queryParameters = new HttpParams({ fromObject: extraHttpRequestParams.search });
            }
        }
        else {
            queryParameters = new HttpParams();
        }
        let headers = new HttpHeaders();
        this.defaultHeaders.keys().forEach(key => {
            headers = headers.set(key, this.defaultHeaders.getAll(key));
        });
        if (extraHttpRequestHeaders) {
            Object.entries(extraHttpRequestHeaders).forEach(([key, value]) => {
                headers = headers.set(key, value);
            });
        }
        // to determine the Accept header
        let produces = [
            'application/json'
        ];
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        if (this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]) {
            headers = headers.set('ECI-PUBLIC-DASHBOARD-KEY', this.configuration.apiKeys["ECI-PUBLIC-DASHBOARD-KEY"]);
        }
        const consumes = [];
        let requestOptions = {
            headers: headers,
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            observe: 'response'
        };
        return this.http.request(RequestMethod.Get, path, requestOptions);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService, deps: [{ token: i1.HttpClient }, { token: BASE_PATH, optional: true }, { token: Configuration, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [BASE_PATH]
                }] }, { type: Configuration, decorators: [{
                    type: Optional
                }] }] });

const APIS = [AccountService, AccountDigestService, AccountMeterService, AccrualService, ActivityService, AdminService, ApiService, ApiKeyService, AuditService, AuthenticationService, BatchService, BillService, BillAccountChargeSplitService, BillSplitService, BillViewService, BudgetService, CalculatedBillService, ChannelService, ChargebackEngineService, ChargebackTaskService, ChargebackWorkflowService, CollectionService, CommodityService, CommodityCategoryService, CommodityDigestService, CostCategoryService, CostCenterService, CostCenterDigestService, CountryService, CustomerService, DashboardService, DataPointService, EmissionRecordService, EmissionSourceService, EnergyManagerService, EnergyProjectService, EnergyStarService, EnvironmentService, EsaChannelService, EsaPlaceService, EsaReadingService, ExportService, FileStoreService, FilterService, FlagService, FormulaService, GHGService, GeneralLedgerService, HierarchyService, ImportService, ListService, MeService, MeterService, MeterDigestService, MeterGroupService, MeterGroupDigestService, NotificationService, ObservationService, ObservationTypeService, PlaceService, PlaceBenchmarkService, PlaceDigestService, PlaceGroupService, PlaceGroupDigestService, PostalCodeService, PrimaryUseService, RateService, RateDigestService, ReportService, ReportBuilderService, ReportDistributionService, RouteService, SavingsService, ScheduleService, SearchService, SentinelService, SetupService, SparkService, SummaryAccountService, SystemUserService, TagService, TaskService, TemplateService, TimeZoneService, UDFService, UnitService, UserGroupService, UserRoleService, UtilityPlatformService, VendorService, VendorDigestService, WeatherStationService, WebhookService, WidgetService, WorkflowService, SpanClasspropertyinfoPaginatedPaginatedspanService, SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService, SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService, SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService, SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService, SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService, SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService, SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService, SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService, SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, SpanClasspropertyinfoPermissionPermissionsRolesManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService, SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService, SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService, SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService];

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AbnormalBillCostWithOutlierAnalysisSettingRequest {
    /**
     * Minimum outlier sensitivity for abnormal cost analysis  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>One of 'Severe', 'High', 'Moderate'</span>
     */
    sensitivity;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AbnormalBillCostWithOutlierAnalysisSettingResponse {
    /**
     * Minimum outlier sensitivity for abnormal cost analysis  Possible values - severe, high, moderate  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    sensitivity;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AbnormalBillDemandWithOutlierAnalysisSettingRequest {
    /**
     * Minimum outlier sensitivity for abnormal demand analysis  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>One of 'Severe', 'High', 'Moderate'</span>
     */
    sensitivity;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AbnormalBillDemandWithOutlierAnalysisSettingResponse {
    /**
     * Minimum outlier sensitivity for abnormal demand analysis  Possible values - severe, high, moderate  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    sensitivity;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AbnormalBillUseWithOutlierAnalysisSettingRequest {
    /**
     * Minimum outlier sensitivity for abnormal use analysis  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>One of 'Severe', 'High', 'Moderate'</span>
     */
    sensitivity;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AbnormalBillUseWithOutlierAnalysisSettingResponse {
    /**
     * Minimum outlier sensitivity for abnormal use analysis  Possible values - severe, high, moderate  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    sensitivity;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountAlertRequest {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    beginDate;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Must be greater than or equal to BeginDate</span>
     */
    endDate;
    /**
     *  <span class='property-internal'>Required</span>
     */
    message;
    /**
     *  <span class='property-internal'>Required</span>
     */
    allowBillProcessing;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountAlertResponse {
    /**
     *
     */
    alertId;
    /**
     *
     */
    beginDate;
    /**
     *
     */
    endDate;
    /**
     *
     */
    message;
    /**
     *
     */
    allowBillProcessing;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountAuditEnable {
    /**
     * List of AccountIds to try and update <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    accountIds;
    /**
     * True to allow the accounts' bills to be audited  False to exclude the accounts' bills from being audited <span class='property-internal'>Required (defined)</span>
     */
    auditEnabled;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountAuditSettingsRequest {
    billContainsLineItemDescriptions;
    billContainsLineItemTypes;
    totalBillCostDoesNotMatchLineItemTypes;
    billingPeriodOutsideStartEndDates;
    billOverlapsWithOtherAccountBill;
    gapBetweenBillAndPreviousBillOnAccount;
    billEndsInFuture;
    accountHasMultipleBillsInBillingPeriod;
    statementDateBeforeEndDate;
    dueDateBeforeEndDate;
    billSignificantlyShorterOrLongerThanPrevious;
    tooManyConsecutiveEstimatedBills;
    dueDateTooLongAfterBillEnd;
    statementDateTooLongAfterBillEnd;
    invoiceNumberIsRepeatedOnAccount;
    likelyDuplicateBillOnAccount;
    totalMeterCostIsPercentageHigherThanPastYear;
    totalMeterUseIsPercentageHigherThanPastYear;
    serialNumberDoesNotMatchImportFile;
    rateCodeDoesNotMatchImportFile;
    importFileStartDateAdjustedToPreventGaps;
    accountAlertExistsOnAccountInImportFile;
    abnormalBillCostWithOutlierAnalysis;
    abnormalBillUseWithOutlierAnalysis;
    abnormalBillDemandWithOutlierAnalysis;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountAuditSettingsResponse {
    account;
    /**
     * Indicates if audits are enabled for the account
     */
    auditEnabled;
    settings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountBillAccountChargeSplitSettingsResponse {
    /**
     * The account identifier
     */
    accountId;
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
    /**
     * Split account charges with a bill line type assigned to the cost categories
     */
    costCategories;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountChild {
    /**
     *
     */
    accountId;
    /**
     *
     */
    accountCode;
    /**
     *
     */
    accountInfo;
    vendor;
    /**
     *
     */
    active;
    /**
     *
     */
    hasCalculatedMeter;
    /**
     *
     */
    hasSplitParentMeter;
    /**
     *
     */
    hasSplitChildMeter;
    /**
     *
     */
    isSubAccount;
    /**
     *
     */
    hasSubAccount;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountChildWithType {
    accountType;
    /**
     *
     */
    accountId;
    /**
     *
     */
    accountCode;
    /**
     *
     */
    accountInfo;
    vendor;
    /**
     *
     */
    active;
    /**
     *
     */
    hasCalculatedMeter;
    /**
     *
     */
    hasSplitParentMeter;
    /**
     *
     */
    hasSplitChildMeter;
    /**
     *
     */
    isSubAccount;
    /**
     *
     */
    hasSubAccount;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountCodeHistoryChild {
    /**
     * The previous account code of this account
     */
    previousAccountCode;
    /**
     * Date that the account code was changed
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountCodeHistoryRequest {
    /**
     * Account code that will replace the existing one <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    newAccountCode;
    /**
     * Account info that can replace the existing info <span class='property-internal'>Must be between 0 and 50 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    newAccountInfo;
    /**
     * Date that the account code was changed <span class='property-internal'>Required (defined)</span>
     */
    codeChangeDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountCodeHistoryResponse {
    /**
     * Account identifier <span class='property-internal'>Required (defined)</span>
     */
    accountId;
    /**
     * Account code of the account <span class='property-internal'>Required (defined)</span>
     */
    accountCode;
    /**
     * Name of the account <span class='property-internal'>Required (defined)</span>
     */
    accountInfo;
    accountCodeHistory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountConnectionStatusResponse {
    /**
     * When true this database is connectable to Portfolio Manager
     */
    connectable;
    /**
     * Whether some other database is registered to portfolio manager or not
     */
    otherDatabaseRegistered;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountCreate {
    /**
     * The account code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    accountCode;
    /**
     * The account info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    accountInfo;
    /**
     * The identifier for the account type <span class='property-internal'>Required</span>
     */
    accountTypeId;
    /**
     * The identifier for the cost center to which the account belongs <span class='property-internal'>Topmost (CostCenter)</span> <span class='property-internal'>Required</span>
     */
    costCenterId;
    /**
     * The identifier for the account's vendor <span class='property-internal'>Required</span>
     */
    vendorId;
    /**
     * The identifier for the customer the account serves. This is normally only set for chargeback accounts
     */
    customerId;
    /**
     * The identifier for the account's contact
     */
    contactId;
    /**
     * Indicates if the account is active or inactive
     */
    active;
    /**
     * Indicates if the account is used with accruals
     */
    accrualEnabled;
    /**
     * The address postal code  Required when the country is US or CA <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    postalCode;
    /**
     * The address city <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    city;
    /**
     * The address state <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    state;
    /**
     * The address country <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    country;
    /**
     * The address first line <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line1;
    /**
     * The address second line <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line2;
    /**
     * The address third line <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line3;
    /**
     * The date and time the account deposit was paid
     */
    depositPaid;
    /**
     * The date and time the account deposit was returned
     */
    depositReturn;
    /**
     * A note related to the account deposit
     */
    depositNote;
    /**
     * The account deposit amount
     */
    depositAmount;
    /**
     * The account memo
     */
    memo;
    /**
     * The account's service begin date and time
     */
    serviceStart;
    /**
     * The account's service end date and time <span class='property-internal'>Must be greater than ServiceStart</span>
     */
    serviceEnd;
    /**
     * An array of identifiers for meters attached to this account
     */
    meters;
    /**
     * The identifier for the account's generalLedgerId
     */
    generalLedgerId;
    /**
     * A description of the account <span class='property-internal'>Must be between 0 and 4000 characters</span>
     */
    accountDescription;
    remitAddress;
    /**
     * The remit email <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    remitEmail;
    /**
     * The remit phone number <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    remitPhoneNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualMonthlyResponse {
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    /**
     * The account identifier
     */
    accountId;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    costUnit;
    /**
     * An array of monthly data per commodity
     */
    commodities;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualMonthlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of commodity monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualMonthlyResponseCommodityResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualYearlyResponse {
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    /**
     * The account identifier
     */
    accountId;
    globalUseUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountDigestActualYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountEdit {
    remitAddress;
    /**
     * The remit email <span class='property-internal'>Must be between 0 and 128 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    remitEmail;
    /**
     * The remit phone number <span class='property-internal'>Must be between 0 and 50 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    remitPhoneNumber;
    /**
     * The account code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    accountCode;
    /**
     * The account info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    accountInfo;
    /**
     * The identifier for the cost center to which the account belongs <span class='property-internal'>Topmost (CostCenter)</span> <span class='property-internal'>Required</span>
     */
    costCenterId;
    /**
     * The identifier for the customer the account serves. This is normally only set for chargeback accounts <span class='property-internal'>Required (defined)</span>
     */
    customerId;
    /**
     * The identifier for the account's contact <span class='property-internal'>Required (defined)</span>
     */
    contactId;
    /**
     * Indicates if the account is active or inactive <span class='property-internal'>Required (defined)</span>
     */
    active;
    /**
     * Indicates if the account is used with accruals <span class='property-internal'>Required (defined)</span>
     */
    accrualEnabled;
    /**
     * The address postal code  Required when country is US or CA <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    postalCode;
    /**
     * The address city <span class='property-internal'>Must be between 0 and 100 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    city;
    /**
     * The address state <span class='property-internal'>Must be between 0 and 100 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    state;
    /**
     * The address country <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    country;
    /**
     * The address first line <span class='property-internal'>Must be between 0 and 100 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    line1;
    /**
     * The address second line <span class='property-internal'>Must be between 0 and 100 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    line2;
    /**
     * The address third line <span class='property-internal'>Must be between 0 and 100 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    line3;
    /**
     * The date and time the account deposit was paid <span class='property-internal'>Required (defined)</span>
     */
    depositPaid;
    /**
     * The date and time the account deposit was returned <span class='property-internal'>Required (defined)</span>
     */
    depositReturn;
    /**
     * A note related to the account deposit <span class='property-internal'>Required (defined)</span>
     */
    depositNote;
    /**
     * The account deposit amount <span class='property-internal'>Required (defined)</span>
     */
    depositAmount;
    /**
     * The account memo <span class='property-internal'>Required (defined)</span>
     */
    memo;
    /**
     * The account's service begin date and time <span class='property-internal'>Required (defined)</span>
     */
    serviceStart;
    /**
     * The account's service end date and time <span class='property-internal'>Must be greater than ServiceStart</span> <span class='property-internal'>Required (defined)</span>
     */
    serviceEnd;
    /**
     * The identifier for the account's generalLedgerId <span class='property-internal'>Required (defined)</span>
     */
    generalLedgerId;
    /**
     * A description of the account <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    accountDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountMeterChild {
    /**
     * The AccountMeter identifier
     */
    accountMeterId;
    /**
     * The beginning date and time for this AccountMeter relationship
     */
    startDate;
    /**
     * The ending date and time for this AccountMeter relationship
     */
    endDate;
    /**
     * The Meter identifier for this AccountMeter
     */
    meterId;
    /**
     * The code of the Meter for this AccountMeter
     */
    meterCode;
    /**
     * The info of the Meter for this AccountMeter
     */
    meterInfo;
    place;
    commodity;
    meterGeneralLedger;
    vendorType;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split
     */
    isSplitChildMeter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountMeterChildWithSerialNumber {
    /**
     * The Serial Number of the Meter
     */
    serialNumber;
    /**
     * The AccountMeter identifier
     */
    accountMeterId;
    /**
     * The beginning date and time for this AccountMeter relationship
     */
    startDate;
    /**
     * The ending date and time for this AccountMeter relationship
     */
    endDate;
    /**
     * The Meter identifier for this AccountMeter
     */
    meterId;
    /**
     * The code of the Meter for this AccountMeter
     */
    meterCode;
    /**
     * The info of the Meter for this AccountMeter
     */
    meterInfo;
    place;
    commodity;
    meterGeneralLedger;
    vendorType;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split
     */
    isSplitChildMeter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountMeterEdit {
    /**
     * The beginning date and time for this account meter relationship <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    beginDate;
    /**
     * The ending date and time for this account meter relationship <span class='property-internal'>Must be greater than BeginDate</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    endDate;
    /**
     * The identifier for the general ledger assigned to this account meter <span class='property-internal'>Required (defined)</span>
     */
    generalLedgerId;
    /**
     * The identifier for the vendor type. Vendors may assume different types on different account meters <span class='property-internal'>Required (defined)</span>
     */
    vendorTypeId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountMeterRateResponse {
    /**
     * The account meter tariff identifier <span class='property-internal'>Required (defined)</span>
     */
    rateId;
    /**
     * The rate name <span class='property-internal'>Required (defined)</span>
     */
    name;
    /**
     * The rate code <span class='property-internal'>Required (defined)</span>
     */
    rateCode;
    /**
     * The rate's note <span class='property-internal'>Required (defined)</span>
     */
    note;
    /**
     * The start date for the rate on the account meter <span class='property-internal'>Required (defined)</span>
     */
    startDate;
    /**
     * The end date for the rate on the account meter <span class='property-internal'>Required (defined)</span>
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountMeterRequest {
    /**
     * The account identifier for this account meter <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Account)</span>
     */
    accountId;
    /**
     * The meter identifier for this account meter <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Meter)</span>
     */
    meterId;
    /**
     * The beginning date and time for this account meter relationship  Defaults to 1899-01-01
     */
    beginDate;
    /**
     * The ending date and time for this account meter relationship  Defaults to 3000-01-01
     */
    endDate;
    /**
     * The identifier for the general ledger assigned to this account meter
     */
    generalLedgerId;
    /**
     * The identifier for the vendor type. Vendors may assume different types on different account meters
     */
    vendorTypeId;
    /**
     * Indicates if the account meter is deregulated
     */
    deregulated;
    /**
     * The account meter template to be used for bill entry  Optional.   If passed in, the templateId will be used. If not passed  If vendortypeid is 2 (supplier),   --then a template on this meter's commodity with code that starts with S_meter's use unit code will be used  --if not found we will try to use a template on this meter's commodity with code that starts with S_  --If not found we will use a non-supplier template described below  If vendortype is non- supplier   -- the template will be defaulted using the meter's assigned use and demand units   --First try and match template by commodityId, useUnitId, demandUnitId   --If no match try commodityId, useUnitId   --If no match select the first use only template that matches on commodity   --If no match find the first template on this commodity   --If none is found no template will be assigned
     */
    templateId;
    /**
     * Indicates if the account meter rate <span class='property-internal'>Required</span>
     */
    rateId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountMeterResponse {
    /**
     * The account meter identifier <span class='property-internal'>Required (defined)</span>
     */
    accountMeterId;
    account;
    meter;
    /**
     * The beginning date and time for this account meter relationship <span class='property-internal'>Required (defined)</span>
     */
    beginDate;
    /**
     * The ending date and time for this account meter relationship <span class='property-internal'>Required (defined)</span>
     */
    endDate;
    generalLedger;
    vendorType;
    /**
     * Indicates if the account meter is deregulated <span class='property-internal'>Required (defined)</span>
     */
    deregulated;
    /**
     * The template assigned to this account meter <span class='property-internal'>Required (defined)</span>
     */
    formTemplates;
    /**
     * The rate assigned to this account meter <span class='property-internal'>Required (defined)</span>
     */
    rates;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountOrMeterUsage {
    /**
     * Number of chargeback accounts or meters.
     */
    chargeback;
    /**
     * Number of non-chargeback accounts or meters.
     */
    nonChargeback;
    /**
     * Number of inactive accounts or meters.
     */
    inactive;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountPeriodRequest {
    /**
     * The period number  When submitted with a list of other account periods, there cannot be more than one account period with the same periodNumber <span class='property-internal'>Must be between 1 and 12</span> <span class='property-internal'>Required (defined)</span>
     */
    periodNumber;
    /**
     * The name of the period <span class='property-internal'>Max length of 32</span> <span class='property-internal'>Required (defined)</span>
     */
    name;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountPeriodResponse {
    /**
     * The account period identifier
     */
    accountPeriodId;
    /**
     * The period number
     */
    periodNumber;
    /**
     * The name of the period
     */
    name;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountRateChild {
    rate;
    /**
     *
     */
    startDate;
    /**
     *
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountRateRequest {
    /**
     * The identifier for the rate to assign to the accountMeter <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    rateId;
    /**
     * The start date for the accountRate <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    startDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountRateResponse {
    /**
     * The meter tariff identifier
     */
    rateId;
    /**
     * The rate name
     */
    name;
    /**
     * The rate code
     */
    rateCode;
    /**
     * The start date for the rate on the account meter
     */
    startDate;
    /**
     * The end date for the rate on the account meter
     */
    endDate;
    meter;
    vendor;
    /**
     * The rate's note
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountResponse {
    /**
     * The account identifier
     */
    accountId;
    /**
     * The accountmeter identifier for the account
     */
    accountMeterId;
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    accountType;
    costCenter;
    vendor;
    contact;
    customer;
    /**
     * Indicates whether the Account is active or inactive
     */
    active;
    /**
     * Indicates if this account is used with accruals
     */
    accrualEnabled;
    address;
    /**
     * The date and time a deposit was paid
     */
    depositPaid;
    /**
     * The date and time the account deposit was returned
     */
    depositReturn;
    /**
     * A note related to the account deposit
     */
    depositNote;
    /**
     * The account deposit amount
     */
    depositAmount;
    /**
     * The account memo
     */
    memo;
    /**
     * The account's service begin date and time
     */
    serviceStart;
    /**
     * The account's service end date and time
     */
    serviceEnd;
    accountGeneralLedger;
    /**
     * An array of identifiers for meters attached to this account
     */
    meters;
    createdBy;
    /**
     * The date and time the account was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    costUnit;
    /**
     * Indicates whether the Account has a child calculated meter
     */
    hasCalculatedMeter;
    /**
     * Indicates whether the Account is a recipient of a split
     */
    hasSplitParentMeter;
    /**
     * Indicates whether the Account has a child split meter
     */
    hasSplitChildMeter;
    /**
     * Indicates whether the Account has a sub-account
     */
    hasSubAccount;
    accountCodeHistory;
    /**
     * A description of the account
     */
    accountDescription;
    /**
     * When true, bills for this account will be audited
     */
    auditEnabled;
    /**
     * The data access release identifier for this Account, null if there is no release.
     */
    dataAccessReleaseId;
    /**
     * Indicates if the DataAccessRelease is approved  null if there is no release
     */
    dataAccessReleaseApproved;
    remitAddress;
    /**
     * The remit email address
     */
    remitEmail;
    /**
     * The remit phone number
     */
    remitPhoneNumber;
    /**
     * If there are settings configured to split account charges for this account
     */
    splitAccountChargesConfigured;
    summaryAccount;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountTemplateResponse {
    /**
     * The meter form template identifier
     */
    formTemplateId;
    /**
     * The template name
     */
    templateInfo;
    /**
     * The template code
     */
    templateCode;
    /**
     * The start date for the form template on the account meter
     */
    startDate;
    /**
     * The end date for the form template on the account meter
     */
    endDate;
    /**
     * The form template's display order
     */
    displayOrder;
    meter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountTypeChild {
    /**
     * The account type identifier
     */
    accountTypeId;
    /**
     * The account type code
     */
    accountTypeCode;
    /**
     * The account type info
     */
    accountTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountUDFResponse {
    /**
     * The account identifier
     */
    accountId;
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    /**
     * An array of user-defined fields (UDFs)
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountingSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountingSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountingSettingsRequest {
    /**
     * First month of fiscal year <span class='property-internal'>Must be between 1 and 12</span> <span class='property-internal'>Required (defined)</span>
     */
    fiscalYearStartMonth;
    /**
     * Fiscal year reflects the calendar year in which it Begins or Ends <span class='property-internal'>One of 'beginning', 'ending'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    fiscalYearDefinedAtYear;
    /**
     * Calendarization method  Value will be one of \"monthly\", \"user-defined\" <span class='property-internal'>One of 'monthly', 'user-defined'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    calendarizationMethod;
    /**
     * List of accounting period names <span class='property-internal'>Required (defined)</span>
     */
    accountPeriods;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountingSettingsResponse {
    /**
     * First month of fiscal year  Value will be from 1-12
     */
    fiscalYearStartMonth;
    /**
     * Fiscal year reflects the calendar year in which it Begins or Ends  Value will be one of \"beginning\", \"ending\"
     */
    fiscalYearDefinedAtYear;
    /**
     * Calendarization method  Value will be one of \"monthly\", \"user-defined\"
     */
    calendarizationMethod;
    /**
     * List of accounting period names
     */
    accountPeriods;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Accounts {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountsModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountsModuleActualData {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountsModuleActualDataClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccountsModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccrualProcessorRequest {
    /**
     * The batch to create for accrual bills <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    batchCode;
    /**
     * Use a safety net for accrued cost calculation?    - if we have usage and we are using an average unit cost safety net and the most recent unit cost does not vary more than the specified percentage from the historical average unit cost,      accrued cost = accrued use * most recent unit cost   - if we have usage and we are not using an average unit cost safety net or the most recent unit cost does vary more than the specified percentage from the historical average unit cost,      accrued cost = accrued use * average historical unit cost   - if we don't have usage,      accrued cost = historical average cost per day * number of days in accrual period <span class='property-internal'>Required</span>
     */
    aucSafetyNet;
    /**
     * Percent of cost variance allowed when using average unit cost safety net <span class='property-internal'>Required when AucSafetyNet is set to True, case sensitive.</span>
     */
    aucPercentVarianceAllowed;
    /**
     * End date for accrual bills generated <span class='property-internal'>Required</span>
     */
    accrualPeriodEndDate;
    /**
     * Earliest bill end date to begin accruing from (end dates become begin dates for accrued bills) <span class='property-internal'>Required</span>
     */
    accrualPeriodMinimumStartDate;
    /**
     * Billing period calculation method.  Valid values are \"bill midpoint\" and \"manual\". <span class='property-internal'>One of 'bill midpoint', 'manual'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required</span>
     */
    billingPeriodCalculationMethod;
    /**
     * Fixed billing period for accrual bills generated when billing period calculation method is manual. <span class='property-internal'>Required when BillingPeriodCalculationMethod is set to manual, case sensitive.</span> <span class='property-internal'>Must be between 190001 and 209912</span>
     */
    manualBillingPeriod;
    /**
     * Account period calculation method.  Valid values are \"blank\", \"billing period\" and \"manual\". <span class='property-internal'>One of 'blank', 'billing period', 'manual'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required</span>
     */
    accountPeriodCalculationMethod;
    /**
     * Fixed account period for accrual bills generated when account period calculation method is manual. <span class='property-internal'>Required when AccountPeriodCalculationMethod is set to manual, case sensitive.</span> <span class='property-internal'>Must be between 190001 and 209913</span>
     */
    manualAccountPeriod;
    /**
     * Generate accrual bills in test mode? Test mode bills are created as voided bills. <span class='property-internal'>Required</span>
     */
    testMode;
    /**
     * Optional percentage for cost adjustment. It can be positive or negative.
     */
    percentCostAdjustment;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccrualSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    run;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccrualSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    run;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AccrualSettingsResponse {
    /**
     * Accrual method to employ. Valid values are:      simple      - cost per day from the most recent bill    use history - unit cost based on historical bills                  (if AUC safety net used, use the most recent bill if the unit cost is within the safety net percentage,                  otherwise use a historical average of the last three years from the same period),                  or average cost per day if no usage
     */
    accrualMethod;
    /**
     * Use an average unit cost safety net (apply to most recent bill unit cost)
     */
    aucSafetyNet;
    /**
     * Average unit cost safety net percentage
     */
    aucSafetyNetPercentage;
    /**
     * Default filter to use when selecting most recent bills. Valid value are:      non-void       - select any non-void bill    approved       - select only approved bills    apexported     - select AP exported bills    non-exporthold - select bills not held from AP export
     */
    accrualBillFilter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ActionableBillCounts {
    /**
     * Count of bills Held from Export
     */
    exportHoldCount;
    /**
     * Count of bills Waiting for Export to AP
     */
    apExportCount;
    /**
     * Count of bills Waiting for Export to GL
     */
    glExportCount;
    /**
     * Count of bills which are Not Approved
     */
    approvalCount;
    /**
     * Count of bills with unresolved flags
     */
    auditProblemCount;
    /**
     * Count of bills created in the last seven days
     */
    createdLastSevenDaysCount;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Activity {
    /**
     *
     */
    id;
    /**
     *
     */
    reason;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ActualVsBudgetResponse {
    budgetPeriodRange;
    /**
     *
     */
    totals;
    /**
     *
     */
    entities;
    /**
     *
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AddressChild {
    /**
     * The address type identifier
     */
    addressTypeId;
    /**
     * The line 1 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line1;
    /**
     * The line 2 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line2;
    /**
     * The line 3 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line3;
    /**
     * The city of the place <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    city;
    /**
     * The state of the place <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    state;
    /**
     * The country of the place <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    country;
    /**
     * The postal code of the place <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    postalCode;
    /**
     * The latitude of the place  Required when the country is not United States or Canada <span class='property-internal'>Must be between -90 and 90</span> <span class='property-internal'>Required when Longitude is set</span>
     */
    latitude;
    /**
     * The longitude of the place  Required when the country is not United States or Canada <span class='property-internal'>Must be between -180 and 180</span> <span class='property-internal'>Required when Latitude is set</span>
     */
    longitude;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AddressChildBase {
    /**
     * The line 1 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line1;
    /**
     * The line 2 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line2;
    /**
     * The line 3 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line3;
    /**
     * The city of the place <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    city;
    /**
     * The state of the place <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    state;
    /**
     * The country of the place <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    country;
    /**
     * The postal code of the place <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    postalCode;
    /**
     * The latitude of the place  Required when the country is not United States or Canada <span class='property-internal'>Must be between -90 and 90</span> <span class='property-internal'>Required when Longitude is set</span>
     */
    latitude;
    /**
     * The longitude of the place  Required when the country is not United States or Canada <span class='property-internal'>Must be between -180 and 180</span> <span class='property-internal'>Required when Latitude is set</span>
     */
    longitude;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AddressLookup {
    /**
     *
     */
    addressTypeId;
    /**
     *
     */
    line1;
    /**
     *
     */
    line2;
    /**
     *
     */
    line3;
    /**
     *
     */
    city;
    /**
     *
     */
    state;
    /**
     *
     */
    country;
    /**
     *
     */
    postalCode;
    /**
     *
     */
    latitude;
    /**
     *
     */
    longitude;
    /**
     *
     */
    uniqueLocationIdentifier;
    /**
     *
     */
    locationProperties;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AdjustedCostTypeResponse {
    /**
     * Adjusted Cost Type identifier
     */
    adjustedCostTypeId;
    /**
     * Adjusted Cost Type code
     */
    adjustedCostTypeCode;
    /**
     * Adjusted Cost Type name
     */
    adjustedCostTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AdjustmentBaseMethodChild {
    /**
     * Special adjustment method identifier
     */
    specialAdjustmentMethodId;
    /**
     * Special adjustment method description
     */
    label;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AdminSettingsRequest {
    /**
     * The setting field <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    fieldName;
    /**
     * The setting value <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     * The setting's data type identifier. Possible value include 1 (boolean), 2 (integer), 3 (string), 4 (double), 6 (date) <span class='property-internal'>Required</span> <span class='property-internal'>One of '1', '2', '3', '4', '6'</span> <span class='property-internal'>Case sensitive</span>
     */
    dataTypeId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AdminSettingsResponse {
    /**
     * The setting field
     */
    fieldName;
    /**
     * The setting value
     */
    value;
    dataType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AggregatedComparisonResponseGHGPerformanceComparison {
    periodRange;
    total;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AggregatedItemRankResponse {
    period;
    /**
     * The display unit of the values
     */
    displayUnit;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AggregatedMonthlyCAPTrendResponse {
    fiscalPeriodRange;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AggregatedResponseGHGBuildingRank {
    period;
    total;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AggregatedResponseItemRankWithUnitResponse {
    period;
    total;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AllInstalledReports {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AllInstalledReportsClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApiKeyCreateRequest {
    /**
     * The name of the API key <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 60 characters</span>
     */
    apiKeyName;
    /**
     * A description for the API key
     */
    apiKeyDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApiKeyCreateResponse {
    /**
     * The API key. This value cannot be retrieved again after it is created.
     */
    apiKey;
    /**
     * The identifier of the API key
     */
    apiKeyId;
    /**
     * The name of the API key
     */
    apiKeyName;
    /**
     * A description of the API key
     */
    apiKeyDescription;
    createdBy;
    /**
     * The API key creation date
     */
    createdDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApiKeyEditRequest {
    /**
     * The name of the API key <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 60 characters</span>
     */
    apiKeyName;
    /**
     * A description for the API key <span class='property-internal'>Required (defined)</span>
     */
    apiKeyDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApiKeyResponse {
    /**
     * The identifier of the API key
     */
    apiKeyId;
    /**
     * The name of the API key
     */
    apiKeyName;
    /**
     * A description of the API key
     */
    apiKeyDescription;
    createdBy;
    /**
     * The API key creation date
     */
    createdDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApiUser {
    /**
     *
     */
    userName;
    /**
     *
     */
    fullName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApplicationSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApplicationSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Bill approval settings
 */
class ApprovalWorkflowChild {
    /**
     * Whether or not Approval Mode is enabled
     */
    approvalModeEnabled;
    /**
     * Whether or not edit / delete should be confirmed
     */
    confirmEditDelete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Bill approval settings
 */
class ApprovalWorkflowRequestChild {
    /**
     * Whether or not edit / delete should be confirmed <span class='property-internal'>Required</span>
     */
    confirmEditDelete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApprovalWorkflowSettings {
    /**
     *
     */
    approvalModeEnabled;
    /**
     *
     */
    confirmEditDelete;
    /**
     *
     */
    maximumApprovalAmount;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApproveBills {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ApproveBillsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AssignVersionsToStep {
    /**
     * List of calculated bill or bill split version IDs to assign to a chargeback workflow step <span class='property-internal'>Required (defined)</span>
     */
    calculateBillVersionIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AucRangeRequest {
    /**
     * The unique identifier for the commodity <span class='property-internal'>Required (defined)</span>
     */
    commodityId;
    /**
     * When the current bill's average unit cost is LOWER than this multiplier x the baseline bill's average unit cost, then the cost avoidance processor will use the average unit cost from the baseline bill instead of the current bill <span class='property-internal'>Must be between 0.1 and 20.0</span> <span class='property-internal'>Required (defined)</span>
     */
    lowerLimitMultiplier;
    /**
     * When the current bill's average unit cost is HIGHER than this multiplier x the baseline bill's average unit cost, then the cost avoidance processor will use the average unit cost from the baseline bill instead of the current bill <span class='property-internal'>Must be greater than LowerLimitMultiplier</span> <span class='property-internal'>Must be between 0.1 and 20.0</span> <span class='property-internal'>Required (defined)</span>
     */
    upperLimitMultiplier;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AucRangeResponse {
    /**
     * Unique identifier for the commodity's average unit cost range
     */
    commodityCapId;
    commodity;
    /**
     * When the current bill's average unit cost is LOWER than this multiplier x the baseline bill's average unit cost, then the cost avoidance processor will use the average unit cost from the baseline bill instead of the current bill
     */
    lowerLimitMultiplier;
    /**
     * When the current bill's average unit cost is HIGHER than this multiplier x the baseline bill's average unit cost, then the cost avoidance processor will use the average unit cost from the baseline bill instead of the current bill
     */
    upperLimitMultiplier;
    /**
     * Indicates whether or not this commodity is used; i.e. there are meters that have been created with this commodity which are included in cost avoidance
     */
    isUsed;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AuditSettingRequest {
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AuditSettingResponse {
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AuditSettingsRequest {
    billContainsLineItemDescriptions;
    billContainsLineItemTypes;
    totalBillCostDoesNotMatchLineItemTypes;
    billingPeriodOutsideStartEndDates;
    billOverlapsWithOtherAccountBill;
    gapBetweenBillAndPreviousBillOnAccount;
    billEndsInFuture;
    accountHasMultipleBillsInBillingPeriod;
    statementDateBeforeEndDate;
    dueDateBeforeEndDate;
    billSignificantlyShorterOrLongerThanPrevious;
    tooManyConsecutiveEstimatedBills;
    dueDateTooLongAfterBillEnd;
    statementDateTooLongAfterBillEnd;
    invoiceNumberIsRepeatedOnAccount;
    likelyDuplicateBillOnAccount;
    totalMeterCostIsPercentageHigherThanPastYear;
    totalMeterUseIsPercentageHigherThanPastYear;
    serialNumberDoesNotMatchImportFile;
    rateCodeDoesNotMatchImportFile;
    importFileStartDateAdjustedToPreventGaps;
    accountAlertExistsOnAccountInImportFile;
    abnormalBillCostWithOutlierAnalysis;
    abnormalBillUseWithOutlierAnalysis;
    abnormalBillDemandWithOutlierAnalysis;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class AuditSettingsResponse {
    billContainsLineItemDescriptions;
    billContainsLineItemTypes;
    totalBillCostDoesNotMatchLineItemTypes;
    billingPeriodOutsideStartEndDates;
    billOverlapsWithOtherAccountBill;
    gapBetweenBillAndPreviousBillOnAccount;
    billEndsInFuture;
    accountHasMultipleBillsInBillingPeriod;
    statementDateBeforeEndDate;
    dueDateBeforeEndDate;
    billSignificantlyShorterOrLongerThanPrevious;
    tooManyConsecutiveEstimatedBills;
    dueDateTooLongAfterBillEnd;
    statementDateTooLongAfterBillEnd;
    invoiceNumberIsRepeatedOnAccount;
    likelyDuplicateBillOnAccount;
    totalMeterCostIsPercentageHigherThanPastYear;
    totalMeterUseIsPercentageHigherThanPastYear;
    serialNumberDoesNotMatchImportFile;
    rateCodeDoesNotMatchImportFile;
    importFileStartDateAdjustedToPreventGaps;
    accountAlertExistsOnAccountInImportFile;
    abnormalBillCostWithOutlierAnalysis;
    abnormalBillUseWithOutlierAnalysis;
    abnormalBillDemandWithOutlierAnalysis;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineEngine {
    /**
     *
     */
    run;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineEngineClassPermission {
    /**
     *
     */
    run;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineLog {
    /**
     * The status of baseline processing
     */
    status;
    /**
     * Number of meters successfully processed
     */
    successCount;
    /**
     * Number of meters processed with warning
     */
    warningCount;
    /**
     * Number of meters processed with errors
     */
    errorCount;
    /**
     * Number of meters to process
     */
    numberOfMeters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineProcessorRequest {
    /**
     * Indicates if the meter will be included in savings calculations
     */
    includeInCAP;
    /**
     * Indicates if floor area adjustments should be made
     */
    adjustArea;
    /**
     * The type of cost adjustment to perform.  Possible values include 1 (current average unit cost) and 5 (net cost difference)
     */
    adjustedCostTypeId;
    /**
     * Indicates if winter weather adjustments should be made
     */
    adjustWinter;
    /**
     * Indicates if summer weather adjustments should be made
     */
    adjustSummer;
    /**
     * The number of months in the baseline.   Setting this to anything other than 12 will turn off weather adjustments irregardless of the settings in adjustWinter and adjustSummer
     */
    baselineMonths;
    /**
     * The baseline's start date
     */
    baselineStartDate;
    /**
     * The savings period's start date
     */
    savingsStartDate;
    /**
     * The cooling balance point
     */
    coolingTemp;
    /**
     * The heating balance point
     */
    heatingTemp;
    /**
     * Indicates if extended weather should be used.  Extended weather uses additional months prior to the baseline start date to   determine weather sensitivity.
     */
    useExtendedWeather;
    /**
     * The start date of the extended weather. This should be 1, 2 or 3 years prior to the baseline start date.  Extended weather uses additional months prior to the baseline start date to   determine weather sensitivity.
     */
    extendedWeatherStartDate;
    /**
     * Indicates if each bill in the baseline should be included in the baseline regression
     */
    baselineBills;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineProcessorRequestBaselineBill {
    /**
     * The identifier of the baseline bill
     */
    billId;
    /**
     * Indicates if the bill should be included in the baseline regression
     */
    isExcluded;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineProcessorResponse {
    /**
     * Indicates if the meter will be included in savings calculations
     */
    includeInCAP;
    /**
     * Indicates if floor area adjustments should be made
     */
    adjustArea;
    adjustedCostType;
    /**
     * Indicates if winter weather adjustments should be made
     */
    adjustWinter;
    /**
     * Indicates if summer weather adjustments should be made
     */
    adjustSummer;
    /**
     * Number of months in the baseline  Setting this to anything other than 12 will turn off weather adjustments irregardless of the settings in adjustWinter and adjustSummer
     */
    baselineMonths;
    /**
     * Baseline start date
     */
    baselineStartDate;
    /**
     * Savings Period start date
     */
    savingsStartDate;
    /**
     * Indicates if extended weather should be used.  Extended weather uses additional months prior to the baseline start date to determine weather sensitivity.
     */
    useExtendedWeather;
    /**
     * Start Date of the extended weather. This should be 1, 2 or 3 years prior to the baseline start date.  Extended weather uses additional months prior to the baseline start date to determine weather sensitivity.
     */
    extendedWeatherStartDate;
    /**
     * Cooling balance point
     */
    coolingTemp;
    /**
     * Cooling intercept
     */
    coolingIntercept;
    /**
     * Cooling max Degree Days
     */
    coolingMaxDegreeDays;
    /**
     * Cooling max use
     */
    coolingMaxUse;
    /**
     * Cooling R2
     */
    coolingR2;
    /**
     * Adjusted Cooling R2
     */
    adjustedCoolingR2;
    /**
     * Cooling minimum R2
     */
    coolingMinR2;
    /**
     * Cooling calculated R2
     */
    coolingCalculatedR2;
    /**
     * Cooling slope
     */
    coolingSlope;
    /**
     * Cooling standard deviation
     */
    coolingStdDev;
    /**
     * Cooling CVRMSE
     */
    coolingCVRMSE;
    /**
     * Cooling NDB
     */
    coolingNDB;
    /**
     * Cooling standard error
     */
    coolingStandardError;
    /**
     * Cooling base T-stat
     */
    coolingBaseTStat;
    /**
     * Cooling weather T-stat
     */
    coolingWeatherTStat;
    /**
     * Cooling FSU
     */
    coolingFSU;
    /**
     * Heating balance point
     */
    heatingTemp;
    /**
     * Heating intercept
     */
    heatingIntercept;
    /**
     * Heating maximum Degree Days
     */
    heatingMaxDegreeDays;
    /**
     * Heating maximum use
     */
    heatingMaxUse;
    /**
     * Heating R2
     */
    heatingR2;
    /**
     *
     */
    adjustedHeatingR2;
    /**
     * Heating minimum R2
     */
    heatingMinR2;
    /**
     * Heating calculated R2
     */
    heatingCalculatedR2;
    /**
     * Heating slope
     */
    heatingSlope;
    /**
     * Heating standard deviation
     */
    heatingStdDev;
    /**
     * Heating CVRMSE
     */
    heatingCVRMSE;
    /**
     * Heating NDB
     */
    heatingNDB;
    /**
     * Heating standard error
     */
    heatingStandardError;
    /**
     * Heating base T-stat
     */
    heatingBaseTStat;
    /**
     * Heating weather T-stat
     */
    heatingWeatherTStat;
    /**
     * Heating FSU
     */
    heatingFSU;
    nativeUseUnit;
    /**
     * Indicates whether or not each bill in the baseline should be included in the baseline regression
     */
    baselineBills;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BaselineProcessorResponseBaselineBill {
    /**
     * Unique bill identifier
     */
    billId;
    /**
     * Average Cooling Degree Days
     */
    avgCoolingDegreeDays;
    /**
     * Average heating Degree Days
     */
    avgHeatingDegreeDays;
    /**
     * Bill start date
     */
    beginDate;
    /**
     * Bill end date
     */
    endDate;
    /**
     * Indicates whether or not the bill is excluded from the baseline regression
     */
    isExcluded;
    /**
     * Indicates whether or not the bill is an outlier
     */
    isOutlier;
    /**
     * Native use
     */
    nativeUse;
    /**
     * Number of days in the bill
     */
    days;
    /**
     * Calendar period name (e.g. Jan)
     */
    periodName;
    /**
     * Calendar period number
     */
    calendarPeriod;
    /**
     * Calendar year
     */
    calendarYear;
    /**
     * Fiscal period
     */
    fiscalPeriod;
    /**
     * Fiscal year
     */
    fiscalYear;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BatchChild {
    /**
     * The batch id.
     */
    batchId;
    /**
     * The batch code.
     */
    batchCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BatchCreate {
    /**
     * The batch code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    batchCode;
    /**
     * If user has another batch open, should it be closed?
     */
    closeExistingBatch;
    /**
     * Statement date for batch - will get applied as default to any bill added to this batch
     */
    statementDate;
    /**
     * Due date for batch - will get applied as default to any bill added to this batch
     */
    dueDate;
    /**
     * Next reading date for batch - will get applied as default to any bill added to this batch
     */
    nextReading;
    /**
     * Control code for batch - will get applied as default to any bill added to this batch <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    controlCode;
    /**
     * Invoice number for batch - will get applied as default to any bill added to this batch <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    invoiceNumber;
    /**
     * Account period number for batch - will get applied as default to any bill added to this batch
     */
    accountPeriodNumber;
    /**
     * Accountperiod year for batch - will get applied as default to any bill added to this batch <span class='property-internal'>Must be between 1900 and 2099</span>
     */
    accountPeriodYear;
    /**
     * Note/comment for batch <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BatchEdit {
    /**
     * The batch code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    batchCode;
    /**
     * Note/comment for batch <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BatchResponse {
    /**
     * The batch identifier
     */
    batchId;
    /**
     * The batch code
     */
    batchCode;
    /**
     * Is the batch open
     */
    isOpen;
    /**
     * The status of the batch (open, pending, closed)
     */
    batchStatus;
    /**
     * The date when the batch was created
     */
    startDate;
    /**
     * The date when the batch was closed
     */
    endDate;
    /**
     * The number of bills in this batch
     */
    billCount;
    /**
     * The cost of  all bills in this batch
     */
    runningTotal;
    /**
     * Statement date batch setting
     */
    statementDate;
    /**
     * Due date batch setting
     */
    dueDate;
    /**
     * Next reading date batch setting
     */
    nextReading;
    /**
     * Control code batch setting
     */
    controlCode;
    /**
     * Invoice number batch setting
     */
    invoiceNumber;
    /**
     * Account period name batch setting
     */
    accountPeriodName;
    /**
     * Account period number batch setting
     */
    accountPeriodNumber;
    /**
     * Account period year batch setting
     */
    accountPeriodYear;
    /**
     * Note/comment for the batch
     */
    note;
    createdBy;
    /**
     * Number of unresolved flags on bills contained in this batch
     */
    flagCount;
    /**
     * Number of bills contained in this batch that are currently being analyzed
     */
    analyzingCount;
    /**
     * Denotes if the Batch has any imported bills associated with it
     */
    hasImportedBills;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BatchSettings {
    /**
     * needs to be one of - \"use existing batch\", \"new batch\", \"new self-contained batch\", \"use pending batch\"  if \"use existing\" - we will use an existing open batch and leave it open  if \"new batch\" - close existing open batch and  make a new batch  if \"new self-contained batch\" - make a new batch and add bills to it and close it. Any open batch will be left open  if \"use pending batch\" - PendingBatchId is required.  We will use the pending batch and leave it pending <span class='property-internal'>One of 'use existing batch', 'new batch', 'new self-contained batch', 'use pending batch'</span>
     */
    batchMode;
    /**
     * Pending batchId to import the bills into <span class='property-internal'>Required when BatchMode is set to use pending batch</span>
     */
    pendingBatchId;
    /**
     * optional- if not provided, we will autocreate the batch code.   If useExistingBatch is true, this value will be ignored <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    newBatchCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Batch workflow settings
 */
class BatchWorkflowChild {
    dueDate;
    statementDate;
    invoiceNumber;
    controlCode;
    nextReading;
    accountPeriodName;
    accountPeriodYear;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BatchWorkflowSettings {
    /**
     *
     */
    batchModeEnabled;
    dueDate;
    statementDate;
    invoiceNumber;
    controlCode;
    nextReading;
    accountPeriodName;
    accountPeriodYear;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkCategoryResponse {
    /**
     * Benchmark Category Id
     */
    benchmarkCategoryId;
    /**
     * Benchmark Category Info
     */
    benchmarkCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkEdit {
    /**
     * benchmark category Id <span class='property-internal'>Required</span>
     */
    benchmarkCategoryId;
    /**
     * benchmark name <span class='property-internal'>Required</span> <span class='property-internal'>Not one of Area, Day</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    benchmarkInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkSettingsEdit {
    benchmark1;
    benchmark2;
    benchmark3;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkSettingsResponse {
    benchmark1;
    benchmark2;
    benchmark3;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkValue {
    /**
     * Indicator for which benchmark factor <span class='property-internal'>Required (defined)</span>
     */
    benchmarkValueId;
    /**
     * Effective Date for the benchmark factor <span class='property-internal'>Required (defined)</span>
     */
    effectiveDate;
    /**
     * End Date for the benchmark factor <span class='property-internal'>Required (defined)</span>
     */
    endDate;
    /**
     * Value set for the benchmark factor <span class='property-internal'>Required (defined)</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkValueRequest {
    /**
     * The effective date for the benchmark <span class='property-internal'>Required</span> <span class='property-internal'>Must be first of the month</span> <span class='property-internal'>Required</span> <span class='property-internal'>Must be first of the month</span>
     */
    effectiveDate;
    /**
     * The benchmark value <span class='property-internal'>Required</span> <span class='property-info'>Max scale of 6</span> <span class='property-internal'>Must be between 0 and 1.7976931348623157E+308</span> <span class='property-internal'>Required</span> <span class='property-info'>Max scale of 6</span> <span class='property-internal'>Must be between 0 and 1.7976931348623157E+308</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkValuesResponse {
    /**
     * List of benchmark values and their effective dates <span class='property-internal'>Required (defined)</span>
     */
    benchmarkValues;
    /**
     * Indicator for which benchmark factor <span class='property-internal'>Required (defined)</span>
     */
    benchmarkIndicator;
    /**
     * benchmark info <span class='property-internal'>Required (defined)</span>
     */
    benchmarkInfo;
    benchmarkCategory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BenchmarkWithUsedCountResponse {
    /**
     * Number of times benchmark is used
     */
    usedCount;
    /**
     * Indicator for which benchmark factor
     */
    benchmarkIndicator;
    /**
     * benchmark info
     */
    benchmarkInfo;
    benchmarkCategory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountBodyLineCreate {
    /**
     * The bodyline's special charge (SingleLine) id, if applicable
     */
    specialChargeId;
    /**
     * The bodyline's observation type <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The bodyline's cost unit of measure for this <span class='property-internal'>Required when Cost is set</span>
     */
    costUnitId;
    /**
     * The cost attributed to the line item <span class='property-internal'>Required when CostUnitId is set</span>
     */
    cost;
    /**
     * The caption <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    caption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountBodyLineEdit {
    /**
     * The bodyline's id for an existing bodyline <span class='property-internal'>Required (defined)</span>
     */
    bodyLineId;
    /**
     * The bodyline's special charge (SingleLine) id, if applicable <span class='property-internal'>Required (defined)</span>
     */
    specialChargeId;
    /**
     * The bodyline's observation type <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The bodyline's cost unit of measure for this <span class='property-internal'>Required when Cost is set</span>
     */
    costUnitId;
    /**
     * The cost attributed to the line item <span class='property-internal'>Required when CostUnitId is set</span>
     */
    cost;
    /**
     * The caption <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    caption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountChargeSplitMethodRequest {
    /**
     * During bill import a bill's account charges will be distributed  to the account's meters either by \"Use\" or \"Cost\"  null means the charges will not be distributed <span class='property-internal'>One of 'Use', 'Cost'</span> <span class='property-internal'>Required (defined)</span>
     */
    splitBillChargesMethod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountChargeSplitMethodResponse {
    /**
     * During bill import a bill's account charges will be distributed  to the account's meters either by \"Use\" or \"Cost\"  null means the charges will not be distributed
     */
    splitBillChargesMethod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountChargeSplitSettingResponse {
    /**
     * The account identifier  Account properties will be null when the setting applies to all accounts for a vendor  If there is a specific account defined this setting will override the vendor settings
     */
    accountId;
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
    /**
     * Split account charges with a bill line type assigned to the cost categories
     */
    costCategories;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountChargeSplitSettingsResponse {
    billAccountChargeSplitMethod;
    /**
     * During bill import a bill's account charges will be distributed  to the account's meters based on the account, vendor, and cost category
     */
    billAccountChargeSplitSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountMeterChild {
    /**
     * The bill-account-meter's account id
     */
    accountId;
    /**
     * The bill-account-meter's meter id
     */
    meterId;
    /**
     * The bill-account-meter's native use
     */
    nativeUse;
    nativeUseUnit;
    /**
     * The bill-account-meter's direct cost
     */
    directCost;
    directCostUnit;
    /**
     * The bill-account-meter's native use unit cost
     */
    nativeUseUnitCost;
    /**
     * The bill-account-meter's native use per day
     */
    nativeUsePerDay;
    /**
     * The bill-account-meter's direct cost per day
     */
    directCostPerDay;
    /**
     * The bill-account-meter's native billed demand
     */
    nativeBilledDemand;
    nativeBilledDemandUnit;
    /**
     * The bill-account-meter's native actual demand
     */
    nativeActualDemand;
    nativeActualDemandUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountMeterResponse {
    /**
     * Global use
     */
    globalUse;
    /**
     * Global use per day
     */
    globalUsePerDay;
    globalUseUnit;
    /**
     * Native use
     */
    nativeUse;
    /**
     * Native use per day
     */
    nativeUsePerDay;
    nativeUseUnit;
    /**
     * Native demand
     */
    nativeDemand;
    nativeDemandUnit;
    /**
     * Native billed demand
     */
    nativeBilledDemand;
    nativeBilledDemandUnit;
    /**
     * Native actual demand
     */
    nativeActualDemand;
    nativeActualDemandUnit;
    /**
     * Common use
     */
    commonUse;
    /**
     * Common use per day
     */
    commonUsePerDay;
    commonUseUnit;
    /**
     * Common demand
     */
    commonDemand;
    commonDemandUnit;
    /**
     * Common billed demand
     */
    commonBilledDemand;
    commonBilledDemandUnit;
    /**
     * Common actual demand
     */
    commonActualDemand;
    commonActualDemandUnit;
    /**
     * Direct cost
     */
    directCost;
    /**
     * Direct cost per day
     */
    directCostPerDay;
    /**
     * Proportional cost
     */
    proportionalCost;
    /**
     * Proportional cost per day
     */
    proportionalCostPerDay;
    costUnit;
    /**
     * The bill identifier
     */
    billId;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The number of days the bill covers
     */
    days;
    account;
    meter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccountMeterStatisticsResponse {
    usePerDay;
    costPerDay;
    demandPerDay;
    /**
     * The bill identifier
     */
    billId;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The number of days the bill covers
     */
    days;
    account;
    meter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillAccrualExclusionRequest {
    /**
     * List of bill IDs to exclude from accruals or include again <span class='property-internal'>Required</span>
     */
    billIds;
    /**
     * Whether or not the bill ids should be excluded from accruals, or included again <span class='property-internal'>Required</span>
     */
    exclude;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionApprove {
    /**
     *  <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    ids;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    approve;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionCustom {
    /**
     * The list of bill ids on which to perform the custom action <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    billIds;
    /**
     * The webhook identifier that represents the custom bill action <span class='property-internal'>Required</span>
     */
    webhookId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionDelete {
    /**
     *  <span class='property-internal'>Cannot be Empty</span>
     */
    ids;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionExportHold {
    /**
     *  <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    ids;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    exportHold;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionHeaderUpdate {
    /**
     * Bill IDs whose headers are going to be updated <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required</span>
     */
    billIds;
    billHeader;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionHistoricalExport {
    /**
     *  <span class='property-internal'>Cannot be Empty</span>
     */
    ids;
    /**
     *  <span class='property-internal'>One of '', 'V', 'P', 'R'</span>
     */
    vpr;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionMove {
    /**
     * Ids of bills to be moved <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    ids;
    /**
     * Destination Account Id <span class='property-internal'>Required (defined)</span>
     */
    accountId;
    /**
     * Destination AccountMeter Ids <span class='property-internal'>Required (defined)</span>
     */
    accountMeterIds;
    /**
     * Use Account General Ledger from destination account? <span class='property-internal'>Required (defined)</span>
     */
    updateAccountGLs;
    /**
     * Use Meter General Ledger from destination meter? <span class='property-internal'>Required (defined)</span>
     */
    updateMeterGLs;
    /**
     * If both the source and destination meter is linked to an emissions source and there are records generated from the bills being moved,  update the scope category and GHG factor on those records to the destination meter defaults?   Defaults to true for GHG Lite users, otherwise false. <span class='property-internal'>Required (defined)</span>
     */
    updateRecordScopeAndFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionMoveList {
    /**
     * Destination Account Id <span class='property-internal'>Required (defined)</span>
     */
    accountId;
    /**
     * Destination AccountMeter Ids <span class='property-internal'>Required (defined)</span>
     */
    accountMeterIds;
    /**
     * Use Account General Ledger from destination account? <span class='property-internal'>Required (defined)</span>
     */
    updateAccountGLs;
    /**
     * Use Meter General Ledger from destination meter? <span class='property-internal'>Required (defined)</span>
     */
    updateMeterGLs;
    /**
     * If both the source and destination meter is linked to an emissions source and there are records generated from the bills being moved,  update the scope category and GHG factor on those records to the destination meter defaults?   Defaults to true for GHG Lite users, otherwise false. <span class='property-internal'>Required (defined)</span>
     */
    updateRecordScopeAndFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionSplit {
    /**
     * List of billIds that need to be split <span class='property-internal'>Cannot be Empty</span>
     */
    ids;
    /**
     * Optional note/comment
     */
    note;
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillActionVoid {
    /**
     *  <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    ids;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    void;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillCAPture {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillCAPtureClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillCalendarizedHistory {
    /**
     * Billing Period (YYYYMM)
     */
    billingPeriod;
    /**
     * Calendarized Month
     */
    month;
    /**
     * Calendarized Year
     */
    year;
    /**
     * Is this period within the last year
     */
    current;
    /**
     * Account ID
     */
    accountId;
    /**
     * Meter ID
     */
    meterId;
    /**
     * Use per day (native)
     */
    usePerDay;
    /**
     * Use unit name (native)
     */
    useUnit;
    /**
     * Cost per day
     */
    costPerDay;
    /**
     * Unit cost
     */
    unitCost;
    /**
     * Cost unit name
     */
    costUnit;
    /**
     * Demand (native)
     */
    demand;
    /**
     * Demand unit name (native)
     */
    demandUnit;
    /**
     * Actual Demand (native)
     */
    actualDemand;
    /**
     * Actual Demand unit name (native)
     */
    actualDemandUnit;
    /**
     * Billed Demand (native)
     */
    billedDemand;
    /**
     * Billed Demand unit name (native)
     */
    billedDemandUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillContainsLineItemDescriptionsSettingRequest {
    /**
     * List of line item descriptions. Each description must be shorter than 100 characters.  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>List cannot be empty</span>
     */
    lineItemDescriptions;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillContainsLineItemDescriptionsSettingResponse {
    /**
     * List of line item descriptions. Each description must be shorter than 100 characters.  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    lineItemDescriptions;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillContainsLineItemTypesSettingRequest {
    /**
     * List of observation type codes  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>List cannot be empty</span>
     */
    lineItemTypes;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillContainsLineItemTypesSettingResponse {
    /**
     * List of observation type codes  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    lineItemTypes;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillCreate {
    /**
     * The bill's account <span class='property-internal'>Required</span>
     */
    accountId;
    /**
     * The bill's begin date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    beginDate;
    /**
     * The bill's end date <span class='property-internal'>Required</span> <span class='property-internal'>Must be greater than BeginDate</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    endDate;
    /**
     * The bill's billing period <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 190001 and 209912</span>
     */
    billingPeriod;
    /**
     * The bill's accounting period  Depending on your settings you can have up to 13 accounting periods <span class='property-internal'>Must be between 190001 and 209913</span>
     */
    accountPeriod;
    /**
     * Indicates if the bill is estimated
     */
    estimated;
    /**
     * The bill's entry method.  True = manual entry, false = automatic entry. <span class='property-internal'>Required</span>
     */
    manualEntry;
    /**
     * The date and time of the bill statement <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    statementDate;
    /**
     * The date and time the bill is due <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    dueDate;
    /**
     * The date and time the of the next reading <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    nextReading;
    /**
     * The bill's control code <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    controlCode;
    /**
     * The bill's invoice number <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    invoiceNumber;
    /**
     * The bill note
     */
    note;
    /**
     * The meters with line items
     */
    meters;
    /**
     * The account line items
     */
    accountBodyLines;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillDeleteActionResult {
    /**
     *
     */
    selected;
    /**
     *
     */
    deleted;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEdit {
    /**
     * The bill's account <span class='property-internal'>Required</span>
     */
    accountId;
    /**
     * The bill's begin date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    beginDate;
    /**
     * The bill's end date <span class='property-internal'>Required</span> <span class='property-internal'>Must be greater than BeginDate</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    endDate;
    /**
     * The bill's billing period <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 190001 and 209912</span>
     */
    billingPeriod;
    /**
     * The bill's accounting period  Depending on your settings you can have up to 13 accounting periods <span class='property-internal'>Must be between 190001 and 209913</span> <span class='property-internal'>Required (defined)</span>
     */
    accountPeriod;
    /**
     * Indicates if the bill is estimated <span class='property-internal'>Required (defined)</span>
     */
    estimated;
    /**
     * The date and time of the bill statement <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    statementDate;
    /**
     * The date and time the bill is due <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    dueDate;
    /**
     * The date and time the next reading <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    nextReading;
    /**
     * The bill's control code <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    controlCode;
    /**
     * The bill's invoice number <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    invoiceNumber;
    /**
     * The bill's \"approval change flag\".  If a bill is approved and the approval system is turned on:      true = unapprove bill, false = don't change bill's approval status.  If the approval system is not turned on:      the bill's approval status will not be changed regardless of this setting. <span class='property-internal'>Required (defined)</span>
     */
    setToUnapproved;
    /**
     * The bill note <span class='property-internal'>Required (defined)</span>
     */
    note;
    /**
     * The meters with line items <span class='property-internal'>Required (defined)</span>
     */
    meters;
    /**
     * The account line items <span class='property-internal'>Required (defined)</span>
     */
    accountBodyLines;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEntryBodyLine {
    /**
     * The body line identifier
     */
    bodyLineId;
    /**
     * The body line's caption
     */
    caption;
    value;
    cost;
    observationType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEntryBodyLineChild {
    /**
     * The body line's numeric value
     */
    value;
    /**
     * The body line's observation type
     */
    type;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEntryBodyLineWithNounChild {
    /**
     * The body line's noun
     */
    noun;
    /**
     * The body line's numeric value
     */
    value;
    /**
     * The body line's observation type
     */
    type;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEntryMeterChild {
    /**
     * True means a \"template\" was used to generate the bodylines  False means an existing bill was used to generate the bodylines
     */
    fromTemplate;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter name
     */
    meterInfo;
    /**
     * The meter gl code
     */
    generalLedgerCode;
    /**
     * The bill's meter-level details
     */
    bodyLines;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEntryObservationTypeChild {
    /**
     * The observation type identifier
     */
    observationTypeId;
    /**
     * The observation type code
     */
    observationTypeCode;
    /**
     * The observation type name
     */
    observationTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillEntryResponse {
    /**
     * The bill identifier
     */
    billId;
    /**
     * The account identifier
     */
    accountId;
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * Indicates if a new bill batch needs to be opened to place this bill in
     */
    needsToOpenBatch;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's number of days
     */
    days;
    /**
     * The bill's total cost in the system currency.  The system currency is the reporting/global currency unit.
     */
    totalCost;
    /**
     * The bill's total cost in the source currency.  The source currency is the native currency unit.
     */
    totalSourceCost;
    costConversion;
    dueDate;
    statementDate;
    invoiceNumber;
    controlCode;
    nextReading;
    accountPeriodName;
    accountPeriodNumber;
    accountPeriodYear;
    estimated;
    /**
     * The bill's note
     */
    billNote;
    /**
     * Indicates if the bill has been voided
     */
    void;
    /**
     * Indicates if the bill is from a vendor
     */
    fromVendor;
    observationMethod;
    /**
     * Indicates if the bill has been approved
     */
    approved;
    /**
     * Indicates if the bill has been split
     */
    hasBeenSplit;
    /**
     * Indicates if the bill is being withheld from bill exports
     */
    exportHold;
    /**
     * Indicates if the bill has been ap exported
     */
    apExported;
    /**
     * Indicates if the bill has been gl exported
     */
    glExported;
    /**
     * Indicates if the bill has been exported to bill payment
     */
    paymentExported;
    /**
     * Indicates if the bill is an accrual bill
     */
    accrual;
    /**
     * The number of the check that the bill was paid with
     */
    checkNumber;
    /**
     * The date and time of the check
     */
    checkDate;
    /**
     * The payment status of the bill
     */
    payStatus;
    /**
     * The date when funds were withdrawn
     */
    fundsWithdrawnDate;
    /**
     * The date and time that the check cleared
     */
    clearedDate;
    /**
     * The fully qualified url to the bill image
     */
    billImageUrl;
    /**
     * The general ledger code of the bill's account-level details (\"Mixed\" if there is more than one)
     */
    generalLedgerCode;
    /**
     * The billing account's meters
     */
    meters;
    /**
     * The bill's account-level details
     */
    accountBodyLines;
    /**
     * The bill's vendor template details
     */
    vendorBodyLines;
    batch;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillExport {
    /**
     *  <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required (defined)</span>
     */
    billIds;
    /**
     * The export mode to use. Valid values are 'AP', 'GL', 'Payment' <span class='property-internal'>Required</span> <span class='property-internal'>One of 'ap', 'gl', 'payment'</span>
     */
    exportMode;
    /**
     * Flag to mark bills as exported after the export is complete. <span class='property-internal'>Required</span>
     */
    markAsExported;
    /**
     * Optional filename to use for the export file.  Filenames may only contain alphanumeric characters, dashes, underscores, or periods. <span class='property-internal'>Required (defined)</span>
     */
    fileName;
    /**
     * Optional note/comment. <span class='property-internal'>Required (defined)</span>
     */
    exportNote;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillExportOptions {
    /**
     * The export mode to use. Valid values are 'AP', 'GL', 'Payment' <span class='property-internal'>Required</span> <span class='property-internal'>One of 'ap', 'gl', 'payment'</span>
     */
    exportMode;
    /**
     * Flag to mark bills as exported after the export is complete. <span class='property-internal'>Required</span>
     */
    markAsExported;
    /**
     * Optional filename to use for the export file.  Filenames may only contain alphanumeric characters, dashes, underscores, or periods. <span class='property-internal'>Required (defined)</span>
     */
    fileName;
    /**
     * Optional note/comment. <span class='property-internal'>Required (defined)</span>
     */
    exportNote;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillHeaderChild {
    /**
     * The bill header value
     */
    value;
    /**
     * Indicates if the bill header is required during bill entry
     */
    required;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Bill header values to update
 */
class BillHeaderUpdate {
    beginDate;
    endDate;
    dueDate;
    statementDate;
    controlCode;
    invoiceNumber;
    accountPeriod;
    billingPeriod;
    estimated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Account Period
 */
class BillHeaderUpdateAccountPeriodChild {
    /**
     *  <span class='property-internal'>Must be between 190001 and 209913</span> <span class='property-internal'>Required (defined)</span>
     */
    accountPeriod;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Begin Date
 */
class BillHeaderUpdateBeginDateChild {
    /**
     *  <span class='property-internal'>Required when Update is set to True, case sensitive.</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    beginDate;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Billing Period
 */
class BillHeaderUpdateBillingPeriodChild {
    /**
     *  <span class='property-internal'>Required when Update is set to True, case sensitive.</span> <span class='property-internal'>Valid billing period between 190001 and 209912</span> <span class='property-internal'>NULL Valid</span>
     */
    billingPeriod;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Control Code
 */
class BillHeaderUpdateControlCodeChild {
    /**
     *  <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    controlCode;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Due Date
 */
class BillHeaderUpdateDueDateChild {
    /**
     *  <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    dueDate;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * End Date
 */
class BillHeaderUpdateEndDateChild {
    /**
     *  <span class='property-internal'>Required when Update is set to True, case sensitive.</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    endDate;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Estimated
 */
class BillHeaderUpdateEstimatedChild {
    /**
     *  <span class='property-internal'>Required when Update is set to True, case sensitive.</span>
     */
    estimated;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Invoice Number
 */
class BillHeaderUpdateInvoiceNumberChild {
    /**
     *  <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    invoiceNumber;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Statement Date
 */
class BillHeaderUpdateStatementDateChild {
    /**
     *  <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span>
     */
    statementDate;
    /**
     * Indicates whether or not the header value is being updated <span class='property-internal'>Required</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillHeaderWorkflowChild {
    /**
     *
     */
    useField;
    /**
     *
     */
    required;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillHistoryResponse {
    /**
     * The bill's bill id
     */
    billId;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The bill's created date
     */
    createdDate;
    /**
     * The bill's total cost
     */
    totalCost;
    totalCostUnit;
    /**
     * The bill's void indicator
     */
    void;
    /**
     * The bill's accrual indicator
     */
    accrual;
    /**
     * The bill's invoice number
     */
    invoiceNumber;
    /**
     * Indicates if the bill is estimated or not
     */
    estimated;
    /**
     * The bill's due date
     */
    dueDate;
    /**
     * The bill's statement date
     */
    statementDate;
    /**
     * The bill's account-meter summaries
     */
    billAccountMeters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillIdResponse {
    /**
     * The bill identifier
     */
    billId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportKickoutDetailsResponse {
    /**
     * The kickout fields
     */
    fields;
    /**
     * The kickout values
     */
    data;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportProfileColumnMapping {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>One of 'mm/dd/yyyy', 'Month dd yyyy', 'dd/mm/yyyy', 'dd Month yyyy', 'yyyymmdd'</span> <span class='property-internal'>Case sensitive</span>
     */
    dateFormat;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    accountCodeColumnIndex;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    startDateColumnIndex;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    endDateColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    vendorCodeColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    payAmountColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    billingPeriodColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    accountPeriodColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    statementDateColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    dueDateColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    controlCodeColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    invoiceNumberColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    meterCodeColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    commodityColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    serviceChargeColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    aceFlagColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    vprFlagColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    rateColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    serialNumberColumnIndex;
    /**
     *  <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    billNoteColumnIndex;
    /**
     *  <span class='property-internal'>Cannot be Empty</span>
     */
    observations;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportProfileObservation {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    columnIndex;
    /**
     *  <span class='property-internal'>Required</span>
     */
    observationTypeCode;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    caption;
    /**
     *  <span class='property-internal'>Required</span>
     */
    unitCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportProfileRequest {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    profileCode;
    columnMapping;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportProfileResponse {
    /**
     *
     */
    profileId;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span> <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    profileCode;
    columnMapping;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportRequest {
    /**
     * optional - if not provided, we assume the data is in Advanced format  A bill import profile code.   Maps given data to Advanced format using the mappings defined by this profile
     */
    profileCode;
    /**
     * FileName for the import file. Should include extension.  Example: fileABC.csv  Data contains the contents. The importer will save the under this file name.  The extension allows the importer to read the data in the proper format (csv,xlsx,zip) <span class='property-internal'>Required</span>
     */
    fileName;
    /**
     * The base64 encoded file. <span class='property-internal'>Required</span>
     */
    data;
    batchSettings;
    /**
     * Optional note/comment.
     */
    importNote;
    /**
     * Optional  property to indicate if failed audits automatically get marked as resolved
     */
    saveAsResolved;
    /**
     * Optional comment to explain why the audit is being auto resolved
     */
    comment;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillImportTaskKickoutSummaryResponse {
    /**
     * The identifier for the task that produced the kickouts
     */
    taskGuid;
    /**
     * The name of the imported file that produced the kickouts
     */
    fileName;
    /**
     * A list of the kickout messages produced by the uploaded file.
     */
    kickoutMessages;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Represents workflow settings for bill imports
 */
class BillImportWorkflowSettings {
    /**
     * Determines how bill import errors are handled. If your organization utilizes BillCAPture, this is forced to MarkBatchPending. <span class='property-internal'>One of 'MarkBatchPending', 'ProcessValidBills'</span>
     */
    errorHandling;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillKickoutImportRequest {
    batchSettings;
    /**
     * Optional note/comment.
     */
    importNote;
    /**
     * Optional  property to indicate if failed audits automatically get marked as resolved
     */
    saveAsResolved;
    /**
     * Optional comment to explain why the audit is being auto resolved
     */
    comment;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillLineTypeMappingResponse {
    /**
     * The observation type identifier
     */
    observationTypeId;
    /**
     * The observation type code that the caption maps to
     */
    observationTypeCode;
    /**
     * The observation type info that the caption maps to
     */
    observationTypeInfo;
    /**
     * The account identifier
     */
    accountId;
    /**
     * The account code that the caption maps to
     */
    accountCode;
    /**
     * The account info that the caption maps to
     */
    accountInfo;
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code that the caption maps to
     */
    vendorCode;
    /**
     * The vendor info that the caption maps to
     */
    vendorInfo;
    /**
     * The type of mapping, either default, vendor or account
     */
    type;
    /**
     * The bill line mapping operator identifier
     */
    operatorId;
    /**
     * The match operator used to map the caption
     */
    operator;
    /**
     * The caption match that maps to the observation type
     */
    caption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillListAdministrator {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillListAdministratorClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillMeterBodyLineCreate {
    /**
     * The bodyline's observation type <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The bodyline's unit of measure <span class='property-internal'>Required when Value is set</span>
     */
    valueUnitId;
    /**
     * The line item's value <span class='property-internal'>Required when ValueUnitId is set</span>
     */
    value;
    /**
     * The bodyline's cost unit of measure for this <span class='property-internal'>Required when Cost is set</span>
     */
    costUnitId;
    /**
     * The cost attributed to the line item <span class='property-internal'>Required when CostUnitId is set</span>
     */
    cost;
    /**
     * The caption <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    caption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillMeterBodyLineEdit {
    /**
     * The bodyline's id for an existing bodyline <span class='property-internal'>Required (defined)</span>
     */
    bodyLineId;
    /**
     * The bodyline's observation type <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The bodyline's unit of measure <span class='property-internal'>Required when Value is set</span>
     */
    valueUnitId;
    /**
     * The line item's value <span class='property-internal'>Required when ValueUnitId is set</span>
     */
    value;
    /**
     * The bodyline's cost unit of measure for this <span class='property-internal'>Required when Cost is set</span>
     */
    costUnitId;
    /**
     * The cost attributed to the line item <span class='property-internal'>Required when CostUnitId is set</span>
     */
    cost;
    /**
     * The caption <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    caption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillMeterCreate {
    /**
     * The meter the line items are assigned to <span class='property-internal'>Required</span>
     */
    meterId;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    bodyLines;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillMeterEdit {
    /**
     * The meter the line items are assigned to <span class='property-internal'>Required</span>
     */
    meterId;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    bodyLines;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillPaymentDetailsFileResponse {
    /**
     * Number of successful bill payment detail updates <span class='property-internal'>Required (defined)</span>
     */
    success;
    /**
     * Number of unsuccessful bill payment detail updates <span class='property-internal'>Required (defined)</span>
     */
    failure;
    /**
     * Base64 encoded File content of unsuccessful bill payment detail updates with reasons for failure <span class='property-internal'>Required (defined)</span>
     */
    kickoutStream;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillPaymentDetailsOptionalItem {
    /**
     * Identifier for bill to update <span class='property-internal'>Required</span>
     */
    billId;
    checkNumber;
    checkDate;
    payStatus;
    clearedDate;
    accountingPeriod;
    fundsWithdrawnDate;
    paymentAmount;
    paymentType;
    paymentVoucher;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillPaymentDetailsOptionalItemWithErrors {
    /**
     * Give error details <span class='property-internal'>Required (defined)</span>
     */
    errors;
    /**
     * Identifier for bill to update <span class='property-internal'>Required</span>
     */
    billId;
    checkNumber;
    checkDate;
    payStatus;
    clearedDate;
    accountingPeriod;
    fundsWithdrawnDate;
    paymentAmount;
    paymentType;
    paymentVoucher;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillPaymentDetailsOptionalResponse {
    /**
     * Number of successful bill payment detail updates <span class='property-internal'>Required (defined)</span>
     */
    success;
    /**
     * Number of unsuccessful bill payment detail updates <span class='property-internal'>Required (defined)</span>
     */
    failure;
    /**
     * List of unsuccessful bill payment detail updates with reasons for failure <span class='property-internal'>Required (defined)</span>
     */
    failedBillPaymentDetailsOptionalItems;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillPaymentEventCreate {
    /**
     * Bill ids for the event <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    billIds;
    /**
     * The payment event type of the event. For example, paymentGroup.approved, payment.open, payment.returned <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    paymentEventType;
    /**
     * An object representing the JSON received by the web hook
     */
    webhookPayload;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillPaymentEventResponse {
    /**
     * The identifier of the payment event
     */
    paymentEventId;
    /**
     * The payment type of the event. For example, paymentGroup.approved, payment.open, payment.returned
     */
    paymentEventType;
    /**
     * The date and time of the bill payment event
     */
    createdDate;
    /**
     * An object representing the JSON received by the web hook
     */
    webhookPayload;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillResponse {
    /**
     * The bill identifier
     */
    billId;
    batch;
    account;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's accounting period
     */
    accountPeriod;
    /**
     * The bill's total cost in the system currency.  The system currency is the reporting/global currency unit.
     */
    totalCost;
    /**
     * The bill's total cost in the source currency.  The source currency is the native currency unit.
     */
    totalSourceCost;
    costConversion;
    /**
     * Indicates if the bill is estimated
     */
    estimated;
    /**
     * Indicates if the bill has been approved
     */
    approved;
    /**
     * The date and time the bill was approved
     */
    approveDate;
    approvedBy;
    /**
     * Indicates if the bill has been exported
     */
    exported;
    /**
     * The date and time the bill was exported
     */
    exportDate;
    exportedBy;
    observationMethod;
    /**
     * The date and time of the bill statement
     */
    statementDate;
    /**
     * The date and time the bill is due
     */
    dueDate;
    /**
     * The date and time of the next reading
     */
    nextReading;
    /**
     * The bill's control code
     */
    controlCode;
    /**
     * The bill's invoice number
     */
    invoiceNumber;
    /**
     * The number of pages on the invoice
     */
    invoicePages;
    /**
     * The check number
     */
    checkNumber;
    /**
     * The date and time of the check
     */
    checkDate;
    /**
     * The pay status of the bill
     */
    payStatus;
    /**
     * The date when funds were withdrawn
     */
    fundsWithdrawnDate;
    /**
     * The cleared date
     */
    clearedDate;
    createdBy;
    /**
     * The date and time the bill was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * Indicates if the bill has been voided
     */
    void;
    /**
     * Indicates if the bill record has been cleaned. Cleaning is an internal EnergyCAP process
     */
    dirty;
    /**
     * Indicates if the import has been verified
     */
    importVerified;
    /**
     * Indicates if the bill is an accrual
     */
    accrual;
    /**
     * Indicates if the bill is a reversed accrual
     */
    accrualReversed;
    /**
     * The date and time the accrual was reversed
     */
    accrualReversedDate;
    /**
     * Indicates if the bill is held for export
     */
    exportHold;
    /**
     * Indicates if the bill has been gl exported
     */
    glExported;
    glExportedBy;
    /**
     * The date and time the bill was exported to gl
     */
    glExportDate;
    /**
     * Indicates if the bill has been bill payment exported
     */
    paymentExported;
    paymentExportedBy;
    /**
     * The date and time the bill was exported to bill payment
     */
    paymentExportDate;
    /**
     * Indicates if the bill is from a vendor
     */
    fromVendor;
    /**
     * Indicates if the bill has been split
     */
    hasBeenSplit;
    /**
     * The date and time the bill was split
     */
    wasSplitDate;
    /**
     * The transaction reference number of the bill
     */
    transRefNum;
    /**
     * The payment type of the bill.   For example, Check, VCard, and ACH.
     */
    paymentType;
    /**
     * The actual amount paid
     */
    actualAmountPaid;
    assignedTo;
    /**
     * The date and time the bill was assigned to a user
     */
    assignedDate;
    /**
     * The bill's pay source
     */
    paySource;
    /**
     * Indicates whom the bill paid
     */
    payTo;
    /**
     * The balance of the previous bill
     */
    previousBalance;
    /**
     * The amount of balance that was forwarded
     */
    balanceForward;
    /**
     * The current charges
     */
    currentCharges;
    /**
     * Bill note for this bill
     */
    billNote;
    reversalDetails;
    /**
     * Indicates whether this bill is excluded from accruals or not
     */
    excludedFromAccruals;
    /**
     * Indicates whether this bill is currently being analyzed
     */
    analyzing;
    /**
     * The net amount of the payment event of the bill
     */
    paymentAmount;
    /**
     * The API URL that can be used to download the file of the payment voucher
     */
    paymentVoucher;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillReversal {
    /**
     * Identifier of the other bill in the reversal pair
     */
    referenceBillId;
    /**
     * Indicates whether the reference bill is a reversal or source of a reversal.  It is \"Source\" if the reference bill is the source bill and \"Reversal\"  if the reference bill is the reversal bill
     */
    referenceType;
    /**
     * Description of the reversal pair
     */
    description;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillReversalRequest {
    /**
     * Bill ids to reverse <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    billIds;
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillSignificantlyShorterOrLongerThanPreviousSettingRequest {
    /**
     * Percent variance for bill length  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>List cannot be empty</span>
     */
    percentLengthVariance;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillSignificantlyShorterOrLongerThanPreviousSettingResponse {
    /**
     * Percent variance for bill length  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    percentLengthVariance;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines details for available types of bill split distributions. Only one of the properties may be populated.
 */
class BillSplitDetailsRequest {
    /**
     * Populate if setting up a fixed percentage split.  You cannot split to the same account and meter combination multiple times within a single version.  The destination account cannot be the same as the master account <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of FixedPercentageSplit, FloorAreaSplit, DynamicPercentageSplit can be set</span>
     */
    fixedPercentageSplit;
    /**
     * Populate if setting up a dynamic percentage split based on the building floor area with weighting factor applied.  You cannot split the same account and meter multiple times within a single version.  You cannot split to the same account and meter combination multiple times within a single version.  The destination account cannot be the same as the master account <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of FixedPercentageSplit, FloorAreaSplit, DynamicPercentageSplit can be set</span>
     */
    floorAreaSplit;
    dynamicPercentageSplit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Details of the bill split   FixedPercentageSplit, FloorAreaSplit, and DynamicPercentageSplit are mutually exclusive  Only 1 of these properties will have a value
 */
class BillSplitDetailsResponse {
    version;
    /**
     * Populate if setting up a fixed percentage split.
     */
    fixedPercentageSplit;
    /**
     * Populate if setting up a dynamic percentage split based on the building floor area with weighting factor applied.
     */
    floorAreaSplit;
    dynamicPercentageSplit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillSplitParentDetailsResponse {
    splitParentAccount;
    splitParentMeter;
    /**
     * First billing period that the bill split was active for
     */
    beginPeriod;
    /**
     * Last billing period that the bill split was active for
     */
    endPeriod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillSplitPlaceSizeChild {
    /**
     *
     */
    placeSizeId;
    /**
     *
     */
    beginDate;
    /**
     *
     */
    endDate;
    /**
     *
     */
    value;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillUnexport {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    billIds;
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>One of 'ap', 'gl', 'payment'</span>
     */
    exportMode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillUnexportOptions {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>One of 'ap', 'gl', 'payment'</span>
     */
    exportMode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillUsage {
    /**
     * Number of bills that are manually entered.
     */
    manuallyEntered;
    /**
     * Number of bills that are imported.
     */
    imported;
    /**
     * Number of bills that are chargeback.
     */
    chargeback;
    /**
     * Number of bills that have accrued.
     */
    accrual;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillViewAccountChild {
    /**
     *
     */
    accountId;
    /**
     *
     */
    accountCode;
    /**
     *
     */
    accountInfo;
    /**
     *
     */
    auditEnabled;
    accountType;
    address;
    vendor;
    generalLedger;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillViewAddressChild {
    /**
     * The address type identifier
     */
    addressTypeId;
    /**
     * The line 1 of the address
     */
    line1;
    /**
     * The line 2 of the address
     */
    line2;
    /**
     * The line 2 of the address
     */
    line3;
    /**
     * The city of the address
     */
    city;
    /**
     * The state of the address
     */
    state;
    /**
     * The country of the address
     */
    country;
    /**
     * The postal code of the address
     */
    postalCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillViewMeterChild {
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * The meter's serial number
     */
    serialNumber;
    rate;
    place;
    generalLedger;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillViewResponse {
    /**
     * The bill identifier
     */
    billId;
    /**
     * Indicates if the bill has been voided
     */
    void;
    /**
     * Indicates if the bill is from a vendor
     */
    fromVendor;
    /**
     * The method used to create the bill Automatic, Manual, Estimated, Simulated, Accrual, or Adjustment
     */
    creationMethod;
    /**
     * Indicates if the bill is an accrual
     */
    accrual;
    /**
     * Indicates if the bill is a reversed accrual
     */
    accrualReversed;
    batch;
    /**
     * The date the batch was closed
     */
    batchEndDate;
    /**
     * Do y'all need to have a batch code?
     */
    hideBatchCode;
    createdBy;
    /**
     * The date and time the bill was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * Indicates if the bill has been approved
     */
    approved;
    /**
     * The date and time the bill was approved
     */
    approveDate;
    approvedBy;
    /**
     * Indicates if the bill has been split
     */
    hasBeenSplit;
    /**
     * The date and time the bill was split
     */
    wasSplitDate;
    /**
     * Indicates if the bill is being withheld from bill exports
     */
    exportHold;
    /**
     * Indicates if the bill has been ap exported
     */
    apExported;
    /**
     * The date and time the bill was ap exported
     */
    apExportDate;
    apExportedBy;
    /**
     * Indicates if the bill has been gl exported
     */
    glExported;
    glExportedBy;
    /**
     * The date and time the bill was exported to gl
     */
    glExportDate;
    /**
     * Indicates if the bill has been exported to bill payment
     */
    paymentExported;
    paymentExportedBy;
    /**
     * The date and time the bill was exported to bill payment
     */
    paymentExportDate;
    /**
     * The number of the check that the bill was paid with
     */
    checkNumber;
    /**
     * The date and time of the check
     */
    checkDate;
    /**
     * The payment status of the bill
     */
    payStatus;
    /**
     * The date when funds were withdrawn
     */
    fundsWithdrawnDate;
    /**
     * The date and time that the check cleared
     */
    clearedDate;
    /**
     * The payment type of the bill.   For example, Check, VCard, and ACH.
     */
    paymentType;
    /**
     * The net amount of the payment event of the bill
     */
    paymentAmount;
    /**
     * The API URL that can be used to download the file of the payment voucher
     */
    paymentVoucher;
    /**
     * The method used to upload the bill to BillCAPture
     */
    bcAcquisitionMethod;
    /**
     * The date and time the bill was received by BillCAPture
     */
    bcReceived;
    /**
     * The date and time the bill was sent to the processor
     */
    bcSentToProcessing;
    /**
     * The date and time the bill completed processing
     */
    bcReturnedFromProcessing;
    /**
     * The date and time the bill was finished processing in BillCAPture
     */
    bcProcessingComplete;
    account;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's number of days
     */
    days;
    /**
     * The bill's accounting period
     */
    accountPeriod;
    /**
     * The bill's accounting period name
     */
    accountPeriodName;
    /**
     * Is account period required?
     */
    hideAccountPeriod;
    /**
     * Is account year required?  What is it?
     */
    hideAccountYear;
    /**
     * The bill's total cost in the system currency.  The system currency is the reporting/global currency unit.
     */
    totalCost;
    /**
     * The bill's total cost in the source currency.  The source currency is the native currency unit.
     */
    totalSourceCost;
    costConversion;
    /**
     * The bill's balance
     */
    balance;
    /**
     * Indicates if the bill is estimated
     */
    estimated;
    /**
     * Is estimated flag required?
     */
    hideEstimated;
    /**
     * The date of the billing statement
     */
    statementDate;
    /**
     * Is statement date required?
     */
    hideStatementDate;
    /**
     * The date and time the bill is due
     */
    dueDate;
    /**
     * Is due date required?
     */
    hideDueDate;
    /**
     * The bill's invoice number
     */
    invoiceNumber;
    /**
     * Is Invoice Number Required?
     */
    hideInvoiceNumber;
    /**
     * The bill's control code
     */
    controlCode;
    /**
     * Is control code required?
     */
    hideControlCode;
    /**
     * The fully qualified url to the bill image
     */
    billImageUrl;
    /**
     * Bill note
     */
    billNote;
    /**
     * The bill's next reading date
     */
    nextReading;
    /**
     * Is next reading date required?
     */
    hideNextReading;
    /**
     * Bill ID for the bill on this account that immediately precedes this bill (used for navigating back to the prior bill)
     */
    priorBillId;
    /**
     * Bill ID for the bill on this account that immediately follows this bill (used for navigating to the next bill)
     */
    nextBillId;
    /**
     * The bill history
     */
    billHistory;
    /**
     * The list of meters on the bill
     */
    meters;
    /**
     * The list of body lines on the bill
     */
    bodyLines;
    /**
     * The list of account-meter summaries on the bill
     */
    billAccountMeters;
    /**
     * Calendarized history information for the account
     */
    calendarizedHistory;
    reversalDetails;
    /**
     * Indicates whether this bill is excluded from accruals or not
     */
    excludedFromAccruals;
    /**
     * Indicates whether this bill is currently being analyzed
     */
    analyzing;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillViewVendorChild {
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
    address;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillWorkflowSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillWorkflowSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillingPeriodCostUnitChild {
    /**
     * The total cost.
     */
    cost;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * This data is not currently being used, it has been included for completeness.
 */
class BillingPeriodCostUnitDeltaChild {
    /**
     * The change in total cost from the current billing period.
     */
    delta;
    /**
     * The total cost.
     */
    cost;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillingPeriodUseCostChild {
    /**
     * The billing period that the data represents.  Will be the current billing period, the same year prior billing period,   or the same period prior year billing period.
     */
    billingPeriod;
    /**
     * The number of bills in the current billing period.
     */
    numberOfBillsInPeriod;
    /**
     * The number of bills in the current billing period that were generated by this workflow step.
     */
    numberOfBillsInPeriodFromWorkflowStep;
    use;
    cost;
    /**
     * The unit cost for the specified billing period.
     */
    unitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillingPeriodUseCostDeltaChild {
    /**
     * The billing period that the data represents.  Will be the current billing period, the same year prior billing period,   or the same period prior year billing period.
     */
    billingPeriod;
    use;
    cost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillingPeriodUseUnitChild {
    /**
     * The total common use.
     */
    use;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillingPeriodUseUnitDeltaChild {
    /**
     * The change in common use from the current billing period.
     */
    delta;
    /**
     * The total common use.
     */
    use;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillsAndBatches {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillsAndBatchesClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillsModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillsModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BillsOverdueFromVendorResponse {
    account;
    costCenter;
    /**
     *
     */
    endDate;
    /**
     *
     */
    directCost;
    /**
     *
     */
    days;
    /**
     *
     */
    gapDays;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BodylineChild {
    /**
     * The bodyline identifier
     */
    bodyLineId;
    /**
     * The account identifier
     */
    accountId;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The display order
     */
    displayOrder;
    /**
     * The caption
     */
    caption;
    /**
     * The bodyline's value
     */
    value;
    /**
     *
     */
    valueIsInfoOnly;
    /**
     * The cost attributed to the bodyline
     */
    cost;
    /**
     * Is the cost value counted towards the overall total cost or info only
     */
    costIsInfoOnly;
    valueUnit;
    costUnit;
    observationType;
    generalLedger;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BodylineResponse {
    /**
     * The bodyline identifier
     */
    bodylineId;
    /**
     * The bill identifier
     */
    billId;
    /**
     * The bodyline's value
     */
    value;
    /**
     * The cost attributed to the bodyline
     */
    cost;
    /**
     * The display order
     */
    displayOrder;
    /**
     * The caption
     */
    caption;
    /**
     * The help tag
     */
    helpTag;
    commodity;
    meter;
    account;
    generalLedger;
    observationType;
    unit;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetCreate {
    /**
     * The budget name <span class='property-internal'>Max length of 50</span> <span class='property-internal'>Required</span>
     */
    budgetInfo;
    /**
     * The notes attached to this budget <span class='property-internal'>Max length of 255</span>
     */
    note;
    /**
     * The fiscal year this budget represents <span class='property-internal'>Required</span>
     */
    budgetFiscalYear;
    /**
     * Number of years of data to include in the budget calculations <span class='property-internal'>Required</span>
     */
    numberOfDataYears;
    /**
     * The last period that should be included in the budget calculations (inclusive) <span class='property-internal'>Required</span>
     */
    dataYearsEndPeriod;
    /**
     * The calendarization method this budget will use <span class='property-internal'>Required</span> <span class='property-internal'>One of '1', '2'</span> <span class='property-internal'>Case sensitive</span>
     */
    budgetPeriodTypeId;
    /**
     * The type of data this budget will use in its calculations.   If BudgetPeriodTypeId is set to 2 (Accounting Period), this must be set to 1 (Billing Period) <span class='property-internal'>Required</span> <span class='property-internal'>One of '2', '1'</span> <span class='property-internal'>Case sensitive</span>
     */
    budgetDataTypeId;
    /**
     * The method used to calculate the baseline budget values. If NumberOfDataYears is 1, this value is ignored and the data from the selected year is used <span class='property-internal'>Required</span> <span class='property-internal'>One of '2', '3', '4', '1'</span> <span class='property-internal'>Case sensitive</span>
     */
    budgetUsageMethodId;
    /**
     * Flag to indicate if inactive accounts should be included in the budget calculations <span class='property-internal'>Required</span>
     */
    includeInactiveAccounts;
    /**
     * Flag to indicate if inactive meters should be included in the budget calculations <span class='property-internal'>Required</span>
     */
    includeInactiveMeters;
    /**
     * Flag to indicate if inactive account/meter relationships should be included in the budget calculations <span class='property-internal'>Required</span>
     */
    includeInactiveAccountMeters;
    /**
     * Flag to indicate if internal chargeback bills should be included in the budget calculations <span class='property-internal'>Required</span>
     */
    includeChargebackBills;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetDataType {
    /**
     * The budget data type identifier
     */
    budgetDataTypeId;
    /**
     * The budget data type name
     */
    budgetDataTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetEdit {
    /**
     * The budget name <span class='property-internal'>Must be between 0 and 50 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    budgetInfo;
    /**
     * Notes for the budget <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetPeriodType {
    /**
     * The budget period type identifier
     */
    budgetPeriodTypeId;
    /**
     * The budget period type name
     */
    budgetPeriodTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetResponse {
    /**
     * The budget identifier
     */
    budgetId;
    /**
     * The budget name
     */
    budgetInfo;
    /**
     * The budget fiscal year
     */
    budgetYear;
    /**
     * The number of versions associated with this budget
     */
    numberOfVersions;
    /**
     * The highest version number associated with this budget
     */
    maxVersionNumber;
    createdBy;
    /**
     * The date when the version was created
     */
    createdDate;
    /**
     * The total budget of the active version
     */
    activeTotalBudget;
    /**
     * Notes for the budget
     */
    notes;
    budgetPeriodType;
    budgetDataType;
    /**
     * Number of years used to generate the budget
     */
    yearsOfData;
    /**
     * Ending period for the budget
     */
    endPeriod;
    budgetUsageMethod;
    /**
     * Should the budget include inactive accounts
     */
    includeInactiveAccounts;
    /**
     * Should the budget include inactive meters
     */
    includeInactiveMeters;
    /**
     * Should the budget include inactive account meters
     */
    includeInactiveAccountMeters;
    /**
     * Should the budget include chargeback bills
     */
    includeChargebackBills;
    taskData;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetUsageMethod {
    /**
     * The budget usage method identifier
     */
    budgetUsageMethodId;
    /**
     * The budget usage method name
     */
    budgetUsageMethodInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetVersionCreate {
    /**
     * The budget version the new version will be based off of <span class='property-internal'>Required</span>
     */
    baseBudgetVersionId;
    /**
     * Name of the new budget version <span class='property-internal'>Required</span>
     */
    budgetVersionInfo;
    /**
     * Notes for the new budget version
     */
    budgetVersionNote;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetVersionEdit {
    /**
     * The budget version name <span class='property-internal'>Must be between 0 and 50 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    budgetVersionInfo;
    /**
     * Notes for the budget <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    notes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetVersionResponse {
    /**
     * The budget version identifier
     */
    budgetVersionId;
    /**
     * The budget identifier
     */
    budgetId;
    /**
     * The budget version name
     */
    budgetVersionInfo;
    /**
     * The budget version number
     */
    versionNumber;
    /**
     * If this is the active budget version
     */
    active;
    /**
     * Flag that shows if this budget version has been modified beyond its initial state using budget worksheets
     */
    hasBeenModified;
    modifiedBy;
    /**
     * The date when the version was modified
     */
    modifiedDate;
    /**
     * The total budget of the budget version
     */
    totalBudget;
    /**
     * Notes for the budget
     */
    notes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetVersionSummary {
    /**
     * Period
     */
    period;
    use;
    /**
     * The cost
     */
    cost;
    /**
     * The average unit cost
     */
    averageUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetVersionSummaryResponse {
    budgetVersion;
    total;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetsAndBudgetVersions {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BudgetsAndBudgetVersionsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingAndMeterGroups {
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingAndMeterGroupsClassPermission {
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleActualData {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleActualDataClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleBudgets {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleBudgetsClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleCalendarizedData {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleCalendarizedDataClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleMeterIntervalData {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleMeterIntervalDataClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleNormalizedData {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleNormalizedDataClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleSavings {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleSavingsClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleSustainability {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndMetersModuleSustainabilityClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndOrganizations {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BuildingsAndOrganizationsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BulkBaselineProcessorRequest {
    /**
     * Determines if weather adjustments are applied to the reprocessed baseline or not  Defaults to \"false\"
     */
    ignoreWeatherAdjustments;
    /**
     * Filter criteria which determine the meters whose cost avoidance baselines will be reprocessed <span class='property-internal'>Cannot be Empty</span>
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class BulkMeterCostAvoidanceSettings {
    /**
     * Indicates whether or not the cost avoidance processor will attempt cooling adjustments <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    attemptCoolingAdjustment;
    /**
     * Indicates whether or not the cost avoidance processor will attempt heating adjustments <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    attemptHeatingAdjustment;
    /**
     * Determines number of months of data included in the meter's cost avoidance baseline <span class='property-internal'>Must be between 12 and 36</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    numBaselineMonths;
    /**
     * Determines the start date of the meter's cost avoidance baseline <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    baselineStartDate;
    /**
     * Determines the external temperature above which cooling is expected to take place <span class='property-internal'>Must be greater than or equal to HeatingNeededBelow</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    coolingNeededAbove;
    /**
     * Determines the external temperature below which heating is expected to take place <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    heatingNeededBelow;
    /**
     * Determines whether or not to include the meter in cost avoidance processing <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    includeMeterInCostAvoidance;
    /**
     * Determines the start date after which energy and cost savings are expected to accrue <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of AttemptCoolingAdjustment, AttemptHeatingAdjustment, NumBaselineMonths, BaselineStartDate, CoolingNeededAbove, HeatingNeededBelow, IncludeMeterInCostAvoidance, SavingsStartDate must not be null</span>
     */
    savingsStartDate;
    /**
     * Filter criteria which determine the meters whose cost avoidance settings will be updated <span class='property-internal'>Required (defined)</span>
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CalculateSavingsRequest {
    /**
     * Determines which option will be used to select the bills for this instance of the cost avoidance processor to process  - \"AllBills\" means all bills will be processed  - \"ModifiedOrNotProcessed\" means only new bills or bills which have been modified since the last time cost avoidance was run will be processed  - \"BillingPeriod\" means that only bills with a billing period which is greater than or equal to the provided billing period will be processed <span class='property-internal'>One of 'AllBills', 'ModifiedOrNotProcessed', 'BillingPeriod'</span>
     */
    billSelectionOption;
    /**
     * When BillSelectionOption is 'BillingPeriod', this defines the billing period to be used to target bills for processing <span class='property-internal'>Valid billing period between 190001 and 300001</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required when BillSelectionOption is set to BillingPeriod, case sensitive.</span>
     */
    billingPeriod;
    /**
     * Allow the user to optionally exclude one or all special adjustments <span class='property-internal'>One of 'SkipAll', 'SkipOne', 'SkipNone'</span>
     */
    skipSpecialAdjustmentOption;
    /**
     * During cost avoidance processing, the special adjustment having the provided special adjustment type ID will not be applied (only if SkipSpecialAdjustmentOption = \"SkipOne\") <span class='property-internal'>Required when SkipSpecialAdjustmentOption is set to SkipOne, case sensitive.</span>
     */
    specialAdjustmentTypeIdToIgnore;
    /**
     * Filter criteria which determine the meters whose savings will be reprocessed
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines how use is calculated for a calculated bill distribution
 */
class CalculatedBillCostRequest {
    /**
     * Apply the meter's current rate when calculating bill cost  \"true\" is the only valid value for this property <span class='property-internal'>One of 'True'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of UseCurrentMetersRateSchedule, FixedUnitCost, UnitCostMeterId, FixedAmount, CopyCostFromMeter, CostCalculation, CalendarizedCostCalculation can be set</span>
     */
    useCurrentMetersRateSchedule;
    fixedUnitCost;
    /**
     * MeterId from where to get the unit cost <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of UseCurrentMetersRateSchedule, FixedUnitCost, UnitCostMeterId, FixedAmount, CopyCostFromMeter, CostCalculation, CalendarizedCostCalculation can be set</span>
     */
    unitCostMeterId;
    /**
     * Use a fixed amount for bill cost <span class='property-info'>Max scale of 2</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of UseCurrentMetersRateSchedule, FixedUnitCost, UnitCostMeterId, FixedAmount, CopyCostFromMeter, CostCalculation, CalendarizedCostCalculation can be set</span>
     */
    fixedAmount;
    copyCostFromMeter;
    costCalculation;
    calendarizedCostCalculation;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Definition of how a calculated bill will get its cost
 */
class CalculatedBillCostResponse {
    rateSchedule;
    fixedUnitCost;
    unitCostFromMeter;
    /**
     * Use a fixed amount for bill cost
     */
    fixedAmount;
    copyCostFromMeter;
    costCalculation;
    calendarizedCostCalculation;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CalculatedBillDemandRequest {
    /**
     * Use channel data readings to calculate bill demand <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of ReadingsChannelId, ReadingsEsaChannelId, FixedDemand, UseWatticsDataPoint can be set</span>
     */
    readingsChannelId;
    /**
     * Use ESA channel data readings to calculate bill demand <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of ReadingsChannelId, ReadingsEsaChannelId, FixedDemand, UseWatticsDataPoint can be set</span>
     */
    readingsEsaChannelId;
    fixedDemand;
    /**
     * Use SmartAnalytics (Wattics) data readings to calculate bill demand <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of ReadingsChannelId, ReadingsEsaChannelId, FixedDemand, UseWatticsDataPoint can be set</span>
     */
    useWatticsDataPoint;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CalculatedBillDemandResponse {
    readingsFromChannel;
    readingsFromEsaChannel;
    fixedDemand;
    readingsFromWatticsDataPoint;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Response object containing all the details related to calculated bill setup for a meter. Includes use, cost, meter line items, and account line items.
 */
class CalculatedBillDetailsResponse {
    version;
    use;
    cost;
    demand;
    /**
     * Additional meter bodylines to be added to the bill  The line items are returned in the correct display order
     */
    meterLineItems;
    /**
     * Additional account bodylines to be added to the bill  The line items are returned in the correct display order
     */
    accountLineItems;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines how use is calculated for a calculated bill distribution
 */
class CalculatedBillUseRequest {
    /**
     * Use monthly channel data readings to calculate bill use <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of ReadingsChannelId, ReadingsEsaChannelId, FixedAmount, CopyUseFromMeter, UseCalculation, CalendarizedUseCalculation, UseWatticsDataPoint can be set</span>
     */
    readingsChannelId;
    /**
     * Use ESA channel data readings to calculate bill use <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of ReadingsChannelId, ReadingsEsaChannelId, FixedAmount, CopyUseFromMeter, UseCalculation, CalendarizedUseCalculation, UseWatticsDataPoint can be set</span>
     */
    readingsEsaChannelId;
    fixedAmount;
    copyUseFromMeter;
    useCalculation;
    calendarizedUseCalculation;
    /**
     * Use SmartAnalytics (Wattics) data readings to calculate bill use <span class='property-internal'>One of 'True'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of ReadingsChannelId, ReadingsEsaChannelId, FixedAmount, CopyUseFromMeter, UseCalculation, CalendarizedUseCalculation, UseWatticsDataPoint can be set</span>
     */
    useWatticsDataPoint;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Definition of how a calculated bill will get its use
 */
class CalculatedBillUseResponse {
    readingsFromChannel;
    readingsFromEsaChannel;
    fixedAmount;
    copyUseFromMeter;
    useCalculation;
    calendarizedUseCalculation;
    readingsFromWatticsDataPoint;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Adding/subtracting calculation involving meters and/or meter groups  You must pass in at least 1 thing to sum or subtract
 */
class CalculationRequest {
    sum;
    subtract;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Adding/subtracting calculation involving meters and/or meter groups  For each type (sum or subtract), expect only one of the properties to be populated (e.g. if SumMeters has values, then SumMeterGroups should not)
 */
class CalculationResponse {
    sum;
    subtract;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Adding calculation involving meters  You must pass in at least 1 thing to sum
 */
class CalendarizedCalculationRequest {
    sum;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Adding calendarized calculation involving meters
 */
class CalendarizedCalculationResponse {
    /**
     * Addition calculation involving meters
     */
    calendarizedSum;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CalendarizedSumRequest {
    /**
     * Meters in this list will have their use or cost added together during the bill calculation <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required</span>
     */
    sumMeterIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelChild {
    /**
     * The channel code  Combines observationTypeCode:unitCode:observationMethodCode:observationRuleCode:interval in minutes
     */
    channelCode;
    /**
     * The channel identifier
     */
    channelId;
    /**
     * The channel interval in seconds.  Monthly = 2592000  Weekly = 604800  Daily = 86400  Hourly = 3600  Thirty_Minutes = 1800  Fifteen_Minutes = 900
     */
    interval;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelChildWithObservationType {
    type;
    rule;
    /**
     * The channel code  Combines observationTypeCode:unitCode:observationMethodCode:observationRuleCode:interval in minutes
     */
    channelCode;
    /**
     * The channel identifier
     */
    channelId;
    /**
     * The channel interval in seconds.  Monthly = 2592000  Weekly = 604800  Daily = 86400  Hourly = 3600  Thirty_Minutes = 1800  Fifteen_Minutes = 900
     */
    interval;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelCreate {
    /**
     * The interval of the channel in minutes  15 = FifteenMinute,  30 = ThirtyMinute,  60 = Hourly,  1440 = Daily,  10080 = Weekly,  43200 = Monthly <span class='property-internal'>Required</span> <span class='property-internal'>One of '15', '30', '60', '1440', '10080', '43200'</span> <span class='property-internal'>Case sensitive</span>
     */
    intervalMinutes;
    /**
     * The observation type of the channel <span class='property-internal'>Required</span>
     */
    observationTypeCode;
    /**
     * Description of the channel <span class='property-internal'>Must be between 0 and 4000 characters</span>
     */
    channelDescription;
    /**
     * The import identifier for the channel <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    channelImportId;
    channelVersion;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelEdit {
    /**
     * The interval of the channel. The interval is measured in minutes  Standard intervals are  15 = FifteenMinute,  30 = ThirtyMinute,  60 = Hourly,  1440 = Daily,  10080 = Weekly,  43200 = Monthly <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    intervalMinutes;
    /**
     * The observation type of the channel <span class='property-internal'>Required</span>
     */
    observationTypeCode;
    /**
     * Description of the channel <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    channelDescription;
    /**
     * The import identifier for the channel. <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    channelImportId;
    channelVersion;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelLatestReading {
    observationType;
    lastReading;
    /**
     * The channel identifier
     */
    channelId;
    /**
     * The channel interval in seconds.  Monthly = 2592000  Weekly = 604800  Daily = 86400  Hourly = 3600  Thirty_Minutes = 1800  Fifteen_Minutes = 900
     */
    interval;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelResponse {
    /**
     * The channel identifier
     */
    channelId;
    /**
     * The interval of the channel. The interval is measured in minutes
     */
    intervalMinutes;
    observationType;
    /**
     * Description of the channel
     */
    channelDescription;
    /**
     * The import identifier for the channel.
     */
    channelImportId;
    /**
     * Indicates if the channel has readings
     */
    hasReadings;
    /**
     * Date of the earliest reading for the channel
     */
    firstReadingDate;
    /**
     * Date of the most recent reading for the channel
     */
    lastReadingDate;
    /**
     * List of channel versions  Versions include channel settings that may change over time
     */
    channelVersions;
    /**
     * Indicates if the channel is a part of a distribution
     */
    isUsedOnDistribution;
    meter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelVersionRequest {
    /**
     * The channel multiplier <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 16, max precision of 38</span>
     */
    multiplier;
    /**
     * The channel's unit of measure <span class='property-internal'>Required</span>
     */
    unitCode;
    /**
     * The channel's observation rule.  Possible values include \"Odometer\" and \"Trip\" <span class='property-internal'>Required</span> <span class='property-internal'>One of 'Odometer', 'Trip'</span>
     */
    observationRule;
    /**
     * The channel's max reading <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 16, max precision of 38</span>
     */
    maximumReading;
    /**
     * List of user defined/custom fields and values for this version  If the Udfs list is null or empty no values are assigned  If a udf is omitted no value is assigned to that udf  To remove a value from an existing Udf, pass in the UdfId and set the Value to null
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelVersionResponse {
    /**
     * The channel version identifier
     */
    channelVersionId;
    /**
     * The channel multiplier
     */
    multiplier;
    unit;
    observationRule;
    /**
     * The channel's max reading
     */
    maximumReading;
    /**
     * Date this channel version started to be used
     */
    beginDate;
    /**
     * Date this channel version stopped being used
     */
    endDate;
    /**
     * List of user defined/custom fields and values for this version
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChannelVersionWithBeginDateRequest {
    /**
     * Date the channel version started to be used <span class='property-internal'>Must be between 12/30/1899 and 12/31/2099</span>
     */
    beginDate;
    /**
     * The channel multiplier <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 16, max precision of 38</span>
     */
    multiplier;
    /**
     * The channel's unit of measure <span class='property-internal'>Required</span>
     */
    unitCode;
    /**
     * The channel's observation rule.  Possible values include \"Odometer\" and \"Trip\" <span class='property-internal'>Required</span> <span class='property-internal'>One of 'Odometer', 'Trip'</span>
     */
    observationRule;
    /**
     * The channel's max reading <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 16, max precision of 38</span>
     */
    maximumReading;
    /**
     * List of user defined/custom fields and values for this version  If the Udfs list is null or empty no values are assigned  If a udf is omitted no value is assigned to that udf  To remove a value from an existing Udf, pass in the UdfId and set the Value to null
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * The settings used to run the chargeback processor
 */
class ChargebackProcessorSettings {
    /**
     * Optional Filters. These will aid in identifying the distributions that should be processed  TODO:List applicable filters
     */
    filters;
    /**
     * Billing Period to be processed <span class='property-internal'>Required</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span>
     */
    billingPeriod;
    /**
     * Optional Start Date for Bill being generated. Only used for Calculate Bill and that too when use is not from sub-meter reading  The bills generated will inherit bill headers (accounting period, invoice number, control code, etc ) from the batch <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    startDateForBill;
    /**
     * Optional End Date for Bill being generated. Only used for Calculate Bill and that too when use is not from sub-meter reading  The bills generated will inherit bill headers (accounting period, invoice number, control code, etc ) from the batch <span class='property-internal'>Must be greater than StartDateForBill</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    endDateForBill;
    /**
     * Optional note/comment
     */
    note;
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackProcessorSettingsForAggregations {
    /**
     * End period of Billing Period range to be processed <span class='property-internal'>Valid billing period between 190001 and 300001</span>
     */
    billingPeriod;
    /**
     * Optional note/comment
     */
    note;
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackProcessorSettingsForSplits {
    /**
     * Optional note/comment
     */
    note;
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackProcessorSettingsWithoutFilters {
    /**
     * Billing Period to be processed <span class='property-internal'>Required</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span>
     */
    billingPeriod;
    /**
     * Optional Start Date for Bill being generated. Only used for Calculate Bill and that too when use is not from sub-meter reading  The bills generated will inherit bill headers (accounting period, invoice number, control code, etc ) from the batch <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    startDateForBill;
    /**
     * Optional End Date for Bill being generated. Only used for Calculate Bill and that too when use is not from sub-meter reading  The bills generated will inherit bill headers (accounting period, invoice number, control code, etc ) from the batch <span class='property-internal'>Must be greater than StartDateForBill</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    endDateForBill;
    /**
     * Optional note/comment
     */
    note;
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackReversals {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackReversalsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackTaskRequest {
    /**
     * Comment to add to the task <span class='property-internal'>Required</span>
     */
    comment;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackTaskResponse {
    /**
     * The number of bills created by the task
     */
    numberOfBillsCreated;
    /**
     * The number of chargeback versions that failed to run within the task
     */
    numberOfFailedVersions;
    /**
     * Identifier for the task
     */
    taskId;
    workflow;
    /**
     * Begin date when the task started
     */
    taskBegin;
    /**
     * End date when the task ended
     */
    taskEnd;
    user;
    /**
     * The billing period the task was run for
     */
    billingPeriod;
    batch;
    /**
     * The task's settings
     */
    settings;
    /**
     * User comments on the task
     */
    comment;
    /**
     * Current status of the task
     */
    status;
    /**
     * The chargeback type.  Either \"Split\" or \"Calculation\"
     */
    chargebackType;
    reversedBy;
    /**
     * The date when all bills generated by the task were voided or deleted
     */
    reversedDate;
    /**
     * The number of bills that are currently analyzing within the task
     */
    numberOfAnalyzingBills;
    /**
     * The number of unresolved flags on bills within the task
     */
    numberOfUnresolvedFlags;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackTaskVersionResponse {
    /**
     * The specific version id within the task we are reporting on
     */
    versionId;
    /**
     * The number of bills created for this version within the task
     */
    numberOfBillsCreated;
    /**
     * Error that may have occurred when running this version within the task
     */
    errorMessage;
    /**
     * The billids of all the destination bills created by this version within the task
     */
    destinationBillIds;
    /**
     * If this was a bill split task, then ID of the bill that was split by this version within the task
     */
    sourceBillId;
    /**
     * Identifier for the task
     */
    taskId;
    workflow;
    /**
     * Begin date when the task started
     */
    taskBegin;
    /**
     * End date when the task ended
     */
    taskEnd;
    user;
    /**
     * The billing period the task was run for
     */
    billingPeriod;
    batch;
    /**
     * The task's settings
     */
    settings;
    /**
     * User comments on the task
     */
    comment;
    /**
     * Current status of the task
     */
    status;
    /**
     * The chargeback type.  Either \"Split\" or \"Calculation\"
     */
    chargebackType;
    reversedBy;
    /**
     * The date when all bills generated by the task were voided or deleted
     */
    reversedDate;
    /**
     * The number of bills that are currently analyzing within the task
     */
    numberOfAnalyzingBills;
    /**
     * The number of unresolved flags on bills within the task
     */
    numberOfUnresolvedFlags;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowBase {
    /**
     * Identifier for the chargeback workflow
     */
    chargebackWorkflowId;
    /**
     * Name given to the chargeback workflow
     */
    chargebackWorkflowInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowCreate {
    /**
     * Name given to the chargeback workflow <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    chargebackWorkflowInfo;
    /**
     * List of chargeback workflow steps with details  Order of the steps in the list determines the steps in the workflow. <span class='property-internal'>Cannot be Empty</span>
     */
    chargebackWorkflowSteps;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * This class inherits all of the billing period summary properties for a source meter   and adds a list of billing period summaries for each bill split destination meter.
 */
class ChargebackWorkflowDigestChild {
    /**
     * List of billing period summaries for meters that are children of a bill split source meter.  This list will be null for calculated source meters.
     */
    splits;
    meter;
    currentPeriod;
    priorPeriod;
    priorYear;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowDigestResponse {
    chargebackWorkflowStep;
    /**
     * The list of digest results for the latest task executed in the specified billing period.
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowDigestSplitChild {
    meter;
    currentPeriod;
    priorPeriod;
    priorYear;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowEdit {
    /**
     * Name given to the chargeback workflow <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    chargebackWorkflowInfo;
    /**
     * List of chargeback workflow steps with details  Order of the steps in the list determines the steps in the workflow. <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    chargebackWorkflowSteps;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowResponse {
    /**
     * List of workflow steps with details
     */
    chargebackWorkflowSteps;
    /**
     * Identifier for the chargeback workflow
     */
    chargebackWorkflowId;
    /**
     * Name given to the chargeback workflow
     */
    chargebackWorkflowInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Represents workflow settings for chargebacks
 */
class ChargebackWorkflowSettings {
    /**
     * Allow or prevent the \"advanced\" dialog to be displayed when running the chargeback processor <span class='property-internal'>Required</span>
     */
    allowAdvancedChargebackSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowStep {
    /**
     * Identifier for the chargeback workflow step
     */
    chargebackWorkflowStepId;
    /**
     * Name given to the chargeback workflow step
     */
    chargebackWorkflowStepInfo;
    /**
     * Description for the chargeback workflow step
     */
    chargebackWorkflowStepDescription;
    /**
     * The chargeback type that can be assign to this chargeback workflow step.  Either \"Split\" or \"Calculation\"
     */
    chargebackWorkflowStepType;
    /**
     * The order for this step within the chargeback workflow
     */
    chargebackWorkflowStepOrder;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowStepChild {
    /**
     * Identifier for the chargeback workflow step
     */
    chargebackWorkflowStepId;
    /**
     * Name given to the chargeback workflow step
     */
    chargebackWorkflowStepInfo;
    /**
     * Description for the chargeback workflow step
     */
    chargebackWorkflowStepDescription;
    /**
     * The chargeback type that can be assign to this chargeback workflow step. <span class='property-internal'>One of 'Split', 'Calculation'</span> <span class='property-internal'>One of 'Split', 'Calculation'</span>
     */
    chargebackWorkflowStepType;
    /**
     * The order for this step within the chargeback workflow
     */
    chargebackWorkflowStepOrder;
    chargebackWorkflow;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowStepCreate {
    /**
     * Name given to the chargeback workflow step <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    chargebackWorkflowStepInfo;
    /**
     * Description for the chargeback workflow step <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    chargebackWorkflowStepDescription;
    /**
     * The chargeback type that can be assign to this chargeback workflow step. <span class='property-internal'>One of 'Split', 'Calculation'</span>
     */
    chargebackWorkflowStepType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebackWorkflowStepEdit {
    /**
     * Identifier for the chargeback workflow step  If calculateBillWorkflowStepId has a value it will be updated  If calculateBillWorkflowStepId is null, a new step will be created <span class='property-internal'>Required (defined)</span>
     */
    chargebackWorkflowStepId;
    /**
     * Name given to the chargeback workflow step  Must be unique for a particular type (split or calculation) across all workflows <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    chargebackWorkflowStepInfo;
    /**
     * Description for the chargeback workflow step <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    chargebackWorkflowStepDescription;
    /**
     * The chargeback type that can be assign to this chargeback workflow step.  When editing a step you cannot change the type <span class='property-internal'>One of 'Split', 'Calculation'</span> <span class='property-internal'>Required (defined)</span>
     */
    chargebackWorkflowStepType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Chargebacks {
    /**
     *
     */
    run;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebacksClassPermission {
    /**
     *
     */
    run;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebacksModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ChargebacksModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Claim {
    /**
     * Type of claim
     */
    claimType;
    /**
     * Claim value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CollectionChild {
    /**
     * The collection identifier
     */
    collectionId;
    /**
     * The collection code
     */
    collectionCode;
    /**
     * The collection info
     */
    collectionInfo;
    collectionIcon;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CollectionEmissionSourceChild {
    /**
     * The emission source identifier
     */
    emissionSourceId;
    /**
     * The emission source code
     */
    emissionSourceCode;
    /**
     * The emission source info
     */
    emissionSourceInfo;
    /**
     * Whether the emission source is active or not
     */
    active;
    commodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CollectionRequest {
    /**
     * The collection code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    collectionCode;
    /**
     * The collection info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    collectionInfo;
    /**
     * The identifier for the parent of the collection. The parent is the collection directly above the current collection on the collections and emission sources tree <span class='property-internal'>Required</span>
     */
    parentCollectionId;
    collectionIcon;
    /**
     * The collection note <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CollectionResponse {
    /**
     * The collection identifier
     */
    collectionId;
    /**
     * The collection code
     */
    collectionCode;
    /**
     * The collection info
     */
    collectionInfo;
    /**
     * The collection description
     */
    note;
    collectionIcon;
    parent;
    /**
     * An array of child collections
     */
    collections;
    /**
     * An array of child emission sources
     */
    emissionSources;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Collections {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CollectionsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ColumnNumberOrOverrideValueNullableInt32 {
    /**
     * Column number
     */
    columnNumber;
    /**
     * The value of the column
     */
    overrideValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ColumnNumberOrOverrideValueString {
    /**
     * Column number
     */
    columnNumber;
    /**
     * The value of the column
     */
    overrideValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityCategory {
    commonUseUnit;
    commonDemandUnit;
    /**
     * The commodity category id
     */
    commodityCategoryId;
    /**
     * The commodity category info
     */
    commodityCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityCategoryChild {
    /**
     * The commodity category id
     */
    commodityCategoryId;
    /**
     * The commodity category info
     */
    commodityCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityCategoryRequest {
    /**
     * The commodity category info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    commodityCategoryInfo;
    /**
     * The default use unit for this category
     */
    commonUseUnitId;
    /**
     * The default demand unit for this category
     */
    commonDemandUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityCategoryResponse {
    /**
     * List of commodities under the category
     */
    commodities;
    commonUseUnit;
    commonDemandUnit;
    /**
     * The commodity category id
     */
    commodityCategoryId;
    /**
     * The commodity category info
     */
    commodityCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityChild {
    /**
     * The commodity identifier <span class='property-internal'>Required (defined)</span>
     */
    commodityId;
    /**
     * The commodity code <span class='property-internal'>Required (defined)</span>
     */
    commodityCode;
    /**
     * The commodity info <span class='property-internal'>Required (defined)</span>
     */
    commodityInfo;
    commodityIcon;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityChildWithCategory {
    commodityCategory;
    /**
     * The commodity identifier
     */
    commodityId;
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    commodityIcon;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityDigestActualYearlyResponse {
    globalUseUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityDigestActualYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityDigestActualYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityDigestActualYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityEditRequest {
    /**
     * The commodity info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    commodityInfo;
    /**
     * Three letter abbreviation code to represent the commodity <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 3 characters</span>
     */
    abbreviation;
    /**
     * The commodity description <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    description;
    icon;
    /**
     * The commodity category identifier <br />  If the category is provided, the default use rollup unit and default demand rollup unit for that category will be used <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of CommodityCategoryId, CommodityRollupUnitId can be set</span> <span class='property-internal'>Only one of CommodityCategoryId, CommodityDemandRollupUnitId can be set</span>
     */
    commodityCategoryId;
    /**
     * The common use unit identifier for reporting purposes <br />  Ignored if a commodity category is provided and it has a rollup unit specified <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of CommodityCategoryId, CommodityRollupUnitId can be set</span>
     */
    commodityRollupUnitId;
    /**
     * Indicates if the commodity should be included in Energy reporting <span class='property-internal'>Required (defined)</span>
     */
    includeInEnergyReporting;
    /**
     * The multiplier to convert from the commodity rollup unit to the energy use reporting unit <br />  Not required if commodity rollup unit is in the energy unit category <span class='property-internal'>Must be null when IncludeInEnergyReporting  is  set to False, case sensitive</span>
     */
    energyReportingUnitConversionMultiplier;
    /**
     * The common demand unit identifier for reporting purposes <br />  Ignored if a commodity category is provided and it has a demand rollup unit specified <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of CommodityCategoryId, CommodityDemandRollupUnitId can be set</span>
     */
    commodityDemandRollupUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityRequest {
    /**
     * The commodity info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    commodityInfo;
    /**
     * Three letter abbreviation code to represent the commodity <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 3 characters</span>
     */
    abbreviation;
    /**
     * The commodity description <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    description;
    icon;
    /**
     * The commodity category identifier <br />  If the category is provided, the default use rollup unit and default demand rollup unit for that category will be used <span class='property-internal'>Only one of CommodityCategoryId, CommodityRollupUnitId can be set</span> <span class='property-internal'>Only one of CommodityCategoryId, CommodityDemandRollupUnitId can be set</span>
     */
    commodityCategoryId;
    /**
     * The common use unit identifier for reporting purposes <br />  Ignored if a commodity category is provided and it has a rollup unit specified <span class='property-internal'>Only one of CommodityCategoryId, CommodityRollupUnitId can be set</span>
     */
    commodityRollupUnitId;
    /**
     * Indicates if the commodity should be included in Energy reporting
     */
    includeInEnergyReporting;
    /**
     * The multiplier to convert from the commodity rollup unit to the energy use reporting unit <br />  Not required if commodity rollup unit is in the energy unit category <span class='property-internal'>Must be null when IncludeInEnergyReporting  is  set to False, case sensitive</span>
     */
    energyReportingUnitConversionMultiplier;
    /**
     * The common demand unit identifier for reporting purposes <br />  Ignored if a commodity category is provided and it has a demand rollup unit specified <span class='property-internal'>Only one of CommodityCategoryId, CommodityDemandRollupUnitId can be set</span>
     */
    commodityDemandRollupUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CommodityResponse {
    /**
     * The commodity identifier
     */
    commodityId;
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * Three letter abbreviation code to represent the commodity
     */
    abbreviation;
    /**
     * The commodity description
     */
    description;
    icon;
    commodityCategory;
    useRollupUnit;
    demandRollupUnit;
    /**
     * Indicates if the commodity should be included in Energy reporting
     */
    includeInEnergyReporting;
    /**
     * The multiplier to convert from the commodity rollup unit to the energy use reporting unit
     */
    energyReportingUnitConversionMultiplier;
    /**
     * Indicates if the commodity is in use on a meter/emissions source
     */
    inUse;
    /**
     * Indicates if the commodity is a system-level commodity
     */
    isSystemCommodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose commodity value comparison DTO
 */
class CommodityValueComparison {
    commodity;
    currentValue;
    previousValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ContactChild {
    /**
     * The contact identifier
     */
    contactId;
    /**
     * The contact's first name
     */
    first;
    /**
     * The contact's middle name
     */
    middle;
    /**
     * The contact's last name
     */
    last;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines an account and meter whose use or cost will be copied when calculating a bill
 */
class CopyFromMeterResponse {
    meter;
    /**
     * Percentage of use or cost to copy
     */
    percentage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines a meter whose use or cost will be copied when calculating a bill  The meter may have a commodity which is different than the destination meter  When doing the calculation we will sum the use or cost across all accounts this meter is associated with for the billing period begin run
 */
class CopyMeterRequest {
    /**
     * Meter from which use or cost will be copied <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (LogicalDevice)</span>
     */
    meterId;
    /**
     * Percentage of use or cost to copy  Pass the percentage value  For example 50.5% should be 50.5 <span class='property-internal'>Required</span> <span class='property-info'>Max scale of 8</span>
     */
    percentage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostAvoidanceSettings {
    /**
     * Only bills with a billing period greater than or equal to this value were included in Cost Avoidance processing  Will be null unless BillSelectionOption is \"BillingPeriod\" and Reason is \"ProcessSavings\"
     */
    minimumBillingPeriod;
    /**
     * Indicates if the Cost Avoidance processor skipped processing meters with multiple accounts if one of the bills was missing  Will be empty unless Reason is \"ProcessSavings\"
     */
    skippedMultiAccountIfBillsMissing;
    /**
     * Indicates if weather adjustments were ignored when the baseline processor was run  Will be null unless Reason is \"ResetBaseline\"
     */
    ignoredWeatherAdjustments;
    /**
     * Defines handling of meter special adjustments during Cost Avoidance processing. Can be either of two static values OR the special adjustment category that the user chose to skip.  Will be empty unless Reason is \"ProcessSavings\"  Possible static values:  \"NONE\" - no special adjustment categories were skipped  \"ALL\" - all special adjustment categories were skipped
     */
    ignoredSpecialAdjustmentType;
    /**
     * For savings calculation, indicates which bills should have been processed  Will be empty unless Reason is \"ProcessSavings\"  Possible values:  - \"AllBills\" means all bills were processed  - \"ModifiedOrNotProcessed\" means only new bills or bills which have been modified since the last time cost avoidance was run have been processed  - \"BillingPeriod\" means that only bills with a billing period which is greater than or equal to the MinimumBillingPeriod have been processed
     */
    billSelectionOption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostAvoidanceTask {
    /**
     * Indicates whether or not the task has an output log available for download
     */
    hasAttachments;
    /**
     * The task ID
     */
    costAvoidanceTaskId;
    /**
     * The task GUID
     */
    taskGUId;
    taskType;
    /**
     * The date and time the task began
     */
    beginDate;
    /**
     * The date and time the task finished. If the task is not finished, endDate will have no value
     */
    endDate;
    user;
    settings;
    /**
     * The task's filters
     */
    filters;
    /**
     * If there was a catastrophic error during task processing, it will go here
     */
    message;
    /**
     * The reason for the cost avoidance task. Will be one of the following:  * ResetBaseline  * SavedAndReprocessedMeter  * ProcessSavings  * SpecialAdjustmentAddedEditedRemoved  * SpecialAdjustmentAddedEditedRemovedSetupSheet  * MeterCostAvoidanceSettingsGloballyUpdated  * AucRangeModified  * OtherSavingsAddedEdited  * OtherSavingsAddedEditedSetupSheet
     */
    reason;
    /**
     * The status of the cost avoidance task. Will be one of the following:  * Processing  * Complete  * Error
     */
    status;
    /**
     * Notes added to the cost avoidance task by the user
     */
    taskNote;
    baselineLog;
    savingsLog;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCategoryEdit {
    /**
     * Name of the cost category <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    costCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCategoryResponse {
    /**
     * The cost category identifier <span class='property-internal'>Required (defined)</span>
     */
    costCategoryId;
    /**
     * Name of the cost category <span class='property-internal'>Required (defined)</span>
     */
    costCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterAccountChild {
    /**
     * The account identifier
     */
    accountId;
    /**
     * The account code
     */
    accountCode;
    /**
     * The account info
     */
    accountInfo;
    /**
     * Whether the account is active or not
     */
    active;
    /**
     * Indicates whether the Account has a child calculated meter
     */
    hasCalculatedMeter;
    /**
     * Indicates whether the Account is a recipient of a split
     */
    hasSplitParentMeter;
    /**
     * Indicates whether the Account has a child split meter
     */
    hasSplitChildMeter;
    /**
     * Indicates whether the Account is a sub-account
     */
    isSubAccount;
    /**
     * Indicates whether the Account has a sub-account
     */
    hasSubAccount;
    accountType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterChild {
    /**
     * The cost center identifier
     */
    costCenterId;
    /**
     * The cost center code
     */
    costCenterCode;
    /**
     * The cost center info
     */
    costCenterInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterCreate {
    /**
     * The cost center code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    costCenterCode;
    /**
     * The cost center info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    costCenterInfo;
    /**
     * The identifier for the parent of the cost center. The parent is the cost center directly above the current cost center on the Accounts tree <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (CostCenter)</span>
     */
    parentCostCenterId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualMonthlyResponse {
    /**
     * The costCenter code
     */
    costCenterCode;
    /**
     * The costCenter info
     */
    costCenterInfo;
    /**
     * The costCenter identifier
     */
    costCenterId;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    costUnit;
    /**
     * An array of monthly data per commodity
     */
    commodities;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualMonthlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of commodity monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualMonthlyResponseCommodityResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualYearlyResponse {
    /**
     * The costCenter code
     */
    costCenterCode;
    /**
     * The costCenter info
     */
    costCenterInfo;
    /**
     * The costCenter identifier
     */
    costCenterId;
    globalUseUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterDigestActualYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenterResponse {
    /**
     * The cost center identifier
     */
    costCenterId;
    /**
     * The cost center code
     */
    costCenterCode;
    /**
     * The cost center info
     */
    costCenterInfo;
    parent;
    /**
     * An array of child cost centers
     */
    costCenters;
    /**
     * An array of child accounts
     */
    accounts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCenters {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostCentersClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostConversion {
    sourceUnit;
    systemUnit;
    /**
     * The conversion factor used to convert from the source cost unit to the system cost unit
     */
    sourceToSystemConversionValue;
    /**
     * The date used to look up the currency conversion
     */
    conversionDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostConversionBase {
    /**
     * The conversion factor used to convert from the source cost unit to the system cost unit
     */
    sourceToSystemConversionValue;
    /**
     * The date used to look up the currency conversion
     */
    conversionDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostSavingsChild {
    /**
     * The cost savings amount
     */
    costSavings;
    costSavingsUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CostSavingsUnit {
    /**
     * The cost savings unit identifier
     */
    costSavingsUnitId;
    /**
     * The cost savings unit code
     */
    costSavingsUnitCode;
    /**
     * The cost savings unit information
     */
    costSavingsUnitInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Country {
    /**
     *
     */
    countryId;
    /**
     *
     */
    name;
    /**
     *
     */
    alpha2Code;
    /**
     *
     */
    possibleSpellings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CreateTemplateFromBill {
    /**
     * The template code  Always converted to uppercase <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    templateCode;
    /**
     * The template note <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class CreateUtilityPlatformMeter {
    /**
     * The meter code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    meterCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CustomerChild {
    /**
     * The customer identifier
     */
    customerId;
    /**
     * The customer code
     */
    customerCode;
    /**
     * The customer info
     */
    customerInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class CustomerResponse {
    /**
     * The customer identifier
     */
    customerId;
    /**
     * The customer code
     */
    customerCode;
    /**
     * The customer info
     */
    customerInfo;
    address;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardAdministrator {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardAdministratorClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardAndMapsModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardAndMapsModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardCopy {
    /**
     * The Dashboard Title  If null, this will default to the copied dashboard's name with ' - Copy' appended <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    dashboardInfo;
    /**
     * The dashboard description  If null, this will default to the copied dashboard's description <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    description;
    /**
     * Flag to indicate if the dashboard is public  If null, this will default to false
     */
    public;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardCreate {
    /**
     * The Dashboard Title <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    dashboardInfo;
    /**
     * The dashboard description <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    description;
    /**
     * The dashboard type <span class='property-internal'>One of 'User', 'Map'</span>
     */
    type;
    /**
     * Flag to indicate if the dashboard is public
     */
    public;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardEdit {
    /**
     * The Dashboard Title <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    dashboardInfo;
    /**
     * The dashboard description <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    description;
    /**
     * The dashboard type <span class='property-internal'>One of 'User', 'Map'</span> <span class='property-internal'>Required (defined)</span>
     */
    type;
    /**
     * Flag to indicate if the dashboard is public <span class='property-internal'>Required</span>
     */
    public;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardGlobalSettings {
    /**
     * Flag to indicate if public-facing links to the application should be displayed
     */
    showLinks;
    /**
     * Flag to indicate if title/description should be displayed
     */
    showInfo;
    /**
     * Visibility of dashboard filter. Values are Show, Hide, or Fixed.  Show - Filter controls are shown on the dashboard, filter can be temporarily set by anybody who can view the dashboard, including public viewers  Hide - Filter controls are hidden, filter cannot be set, dashboard will be filtered using the topmost place of the user that creates the dashboard  Fixed - Filter controls are hidden, a fixed filter is applied to the dashboard
     */
    globalFilterVisibility;
    /**
     * If GlobalFilterVisibility is Fixed, this is the type of filter currently applied to this dashboard. Values are either TopmostPlace or BuildingGroup, or blank if GlobalFilterVisibility is not Fixed.  TopmostPlace - Filters the dashboard by a topmost place  BuildingGroup - Filters the dashboard by a building group
     */
    globalFilterType;
    topmostPlace;
    buildingGroup;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardGlobalSettingsEdit {
    /**
     * Flag to indicate if public-facing links to the application should be displayed <span class='property-internal'>Required (defined)</span>
     */
    showLinks;
    /**
     * Flag to indicate if title/description should be displayed <span class='property-internal'>Required (defined)</span>
     */
    showInfo;
    /**
     * Visibility of dashboard filter. Valid values are Show, Hide, or Fixed. If settings are applied to a Map dashboard, this is automatically set to Fixed, and any other filter settings are automatically nulled.  Show - Filter controls will be show on the dashboard, filter can be temporarily set by anybody who can view the dashboard, including public viewers.  Hide - Filter controls will be hidden, manual filtering will be disabled, dashboard will be filtered using the topmost place of the user who applies the settings  Fixed - Filter controls will be hidden, dashboard will be filtered using the specified Topmost Place or Building Group. PlaceID or PlaceGroupID are required when this field is set to Fixed. <span class='property-internal'>One of 'Show', 'Hide', 'Fixed'</span>
     */
    globalFilterVisibility;
    /**
     * The Identifier for the Topmost Place the dashboard should filter by.  Required when GlobalFilterVisibility is Fixed. Set to null if GlobalFilterVisibility is set to Show or Hide. <span class='property-internal'>Only one of PlaceID, PlaceGroupID can be set</span>
     */
    placeId;
    /**
     * The Identifier for the Building Group the dashboard should filter by.  Required when GlobalFilterVisibility is Fixed. Set to null if GlobalFilterVisibility is set to Show or Hide. <span class='property-internal'>Only one of PlaceID, PlaceGroupID can be set</span>
     */
    placeGroupId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DashboardResponse {
    /**
     * The dashboard identifier
     */
    dashboardId;
    /**
     * The dashboard info
     */
    dashboardInfo;
    /**
     * The dashboard description
     */
    description;
    /**
     * The dashboard type
     */
    type;
    createdBy;
    /**
     * The date and time the dashboard was created
     */
    createdDate;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * Flag to indicate if the dashboard is shared at all  This means the dashboard is shared with everyone, shared with a user, or shared with a user group
     */
    shared;
    /**
     * Flag to indicate if dashboard should show in the caller's tree
     */
    visible;
    /**
     * The date and time of the last time this dashboard was viewed by the caller
     */
    lastViewed;
    /**
     * If the dashboard is public, this value holds the public key  that allows the dashboard to be embedded
     */
    key;
    /**
     * Flag to indicate if the dashboard is public
     */
    public;
    dashboardGlobalSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataAccessRelease {
    /**
     * Data Access Release Identifier
     */
    dataAccessReleaseId;
    metaData;
    /**
     * File name of the uploaded release form  This is only saved on a manual data release request  Null when request was completed by email
     */
    releaseForm;
    /**
     * Date and time the data release request was submitted
     */
    submittedDate;
    /**
     * Email address of the person who completed the request
     */
    submittedBy;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataAccessReleaseMetaData {
    /**
     *
     */
    accountNumber;
    /**
     *
     */
    nameOnBill;
    /**
     *
     */
    serviceAddress;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataAccessReleaseNoFileRequest {
    /**
     * Account Number  Should be a 12 digit number starting with 2. <span class='property-internal'>Required</span>
     */
    accountNumber;
    /**
     *  <span class='property-internal'>Required</span>
     */
    nameOnBill;
    /**
     *  <span class='property-internal'>Required</span>
     */
    serviceAddress;
    /**
     * Is the data release declined  If true is passed the data provider must support declining a data release otherwise this will throw an exception
     */
    declined;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataAccessReleaseRequest {
    /**
     * The response from uploading the file to the file store  API: POST  /api/v202105/fileStore/fileDataType/{fileDataTypeId}/upload  SDK Operation: UploadFile
     */
    dataReleaseFile;
    /**
     * Account Number  Should be a 12 digit number starting with 2. <span class='property-internal'>Required</span>
     */
    accountNumber;
    /**
     *  <span class='property-internal'>Required</span>
     */
    nameOnBill;
    /**
     *  <span class='property-internal'>Required</span>
     */
    serviceAddress;
    /**
     * Is the data release declined  If true is passed the data provider must support declining a data release otherwise this will throw an exception
     */
    declined;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataAccessReleaseState {
    /**
     * The date that the data access release was submitted.  Null if there is not a release yet.
     */
    submittedDate;
    releaseStatus;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataAccessReleaseStatus {
    /**
     * Id of the Data Access Release Status  Possible values are:      1 - Not Applicable      2 - Required      3 - Pending      4 - Released      5 - Declined
     */
    dataAccessReleaseStatusId;
    /**
     * Data Access Release Status Information  Possible values are:   Not Applicable   Required   Pending    Released    Declined
     */
    dataAccessReleaseStatusInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataPointChild {
    /**
     * The data point identifier
     */
    dataPointId;
    /**
     * The data point code
     */
    dataPointCode;
    /**
     * The data point info
     */
    dataPointInfo;
    commodity;
    /**
     * Indicates whether the data point is Active
     */
    active;
    /**
     * Indicates whether the data point is a calculated data point
     */
    isCalculatedDataPoint;
    /**
     * The data point's current serial number
     */
    serialNumber;
    /**
     * Indicates if the primary value channel on the datapoint has a summarization method of SUM
     */
    isDataRolledUp;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataPointChildWithParentAndImportId {
    parentPlace;
    /**
     * The import identifier for the data point
     */
    dataPointImportId;
    /**
     * The data point identifier
     */
    dataPointId;
    /**
     * The data point code
     */
    dataPointCode;
    /**
     * The data point info
     */
    dataPointInfo;
    commodity;
    /**
     * Indicates whether the data point is Active
     */
    active;
    /**
     * Indicates whether the data point is a calculated data point
     */
    isCalculatedDataPoint;
    /**
     * The data point's current serial number
     */
    serialNumber;
    /**
     * Indicates if the primary value channel on the datapoint has a summarization method of SUM
     */
    isDataRolledUp;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class DataPointCreate {
    /**
     * The Data Point code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    dataPointCode;
    /**
     * The Data Point name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    dataPointInfo;
    /**
     * The place this Data Point is assigned to <span class='property-internal'>Topmost (Space)</span> <span class='property-internal'>Required</span>
     */
    esaPlaceId;
    /**
     * The Commodity (type) of the Data Point <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The Data Point description <span class='property-internal'>Must be between 0 and 4000 characters</span>
     */
    dataPointDescription;
    /**
     * The identifier for the Data Point's time zone.   If the place Data Point is under a site this must be left null or set to the same time zone as the site.
     */
    dataPointTimeZoneId;
    /**
     * The serial number of the Data Point <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    serialNumber;
    /**
     * The model of the Data Point <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    model;
    /**
     * The import identifier of the Data Point <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    importId;
    /**
     * The latitude of the Data Point,   if set it overrides the latitude of it's parent Place <span class='property-internal'>Must be between -90 and 90</span> <span class='property-internal'>Required when LongitudeOverride is set</span>
     */
    latitudeOverride;
    /**
     * The longitude of the Data Point,   if set it overrides the longitude of it's parent Place <span class='property-internal'>Must be between -180 and 180</span> <span class='property-internal'>Required when LatitudeOverride is set</span>
     */
    longitudeOverride;
    /**
     * The manufacturer of the Data Point
     */
    manufacturerId;
    /**
     * The primary use of the Data Point
     */
    primaryUseId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataPointEdit {
    /**
     * Indicates if the data point is active <span class='property-internal'>Required (defined)</span>
     */
    active;
    /**
     * The Data Point code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    dataPointCode;
    /**
     * The Data Point name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    dataPointInfo;
    /**
     * The place this Data Point is assigned to <span class='property-internal'>Topmost (Space)</span> <span class='property-internal'>Required</span>
     */
    esaPlaceId;
    /**
     * The Commodity (type) of the Data Point <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The Data Point description <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    dataPointDescription;
    /**
     * The identifier for the Data Point's time zone.   If the place Data Point is under a site this must be left null or set to the same time zone as the site. <span class='property-internal'>Required (defined)</span>
     */
    dataPointTimeZoneId;
    /**
     * The serial number of the Data Point <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    serialNumber;
    /**
     * The model of the Data Point <span class='property-internal'>Must be between 0 and 50 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    model;
    /**
     * The import identifier of the Data Point <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    importId;
    /**
     * The latitude of the Data Point,   if set it overrides the latitude of it's parent Place <span class='property-internal'>Must be between -90 and 90</span> <span class='property-internal'>Required when LongitudeOverride is set</span>
     */
    latitudeOverride;
    /**
     * The longitude of the Data Point,   if set it overrides the longitude of it's parent Place <span class='property-internal'>Must be between -180 and 180</span> <span class='property-internal'>Required when LatitudeOverride is set</span>
     */
    longitudeOverride;
    /**
     * The manufacturer of the Data Point <span class='property-internal'>Required (defined)</span>
     */
    manufacturerId;
    /**
     * The primary use of the Data Point <span class='property-internal'>Required (defined)</span>
     */
    primaryUseId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class DataPointResponse {
    /**
     * The identifier for the Data Point
     */
    dataPointId;
    /**
     * The Data Point code
     */
    dataPointCode;
    /**
     * The Data Point name
     */
    dataPointInfo;
    /**
     * The Data Point description
     */
    dataPointDescription;
    /**
     * Indicates whether the Data Point is active
     */
    active;
    /**
     * The serial number of the Data Point
     */
    serialNumber;
    /**
     * The model of the Data Point
     */
    model;
    /**
     * The import identifier of the Data Point
     */
    importId;
    /**
     * The latitude of the Data Point,   if set it overrides the latitude of it's parent Place
     */
    latitudeOverride;
    /**
     * The longitude of the Data Point,   if set it overrides the longitude of it's parent Place
     */
    longitudeOverride;
    commodity;
    place;
    dataPointTimeZone;
    manufacturer;
    primaryUse;
    createdBy;
    /**
     * The date and time the Data Point was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification of the Data Point
     */
    modifiedDate;
    /**
     * An array of channels assigned to this Data Point
     */
    channels;
    /**
     * Indicates if the primary value channel on the datapoint has a summarization method of SUM
     */
    isDataRolledUp;
    /**
     * Indicates if the Sentinel is active for primary value channels
     */
    sentinelEnabled;
    /**
     * Provides some insight into the current Sentinel enabled status.
     */
    sentinelStatus;
    sentinelModifiedBy;
}
(function (DataPointResponse) {
    let SentinelStatusEnum;
    (function (SentinelStatusEnum) {
        SentinelStatusEnum[SentinelStatusEnum["NUMBER_1"] = 1] = "NUMBER_1";
        SentinelStatusEnum[SentinelStatusEnum["NUMBER_2"] = 2] = "NUMBER_2";
        SentinelStatusEnum[SentinelStatusEnum["NUMBER_3"] = 3] = "NUMBER_3";
        SentinelStatusEnum[SentinelStatusEnum["NUMBER_4"] = 4] = "NUMBER_4";
        SentinelStatusEnum[SentinelStatusEnum["NUMBER_5"] = 5] = "NUMBER_5";
    })(SentinelStatusEnum = DataPointResponse.SentinelStatusEnum || (DataPointResponse.SentinelStatusEnum = {}));
})(DataPointResponse || (DataPointResponse = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataPointSentinel {
    /**
     * Indicates if the data point sentinel is enabled <span class='property-internal'>Required (defined)</span>
     */
    sentinelEnabled;
    /**
     * The reason the sentinel was deactivated <span class='property-internal'>Must be null when SentinelEnabled  is  set to True, case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    sentinelDeactivatedReason;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DataTypeResponse {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    dataTypeId;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    dataTypeCode;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    dataTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose date range DTO
 */
class DateRange {
    /**
     * The start date for the range
     */
    startDate;
    /**
     * The end date for the range
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DayOfWeek {
    /**
     * Day of the week as represented by a number
     */
    dayOfWeekNumber;
    /**
     * Day of the week name
     */
    dayOfWeekName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DeleteReadingResponse {
    /**
     * The number of readings deleted
     */
    deleted;
    /**
     * Data representing the failed reading deletion
     */
    failures;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DestinationAccountMeterChild {
    /**
     * The AccountMeter identifier <span class='property-internal'>Required (defined)</span>
     */
    accountMeterId;
    /**
     * The Meter identifier for this AccountMeter <span class='property-internal'>Required (defined)</span>
     */
    meterId;
    /**
     * The code of the Meter for this AccountMeter <span class='property-internal'>Required (defined)</span>
     */
    meterCode;
    /**
     * The info of the Meter for this AccountMeter <span class='property-internal'>Required (defined)</span>
     */
    meterInfo;
    commodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DestinationAccountResponse {
    /**
     * The account identifier <span class='property-internal'>Required (defined)</span>
     */
    accountId;
    /**
     * The account code <span class='property-internal'>Required (defined)</span>
     */
    accountCode;
    /**
     * The account info <span class='property-internal'>Required (defined)</span>
     */
    accountInfo;
    vendor;
    /**
     * An array of identifiers for meters attached to this account <span class='property-internal'>Required (defined)</span>
     */
    meters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DetailedGuidResponse {
    /**
     * The name of the file that was uploaded
     */
    fileName;
    /**
     * A guid that identifies the current task
     */
    taskGUId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributeAccountChargesBase {
    /**
     * Determines if account charges should be assigned proportionally based on the usage values of each meter or based on the bill cost from each meter.  If not provided, defaults to \"Usage\". <span class='property-internal'>One of 'Usage', 'Cost', ''</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    splitBasis;
}
(function (DistributeAccountChargesBase) {
    let SplitBasisEnum;
    (function (SplitBasisEnum) {
        SplitBasisEnum[SplitBasisEnum["NUMBER_0"] = 0] = "NUMBER_0";
        SplitBasisEnum[SplitBasisEnum["NUMBER_1"] = 1] = "NUMBER_1";
    })(SplitBasisEnum = DistributeAccountChargesBase.SplitBasisEnum || (DistributeAccountChargesBase.SplitBasisEnum = {}));
})(DistributeAccountChargesBase || (DistributeAccountChargesBase = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributeAccountChargesToBillsRequest {
    /**
     * Bill IDs for which account charges will be proportionally distributed to the meters <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    billIds;
    /**
     * Determines if account charges should be assigned proportionally based on the usage values of each meter or based on the bill cost from each meter.  If not provided, defaults to \"Usage\". <span class='property-internal'>One of 'Usage', 'Cost', ''</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    splitBasis;
}
(function (DistributeAccountChargesToBillsRequest) {
    let SplitBasisEnum;
    (function (SplitBasisEnum) {
        SplitBasisEnum[SplitBasisEnum["NUMBER_0"] = 0] = "NUMBER_0";
        SplitBasisEnum[SplitBasisEnum["NUMBER_1"] = 1] = "NUMBER_1";
    })(SplitBasisEnum = DistributeAccountChargesToBillsRequest.SplitBasisEnum || (DistributeAccountChargesToBillsRequest.SplitBasisEnum = {}));
})(DistributeAccountChargesToBillsRequest || (DistributeAccountChargesToBillsRequest = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributedReportsConfiguration {
    /**
     * Desired format for the resulting report.  Available options are PDF, Excel, Excel formatted, Excel data only, Word, and CSV. Support for each format varies by report.
     */
    format;
    /**
     * Indicates whether or not to use a copy of the report when generating it.  When set to true, a one-time copy of the requested specific report will be created, set with the provided filters, and then deleted afterward.          This functionality is useful when you want to run a report with a one-time filter set, without touching the original report's filters.
     */
    useCopy;
    /**
     * List of filters to use when executing this report. How they are handled depends upon the other configuration options used in this request.
     */
    filters;
    /**
     * Indicates whether or not to clear out stored filters for the requested report during execution.  When set to true, any stored filters for this report will be removed. Only filters provided in the Filters property will be applied.  When set to false, any stored filters will still apply when the report is executed.
     */
    clearFilters;
    /**
     * Indicates whether or not to save the filters provided in the Filters property.  When set to true, any filters currently stored for the requested report will be overwritten with those provided in the Filters property.  When set to false, any filters provided in the Filters property will not be saved after execution. However, they will be used for this report execution.
     */
    saveFilters;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, if distributing the requested report to an email list and the report contains no data, the report will not be emailed.  When set to false, if the requested report has no data, it will still be sent to the email list.
     */
    onlySendIfData;
    /**
     * Filename for the resulting report file. Do not provide file type suffix.  Defaults to {specificReportCode}-{specificReportInfo}{fileNameExtension}
     */
    fileName;
    distribution;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributedReportsSettings {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributedReportsSettingsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributionVersionManage {
    /**
     * Version id to update  VersionId must exist on the account and meter relationship being updated <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of VersionId, CopyVersionId can be set</span>
     */
    versionId;
    /**
     * An existing version id on this account meter to copy  A new version will be created and all instructions will be copied to the new version  CopyVersionId chargeback type must match the chargeback type being managed (Either \"Split\" or \"Calculation\").  CopyVersionId must exist on the account and meter relationship being updated <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of VersionId, CopyVersionId can be set</span>
     */
    copyVersionId;
    /**
     * Name given to the version  Name must be unique for a particular account and meter <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    name;
    /**
     * Workflow step this version will belong to  The workflow step type must match the chargeback type being managed (Either \"Split\" or \"Calculation\") <span class='property-internal'>Required (defined)</span>
     */
    workflowStepId;
    /**
     * Begin period for the version in the format YYYYMM  Cannot overlap any existing versions on this account and meter for the chargeback type being managed <span class='property-internal'>Required</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span>
     */
    beginPeriod;
    /**
     * End period for the version in the format YYYYMM  null value means continuing indefinitely  Cannot overlap any existing versions on this account and meter for the chargeback type being managed <span class='property-internal'>Valid billing period between 190001 and 300001</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be greater than or equal to BeginPeriod</span> <span class='property-internal'>Required (defined)</span>
     */
    endPeriod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DistributionVersionResponse {
    /**
     * Identifier for the version
     */
    versionId;
    /**
     * Name given to a version
     */
    versionInfo;
    /**
     * The chargeback type.  Either \"Split\" or \"Calculation\"
     */
    chargebackType;
    /**
     * Begin period for the version
     */
    beginPeriod;
    /**
     * End period for the version  null value means continuing indefinitely
     */
    endPeriod;
    account;
    meter;
    workflow;
    /**
     * Do any bills exist that were created by this version?  A version cannot be deleted if there are any existing bills that were created using this version
     */
    hasBills;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DueDateTooLongAfterBillEndSettingRequest {
    /**
     * Threshold for how long the due date can be after the end date  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Must be between 0 and 2147483647</span> <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span>
     */
    days;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DueDateTooLongAfterBillEndSettingResponse {
    /**
     * Threshold for how long the due date can be after the end date  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    days;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class DynamicListRequest {
    /**
     * Filters to apply to the dynamic list when initializing it <span class='property-internal'>Cannot be Empty</span>
     */
    filters;
    /**
     * Flag indicating whether or not to initialize the dynamic list column definitions
     */
    resetColumns;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines details for a dynamic percentage split of use, cost, or both based on the use or cost values of the meters in the destination meter group.
 */
class DynamicPercentageBillSplit {
    /**
     * ID of a meter group to receive the results of the split bill. <span class='property-internal'>Required</span>
     */
    destinationMeterGroupId;
    /**
     * Value to distribute to the destination meters. <span class='property-internal'>Required</span> <span class='property-internal'>One of 'use', 'cost', 'useAndCost'</span>
     */
    sourceValueToSplit;
    /**
     * Value to define how dynamic percentages are calculated. <span class='property-internal'>Required</span> <span class='property-internal'>One of 'use', 'cost'</span>
     */
    destinationShareValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Defines details for a dynamic percentage split of use, cost, or both based on the use or cost values of the meters in the destination meter group.
 */
class DynamicPercentageBillSplitResponse {
    destinationMeterGroup;
    /**
     * Value to distribute to the destination meters  \"use\", \"cost\", or \"useAndCost\"
     */
    sourceValueToSplit;
    /**
     * Value to define how dynamic percentages are calculated.  \"use\" or \"cost\"
     */
    destinationShareValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ENERGYSTARSubmissions {
    /**
     *
     */
    run;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ENERGYSTARSubmissionsClassPermission {
    /**
     *
     */
    run;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EditEsaPlaceSizesRequest {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    calculateArea;
    /**
     *  <span class='property-internal'>Must be null when CalculateArea  is  set to True, case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    placeSizes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmailProperties {
    /**
     *  <span class='property-internal'>Required</span>
     */
    subject;
    /**
     *
     */
    body;
    /**
     *  <span class='property-internal'>Cannot be Empty</span>
     */
    recipients;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionRecordRequest {
    /**
     * The Emission Source this record will be assigned to <span class='property-internal'>Required</span>
     */
    emissionSourceId;
    /**
     * The begin date for this record <span class='property-internal'>Required</span>
     */
    beginDate;
    /**
     * The end date for this record <span class='property-internal'>Required</span> <span class='property-internal'>Must be greater than BeginDate</span>
     */
    endDate;
    /**
     * The supplier for this record <span class='property-internal'>Required (defined)</span>
     */
    vendorId;
    /**
     * The type of this record. Valid values are:  1 - Use  2 - Cost  3 - Direct/Offset <span class='property-internal'>Required</span> <span class='property-internal'>One of '1', '2', '3'</span> <span class='property-internal'>Case sensitive</span>
     */
    recordTypeId;
    /**
     * The scope category for this record <span class='property-internal'>Required</span>
     */
    scopeCategoryId;
    /**
     * The factor for this record <span class='property-internal'>Required</span>
     */
    factorId;
    /**
     * The use that is being tracked by this record.   This value is required if RecordTypeId is set to 1 (Use) or 3 (Direct/Offset),   but must be left null if RecordTypeId is set to 2 (Cost). <span class='property-internal'>Required when RecordTypeId is set to 1, or 3, case sensitive.</span> <span class='property-internal'>Must be null when RecordTypeId  is  set to 2, case sensitive</span>
     */
    quantity;
    /**
     * The unit for the use being tracked by this record.  This value is required if RecordTypeId is set to 1 (Use) or 3 (Direct/Offset),  but must be left null if RecordTypeId is set to 2 (Cost). <span class='property-internal'>Required when RecordTypeId is set to 1, or 3, case sensitive.</span> <span class='property-internal'>Must be null when RecordTypeId  is  set to 2, case sensitive</span>
     */
    quantityUnitId;
    /**
     * The cost for this record  Required if RecordTypeId is set to 2 (Cost), otherwise it is optional. <span class='property-internal'>Required when RecordTypeId is set to 2, case sensitive.</span> <span class='property-internal'>Required when CostUnitId is set</span>
     */
    cost;
    /**
     * The unit for this record's cost.  Required if RecordTypeId is set to 2 (Cost), otherwise it is optional. <span class='property-internal'>Required when RecordTypeId is set to 2, case sensitive.</span> <span class='property-internal'>Required when Cost is set</span>
     */
    costUnitId;
    /**
     * The note for this record <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
    /**
     * The attachment for this record <span class='property-internal'>Must be between 0 and 260 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    attachment;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionRecordResponse {
    /**
     * The record identifier
     */
    emissionRecordId;
    /**
     * The bill identifier, if this record originated from a bill in UtilityManagement
     */
    billId;
    emissionSource;
    vendor;
    /**
     * The start date for the record
     */
    startDate;
    /**
     * The end date for the record
     */
    endDate;
    /**
     * The bill's billing period, if this record originated from a bill in UtilityManagement
     */
    billingPeriod;
    emissionRecordType;
    scopeCategory;
    factor;
    quantity;
    cost;
    systemCost;
    costConversion;
    /**
     * The total GHG emissions for this record in kgCO2e.
     */
    totalEmissions;
    /**
     * The GHG emissions for this record, split by greenhouse gas type
     */
    emissionValues;
    /**
     * The note for this record
     */
    note;
    /**
     * The attachment for this record
     */
    attachment;
    createdBy;
    /**
     * The date this record was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date this record was last modified
     */
    modifiedDate;
    /**
     * The emission record creation method
     */
    creationMethod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionRecordType {
    /**
     * Id of the emission record type
     */
    emissionRecordTypeId;
    /**
     * Name of the emission record type
     */
    emissionRecordTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceChild {
    /**
     * The emission source identifier
     */
    emissionSourceId;
    /**
     * The emission source code
     */
    emissionSourceCode;
    /**
     * The emission source info
     */
    emissionSourceInfo;
    commodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceCreate {
    /**
     * The default scope category for the emission source <span class='property-internal'>Required</span>
     */
    defaultScopeCategoryId;
    defaultEmissionFactor;
    /**
     * The emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    emissionSourceCode;
    /**
     * The emission source info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    emissionSourceInfo;
    /**
     * The emission source's commodity <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The collection to which the emission source belongs <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Collection)</span>
     */
    collectionId;
    /**
     * The emission source note <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    note;
    address;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceEdit {
    /**
     * Is the emission source active <span class='property-internal'>Required</span>
     */
    active;
    /**
     * The default scope category for the emission source <span class='property-internal'>Required</span>
     */
    defaultScopeCategoryId;
    defaultEmissionFactor;
    /**
     * The emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    emissionSourceCode;
    /**
     * The emission source info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    emissionSourceInfo;
    /**
     * The emission source's commodity <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The collection to which the emission source belongs <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Collection)</span>
     */
    collectionId;
    /**
     * The emission source note <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
    address;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceFactorCategoryBulkUpdate {
    /**
     * A list of emission source IDs to apply the specified factor/category pairs to <span class='property-internal'>Required (defined)</span>
     */
    emissionSourceIds;
    /**
     * A list of factor/category pairs to apply to the specified emission sources <span class='property-internal'>Required (defined)</span>
     */
    factorCategoryPairs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceLink {
    /**
     * The identifier for an Emission source.
     */
    emissionSourceId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceLinkRequest {
    /**
     * The identifier for an Emission source.  Set to null to remove the link. <span class='property-internal'>Topmost (EmissionSource)</span> <span class='property-internal'>Required (defined)</span>
     */
    emissionSourceId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceMultiFactorCreate {
    /**
     * A list of Factor and Scope Category pairings to be attached to this Emission Source
     */
    scopeCategoryEmissionFactorPairs;
    /**
     * The emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    emissionSourceCode;
    /**
     * The emission source info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    emissionSourceInfo;
    /**
     * The emission source's commodity <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The collection to which the emission source belongs <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Collection)</span>
     */
    collectionId;
    /**
     * The emission source note <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    note;
    address;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceMultiFactorEdit {
    /**
     * Is the emission source active <span class='property-internal'>Required (defined)</span>
     */
    isActive;
    /**
     * A list of Factor and Scope Category pairings to be attached to this Emission Source <span class='property-internal'>Required (defined)</span>
     */
    scopeCategoryEmissionFactorPairs;
    /**
     * The emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    emissionSourceCode;
    /**
     * The emission source info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    emissionSourceInfo;
    /**
     * The emission source's commodity <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The collection to which the emission source belongs <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Collection)</span>
     */
    collectionId;
    /**
     * The emission source note <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
    address;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceMultiFactorResponse {
    /**
     * The pairs of Scope Categories and Emission Factors assigned to this Emission Source
     */
    scopeCategoryEmissionFactorPairs;
    /**
     * The emission source identifier
     */
    emissionSourceId;
    /**
     * The emission source code
     */
    emissionSourceCode;
    /**
     * The emission source info
     */
    emissionSourceInfo;
    collection;
    commodity;
    address;
    createdBy;
    /**
     * The date and time the emission source was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification of the emission source
     */
    modifiedDate;
    /**
     * The emission source description
     */
    note;
    /**
     * Indicates whether the emission source is active
     */
    active;
    meter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionSourceResponse {
    defaultScopeCategory;
    defaultEmissionFactor;
    /**
     * The emission source identifier
     */
    emissionSourceId;
    /**
     * The emission source code
     */
    emissionSourceCode;
    /**
     * The emission source info
     */
    emissionSourceInfo;
    collection;
    commodity;
    address;
    createdBy;
    /**
     * The date and time the emission source was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification of the emission source
     */
    modifiedDate;
    /**
     * The emission source description
     */
    note;
    /**
     * Indicates whether the emission source is active
     */
    active;
    meter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionsSources {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionsSourcesClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionsSourcesModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EmissionsSourcesModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyCapOptionsEnergyCapIDOptions {
    /**
     *
     */
    baseUrl;
    /**
     *
     */
    gatewayApiPath;
    /**
     *
     */
    gatewayApplicationUrlApiPath;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyProjectCreate {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The energy project code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    energyProjectCode;
    /**
     * The energy project info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    energyProjectInfo;
    /**
     * The energy project installation begin date
     */
    installationBeginDate;
    /**
     * The energy project installation end date <span class='property-internal'>Must be greater than InstallationBeginDate</span>
     */
    installationEndDate;
    /**
     * The energy project installation cost
     */
    installationCost;
    /**
     * The energy project type code <span class='property-internal'>Required</span>
     */
    energyProjectTypeCode;
    /**
     * The rebate amount of energy project
     */
    utilityRebate;
    /**
     * The funding source of the project
     */
    fundingSource;
    /**
     * The project manager of the energy project
     */
    projectManager;
    /**
     * The miscellaneous note about the project
     */
    note;
    /**
     * The energy savings amount
     */
    energySavings;
    /**
     * The energy savings unit code
     */
    energySavingsUnitCode;
    /**
     * The cost savings amount
     */
    costSavings;
    /**
     * The cost savings unit code
     */
    costSavingsUnitCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyProjectEdit {
    /**
     * The place identifier <span class='property-internal'>Required (defined)</span>
     */
    placeId;
    /**
     * The energy project code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    energyProjectCode;
    /**
     * The energy project info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    energyProjectInfo;
    /**
     * The energy project installation begin date <span class='property-internal'>Required (defined)</span>
     */
    installationBeginDate;
    /**
     * The energy project installation end date <span class='property-internal'>Must be greater than InstallationBeginDate</span> <span class='property-internal'>Required (defined)</span>
     */
    installationEndDate;
    /**
     * The energy project installation cost <span class='property-internal'>Required (defined)</span>
     */
    installationCost;
    /**
     * The energy project type code <span class='property-internal'>Required</span>
     */
    energyProjectTypeCode;
    /**
     * The rebate amount of energy project <span class='property-internal'>Required (defined)</span>
     */
    utilityRebate;
    /**
     * The funding source of the project <span class='property-internal'>Required (defined)</span>
     */
    fundingSource;
    /**
     * The project manager of the energy project <span class='property-internal'>Required (defined)</span>
     */
    projectManager;
    /**
     * The miscellaneous note about the project <span class='property-internal'>Required (defined)</span>
     */
    note;
    /**
     * The energy savings amount <span class='property-internal'>Required (defined)</span>
     */
    energySavings;
    /**
     * The energy savings unit code <span class='property-internal'>Required (defined)</span>
     */
    energySavingsUnitCode;
    /**
     * The cost savings amount <span class='property-internal'>Required (defined)</span>
     */
    costSavings;
    /**
     * The cost savings unit code <span class='property-internal'>Required (defined)</span>
     */
    costSavingsUnitCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyProjectPlaceChild {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * Tells whether or not the place's data is rolled up to its parents.
     */
    isDataRolledUp;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyProjectResponse {
    /**
     * The energy project identifier
     */
    energyProjectId;
    /**
     * The energy project code
     */
    energyProjectCode;
    /**
     * The energy project info
     */
    energyProjectInfo;
    /**
     * The energy project installation begin date
     */
    installationBeginDate;
    /**
     * The energy project installation end date
     */
    installationEndDate;
    /**
     * The energy project installation cost
     */
    installationCost;
    /**
     * The rebate amount of energy project
     */
    utilityRebate;
    /**
     * The funding source of the project
     */
    fundingSource;
    /**
     * The project manager of the energy project
     */
    projectManager;
    /**
     * The miscellaneous note about the project
     */
    note;
    energySavings;
    costSavings;
    place;
    energyProjectType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyProjectType {
    /**
     * The energy project type identifier
     */
    energyProjectTypeId;
    /**
     * The energy project type code
     */
    energyProjectTypeCode;
    /**
     * The energy project type  info
     */
    energyProjectTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyProjectTypeCreate {
    /**
     * The energy project type code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    energyProjectTypeCode;
    /**
     * The energy project type  info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    energyProjectTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergySavingsChild {
    /**
     * The energy savings amount
     */
    energySavings;
    energySavingsUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergySavingsUnit {
    /**
     * The energy savings unit identifier
     */
    energySavingsUnitId;
    /**
     * The energy savings unit code
     */
    energySavingsUnitCode;
    /**
     * The energy savings unit information
     */
    energySavingsUnitInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarCommodityLinkChild {
    /**
     * The Portfolio Manager meter identifier
     */
    pmMeterId;
    commodity;
    /**
     * Indicates if the commodity is compatible with ENERGY STAR
     */
    energyStarCompatible;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarCommodityLinkRequest {
    /**
     * The commodity identifier <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The Portfolio Manager meter identifier.  Set to null to unlink meter. <span class='property-internal'>Required (defined)</span>
     */
    pmMeterId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarCommodityMeterTypeMapping {
    submissionUnit;
    portfolioManagerCommodityMapping;
    /**
     * The commodity identifier
     */
    commodityId;
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    commodityIcon;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarCommodityMeterTypeMappingChild {
    /**
     * The unit code in Portfolio Manager
     */
    pmUnitCode;
    /**
     * When true, auto-created Portfolio Manager meters of this commodity are serviced \"by delivery\" rather than \"by metering\"
     */
    isDelivery;
    /**
     * List of supported Portfolio Manager commodities for this ECAP Commodity  Every entry includes the commodity code and whether the commodity is the default for Portfolio Manager
     */
    suportedPmCommoditiesWithDefault;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarMeterLinkChild {
    meter;
    /**
     * The Portfolio Manager meter identifier
     */
    pmMeterId;
    /**
     * The meter's average use per day
     */
    usePerDay;
    useUnit;
    /**
     * The meter's average cost per day
     */
    costPerDay;
    costUnit;
    /**
     * Is this meter's commodity ENERGY STAR-compatible?
     */
    energyStarCompatible;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarMeterLinkRequest {
    /**
     * The meter identifier <span class='property-internal'>Required</span>
     */
    meterId;
    /**
     * The Portfolio Manager meter identifier.  Set to null to unlink meter. <span class='property-internal'>Required (defined)</span>
     */
    pmMeterId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceHierarchyResponse {
    place;
    placeSize;
    placeSubmissionType;
    /**
     * The status of the latest submission for this place
     */
    latestSubmissionStatus;
    /**
     * The date that the latest submission for this place occurred
     */
    latestSubmissionDate;
    /**
     * The status of the latest metrics retrieval for this place
     */
    latestMetricsRetrievalStatus;
    /**
     * ENERGY STAR score data for the place  If there are multiple places returned in the response, will be the most recent score
     */
    metrics;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceLinkRequest {
    /**
     * The Portfolio Manager property identifier.  Set to null to unlink place. <span class='property-internal'>Required (defined)</span>
     */
    pmPropertyId;
    /**
     * List of meter links for this place  If PmPropertyId is null to unlink the place then Meters should be null.    All meters under the place will be unlinked automatically. <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of Meters, Commodities can be set</span>
     */
    meters;
    /**
     * List of commodity links for this place  If PmPropertyId is null to unlink the place then Commodities should be null.    All commodities under the place will be unlinked automatically. <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of Meters, Commodities can be set</span>
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceLinkResponse {
    place;
    /**
     * The submit mode. Could be \"Meter\" or \"Commodity\"
     */
    submitMode;
    /**
     * una co              The Portfolio Manager property identifier
     */
    pmPropertyId;
    /**
     * List of meters for this place
     */
    meters;
    /**
     * List of commodities for this place
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceMetricsRequest {
    /**
     * The begin period for updating ENERGY STAR metrics <span class='property-internal'>Required</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span>
     */
    beginPeriod;
    /**
     * The end period for updating ENERGY STAR metrics  If null, metrics will only be retrieved for the period specified in BeginPeriod
     */
    endPeriod;
    /**
     * List of place identifiers to for which to update metrics <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    placeIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceMetricsResponse {
    /**
     * The year and month for the ENERGY STAR score
     */
    calendarPeriod;
    /**
     * The ENERGY STAR score
     */
    score;
    /**
     * The date the score was received
     */
    dateReceived;
    /**
     * The weather-normalized property energy use (kBtu)
     */
    siteEnergyUse;
    /**
     * The weather-normalized property energy use intensity (kBtu/ft²)
     */
    siteEnergyUseIntensity;
    /**
     * The national median ENERGY STAR score for the same type of property
     */
    nationalMedianScore;
    /**
     * The national median weather-normalized property energy use intensity (kBtu/ft²)
     */
    nationalMedianSiteEnergyUseIntensity;
    /**
     * The percent difference in the property energy use intensity vs. the national median
     */
    pctDiffNationalMedianSiteEnergyUseIntensity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceSubmissionStatusChild {
    /**
     * The submission period
     */
    submissionPeriod;
    /**
     * The submission period display name.  Only populated if the submission period has a custom name.
     */
    submissionPeriodDisplayName;
    /**
     * The submission status:        Submitted  - submission has been made for this place and submission period      Incomplete - no submission has been made for this place and submission period, and current billing data is incomplete      Ready      - no submission has been made for this place and submission period, and current billing data is complete
     */
    submissionStatus;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPlaceSubmissionStatusResponse {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place name
     */
    placeInfo;
    /**
     * The place code
     */
    placeCode;
    placeSubmissionType;
    placeSize;
    /**
     * The list of submission periods and the submission status for each period
     */
    placeSubmissionStatus;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPmMeter {
    /**
     * The Portfolio Manager meter identifier
     */
    pmMeterId;
    /**
     * The Portfolio Manager meter name
     */
    pmMeterName;
    /**
     * The Portfolio Manager commodity
     */
    pmCommodityCode;
    /**
     * The Portfolio Manager unit of measure
     */
    pmUnitCode;
    meter;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarPmProperty {
    /**
     * The Portfolio Manager property identifier  null when not linked to a portfolio manager property
     */
    pmPropertyId;
    /**
     * The Portfolio Manager property name  null when not linked to a portfolio manager property
     */
    pmPropertyName;
    /**
     * The Portfolio Manager property use type  null when not linked to a portfolio manager property
     */
    pmPropertyUseType;
    /**
     * The Portfolio Manager floor area  null when not linked to portfolio manager property
     */
    pmFloorArea;
    /**
     * The Portfolio Manager floor area units  null when not linked to a portfolio manager property
     */
    pmFloorAreaUnits;
    place;
    placeSize;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarRatingChild {
    /**
     * The date the score was received
     */
    ratingDate;
    /**
     * The year and month for the ENERGY STAR score
     */
    calendarPeriod;
    /**
     * The ENERGY STAR score
     */
    rating;
    /**
     * The weather-normalized property energy use intensity (kBtu/ft²)
     */
    siteEnergyUseIntensity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarSettings {
    /**
     * Indicates to always configure ENERGY STAR on a per commodity basis
     */
    submitByCommodityOnly;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarSettingsRequest {
    /**
     * The user name of the Portfolio Manager account to link. Not required if account already registered. <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    pmUserName;
    /**
     * The earliest period to submit <span class='property-internal'>Valid billing period between 190001 and 300001</span> <span class='property-internal'>Required</span>
     */
    earliestSubmissionPeriod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarSettingsResponse {
    /**
     * Full name of Portfolio Account Manager
     */
    pmAccountManagerFullName;
    /**
     * User name of Portfolio Account Manager
     */
    pmAccountManagerUserName;
    /**
     * The earliest period to submit
     */
    earliestSubmissionPeriod;
    /**
     * Number of Portfolio Manager properties that are not linked to any buildings in EnergyCAP
     */
    unlinkedPropertyCount;
    /**
     * Number of Portfolio Manager properties that are linked to a building in EnergyCAP
     */
    linkedPropertyCount;
    /**
     * True if this client is configured for ENERGY STAR and Portfolio manager is available. False indicates an issue. EnergyStarConfigurationErrorMessage will contain details
     */
    isEnergyStarAvailable;
    /**
     * If IsEnergystarAvailable is false, this reports the error
     */
    energyStarConfigurationErrorMessage;
    /**
     * True if running offline mode or if ENERGY STAR has been disabled for this client, false otherwise
     */
    isEnergyStarDisabled;
    /**
     * True if ENERGY STAR has been configured
     */
    isEnergyStarConfigured;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarSubmissionPlaceChild {
    /**
     * The place identifier <span class='property-internal'>Required</span>
     */
    placeId;
    /**
     * The list of submission periods to include in the submission <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    submissionPeriods;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * NOTE: this class also serves as a representation of EnergyStarTask.settings
 */
class EnergyStarSubmissionRequest {
    /**
     * List of places/submission periods to include in ENERGY STAR submission <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    places;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarTaskPlaceChild {
    building;
    /**
     * The list of submission or metrics periods for the task
     */
    taskPeriods;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EnergyStarTaskResponse {
    /**
     * The task identifier
     */
    energyStarTaskId;
    /**
     * The task type
     */
    taskType;
    /**
     * The date the submission was initiated
     */
    beginDate;
    user;
    /**
     * The number of buildings in the submission
     */
    numberOfPlaces;
    /**
     * Status for the submission portion of the task
     */
    submissionTaskStatus;
    /**
     * Status for the metrics retrieval portion of the task
     */
    metricsRetrievalTaskStatus;
    /**
     * Filename of the log containing errors encountered during submission  Will be null if this task is only for metrics retrieval or if there were no errors during submission
     */
    submissionLogFileName;
    /**
     * Filename of the log containing errors or alerts encountered during metrics retrieval
     */
    metricsRetrievalLogFileName;
    submissionType;
    /**
     * The list of buildings/submission periods in the submission
     */
    places;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EntityScheduleSummary {
    /**
     *
     */
    entityId;
    inSchedule;
    outSchedule;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Environment {
    /**
     *
     */
    buildDate;
    /**
     *
     */
    version;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class EsaChannelChild {
    /**
     * The identifier for the channel
     */
    channelId;
    /**
     * The channel interval
     */
    interval;
    /**
     * The channel name
     */
    channelInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelChildWithObservationType {
    /**
     *
     */
    esaChannelId;
    /**
     *
     */
    interval;
    /**
     *
     */
    esaChannelInfo;
    type;
    rule;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelCreate {
    /**
     * The DatapointId identifier <span class='property-internal'>Required</span>
     */
    dataPointId;
    esaChannelVersion;
    /**
     * The channel type identifier <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The channel interval identifier <span class='property-internal'>One of '5', '10', '15', '30', '60', '1440', '10080', '43200'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required when IsCalculated is set to False, case sensitive.</span> <span class='property-internal'>Must be null when IsCalculated  is  set to True, case sensitive</span>
     */
    intervalMinutes;
    /**
     * The name of the ESA channel <span class='property-internal'>Max length of 50</span> <span class='property-internal'>Required</span>
     */
    channelInfo;
    /**
     * The channel summarization method identifier <span class='property-internal'>Required</span>
     */
    summarizationMethodId;
    /**
     * The channel import identifier <span class='property-internal'>Max length of 255</span>
     */
    channelImportId;
    /**
     * If the channel is primary value
     */
    isPrimaryValue;
    /**
     * If the channel is demand value
     */
    isPrimaryDemand;
    /**
     * The channel description <span class='property-internal'>Max length of 255</span>
     */
    channelDescription;
    /**
     * Indicates whether or not this is a calculated channel with a formula.  When IsCalculated is true, the formula will need to be provided in channel version.  Conversions from Non-Calculated Channel to Calculated Channel: If the channel has no readings, If the channel has only one version, If the channel is not in other formulas  Conversions from Calculated Channel to Non-Calculated Channel: If the channel has no readings
     */
    isCalculated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelEdit {
    /**
     * The channel type identifier <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The channel interval identifier <span class='property-internal'>One of '5', '10', '15', '30', '60', '1440', '10080', '43200'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required when IsCalculated is set to False, case sensitive.</span> <span class='property-internal'>Must be null when IsCalculated  is  set to True, case sensitive</span>
     */
    intervalMinutes;
    /**
     * The name of the ESA channel <span class='property-internal'>Max length of 50</span> <span class='property-internal'>Required</span>
     */
    channelInfo;
    /**
     * The channel summarization method identifier <span class='property-internal'>Required</span>
     */
    summarizationMethodId;
    /**
     * The channel import identifier <span class='property-internal'>Max length of 255</span> <span class='property-internal'>Required (defined)</span>
     */
    channelImportId;
    /**
     * If the channel is primary value <span class='property-internal'>Required (defined)</span>
     */
    isPrimaryValue;
    /**
     * If the channel is demand value <span class='property-internal'>Required (defined)</span>
     */
    isPrimaryDemand;
    /**
     * The channel description <span class='property-internal'>Max length of 255</span> <span class='property-internal'>Required (defined)</span>
     */
    channelDescription;
    /**
     * Indicates whether or not this is a calculated channel with a formula.  When IsCalculated is true, the formula will need to be provided in channel version.  Conversions from Non-Calculated Channel to Calculated Channel: If the channel has no readings, If the channel has only one version, If the channel is not in other formulas  Conversions from Calculated Channel to Non-Calculated Channel: If the channel has no readings <span class='property-internal'>Required (defined)</span>
     */
    isCalculated;
    esaChannelVersion;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelResponse {
    observationType;
    /**
     * Description of the channel
     */
    channelDescription;
    /**
     * The import identifier for the channel.
     */
    channelImportId;
    /**
     * Indicates if the channel has readings
     */
    hasReadings;
    /**
     * Date of the earliest reading for the channel
     */
    firstReadingDate;
    /**
     * Date of the most recent reading for the channel
     */
    lastReadingDate;
    lastReadingValue;
    /**
     * Indicates if the channel is the primary value channel for the data point
     */
    isPrimaryValue;
    /**
     * Indicates if the channel is the primary demand channel for the data point
     */
    isPrimaryDemand;
    /**
     * Indicates if the channel is calculated
     */
    isCalculated;
    /**
     * Indicates if the channel can be converted from calculated to non-calculated or vice-versa  From Non-Calculated to Calculated: If the channel has no readings, If the channel has only one version, If the channel is not in other formulas  From Calculated to Non-Calculated: If the channel has no readings
     */
    isCalculatedConvertible;
    summarizationMethod;
    /**
     * List of channel versions  Versions include channel settings that may change over time
     */
    channelVersions;
    dataPoint;
    meter;
    /**
     * The identifier for the channel
     */
    channelId;
    /**
     * The channel interval
     */
    interval;
    /**
     * The channel name
     */
    channelInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelVersionCreate {
    /**
     * Indicates the channel observation rule  Demand channels cannot have the odometer observation rule <span class='property-internal'>Required</span> <span class='property-internal'>Must be a valid value for ObservationRuleEnum: Odometer = 1, Trip = 2</span>
     */
    observationRuleId;
    /**
     * The channel multiplier <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span> <span class='property-internal'>Required</span> <span class='property-internal'>Max scale of 15, max precision of 30</span>
     */
    multiplier;
    /**
     * The channel offset   Exclusive to the Trip observation rule <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span>
     */
    offset;
    /**
     * The channel unit identifier. It cannot be a Money unit type. <span class='property-internal'>Required</span>
     */
    unitId;
    /**
     * Indicates if the final value is always positive
     */
    isValuePositive;
    /**
     * The channel Odometer Rollover Value. Exclusive to the Odometer observation rule  If not provided, the default 999999999999999 is used <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be null when ObservationRuleId  is  set to Trip, case sensitive</span>
     */
    rolloverValue;
    /**
     * The channel Odometer Rollover Allowance. Exclusive to the Odometer observation rule  If not provided, the default 0.1 is used <span class='property-internal'>Must be between 0 and 1</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be null when ObservationRuleId  is  set to Trip, case sensitive</span>
     */
    rollbackAllowance;
    /**
     * The channel Minimum Computed Reading <span class='property-internal'>Must be between -999999999999999 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span>
     */
    minimumReading;
    /**
     * The channel Maximum Computed Reading <span class='property-internal'>Must be between -999999999999999 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span>
     */
    maximumReading;
    /**
     * The formula that should be used to calculate the channel's values.   Should only be provided when channel's IsCalculated property equals true.
     */
    formula;
}
(function (EsaChannelVersionCreate) {
    let ObservationRuleIdEnum;
    (function (ObservationRuleIdEnum) {
        ObservationRuleIdEnum[ObservationRuleIdEnum["NUMBER_1"] = 1] = "NUMBER_1";
        ObservationRuleIdEnum[ObservationRuleIdEnum["NUMBER_2"] = 2] = "NUMBER_2";
    })(ObservationRuleIdEnum = EsaChannelVersionCreate.ObservationRuleIdEnum || (EsaChannelVersionCreate.ObservationRuleIdEnum = {}));
})(EsaChannelVersionCreate || (EsaChannelVersionCreate = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelVersionCreateWithBeginDate {
    /**
     * Date and time that this channel version is valid from.  The valid period is exclusive of the beginDate.   The time zone of this date will match the data point's time zone. Therefore, if any time zone information is provided, it will be ignored.
     */
    beginDate;
    /**
     * Indicates the channel observation rule  Demand channels cannot have the odometer observation rule <span class='property-internal'>Required</span> <span class='property-internal'>Must be a valid value for ObservationRuleEnum: Odometer = 1, Trip = 2</span>
     */
    observationRuleId;
    /**
     * The channel multiplier <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span> <span class='property-internal'>Required</span> <span class='property-internal'>Max scale of 15, max precision of 30</span>
     */
    multiplier;
    /**
     * The channel offset   Exclusive to the Trip observation rule <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span>
     */
    offset;
    /**
     * The channel unit identifier. It cannot be a Money unit type. <span class='property-internal'>Required</span>
     */
    unitId;
    /**
     * Indicates if the final value is always positive
     */
    isValuePositive;
    /**
     * The channel Odometer Rollover Value. Exclusive to the Odometer observation rule  If not provided, the default 999999999999999 is used <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be null when ObservationRuleId  is  set to Trip, case sensitive</span>
     */
    rolloverValue;
    /**
     * The channel Odometer Rollover Allowance. Exclusive to the Odometer observation rule  If not provided, the default 0.1 is used <span class='property-internal'>Must be between 0 and 1</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be null when ObservationRuleId  is  set to Trip, case sensitive</span>
     */
    rollbackAllowance;
    /**
     * The channel Minimum Computed Reading <span class='property-internal'>Must be between -999999999999999 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span>
     */
    minimumReading;
    /**
     * The channel Maximum Computed Reading <span class='property-internal'>Must be between -999999999999999 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span>
     */
    maximumReading;
    /**
     * The formula that should be used to calculate the channel's values.   Should only be provided when channel's IsCalculated property equals true.
     */
    formula;
}
(function (EsaChannelVersionCreateWithBeginDate) {
    let ObservationRuleIdEnum;
    (function (ObservationRuleIdEnum) {
        ObservationRuleIdEnum[ObservationRuleIdEnum["NUMBER_1"] = 1] = "NUMBER_1";
        ObservationRuleIdEnum[ObservationRuleIdEnum["NUMBER_2"] = 2] = "NUMBER_2";
    })(ObservationRuleIdEnum = EsaChannelVersionCreateWithBeginDate.ObservationRuleIdEnum || (EsaChannelVersionCreateWithBeginDate.ObservationRuleIdEnum = {}));
})(EsaChannelVersionCreateWithBeginDate || (EsaChannelVersionCreateWithBeginDate = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelVersionEdit {
    /**
     * Date and time that this channel version is valid from.  The valid period is exclusive of the beginDate.   The time zone of this date will match the data point's time zone. Therefore, if any time zone information is provided, it will be ignored.
     */
    beginDate;
    /**
     * Indicates the channel observation rule  Demand channels cannot have the odometer observation rule <span class='property-internal'>Required</span> <span class='property-internal'>Must be a valid value for ObservationRuleEnum: Odometer = 1, Trip = 2</span>
     */
    observationRuleId;
    /**
     * The channel multiplier <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span> <span class='property-internal'>Required</span> <span class='property-internal'>Max scale of 15, max precision of 30</span>
     */
    multiplier;
    /**
     * The channel offset   Exclusive to the Trip observation rule <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span>
     */
    offset;
    /**
     * The channel unit identifier. It cannot be a Money unit type. <span class='property-internal'>Required</span>
     */
    unitId;
    /**
     * Indicates if the final value is always positive
     */
    isValuePositive;
    /**
     * The channel Odometer Rollover Value. Exclusive to the Odometer observation rule  If not provided, the default 999999999999999 is used <span class='property-internal'>Must be between 0 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be null when ObservationRuleId  is  set to Trip, case sensitive</span>
     */
    rolloverValue;
    /**
     * The channel Odometer Rollover Allowance. Exclusive to the Odometer observation rule  If not provided, the default 0.1 is used <span class='property-internal'>Must be between 0 and 1</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be null when ObservationRuleId  is  set to Trip, case sensitive</span>
     */
    rollbackAllowance;
    /**
     * The channel Minimum Computed Reading <span class='property-internal'>Must be between -999999999999999 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span>
     */
    minimumReading;
    /**
     * The channel Maximum Computed Reading <span class='property-internal'>Must be between -999999999999999 and 999999999999999</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>NULL Valid</span>
     */
    maximumReading;
    /**
     * The formula that should be used to calculate the channel's values.   Should only be provided when channel's IsCalculated property equals true.
     */
    formula;
}
(function (EsaChannelVersionEdit) {
    let ObservationRuleIdEnum;
    (function (ObservationRuleIdEnum) {
        ObservationRuleIdEnum[ObservationRuleIdEnum["NUMBER_1"] = 1] = "NUMBER_1";
        ObservationRuleIdEnum[ObservationRuleIdEnum["NUMBER_2"] = 2] = "NUMBER_2";
    })(ObservationRuleIdEnum = EsaChannelVersionEdit.ObservationRuleIdEnum || (EsaChannelVersionEdit.ObservationRuleIdEnum = {}));
})(EsaChannelVersionEdit || (EsaChannelVersionEdit = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaChannelVersionResponse {
    /**
     * The channel version identifier
     */
    channelVersionId;
    /**
     * The channel multiplier
     */
    multiplier;
    /**
     * The channel offset
     */
    offset;
    unit;
    observationRule;
    /**
     * The channel's minimum reading
     */
    minimumReading;
    /**
     * The channel's maximum reading
     */
    maximumReading;
    /**
     * Date and time that this channel version is valid from.  The valid period is exclusive of the beginDate.
     */
    beginDate;
    /**
     * Date and time that this channel version is valid until.  The valid period is inclusive of the endDate.
     */
    endDate;
    /**
     * Indicates if the channel final value is always positive
     */
    isValuePositive;
    /**
     * The channel's rollover value
     */
    rolloverValue;
    /**
     * The channel's roll back allowance
     */
    rollbackAllowance;
    /**
     * The formula that should be used in calculated channels.
     */
    formula;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaDeleteReadingResponse {
    /**
     * Data representing the failed reading deletion
     */
    failures;
    /**
     * The number of readings deleted
     */
    deleted;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaDeleteReadingSummarizedResponse {
    /**
     * Data representing the failed reading deletion
     */
    failures;
    /**
     * The number of readings deleted
     */
    deleted;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * This DTO is used for the EsaIntervalData Widget
 */
class EsaIntervalDataResponse {
    dateRange;
    /**
     * Data grouping interval in minutes
     */
    groupIntervalMinutes;
    schedule;
    /**
     * A collection of summaries (min, max, sum, average) for each Entity in the time series response.
     */
    entitySummaries;
    /**
     *
     */
    entities;
    /**
     *
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaPlaceCreate {
    /**
     * The place code. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Not ROOT</span>
     */
    placeCode;
    /**
     * The place info. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    placeInfo;
    /**
     * The identifier for the parent of the place. The parent is the place directly above the current place. <span class='property-internal'>Topmost (Space)</span> <span class='property-internal'>Required</span>
     */
    parentPlaceId;
    /**
     * The identifier for the place type. <span class='property-internal'>Required</span>
     */
    placeTypeId;
    /**
     * The identifier for the place's primary use.  If this is a site and PrimaryUseId is null this will be set to Unknown (PrimaryUseId 55).  Not valid for Spaces.
     */
    primaryUseId;
    /**
     * The date and time the place was built.  Not valid for Spaces.
     */
    buildDate;
    address;
    /**
     * The code for the weather station the place is assigned to.  Not valid for Spaces. <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    weatherStationCode;
    /**
     * A description of the place. <span class='property-internal'>Must be between 0 and 4000 characters</span>
     */
    placeDescription;
    /**
     * The name of the place's image.  Not valid for Spaces.
     */
    imageFilename;
    /**
     * The time zone identifier.  Not valid for Spaces.
     */
    timeZoneId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaPlaceDataRollupRequest {
    /**
     * The IDs of the Places to be updated. Each ID should appear no more than once. <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    placeIds;
    /**
     * A flag indicating whether or not this Place's summary totals should \"roll up\".  - i.e. whether they should contribute to the Place's parent's (and other ancestors') <span class='property-internal'>Required (defined)</span>
     */
    dataRollup;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaPlaceEdit {
    /**
     * The place code. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Not ROOT</span>
     */
    placeCode;
    /**
     * The place info. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    placeInfo;
    /**
     * The identifier for the parent of the place. The parent is the place directly above the current place. <span class='property-internal'>Topmost (Space)</span> <span class='property-internal'>Required</span>
     */
    parentPlaceId;
    /**
     * The identifier for the place type. <span class='property-internal'>Required</span>
     */
    placeTypeId;
    /**
     * The identifier for the place's primary use.  If this is a site and PrimaryUseId is null this will be set to Unknown (PrimaryUseId 55).  Not valid for Spaces. <span class='property-internal'>Required (defined)</span>
     */
    primaryUseId;
    /**
     * The date and time the place was built.  Not valid for Spaces. <span class='property-internal'>Required (defined)</span>
     */
    buildDate;
    address;
    /**
     * The code for the weather station the place is assigned to.  Not valid for Spaces. <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    weatherStationCode;
    /**
     * A description of the place. <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    placeDescription;
    /**
     * The name of the place's image.  Not valid for Spaces. <span class='property-internal'>Required (defined)</span>
     */
    imageFilename;
    /**
     * The time zone identifier.  Not valid for Spaces. <span class='property-internal'>Required (defined)</span>
     */
    timeZoneId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaPlaceResponse {
    parent;
    placeType;
    /**
     * The date and time the place was created
     */
    createdDate;
    createdBy;
    /**
     * The date and time of the most recent modification to the place
     */
    modifiedDate;
    modifiedBy;
    address;
    /**
     * The date and time the place was built
     */
    buildDate;
    primaryUse;
    weatherStation;
    size;
    benchmark1;
    benchmark2;
    benchmark3;
    /**
     * Tells whether energy star is enabled for the given place
     */
    energyStarEnabled;
    energyStarRating;
    /**
     * An array of child places. A child place is one directly beneath the current place
     */
    places;
    /**
     * An array of child meters. A child meter is one directly beneath the current place
     */
    meters;
    /**
     * An array of child data points. A child data point is one directly beneath the current place
     */
    dataPoints;
    contact;
    /**
     * A description of the place
     */
    placeDescription;
    watticsSite;
    /**
     * Tells whether the place area is calculated from its children (TODO: Use 'Area' instead of 'Size'? Would be inconsistent with Size property in DTO)
     */
    isSizeCalculated;
    /**
     * Tells whether or not the place's data is rolled up to its parents.  Currently only supported by ESA.
     */
    isDataRolledUp;
    sizeInReportingUnit;
    /**
     * The name of the place's image.  Currently only supported by ESA.
     */
    imageFilename;
    timeZone;
    /**
     * The place's schedules
     */
    schedules;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaPlaceSizeCreate {
    /**
     * The begin date for the place size <span class='property-internal'>Required</span>
     */
    beginDate;
    /**
     * The place size value <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    value;
    /**
     * <p>The place size's unit code</p>  <p>Options are: SQFEET for Square Feet, SQMETER for Square Meters, HECTARE, SQKILOMETER for Square Kilometers,              SQMILE for Square Miles, SQYARD for Square Yards, and ACRE.</p> <span class='property-internal'>One of 'SQFEET', 'SQMETER', 'HECTARE', 'SQKILOMETER', 'SQMILE', 'SQYARD', 'ACRE'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Must be between 0 and 16 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    unitCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * ESA reading request
 */
class EsaReadingCreate {
    /**
     *  Channel Identification         The channel that receives the reading is determined by the following rules:        Direct pointers to a channel      If the EsaChannelId is supplied, then import to that channel.      If the EsaChannelId is not supplied look at the EsaChannelImportId property, which indicates a specific channel.  Inferred pointers to a channel      If the EsaChannelId and EsaChannelImportId are not supplied, look at the DataPointImportId property, which indicates a data point.If that data point has one channel, import to that channel.      If that data point has more than one channel, find the channel with the same observation type as the ObservationTypeCode property.If only one is found, import to that channel.      If more than one channel is found based on observation type, find the channel with the same output unit as the UnitCode property.If only one is found, import to that channel.      If more than one channel is found based on unit, find the channel with the same EsaChannelIntervalMinutes property. If only one is found, import to that channel. <span class='property-internal'>Topmost (EsaChannel)</span> <span class='property-internal'>At least one of EsaChannelId, EsaChannelImportId, DataPointImportId must not be null</span>
     */
    esaChannelId;
    /**
     * The import identifier for the channel on which to create the reading. See the EsaChannelId property for more information <span class='property-internal'>At least one of EsaChannelId, EsaChannelImportId, DataPointImportId must not be null</span>
     */
    esaChannelImportId;
    /**
     * The import identifier for the data point on which to create the reading. See the EsaChannelId property for more information <span class='property-internal'>At least one of EsaChannelId, EsaChannelImportId, DataPointImportId must not be null</span>
     */
    dataPointImportId;
    /**
     * The interval in minutes for the channel on which to create the reading. See the EsaChannelId property for more information
     */
    esaChannelIntervalMinutes;
    /**
     * The observationType code of the reading. See the EsaChannelId property for more information
     */
    observationTypeCode;
    /**
     * The unit code of the reading. See the EsaChannelId property for more information
     */
    unitCode;
    /**
     * List of readings <span class='property-internal'>Required</span>
     */
    readings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Failed reading create dtos
 */
class EsaReadingCreateError {
    /**
     * The ESA channel id
     */
    esaChannelId;
    /**
     * The ESA channel import id
     */
    esaChannelImportId;
    /**
     * The data point import id
     */
    dataPointImportId;
    /**
     * The esa channel interval
     */
    esaChannelIntervalMinutes;
    /**
     * The observation type of the esa channel
     */
    observationTypeCode;
    /**
     * The unit code of the esa channel
     */
    unitCode;
    /**
     * List of readings
     */
    readings;
    /**
     * The error message
     */
    error;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * ESA reading create response
 */
class EsaReadingCreateResponse {
    /**
     * The number of successfully imported readings
     */
    importedReadingsCount;
    /**
     * The number of failed readings
     */
    failedReadingsCount;
    /**
     * Data representing the failed readings
     */
    failedReadings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingDelete {
    /**
     * The identifier for the ESA channel of the reading <span class='property-internal'>Required</span>
     */
    esaChannelId;
    /**
     * The begin date and time of the set of readings to be deleted.   If provided, readings after (but not including) this date and time will be deleted.  If provided, and equal to TimeEnd, delete the single reading at this date and time (if present).  If not provided, readings since the start of time will be deleted. If TimeEnd is also not provided,  ALL readings belonging to EsaChannelId will be deleted.<br />  If UseDataPointTimeZone is false, this time is interpreted as an absolute timestamp. For example,  \"2024-01-01 05:00:00 -04:00\".<br />  If UseDataPointTimeZone is true, the following applies:<br />  The time is presumed to be in the time zone of the data point. If an offset is provided, it will  be ignored. For example, if \"2024-01-01 05:00:00 -04:00\" is provided but the time zone of the data  point is \"GMT\" then this will get turned into \"2024-01-01 05:00:00 +00:00\" before being applied.  If an ambiguous time is provided (for instance 01:30 when the clocks go backward for a DST change)  then choose the earliest one in absolute time. If an invalid time is provided (for example 02:30 when the  clocks go forward for a DST change) then shift forward by the amount of the DST change (in this example,  +1hr will make it 03:30, in the DataPoint's time zone).
     */
    timeBegin;
    /**
     * The end date and time of the set of readings to be deleted.   If provided, readings up to (and including) this date and time will be deleted.  If provided, and equal to TimeBegin, delete the single reading at this date and time (if present).  If not provided, readings until the end of time will be deleted. If TimeBegin is also not provided,  ALL readings belonging to EsaChannelId will be deleted.<br />  See TimeBegin for a discussion of how the value of UseDataPointTimeZone affects the interpretation  of this value.
     */
    timeEnd;
    /**
     *
     */
    useDataPointTimeZone;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingImportProfile {
    /**
     * The time zone for the import profile
     */
    timeZoneId;
    /**
     * The string that represents how the file contents are delimited <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2 characters</span>
     */
    delimiter;
    /**
     * The string that represents how the decimal values are separated <span class='property-internal'>Must be between 1 and 2 characters</span> <span class='property-internal'>One of ',', '.'</span> <span class='property-internal'>Case sensitive</span>
     */
    decimalSeparator;
    /**
     * Number of header rows before the data begins (Skip Rows) <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    numberOfHeaderRows;
    dataPointImportId;
    channelImportId;
    /**
     * The format for the Date and Time of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz <span class='property-internal'>Only one of DateFormat, DateTimeFormat can be set</span> <span class='property-internal'>Only one of TimeFormat, DateTimeFormat can be set</span>
     */
    dateTimeFormat;
    /**
     * The number of the column that holds the Date and Time   Mandatory when Date Time Format column is provided <span class='property-internal'>Required when DateTimeFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    dateTimeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy <span class='property-internal'>Only one of DateFormat, DateTimeFormat can be set</span>
     */
    dateFormat;
    /**
     * The number of the column that holds the date   Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    dateColumnNumber;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz  Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Only one of TimeFormat, DateTimeFormat can be set</span>
     */
    timeFormat;
    /**
     * The number of the column that holds the time   Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    timeColumnNumber;
    estimated;
    interval;
    /**
     * Column number that holds a note to be stored with the reading <span class='property-internal'>Must be between 1 and 104</span>
     */
    readingNoteColumnNumber;
    /**
     * Column number that holds reading value to be imported onto the ChannelImportId <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when ChannelImportId is set</span> <span class='property-internal'>Only one of ReadingValueColumnNumber, IntervalDataTypes can be set</span>
     */
    readingValueColumnNumber;
    /**
     * A list of columns from the import sheet with their observation type and unit <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required when DataPointImportId is set</span> <span class='property-internal'>Only one of ReadingValueColumnNumber, IntervalDataTypes can be set</span>
     */
    intervalDataTypes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingImportProfileColumn {
    /**
     * The number of the column <span class='property-internal'>Must be between 1 and 104</span>
     */
    columnNumber;
    /**
     * The observation type code of the reading <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    observationTypeCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingImportProfileCreate {
    /**
     * Name of the import profile <span class='property-internal'>Max length of 50</span> <span class='property-internal'>Required</span>
     */
    profileInfo;
    /**
     * Description of the import profile <span class='property-internal'>Max length of 255</span>
     */
    profileDescription;
    /**
     * The time zone for the import profile
     */
    timeZoneId;
    /**
     * The string that represents how the file contents are delimited <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2 characters</span>
     */
    delimiter;
    /**
     * The string that represents how the decimal values are separated <span class='property-internal'>Must be between 1 and 2 characters</span> <span class='property-internal'>One of ',', '.'</span> <span class='property-internal'>Case sensitive</span>
     */
    decimalSeparator;
    /**
     * Number of header rows before the data begins (Skip Rows) <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    numberOfHeaderRows;
    dataPointImportId;
    channelImportId;
    /**
     * The format for the Date and Time of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz <span class='property-internal'>Only one of DateFormat, DateTimeFormat can be set</span> <span class='property-internal'>Only one of TimeFormat, DateTimeFormat can be set</span>
     */
    dateTimeFormat;
    /**
     * The number of the column that holds the Date and Time   Mandatory when Date Time Format column is provided <span class='property-internal'>Required when DateTimeFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    dateTimeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy <span class='property-internal'>Only one of DateFormat, DateTimeFormat can be set</span>
     */
    dateFormat;
    /**
     * The number of the column that holds the date   Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    dateColumnNumber;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz  Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Only one of TimeFormat, DateTimeFormat can be set</span>
     */
    timeFormat;
    /**
     * The number of the column that holds the time   Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    timeColumnNumber;
    estimated;
    interval;
    /**
     * Column number that holds a note to be stored with the reading <span class='property-internal'>Must be between 1 and 104</span>
     */
    readingNoteColumnNumber;
    /**
     * Column number that holds reading value to be imported onto the ChannelImportId <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when ChannelImportId is set</span> <span class='property-internal'>Only one of ReadingValueColumnNumber, IntervalDataTypes can be set</span>
     */
    readingValueColumnNumber;
    /**
     * A list of columns from the import sheet with their observation type and unit <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required when DataPointImportId is set</span> <span class='property-internal'>Only one of ReadingValueColumnNumber, IntervalDataTypes can be set</span>
     */
    intervalDataTypes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingImportProfileEdit {
    /**
     * Name of the import profile <span class='property-internal'>Max length of 50</span> <span class='property-internal'>Required</span>
     */
    profileInfo;
    /**
     * Description of the import profile <span class='property-internal'>Max length of 255</span> <span class='property-internal'>Required (defined)</span>
     */
    profileDescription;
    /**
     * The time zone for the import profile <span class='property-internal'>Required (defined)</span>
     */
    timeZoneId;
    /**
     * The string that represents how the file contents are delimited <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2 characters</span>
     */
    delimiter;
    /**
     * The string that represents how the decimal values are separated <span class='property-internal'>Must be between 1 and 2 characters</span> <span class='property-internal'>One of ',', '.'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    decimalSeparator;
    /**
     * Number of header rows before the data begins (Skip Rows) <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    numberOfHeaderRows;
    dataPointImportId;
    channelImportId;
    /**
     * The format for the Date and Time of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of DateFormat, DateTimeFormat can be set</span> <span class='property-internal'>Only one of TimeFormat, DateTimeFormat can be set</span>
     */
    dateTimeFormat;
    /**
     * The number of the column that holds the Date and Time   Mandatory when Date Time Format column is provided <span class='property-internal'>Required when DateTimeFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    dateTimeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of DateFormat, DateTimeFormat can be set</span>
     */
    dateFormat;
    /**
     * The number of the column that holds the date   Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    dateColumnNumber;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz  Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Only one of TimeFormat, DateTimeFormat can be set</span>
     */
    timeFormat;
    /**
     * The number of the column that holds the time   Mandatory when Date Format column is provided <span class='property-internal'>Required when DateFormat is set</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    timeColumnNumber;
    estimated;
    interval;
    /**
     * Column number that holds a note to be stored with the reading <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required (defined)</span>
     */
    readingNoteColumnNumber;
    /**
     * Column number that holds reading value to be imported onto the ChannelImportId <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when ChannelImportId is set</span> <span class='property-internal'>Only one of ReadingValueColumnNumber, IntervalDataTypes can be set</span>
     */
    readingValueColumnNumber;
    /**
     * A list of columns from the import sheet with their observation type and unit <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Required when DataPointImportId is set</span> <span class='property-internal'>Only one of ReadingValueColumnNumber, IntervalDataTypes can be set</span>
     */
    intervalDataTypes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingImportProfileResponse {
    /**
     * Identifier of the record import profile
     */
    profileId;
    /**
     * Name of the import profile
     */
    profileInfo;
    /**
     * Description of the import profile
     */
    profileDescription;
    timeZone;
    /**
     * The string that represents how the file contents are delimited
     */
    delimiter;
    /**
     * The string that represents how the decimal values are separated
     */
    decimalSeparator;
    /**
     * Number of header rows before the data begins
     */
    numberOfHeaderRows;
    dataPointImportId;
    channelImportId;
    /**
     * The format for the Date and Time of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz
     */
    dateTimeFormat;
    /**
     * The number of the column that holds the Date and Time
     */
    dateTimeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy
     */
    dateFormat;
    /**
     * The number of the column that holds the date
     */
    dateColumnNumber;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz
     */
    timeFormat;
    /**
     * The number of the column that holds the time
     */
    timeColumnNumber;
    estimated;
    interval;
    /**
     * Column number that holds a note to be stored with the reading
     */
    readingNoteColumnNumber;
    /**
     * Column number that holds reading value to be imported onto the ChannelImportId
     */
    readingValueColumnNumber;
    /**
     * A list of columns from the import sheet with their observation type and unit
     */
    intervalDataTypes;
    createdBy;
    /**
     * The date and time the import profile was modified
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time the import profile was modified
     */
    modifiedDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingImportRequest {
    /**
     * Name of the import profile <span class='property-internal'>Must be between 0 and 64 characters</span> <span class='property-internal'>Only one of ProfileInfo, InlineProfile can be set</span>
     */
    profileInfo;
    inlineProfile;
    /**
     * FileName for the import file. Should include extension.  The extension allows the importer to read the data in the proper format (csv, xlsx, zip) <span class='property-internal'>Required</span>
     */
    fileName;
    /**
     * The base64 encoded file <span class='property-internal'>Required</span>
     */
    fileContent;
    /**
     * Optional note/comment.
     */
    importNote;
    /**
     * The type of notification to send when the import is completed with errors.  Default is \"SystemMessages\". <span class='property-internal'>Must be a valid value for NotificationTypeEnum: SystemMessages = 1, BillImportAutomation = 2, BillExportToApAutomation = 3, IntervalDataAutomation = 4, UserGroupMessages = 5, UpdatesAndNewFeatures = 6, HelpArticlesTipsAndSuggestions = 7, CustomerServiceMessages = 8, EnergyStarSubmissionFailures = 9, BillExportToGlAutomation = 10, AutomaticallyCreatedMetersOrAccounts = 11, ExceededLicensedObjectCount = 12, BillCaptureAutomation = 13</span>
     */
    completeWithErrorsNotificationType;
}
(function (EsaReadingImportRequest) {
    let CompleteWithErrorsNotificationTypeEnum;
    (function (CompleteWithErrorsNotificationTypeEnum) {
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_1"] = 1] = "NUMBER_1";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_2"] = 2] = "NUMBER_2";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_3"] = 3] = "NUMBER_3";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_4"] = 4] = "NUMBER_4";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_5"] = 5] = "NUMBER_5";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_6"] = 6] = "NUMBER_6";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_7"] = 7] = "NUMBER_7";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_8"] = 8] = "NUMBER_8";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_9"] = 9] = "NUMBER_9";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_10"] = 10] = "NUMBER_10";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_11"] = 11] = "NUMBER_11";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_12"] = 12] = "NUMBER_12";
        CompleteWithErrorsNotificationTypeEnum[CompleteWithErrorsNotificationTypeEnum["NUMBER_13"] = 13] = "NUMBER_13";
    })(CompleteWithErrorsNotificationTypeEnum = EsaReadingImportRequest.CompleteWithErrorsNotificationTypeEnum || (EsaReadingImportRequest.CompleteWithErrorsNotificationTypeEnum = {}));
})(EsaReadingImportRequest || (EsaReadingImportRequest = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingResponse {
    /**
     * The reading's raw value
     */
    rawValue;
    /**
     * The reading's value after processing
     */
    processedValue;
    /**
     * Creation method of the reading.   'Manual' when readings are created by users in the UI  'Imported' when readings are created by imports  'Calculated' when readings are created by calculated channels
     */
    creationMethod;
    /**
     * The date and time of the reading
     */
    timestamp;
    /**
     * The date and time of the reading adjusted to the data point's time zone
     */
    localTimestamp;
    /**
     * Indicates whether or not the reading is estimated
     */
    estimated;
    /**
     * A note pertaining to the reading
     */
    note;
    /**
     * Reading's channel ID
     */
    esaChannelId;
    /**
     * Reading's channel name
     */
    esaChannelInfo;
    /**
     * Indicates if the channel is calculated
     */
    isCalculatedEsaChannel;
    /**
     * Interval of the reading in minutes
     */
    interval;
    /**
     * Interval description for the channel on which the reading was originated
     */
    intervalInfo;
    unit;
    observationType;
    dataPoint;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingSummarizedDelete {
    /**
     * The identifier for the ESA channel of the reading <span class='property-internal'>Required</span>
     */
    esaChannelId;
    /**
     * The begin date and time of the set of readings to be deleted.   If provided, readings after (but not including) this date and time will be deleted.  If provided, and equal to TimeEnd, delete the single reading at this date and time (if present).  If not provided, readings since the start of time will be deleted. If TimeEnd is also not provided,  ALL readings belonging to EsaChannelId will be deleted.<br />  If UseDataPointTimeZone is false, this time is interpreted as an absolute timestamp. For example,  \"2024-01-01 05:00:00 -04:00\".<br />  If UseDataPointTimeZone is true, the following applies:<br />  The time is presumed to be in the time zone of the data point. If an offset is provided, it will  be ignored. For example, if \"2024-01-01 05:00:00 -04:00\" is provided but the time zone of the data  point is \"GMT\" then this will get turned into \"2024-01-01 05:00:00 +00:00\" before being applied.  If an ambiguous time is provided (for instance 01:30 when the clocks go backward for a DST change)  then choose the earliest one in absolute time. If an invalid time is provided (for example 02:30 when the  clocks go forward for a DST change) then shift forward by the amount of the DST change (in this example,  +1hr will make it 03:30, in the DataPoint's time zone).
     */
    timeBegin;
    /**
     * The end date and time of the set of readings to be deleted.   If provided, readings up to (and including) this date and time will be deleted.  If provided, and equal to TimeBegin, delete the single reading at this date and time (if present).  If not provided, readings until the end of time will be deleted. If TimeBegin is also not provided,  ALL readings belonging to EsaChannelId will be deleted.<br />  See TimeBegin for a discussion of how the value of UseDataPointTimeZone affects the interpretation  of this value.
     */
    timeEnd;
    /**
     *
     */
    useDataPointTimeZone;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaReadingSummarizedResponse {
    /**
     *
     */
    summarizedValue;
    /**
     * Creation method of the reading.   'Manual' when readings are created by users in the UI  'System' when readings are calculated from raw or processed readings
     */
    creationMethod;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * The summarized reading value converted from the channel unit to the common rollup unit value
     */
    commonRollupValue;
    /**
     * The summarized reading value converted from the channel unit to the global rollup unit value
     */
    globalRollupValue;
    /**
     * The date and time of the reading
     */
    timestamp;
    /**
     * The date and time of the reading adjusted to the data point's time zone
     */
    localTimestamp;
    /**
     * Indicates whether or not the reading is estimated
     */
    estimated;
    /**
     * A note pertaining to the reading
     */
    note;
    /**
     * Reading's channel ID
     */
    esaChannelId;
    /**
     * Reading's channel name
     */
    esaChannelInfo;
    /**
     * Indicates if the channel is calculated
     */
    isCalculatedEsaChannel;
    /**
     * Interval of the reading in minutes
     */
    interval;
    /**
     * Interval description for the channel on which the reading was originated
     */
    intervalInfo;
    unit;
    observationType;
    dataPoint;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * ESA reading value request
 */
class EsaReadingValue {
    /**
     * The date and time of the reading. If the 'seconds' portion of the timestamp is greater than 0 the reading is rounded up to the next minute.<br />   If UseDataPointTimeZone is true any time zone information on the reading is ignored and the reading is saved in the data point's time zone.<br />  If UseDataPointTimeZone is false and a time zone is not present in the timestamp, the reading is saved in UTC.<br />  Else, the reading is saved in the time zone provided.<br />  Note that the time zone of existing readings are not updated. Delete and recreate a reading if you wish to change its 'raw' time zone.  In-app reporting will display the reading adjusted to the data point's time zone from the original time zone it was saved in. <span class='property-internal'>Required</span>
     */
    timestamp;
    /**
     * If true, any time zone information on the timestamp property is ignored and the reading is saved in the data point's time zone. <br />  For example, if the timestamp provided is \"2024-01-01 05:00:00 -04:00\" and the data point's time zone offset is -07:00,  the reading will be saved as \"2024-01-01 05:00:00 -07:00\".<br />  If omitted, this property is presumed to be false, meaning the offset in the timestamp property is honored.
     */
    useDataPointTimeZone;
    /**
     * The reading's value <span class='property-internal'>Required</span> <span class='property-internal'>Max scale of 15, max precision of 30</span> <span class='property-internal'>Must be between -9999999999999 and 9999999999999</span>
     */
    value;
    /**
     * Indicates if the reading is estimated. If omitted, this is presumed to be false.
     */
    estimated;
    /**
     * A note pertaining to the reading <span class='property-internal'>Max length of 255</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Failed reading value dtos
 */
class EsaReadingValueError {
    /**
     * The date and time of the reading
     */
    timestamp;
    /**
     * Indicates if the reading used the data point's time zone
     */
    useDataPointTimeZone;
    /**
     * The reading's value
     */
    value;
    /**
     * Indicates if the reading is estimated
     */
    estimated;
    /**
     * A note pertaining to the reading
     */
    note;
    /**
     * The error message
     */
    error;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaSentinelPrediction {
    /**
     *
     */
    esaChannelId;
    /**
     *
     */
    localDateTime;
    /**
     *
     */
    value;
    /**
     *
     */
    estimatedUpperBound;
    /**
     *
     */
    estimatedLowerBound;
    /**
     *
     */
    isOutOfBounds;
    /**
     *
     */
    outOfBoundsAmount;
    /**
     *
     */
    outOfBoundsPercent;
    /**
     *
     */
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaSentinelPredictionRequest {
    /**
     * The start local date/time of the range for which predictions are requested.  If equal to endLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions since this date and time (exclusive).
     */
    startLocalDate;
    /**
     * The end local date/time of the range for which predictions are requested  If equal to startLocalDate, returns sentinel prediction at this date and time (if present).  Otherwise, returns sentinel predictions up to (and including) this date and time. <span class='property-internal'>Must be greater than or equal to StartLocalDate</span>
     */
    endLocalDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaSentinelPredictionResponse {
    /**
     * Prediction’s channel ID
     */
    esaChannelId;
    /**
     * The local date and time of the prediction. Note that prediction entries will be rounded to hourly intervals.
     */
    localDateTime;
    /**
     * Total offset minutes that the local date and time differ from UTC.
     */
    timeZoneTotalOffsetMinutes;
    /**
     * The predicted estimated upper limit for this date/time.
     */
    estimatedUpperBound;
    /**
     * The predicted estimated lower limit for this date/time.
     */
    estimatedLowerBound;
    /**
     * The predicted estimated value for this date/time.
     */
    estimatedValue;
    /**
     * Details for the model that was used to generate the estimates for the date/time.   This may be nothing more than a name assigned to the model (e.g. Facebook Prophet).
     */
    sourceModel;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class EsaSentinelPredictionsResponse {
    dateRange;
    esaChannel;
    /**
     *
     */
    values;
    schedule;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Estimated {
    /**
     * Column number specifying where to look for the estimated indicator <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    columnNumber;
    /**
     * The string used to indicate the reading is estimated  If this value is found in the column number specified the reading will be marked as estimated  Example: e, E, 1, 0, est, *, this is my estimated read <span class='property-internal'>Required</span>
     */
    indicator;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ExportBills {
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    run;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ExportBillsClassPermission {
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    run;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ExportFormatChild {
    /**
     *
     */
    exportFormatInfo;
    /**
     *
     */
    preferred;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ExportHold {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ExportHoldClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Represents workflow settings for bill export
 */
class ExportWorkflowChild {
    /**
     * Whether or not payment details should be included in export <span class='property-internal'>Required</span>
     */
    includePaymentDetails;
    /**
     * Whether or not Export Mode is enabled <span class='property-internal'>Required</span>
     */
    exportModeEnabled;
    /**
     * The point at which a bill is eligible for export <span class='property-internal'>Required</span> <span class='property-internal'>One of 'never', 'after entry', 'after batch', 'after approval', 'after batch approval'</span>
     */
    canExport;
    /**
     * Whether or not custom fields should be included in export <span class='property-internal'>Required</span>
     */
    includeUdfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ExportWorkflowSettings {
    /**
     *
     */
    exportModeEnabled;
    /**
     *
     */
    canExport;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FacilityProjects {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FacilityProjectsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FailedReadingResponse {
    /**
     *
     */
    channelId;
    /**
     *
     */
    channelImportId;
    /**
     *
     */
    meterImportId;
    /**
     *
     */
    observationTypeCode;
    /**
     *
     */
    unitCode;
    /**
     *
     */
    channelIntervalInSeconds;
    /**
     *
     */
    readings;
    /**
     *
     */
    error;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FailedReadings {
    /**
     *
     */
    time;
    /**
     *
     */
    value;
    /**
     *
     */
    estimated;
    /**
     *
     */
    note;
    /**
     *
     */
    error;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FileDataTypeResponse {
    /**
     * The id of the file data type
     */
    fileDataTypeId;
    /**
     * The code of the file data type
     */
    fileDataTypeCode;
    /**
     * The name of the file data type
     */
    fileDataTypeInfo;
    /**
     * A list of supported extensions for this file data type
     */
    supportedExtensions;
    /**
     * The maximum size, in bytes, supported for this file data type
     */
    maxSizeInBytes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FilterDataResponse {
    /**
     *
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FilterEdit {
    /**
     * Data field ID for the filter <span class='property-internal'>Required</span>
     */
    fieldId;
    /**
     * Filter operator expressed as a string (e.g. \"equals\") <span class='property-internal'>Required</span>
     */
    operator;
    /**
     * Filter value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FilterResponse {
    /**
     * The list of available operators <span class='property-internal'>Required (defined)</span>
     */
    availableOperator;
    /**
     * The caption of the filter <span class='property-internal'>Required (defined)</span>
     */
    caption;
    /**
     * The Query parameter name <span class='property-internal'>Required (defined)</span>
     */
    queryParameterName;
    /**
     * The field identifier <span class='property-internal'>Required (defined)</span>
     */
    fieldId;
    /**
     * The datafield identifier <span class='property-internal'>Required (defined)</span>
     */
    dataFieldId;
    dataType;
    /**
     * The operator <span class='property-internal'>Required (defined)</span>
     */
    operator;
    /**
     * The value of the filter <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     * Indicates if the filter is required
     */
    required;
    /**
     * Indicates if the filter is recommended <span class='property-internal'>Required (defined)</span>
     */
    recommended;
    /**
     * Indicates if the filter is hidden <span class='property-internal'>Required (defined)</span>
     */
    hidden;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Fixed amount per unit to apply during bill calculation
 */
class FixedAmountResponse {
    /**
     * Fixed amount
     */
    amount;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FixedDemandRequest {
    /**
     * Fixed demand amount <span class='property-internal'>Required</span> <span class='property-info'>Max scale of 6</span>
     */
    fixedDemandAmount;
    /**
     * Unit to which demand is applied <span class='property-internal'>Required</span>
     */
    unitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FixedPercentage {
    /**
     * Destination account ID <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (CostCenter)</span>
     */
    destinationAccountId;
    /**
     * Destination meter ID  The DestinationMeterId commodity must match the commodity <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (LogicalDevice)</span>
     */
    destinationMeterId;
    /**
     * Fixed percentage to apply in bill split for this account and meter  Pass the percentage value  For example 50.5% should be 50.5 <span class='property-info'>Max scale of 8</span> <span class='property-internal'>Required</span>
     */
    splitPercentage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FixedPercentageResponse {
    destinationAccount;
    destinationMeter;
    destinationPlace;
    /**
     * Fixed percentage to apply in bill split for this account and meter
     */
    splitPercentage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Fixed amount per unit to apply during bill calculation
 */
class FixedUnitCostRequest {
    /**
     * Fixed unit cost <span class='property-internal'>Required</span> <span class='property-info'>Max scale of 8</span>
     */
    unitCost;
    /**
     * Unit to which unit cost is applied <span class='property-internal'>Required</span>
     */
    unitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FixedUseRequest {
    /**
     * Fixed use amount <span class='property-internal'>Required</span> <span class='property-info'>Max scale of 6</span>
     */
    fixedUseAmount;
    /**
     * Unit to which use is applied <span class='property-internal'>Required</span>
     */
    unitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagActionChild {
    /**
     * The flag action identifier
     */
    flagActionId;
    /**
     * Flag action information
     */
    flagActionInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagEdit {
    /**
     * Type of the flag  Note: Audit exception flag type id cannot be assigned manually <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of FlagTypeId, FlagStatusId, CostRecovery, Comment, Assignees must not be null</span>
     */
    flagTypeId;
    /**
     * Current status of the flag <span class='property-internal'>One of '1', '2'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of FlagTypeId, FlagStatusId, CostRecovery, Comment, Assignees must not be null</span>
     */
    flagStatusId;
    /**
     * Cost recovery associated with the issue this flag represents <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of FlagTypeId, FlagStatusId, CostRecovery, Comment, Assignees must not be null</span>
     */
    costRecovery;
    /**
     * Event and action that has occurred with this flag <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of FlagTypeId, FlagStatusId, CostRecovery, Comment, Assignees must not be null</span>
     */
    comment;
    /**
     * All users currently assigned to this flag <span class='property-internal'>Required (defined)</span> <span class='property-internal'>At least one of FlagTypeId, FlagStatusId, CostRecovery, Comment, Assignees must not be null</span>
     */
    assignees;
    /**
     * Determines whether or not the bill will be released from export hold when resolving the bill flag  This property cannot be true if HoldFromExport is true. <span class='property-internal'>Required (defined)</span>
     */
    releaseExportHold;
    /**
     * Determines whether or not the bill will be held for export when flagging the bill  This property cannot be true if ReleaseExportHold is true. <span class='property-internal'>Required (defined)</span>
     */
    holdFromExport;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagEventChild {
    /**
     * The flag event identifier
     */
    flagEventId;
    createdBy;
    /**
     * Date that this flag event was created
     */
    createdDate;
    /**
     * Comment about the flag event
     */
    comment;
    /**
     * Description of the flag event
     */
    description;
    flagAction;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueActionChild {
    /**
     * The flag issue action identifier
     */
    flagIssueActionId;
    /**
     * Flag issue action information
     */
    flagIssueActionInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueEdit {
    /**
     * The flag issue identifier <span class='property-internal'>Required (defined)</span>
     */
    flagIssueId;
    /**
     * Current status of the flag issue <span class='property-internal'>Must be a valid value for FlagStatusEnum: Unresolved = 1, Resolved = 2</span> <span class='property-internal'>Required (defined)</span>
     */
    flagIssueStatusId;
    /**
     * Comment about the flag issue <span class='property-internal'>Required (defined)</span>
     */
    comment;
    /**
     * All users currently assigned to this flag issue <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}
(function (FlagIssueEdit) {
    let FlagIssueStatusIdEnum;
    (function (FlagIssueStatusIdEnum) {
        FlagIssueStatusIdEnum[FlagIssueStatusIdEnum["NUMBER_1"] = 1] = "NUMBER_1";
        FlagIssueStatusIdEnum[FlagIssueStatusIdEnum["NUMBER_2"] = 2] = "NUMBER_2";
    })(FlagIssueStatusIdEnum = FlagIssueEdit.FlagIssueStatusIdEnum || (FlagIssueEdit.FlagIssueStatusIdEnum = {}));
})(FlagIssueEdit || (FlagIssueEdit = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueEditAction {
    /**
     * Current status of the flag issue <span class='property-internal'>Must be a valid value for FlagStatusEnum: Unresolved = 1, Resolved = 2</span> <span class='property-internal'>Required (defined)</span>
     */
    flagIssueStatusId;
    /**
     * Comment about the flag issue <span class='property-internal'>Required (defined)</span>
     */
    comment;
    /**
     * All users currently assigned to this flag issue <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}
(function (FlagIssueEditAction) {
    let FlagIssueStatusIdEnum;
    (function (FlagIssueStatusIdEnum) {
        FlagIssueStatusIdEnum[FlagIssueStatusIdEnum["NUMBER_1"] = 1] = "NUMBER_1";
        FlagIssueStatusIdEnum[FlagIssueStatusIdEnum["NUMBER_2"] = 2] = "NUMBER_2";
    })(FlagIssueStatusIdEnum = FlagIssueEditAction.FlagIssueStatusIdEnum || (FlagIssueEditAction.FlagIssueStatusIdEnum = {}));
})(FlagIssueEditAction || (FlagIssueEditAction = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueEventChild {
    /**
     * The flag issue event identifier
     */
    flagIssueEventId;
    createdBy;
    /**
     * Date that this flag issue event was created
     */
    createdDate;
    /**
     * Comment about the flag issue event
     */
    comment;
    /**
     * Description of the flag issue event
     */
    description;
    flagIssueAction;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueListAction {
    /**
     * The flag issues to update <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    flagIssueIds;
    flagIssueAction;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueResponse {
    /**
     * The flag issue identifier
     */
    flagIssueId;
    flagIssueType;
    flagIssueStatus;
    /**
     * All events and actions that have occurred with this issue
     */
    flagIssueEvents;
    /**
     * All users currently assigned to this issue
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueStatusChild {
    /**
     * The flag issue status identifier
     */
    flagIssueStatusId;
    /**
     * Flag issue status information
     */
    flagIssueStatusInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagIssueTypeChild {
    /**
     * The flag issue type identifier
     */
    flagIssueTypeId;
    /**
     * Flag issue info
     */
    flagIssueTypeInfo;
    /**
     * More detailed description of the flag issue type
     */
    flagIssueTypeDescription;
    /**
     * Flag issue category
     */
    flagIssueCategory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagListAction {
    /**
     * The entities to update <span class='property-internal'>Required (defined)</span>
     */
    entityIds;
    flagAction;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagResponse {
    /**
     * The flag identifier
     */
    flagId;
    flagType;
    flagStatus;
    createdBy;
    /**
     * Date the flag was created
     */
    createdDate;
    modifiedBy;
    /**
     * Latest date the flag was modified
     */
    modifiedDate;
    /**
     * Cost recovery associated with the issue this flag represents
     */
    costRecovery;
    /**
     * All events and actions that have occurred with this flag
     */
    flagEvents;
    /**
     * All users currently assigned to this flag
     */
    assignees;
    /**
     * All issues associated with the flag  Even if the flag is marked as resolved, the list of issues that were on the flag at that time will remain.  This keeps a historic record and allows for filtering.
     */
    flagIssues;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagStatusChild {
    /**
     * The flag status identifier
     */
    flagStatusId;
    /**
     * Flag status information
     */
    flagStatusInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagTypeChild {
    /**
     * The flag type identifier
     */
    flagTypeId;
    /**
     * Flag type information
     */
    flagTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagTypeCreate {
    /**
     * The name of the flag type being created <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 32 characters</span>
     */
    flagTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagWidget {
    /**
     * The type of entity we are grouping bill flags by - Meter, Account or Building
     */
    viewBy;
    /**
     * The status of bill flags - Unresolved or Resolved
     */
    flagStatus;
    /**
     * Total cost for all the bills that are represented by the bill flags
     */
    totalCost;
    /**
     * Total cost recovery represented by the bill flags
     */
    totalCostRecovery;
    /**
     * Total number of bill flags represented
     */
    flagCount;
    /**
     * List of bill flag rows  The rows are sorted by highest cost , then by highest cost recovery, and then by the item's display alphabetically
     */
    results;
    /**
     * Total number of results available  If pagination was applied, Results list will have \"pagesize\" out of  TotalNumberOfResults  If pagination was not applied, Results list will have 100 out of  TotalNumberOfResults
     */
    totalNumberOfResults;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlagWidgetChild {
    /**
     * Identifier for the item could be meterId, placeId, accountId
     */
    itemId;
    /**
     * Item display (name or code)
     */
    itemDisplay;
    /**
     * If item is a meter, this will be commodityCode  If item is a building, this will say BUILDING  If item is a account, this will say ACCOUNT
     */
    itemType;
    /**
     * Identifier for the parent of the item could be placeId, costCenterId
     */
    parentId;
    /**
     * Parent display (name or code)
     */
    parentDisplay;
    /**
     * If parent is a building, this will say BUILDING  For all other types, it will say ORGANIZATION  If parent is a costcenter, this will say COSTCENTER
     */
    parentItemType;
    /**
     * If the view is by Account or Meter, true indicates the account or meter is a master for a \"Bill split\"
     */
    splitParent;
    /**
     * If the view is by Account or Meter, true indicates the account or meter is a recipient of a \"Bill split\"
     */
    splitChild;
    /**
     * If the view is by Account or Meter, true indicates the account or meter is part of a \"Bill calculation\"
     */
    calculated;
    /**
     * If the view is by Account or Meter, true indicates the account or meter is active
     */
    active;
    /**
     * Total cost of all the bills that have flags for this item
     */
    cost;
    /**
     * Total cost recovery for bill flags for this item
     */
    costRecovery;
    /**
     * Total number of bill flags for this item
     */
    flagCount;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlaggedItems {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FlaggedItemsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FloorAreaSplit {
    /**
     * Destination account ID  There must be an existing relationship between the DestinationAccountId and DestinationMeterId <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (CostCenter)</span>
     */
    destinationAccountId;
    /**
     * Destination meter ID  There must be an existing relationship between the DestinationAccountId and DestinationMeterId <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (LogicalDevice)</span>
     */
    destinationMeterId;
    /**
     * Weighting factor to apply in floor area bill split for this account and meter <span class='property-info'>Max scale of 8</span> <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 1.7976931348623157E+308</span>
     */
    weightingFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FloorAreaSplitResponse {
    destinationAccount;
    destinationMeter;
    destinationPlace;
    /**
     * Weighting factor to apply in floor area bill split for this account and meter
     */
    weightingFactor;
    /**
     * Fixed percentage to apply in bill split for this account and meter
     */
    splitPercentage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FormTemplateChild {
    /**
     *
     */
    formTemplateId;
    /**
     *
     */
    displayOrder;
    template;
    /**
     *
     */
    beginDate;
    /**
     *
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FormTemplateRequest {
    /**
     * The identifier for the template being assigned <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    templateId;
    /**
     * The begin date of the template assignment <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    beginDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FormTemplateResponse {
    /**
     * The identifier for the template assignment <span class='property-internal'>Required (defined)</span>
     */
    formTemplateId;
    template;
    /**
     * The display order for the bill entry screen <span class='property-internal'>Required (defined)</span>
     */
    displayOrder;
    /**
     * The begin date of the template assignment <span class='property-internal'>Required (defined)</span>
     */
    beginDate;
    /**
     * The end date of the template assignment <span class='property-internal'>Required (defined)</span>
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FormulaValidationRequest {
    /**
     *  <span class='property-internal'>Required</span>
     */
    formula;
    /**
     *
     */
    dataPointId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class FormulaValidationResponse {
    /**
     *
     */
    valid;
    /**
     *
     */
    errorMessages;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Frequency {
    /**
     * Frequency of special adjustment (Continuous or Recurring)
     */
    frequency;
    /**
     * Start date
     */
    startDate;
    /**
     * End date
     */
    endDate;
    /**
     * Frequency start period
     */
    annualCycleStartMMDD;
    /**
     * Frequency end period
     */
    annualCycleEndMMDD;
    /**
     * Frequency cycle beginning of recurrence (format is MMM DD)
     */
    annualCycleStartInfo;
    /**
     * Frequency cycle end of recurrence (format is MMM DD)
     */
    annualCycleEndInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGBuildingRank {
    placeInfo;
    /**
     * The place size
     */
    placeSize;
    placeSizeUnit;
    /**
     * The overall Greenhouse Gas emissions
     */
    emissions;
    /**
     * The Greenhouse Gas emissions from Scope 1
     */
    scope1Emissions;
    /**
     * The Greenhouse Gas emissions from Scope 2
     */
    scope2Emissions;
    /**
     * The Greenhouse Gas emissions from Scope 3
     */
    scope3Emissions;
    emissionsUnit;
    /**
     * The Greenhouse Gas intensity. Emissions/Place Size
     */
    intensity;
    /**
     * The item type
     */
    type;
    /**
     * The item identifier
     */
    id;
    /**
     * The item display name
     */
    display;
    /**
     * The item formated value
     */
    secondaryDisplay;
    /**
     * The item value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGCarbonFootprintResponse {
    periodRange;
    targetData;
    /**
     * GHG Emissions data, split by year, then by group and gas type.
     */
    yearlyData;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGDefaultFactor {
    /**
     * The Greenhouse Gas Factor identifier <span class='property-internal'>Required when FactorType is set to specific factor</span> <span class='property-internal'>Must be null when FactorType  is  set to use meter address</span>
     */
    factorId;
    /**
     * The Greenhouse Gas Factor type.  The valid values for this field are \"use meter address\" or \"specific factor\" <span class='property-internal'>Required</span> <span class='property-internal'>One of 'use meter address', 'specific factor'</span>
     */
    factorType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactor {
    /**
     * The GHG Factor type.  Values for this field can be \"use meter address\" or \"specific factor\"
     */
    factorType;
    factorCategory;
    /**
     * The Factor Identifier
     */
    factorId;
    /**
     * The Factor Info
     */
    factorInfo;
    /**
     * The Factor Description
     */
    factorDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactorCategory {
    /**
     * The Factor Category identifier
     */
    factorCategoryId;
    /**
     * The Factor Category Info
     */
    factorCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactorChild {
    /**
     * The Factor Identifier
     */
    factorId;
    /**
     * The Factor Info
     */
    factorInfo;
    /**
     * The Factor Description
     */
    factorDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactorRegion {
    /**
     * The Factor Region identifier
     */
    factorRegionId;
    /**
     * The Factor Region info
     */
    factorRegionInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactorResponse {
    /**
     * The factor identifier
     */
    factorId;
    /**
     * The factor code
     */
    factorCode;
    /**
     * The factor info
     */
    factorInfo;
    /**
     * The factor description
     */
    factorDescription;
    /**
     * The source organization
     */
    sourceOrganization;
    /**
     * The model
     */
    model;
    factorCategory;
    fromUnit;
    factorRegion;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactorVersionHistoryResponse {
    /**
     * Identifier for the factor
     */
    factorId;
    /**
     * Name of the factor
     */
    factorInfo;
    /**
     * Description of the factor
     */
    factorDescription;
    factorUnit;
    factorCO2EUnit;
    commodityUnit;
    commodity;
    factorCategory;
    /**
     * List of versions
     */
    versions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGFactorsResponse {
    /**
     * The identifier for ghg factor
     */
    ghgFactorId;
    /**
     * The ghg factor
     */
    ghgFactor;
    /**
     * The ghg CO2 factor
     */
    ghgCO2Factor;
    /**
     * The start date
     */
    startDate;
    /**
     * The end date
     */
    endDate;
    /**
     * The description
     */
    description;
    /**
     * The notes
     */
    memo;
    ghgType;
    commodityUnit;
    ghgUnit;
    commodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGGas {
    /**
     * Gas identifier
     */
    gasId;
    /**
     * Gas descrption
     */
    gasInfo;
    /**
     * Gas amount
     */
    gasAmount;
    /**
     * Co2Evalue
     */
    co2Evalue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGGroupEmissions {
    /**
     * The name of the greenhouse gas.
     */
    groupInfo;
    /**
     * The total emissions for this gas, in CO2 Equivalent.
     */
    totalEmissions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGPerformanceComparison {
    /**
     * The record type
     */
    type;
    /**
     * The performance comparison identifier
     */
    id;
    /**
     * The label
     */
    label;
    /**
     * The current use
     */
    currentUse;
    /**
     * The current cost
     */
    currentCost;
    /**
     * The current emissions
     */
    currentEmissions;
    /**
     * The previous use
     */
    previousUse;
    /**
     * The previous cost
     */
    previousCost;
    /**
     * The previous emissions
     */
    previousEmissions;
    /**
     * The use KPI variance
     */
    usePercentDiff;
    /**
     * The cost KPI variance
     */
    costPercentDiff;
    /**
     * The emission KPI variance
     */
    emissionsPercentDiff;
    useUnit;
    emissionsUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGScope {
    /**
     * The Scope Identifier
     */
    scopeId;
    /**
     * The Scope Info
     */
    scopeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGScopeCategory {
    scope;
    /**
     * The GHG Scope Category Identifier
     */
    scopeCategoryId;
    /**
     * The GHG Scope Category Info
     */
    scopeCategoryInfo;
    /**
     * The GHG Scope Category Description
     */
    scopeCategoryDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGScopeCategoryChild {
    /**
     * The GHG Scope Category Identifier
     */
    scopeCategoryId;
    /**
     * The GHG Scope Category Info
     */
    scopeCategoryInfo;
    /**
     * The GHG Scope Category Description
     */
    scopeCategoryDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGScopeResponse {
    /**
     * The Scope Identifier
     */
    scopeId;
    /**
     * The Scope Info
     */
    scopeInfo;
    /**
     * The list of Scope Categories under this scope
     */
    scopeCategories;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGSettingResponse {
    scopeCategory;
    factor;
    /**
     * If true, this meter is using the default GHG settings that were in effect at the time the meter was created
     */
    usingDefaultSettings;
    /**
     * Flag indicating whether or not configuration exists for this meter.   If false, EnergyCap.DTO.V202210.GHG.GHGSettingResponseDTO.Factor or EnergyCap.DTO.V202210.GHG.GHGSettingResponseDTO.ScopeCategory may be null.
     */
    isConfigured;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGSettings {
    /**
     * The GHG Global Warming Assessment Report (AR) identifier
     */
    globalWarmingAssessmentReportId;
    /**
     * The GHG Global Warming Assessment Report (AR) name
     */
    globalWarmingAssessmentReportInfo;
    reportingUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGTargetEmissions {
    baseTargetYear;
    adjustedTargetYear;
    adjustedYTDTargetYear;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGTypeChild {
    /**
     * The identifier for the ghg type
     */
    ghgTypeId;
    /**
     * The ghg type code
     */
    ghgTypeCode;
    /**
     * The ghg type info
     */
    ghgTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGVersion {
    /**
     * Effective Date
     */
    effectiveDate;
    /**
     * Source
     */
    source;
    /**
     * List of gases per version.
     */
    gases;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGYearlyEmissions {
    /**
     * The year this data belongs to.
     */
    year;
    /**
     * The total emissions for this year, in CO2 Equivalent
     */
    totalYearlyEmissions;
    /**
     * A percentage value that represents how close to the target year this year's data is. A positive value  means the current year is over the target, a negative value means the current year is under the target.  Field is null if target data is not available.
     */
    targetPerformancePercentage;
    /**
     * The total emissions for this year, grouped by gas type.
     */
    yearlyEmissionsByGasType;
    /**
     * The total emissions for this year, grouped by Scope, Commodity, or Scope Category.
     */
    yearlyEmissionsByGroup;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasDefaultSettingRequest {
    /**
     * Do we want to an create emission source automatically when we create a new meter? <span class='property-internal'>Required (defined)</span>
     */
    createEmissionSourcesForMeters;
    /**
     * The Commodity default settings <span class='property-internal'>Required</span>
     */
    defaultSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasDefaultSettingRequestCommodityChild {
    /**
     * The Commodity ID <span class='property-internal'>Required (defined)</span>
     */
    commodityId;
    /**
     * The Commodity default settings <span class='property-internal'>Required</span>
     */
    defaultSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasDefaultSettingRequestScopeCategoryAndFactorChild {
    /**
     * The Greenhouse Gas Scope category identifier <span class='property-internal'>Required (defined)</span>
     */
    scopeCategoryId;
    defaultFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasDefaultSettingResponse {
    /**
     * Do we want to an create emission source automatically when we create a new meter?
     */
    createEmissionSourcesForMeters;
    /**
     * The default commodity settings
     */
    defaultSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasDefaultSettingResponseCommodityChild {
    /**
     * The Commodity default settings
     */
    defaultSettings;
    /**
     * The Commodity ID
     */
    commodityId;
    /**
     * The Commodity Code
     */
    commodityCode;
    /**
     * The Commodity Info
     */
    commodityInfo;
    commodityIcon;
    /**
     * Flag to indicate if the commodity is assigned to any meters
     */
    inUseByVendor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasFactorAndScopeCategoryPair {
    /**
     * Flag to indicate if this pair is the default Factor/Category pair for an Emission Source
     */
    isDefaultFactor;
    scopeCategory;
    factor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasFactorAndScopeCategoryPairCreate {
    factor;
    /**
     * The Scope Category ID to use for this Factor/Category Pairing <span class='property-internal'>Required (defined)</span>
     */
    scopeCategoryId;
    /**
     * Flag to indicate if this Factor and Category should be considered the default for this Emission Source <span class='property-internal'>Required (defined)</span>
     */
    isDefault;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasFactorChild {
    /**
     * The identifier for this factor
     */
    factorId;
    /**
     * The code for this factor
     */
    factorCode;
    /**
     * The name of this factor
     */
    factorInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GHGasScopeCategoryChild {
    /**
     * The identifier for this Scope Category
     */
    scopeCategoryId;
    /**
     * The name of this Scope Category
     */
    scopeCategoryInfo;
    /**
     * The description of this Scope Category
     */
    scopeCategoryDescription;
    /**
     * The Scope this Scope Category belongs to
     */
    scopeId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GLSubCodeChild {
    /**
     * Index of this subcode (01-20)
     */
    subCodeIndex;
    /**
     * Name for this SubCode
     */
    subCodeName;
    /**
     * The value assigned to the subcode
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GLSubCodeChildRequest {
    /**
     * Index of this sub code (1-20) <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 20</span>
     */
    subCodeIndex;
    /**
     * Value for the sub code <span class='property-internal'>Must be between 0 and 25 characters</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GLSubcodeRequest {
    /**
     * Index of this subcode (1-20) <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 20</span>
     */
    subCodeIndex;
    /**
     * Name for this SubCode <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    subCodeName;
    /**
     * SubCodeType - should be \"list\"(fixed=1 in DB) or \"text\" (fixed=0 in DB) <span class='property-internal'>Required</span> <span class='property-internal'>One of 'list', 'text'</span>
     */
    subCodeType;
    /**
     * An array of pick list values when this subcode is a \"list\" <span class='property-internal'>Required when subCodeType is set to list</span>
     */
    subCodeValues;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GLSubcodeResponse {
    /**
     * Index of this subcode (01-20)
     */
    subCodeIndex;
    /**
     * Name for this SubCode
     */
    subCodeName;
    /**
     * SubCodeType - will be \"list\"(if fixed=1 in DB) or \"text\" (if fixed=0) in DB
     */
    subCodeType;
    /**
     * An array of pick list values when this subcode is a \"list\"
     */
    subCodeValues;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GeneralLedgerChild {
    /**
     *
     */
    generalLedgerId;
    /**
     *
     */
    generalLedgerCode;
    /**
     *
     */
    generalLedgerInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GeneralLedgerRequest {
    /**
     * Unique identifier for the General Ledger <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    generalLedgerCode;
    /**
     * List of 20 sub codes and their values <span class='property-internal'>Required</span>
     */
    subCodes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GeneralLedgerResponse {
    /**
     * General Ledger Identifier
     */
    generalLedgerId;
    /**
     * Unique code for the general ledger
     */
    generalLedgerCode;
    /**
     * List of 20 subCodes with their index, name, and value
     */
    subCodes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Representation of a generic \"empty\" bodyline which is not associated with a specific bill or template
 */
class GenericBodylineRequest {
    /**
     * The observation type  For account body lines the observation type must be a charge type <span class='property-internal'>Required when CalculationType is set to Fixed, or Percentage</span>
     */
    observationTypeId;
    /**
     * The caption <span class='property-internal'>Must be between 0 and 100 characters</span> <span class='property-internal'>Required when CalculationType is set to Fixed, or Percentage, or Subtotal</span>
     */
    caption;
    /**
     * The calculation type for the line item <span class='property-internal'>One of 'Fixed', 'Percentage', 'Subtotal'</span> <span class='property-internal'>Required (defined)</span>
     */
    calculationType;
    /**
     * The bodyline's value  When CalculationType is Fixed.  Precision max is 2  When CalculationType is Percentage.  Precision max is 8 <span class='property-internal'>Required when CalculationType is set to Fixed, or Percentage</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Representation of a generic \"empty\" bodyline which is not associated with a specific bill or template
 */
class GenericBodylineResponse {
    observationType;
    /**
     * The caption
     */
    caption;
    /**
     * The calculation type for the line item.  Either \"Fixed\", \"Percentage\", or \"Subtotal\"
     */
    calculationType;
    /**
     * The bodyline's value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GenericCount {
    /**
     * Number of items
     */
    count;
    /**
     * A short description of the items counted
     */
    description;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GlobalCostAvoidanceSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GlobalCostAvoidanceSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GreenhouseGasAdministrator {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GreenhouseGasAdministratorClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Display settings for the user when viewing benchmark charts
 */
class GroupDisplaySetting {
    /**
     * Date period type  Possible value include 1 (Last Twelve Months), 2 (Last Calendar Year), 3 (Last Fiscal Year), 4 (User Defined Range) <span class='property-internal'>One of '1', '2', '3', '4'</span> <span class='property-internal'>Case sensitive</span>
     */
    periodType;
    /**
     * Benchmark Chart Start Period when using Period Type 4 (User Defined Range)  Will return null for all other period types <span class='property-internal'>Required when PeriodType is set to 4, case sensitive.</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span> <span class='property-internal'>NULL Valid</span>
     */
    userDefinedRangeStartPeriod;
    /**
     * Benchmark Chart End Period when using Period Type 4 (User Defined Range)  Will return null for all other period types <span class='property-internal'>Required when PeriodType is set to 4, case sensitive.</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Must be greater than or equal to UserDefinedRangeStartPeriod</span>
     */
    userDefinedRangeEndPeriod;
    /**
     * Data view (actual, calendarized, normalized) <span class='property-internal'>One of 'actual', 'calendarized', 'normalized'</span> <span class='property-internal'>Case sensitive</span>
     */
    dataView;
    /**
     * Unique identifier of the commodity by which benchmark charts will be filtered
     */
    commodityId;
    /**
     * Unique identifier of the commodity category by which benchmark charts will be filtered
     */
    commodityCategoryId;
    /**
     * Indicates whether or not to show excluded group members
     */
    showExcludedMembers;
    /**
     * Indicates whether or not to show zero averages in benchmark charts
     */
    showZeroAverages;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GroupMemberRequest {
    /**
     * The flag determining whether the member is included in group charts <span class='property-internal'>Required</span>
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GroupMeterGroupResponse {
    /**
     * The meter group identifier
     */
    meterGroupId;
    /**
     * The meter group code
     */
    meterGroupCode;
    /**
     * The meter group info
     */
    meterGroupInfo;
    /**
     * Indicates if this meter group is an autogroup
     */
    autoGroup;
    /**
     * The number of meters in this group
     */
    memberCount;
    /**
     * The number of meters within the currently authenticated user's topmost
     */
    memberCountWithTopmost;
    meterGroupCategory;
    /**
     * Indicates if the meter group has been set limit the list of members by the user's topmost
     */
    limitMembersByTopmost;
    /**
     * Indicates if this meter group is an user defined auto group
     */
    userDefinedAutoGroup;
    /**
     * The filters applied to determine the members of a user defined auto group
     */
    userDefinedAutoGroupFilters;
    /**
     * The last time a member was inserted, updated, or deleted from the group
     */
    lastUpdated;
    /**
     * The commodity code for the meters in this group -   if all meters belong to the same commodity the commodity code will be used here  if meters belong to different commodities, value will be \"MULTIPLE\"  if this group has no meters, value will be \"\"
     */
    memberCommodityCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GroupPlaceGroupMember {
    /**
     * The place identifier <span class='property-internal'>Required (defined)</span>
     */
    placeId;
    /**
     * The place code <span class='property-internal'>Required (defined)</span>
     */
    placeCode;
    /**
     * The place info <span class='property-internal'>Required (defined)</span>
     */
    placeInfo;
    parent;
    placeType;
    /**
     * The flag determining whether the place is included in group charts <span class='property-internal'>Required (defined)</span>
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GroupPlaceGroupResponse {
    /**
     * The place group identifier
     */
    placeGroupId;
    /**
     * The place group code
     */
    placeGroupCode;
    /**
     * The place group info
     */
    placeGroupInfo;
    /**
     * Indicates if this place group is an autogroup
     */
    autoGroup;
    /**
     * The number of places in this group
     */
    memberCount;
    /**
     * The number of places within the currently authenticated user's topmost
     */
    memberCountWithTopmost;
    placeGroupCategory;
    /**
     * Indicates if the place group has been set limit the list of members by the user's topmost
     */
    limitMembersByTopmost;
    /**
     * Indicates if this place group is an user defined auto group
     */
    userDefinedAutoGroup;
    /**
     * The filters applied to determine the members of a user defined auto group
     */
    userDefinedAutoGroupFilters;
    /**
     * The last time a member was inserted, updated, or deleted from the group
     */
    lastUpdated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GroupsAndBenchmarksModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GroupsAndBenchmarksModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class GuidResponse {
    /**
     * A guid that identifies the current task
     */
    taskGUId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HiddenRequest {
    /**
     * Set a system user role to be hidden or shown  Roles Manage permission is required to access hidden roles <span class='property-internal'>Required</span>
     */
    hidden;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalCollections {
    /**
     * The collection's parent
     */
    parentId;
    /**
     * The collection's primary ID
     */
    collectionId;
    /**
     * The collection info
     */
    collectionInfo;
    /**
     * The collection code
     */
    collectionCode;
    collectionIcon;
    /**
     * If this collection has any children, either emission sources or collections
     */
    hasChildren;
    /**
     * If this collection has any collection children
     */
    hasCollectionChildren;
    /**
     * If this collection has any emission source children
     */
    hasEmissionSourceChildren;
    /**
     * If this collection has any collection children or active emission source children
     */
    hasActiveChildren;
    /**
     * If this collection has any active emission source children
     */
    hasActiveEmissionSourceChildren;
    /**
     * List of emission source children
     */
    emissionSourceChildren;
    /**
     * List of collection children
     */
    collectionChildren;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalCollections2 {
    /**
     *
     */
    parentId;
    /**
     *
     */
    collectionId;
    /**
     *
     */
    collectionInfo;
    /**
     *
     */
    collectionCode;
    collectionIcon;
    /**
     *
     */
    hasChildren;
    /**
     *
     */
    hasCollectionChildren;
    /**
     *
     */
    hasEmissionSourceChildren;
    /**
     *
     */
    hasActiveChildren;
    /**
     *
     */
    hasActiveEmissionSourceChildren;
    /**
     *
     */
    emissionSourceChildren;
    /**
     *
     */
    collectionChildren;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalCostCenters {
    /**
     * The cost center's parent
     */
    parentId;
    /**
     * The cost center's primary ID
     */
    costCenterId;
    /**
     * CostCenterInfo
     */
    costCenterInfo;
    /**
     * CostCenterCode
     */
    costCenterCode;
    /**
     * If this costCenter has any children, either accounts or costCenters
     */
    hasChildren;
    /**
     * If this costCenter has any costCenter children
     */
    hasCostCenterChildren;
    /**
     * If this costCenter has any account children
     */
    hasAccountChildren;
    /**
     * If this costCenter has any costCenter children or active account children
     */
    hasActiveChildren;
    /**
     * If this costCenter has any active account children
     */
    hasActiveAccountChildren;
    /**
     * List of account children
     */
    accountChildren;
    /**
     * List of costCenter children
     */
    costCenterChildren;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalCostCenters2 {
    /**
     *
     */
    parentId;
    /**
     *
     */
    costCenterId;
    /**
     *
     */
    costCenterInfo;
    /**
     *
     */
    costCenterCode;
    /**
     *
     */
    hasChildren;
    /**
     *
     */
    hasCostCenterChildren;
    /**
     *
     */
    hasAccountChildren;
    /**
     *
     */
    hasActiveChildren;
    /**
     *
     */
    hasActiveAccountChildren;
    /**
     *
     */
    accountChildren;
    /**
     *
     */
    costCenterChildren;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalDataPoint {
    /**
     * The data point identifier
     */
    dataPointId;
    /**
     * The data point code
     */
    dataPointCode;
    /**
     * The data point info
     */
    dataPointInfo;
    commodity;
    /**
     * Indicates whether the data point is Active
     */
    active;
    /**
     * Indicates whether the data point is a calculated data point
     */
    isCalculatedDataPoint;
    /**
     * The data point's current serial number
     */
    serialNumber;
    /**
     * Indicates if the primary value channel on the datapoint has a summarization method of SUM
     */
    isDataRolledUp;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalEmissionSource {
    /**
     * Indicates if the emission source has a EUM Meter link
     */
    hasEUMMeter;
    /**
     * The emission source identifier
     */
    emissionSourceId;
    /**
     * The emission source code
     */
    emissionSourceCode;
    /**
     * The emission source info
     */
    emissionSourceInfo;
    /**
     * Whether the emission source is active or not
     */
    active;
    commodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalMeter {
    /**
     * Indicates if the meter has a Smart Analytics (Wattics) Data Point link
     */
    hasWatticsDataPoint;
    /**
     * Indicates if the meter has an Emission Source link
     */
    hasEmissionSource;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalPlaces {
    /**
     * The place's parent
     */
    parentId;
    /**
     * The place's primary ID
     */
    placeId;
    /**
     * PlaceInfo
     */
    placeInfo;
    /**
     * PlaceCode
     */
    placeCode;
    /**
     * PlaceTypeID
     */
    placeTypeId;
    /**
     * If this place has any children, either meters or places
     */
    hasChildren;
    /**
     * If this place has any place children
     */
    hasPlaceChildren;
    /**
     * If this place has any meter children
     */
    hasMeterChildren;
    /**
     * If this place has any place children or active meter children
     */
    hasActiveChildren;
    /**
     * If this place has any active meter children
     */
    hasActiveMeterChildren;
    placeType;
    /**
     * List of meter children
     */
    meterChildren;
    /**
     * List of place children
     */
    placeChildren;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalPlaces2 {
    /**
     *
     */
    parentId;
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeInfo;
    /**
     *
     */
    placeCode;
    /**
     *
     */
    placeTypeId;
    /**
     *
     */
    hasChildren;
    /**
     *
     */
    hasPlaceChildren;
    /**
     *
     */
    hasMeterChildren;
    /**
     *
     */
    hasActiveChildren;
    /**
     *
     */
    hasActiveMeterChildren;
    placeType;
    /**
     *
     */
    meterChildren;
    /**
     *
     */
    placeChildren;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalSpaces {
    /**
     * The place's parent
     */
    parentId;
    /**
     * The place's primary ID
     */
    placeId;
    /**
     * The place's Info
     */
    placeInfo;
    /**
     * The place's Code
     */
    placeCode;
    placeType;
    /**
     * If this place has any children, either datapoins or places
     */
    hasChildren;
    /**
     * If this place has any space children
     */
    hasSpaceChildren;
    /**
     * If this place has any data point children
     */
    hasDataPointChildren;
    /**
     * If this place has any active space children or active data point children
     */
    hasActiveChildren;
    /**
     * If this place has any active data point children
     */
    hasActiveDataPointChildren;
    /**
     * List of data point children
     */
    dataPointChildren;
    /**
     * List of place children
     */
    spaceChildren;
    /**
     * Tells whether or not the place's data is rolled up to its parents.
     */
    isDataRolledUp;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HierarchicalSpaces2 {
    /**
     *
     */
    parentId;
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeInfo;
    /**
     *
     */
    placeCode;
    placeType;
    /**
     *
     */
    hasChildren;
    /**
     *
     */
    hasSpaceChildren;
    /**
     *
     */
    hasDataPointChildren;
    /**
     *
     */
    hasActiveChildren;
    /**
     *
     */
    hasActiveDataPointChildren;
    /**
     *
     */
    dataPointChildren;
    /**
     *
     */
    spaceChildren;
    /**
     *
     */
    isDataRolledUp;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class HighPrecisionTimeSeriesValue {
    /**
     *
     */
    date;
    /**
     * Value, as a decimal. Note that this could be very large, and/or to a high degree of  precision. In particular, in Javascript, it might not be able to be precisely  represented in a 64-bit float. See: `formattedValue`.
     */
    value;
    /**
     * Value, serialized as a String. This is the value that should be displayed to the  User. If Value is very large or to a high degree of precision its Number value  in Javascript cannot be relied upon. Other client languages might have similar  limitations. In order to guarantee that Value is displayed to the User to the  same degree of precision as is stored in the readings database, this  `formattedValue` property must be used.
     */
    formattedValue;
    /**
     * The Unit that `Value` is expressed in. E.g. \"kWh\".
     */
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Time series value DTO. Includes a `formattedValue` to overcome client Number-parsing limitations.
 */
class HighPrecisionValue {
    /**
     * Value, as a decimal. Note that this could be very large, and/or to a high degree of  precision. In particular, in Javascript, it might not be able to be precisely  represented in a 64-bit float. See: `formattedValue`.
     */
    value;
    /**
     * Value, serialized as a String. This is the value that should be displayed to the  User. If Value is very large or to a high degree of precision its Number value  in Javascript cannot be relied upon. Other client languages might have similar  limitations. In order to guarantee that Value is displayed to the User to the  same degree of precision as is stored in the readings database, this  `formattedValue` property must be used.
     */
    formattedValue;
    /**
     * The Unit that `Value` is expressed in. E.g. \"kWh\".
     */
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IActionResult {
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IGHGDefaultScopeCategoryAndFactor {
    defaultScopeCategory;
    defaultFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IOutputFormatter {
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Icon {
    /**
     * The icon code <span class='property-internal'>Must be between 0 and 64 characters</span> <span class='property-internal'>Required when Color is set</span>
     */
    code;
    /**
     * The icon color <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required when Code is set</span>
     */
    color;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IntervalData {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IntervalDataAnalysis {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IntervalDataAnalysisClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IntervalDataClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IntervalDataRollup {
    /**
     *
     */
    run;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class IntervalDataRollupClassPermission {
    /**
     *
     */
    run;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ItemRankResponse {
    /**
     * The item type
     */
    type;
    /**
     * The item identifier
     */
    id;
    /**
     * The item display name
     */
    display;
    /**
     * The item formated value
     */
    secondaryDisplay;
    /**
     * The item value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ItemRankWithUnitResponse {
    valueUnit;
    /**
     * The item type
     */
    type;
    /**
     * The item identifier
     */
    id;
    /**
     * The item display name
     */
    display;
    /**
     * The item formated value
     */
    secondaryDisplay;
    /**
     * The item value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportAccount {
    /**
     *
     */
    accountId;
    /**
     *
     */
    accountCode;
    /**
     *
     */
    accountInfo;
    accountType;
    address;
    vendor;
    /**
     *
     */
    customFields;
    /**
     *
     */
    meters;
    /**
     *
     */
    generalLedgers;
    /**
     *
     */
    lines;
    /**
     *
     */
    cost;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportGeneralLedger {
    /**
     *
     */
    generalLedgerId;
    /**
     *
     */
    generalLedgerCode;
    /**
     *
     */
    generalLedgerInfo;
    /**
     *
     */
    subCode01;
    /**
     *
     */
    subCode02;
    /**
     *
     */
    subCode03;
    /**
     *
     */
    subCode04;
    /**
     *
     */
    subCode05;
    /**
     *
     */
    subCode06;
    /**
     *
     */
    subCode07;
    /**
     *
     */
    subCode08;
    /**
     *
     */
    subCode09;
    /**
     *
     */
    subCode10;
    /**
     *
     */
    subCode11;
    /**
     *
     */
    subCode12;
    /**
     *
     */
    subCode13;
    /**
     *
     */
    subCode14;
    /**
     *
     */
    subCode15;
    /**
     *
     */
    subCode16;
    /**
     *
     */
    subCode17;
    /**
     *
     */
    subCode18;
    /**
     *
     */
    subCode19;
    /**
     *
     */
    subCode20;
    /**
     *
     */
    lines;
    /**
     *
     */
    cost;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportLine {
    /**
     *
     */
    bodyLineId;
    /**
     *
     */
    caption;
    /**
     *
     */
    value;
    /**
     *
     */
    valueIsInfoOnly;
    /**
     *
     */
    cost;
    /**
     *
     */
    costIsInfoOnly;
    valueUnit;
    costUnit;
    observationType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportMeter {
    /**
     *
     */
    meterId;
    /**
     *
     */
    meterCode;
    /**
     *
     */
    meterInfo;
    meterType;
    address;
    commodity;
    /**
     *
     */
    serialNumber;
    rate;
    place;
    /**
     *
     */
    customFields;
    /**
     *
     */
    generalLedgers;
    /**
     *
     */
    lines;
    /**
     *
     */
    nativeUse;
    nativeUseUnit;
    /**
     *
     */
    cost;
    costUnit;
    /**
     *
     */
    nativeBilledDemand;
    nativeBilledDemandUnit;
    /**
     *
     */
    nativeActualDemand;
    nativeActualDemandUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportPlace {
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeCode;
    /**
     *
     */
    placeInfo;
    placeType;
    address;
    /**
     *
     */
    customFields;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportResponse {
    /**
     * The bill identifier
     */
    billId;
    /**
     * Indicates if the bill has been voided
     */
    void;
    /**
     * Indicates if the bill is from a vendor
     */
    fromVendor;
    /**
     * The method used to create the bill Automatic, Manual, Estimated, Simulated, Accrual, or Adjustment
     */
    creationMethod;
    /**
     * Indicates if the bill is an accrual
     */
    accrual;
    /**
     * Indicates if the bill is a reversed accrual
     */
    accrualReversed;
    batch;
    /**
     * The date the batch was closed
     */
    batchEndDate;
    createdBy;
    /**
     * The date and time the bill was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * Indicates if the bill has been approved
     */
    approved;
    /**
     * The date and time the bill was approved
     */
    approveDate;
    approvedBy;
    /**
     * Indicates if the bill has been split
     */
    hasBeenSplit;
    /**
     * The date and time the bill was split
     */
    wasSplitDate;
    /**
     * Indicates if the bill is being withheld from bill exports
     */
    exportHold;
    /**
     * Indicates if the bill has been ap exported
     */
    apExported;
    /**
     * The date and time the bill was ap exported
     */
    apExportDate;
    apExportedBy;
    /**
     * Indicates if the bill has been gl exported
     */
    glExported;
    glExportedBy;
    /**
     * The date and time the bill was exported to gl
     */
    glExportDate;
    /**
     * Indicates if the bill has been exported to bill payment
     */
    paymentExported;
    paymentExportedBy;
    /**
     * The date and time the bill was exported to bill payment
     */
    paymentExportDate;
    /**
     * The method used to upload the bill to BillCAPture, if applicable
     */
    bcAcquisitionMethod;
    /**
     * The date and time the bill was received by BillCAPture
     */
    bcReceived;
    /**
     * The date and time the bill entered processing in BillCAPture
     */
    bcSentToProcessing;
    /**
     * The date and time the bill was returned from processing in BillCAPture
     */
    bcReturnedFromProcessing;
    /**
     * The date and time the bill processing was completed in BillCAPture
     */
    bcProcessingComplete;
    /**
     * The number of the check that the bill was paid with
     */
    checkNumber;
    /**
     * The date and time of the check
     */
    checkDate;
    /**
     * The payment status of the bill
     */
    payStatus;
    /**
     * The date when funds were withdrawn
     */
    fundsWithdrawnDate;
    /**
     * The date and time that the check cleared
     */
    clearedDate;
    /**
     * The payment type of the bill.   For example, Check, VCard, and ACH.
     */
    paymentType;
    /**
     * The net amount of the payment event of the bill
     */
    paymentAmount;
    /**
     * The API URL that can be used to download the file of the payment voucher
     */
    paymentVoucher;
    account;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's number of days
     */
    days;
    /**
     * The bill's accounting period
     */
    accountPeriod;
    /**
     * The bill's accounting period name
     */
    accountPeriodName;
    /**
     * The bill's total cost in the system currency.  The system currency is the reporting/global currency unit.
     */
    totalCost;
    /**
     * The bill's total cost in the source currency.  The source currency is the native currency unit.
     */
    totalSourceCost;
    costConversion;
    /**
     * The bill's balance
     */
    balance;
    /**
     * Indicates if the bill is estimated
     */
    estimated;
    /**
     * The date of the billing statement
     */
    statementDate;
    /**
     * The date and time the bill is due
     */
    dueDate;
    /**
     * The bill's invoice number
     */
    invoiceNumber;
    /**
     * The bill's control code
     */
    controlCode;
    /**
     * The fully qualified url to the bill image
     */
    billImageUrl;
    /**
     * Bill note
     */
    billNote;
    /**
     * The bill's next reading date
     */
    nextReading;
    reversalDetails;
    /**
     * Indicates whether this bill is excluded from accruals or not
     */
    excludedFromAccruals;
    /**
     * Indicates whether this bill is currently being analyzed
     */
    analyzing;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class JsonBillExportVendor {
    /**
     *
     */
    vendorId;
    /**
     *
     */
    vendorCode;
    /**
     *
     */
    vendorInfo;
    address;
    /**
     *
     */
    customFields;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class KickoutField {
    /**
     * The column identifier.  This is a dynamic field and may vary between requests.
     */
    id;
    /**
     * The column name
     */
    name;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class KickoutValue {
    /**
     * The field identifier
     */
    fieldId;
    /**
     * The kickout value
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LatestBenchmarkValue {
    benchmarkValue;
    /**
     * Indicator for which benchmark factor
     */
    benchmarkIndicator;
    /**
     * benchmark info
     */
    benchmarkInfo;
    benchmarkCategory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureAccountingExport {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureAccrualBills {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureBillCAPtureManagedServices {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureBillCapturePostPay {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureBillCapturePrePay {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureBudgets {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureCarbonHub {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureChargebacks {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureCostAvoidance {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureCustomBenchmarks {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureEnergyCAPPayments {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureGhg {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureGhgPremium {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureIntervalData {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureIntervalDataAnalysis {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureLegacyGHG {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureNonEnglishBills {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureReportDesigner {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureReportDistribution {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureUIDI {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatureVendorManagementServices {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseFeatures {
    /**
     * Whether accounting export is available on the user's the license.
     */
    accountingExport;
    /**
     * Whether bill accruals are available on the user's license.
     */
    billAccruals;
    /**
     * Whether chargebacks are available on the user's license.
     */
    chargebacks;
    /**
     * Whether cost avoidance is available on the user's license.
     */
    costAvoidance;
    /**
     * Whether custom benchmarks are available on the user's license.
     */
    customBenchmarks;
    /**
     * Whether interval data analysis is available on the user's license.
     */
    intervalDataAnalysis;
    /**
     * Whether report designer is available on the user's license.
     */
    reportDesigner;
    /**
     * Whether report distribution is available on the user's license.
     */
    reportDistribution;
    /**
     * Whether CarbonHub Standard is available on the user's license.
     */
    ghg;
    /**
     * Whether CarbonHub Premium is available on the user's license.
     */
    ghgPremium;
    /**
     * Whether Legacy GHG features are available on the user's license.
     */
    ghgLegacy;
    /**
     * Whether Budgets is available on the user's license
     */
    budgets;
    /**
     * Whether EnergyCAP Payments is available on the user's license
     */
    energyCAPPayments;
    /**
     * Whether Bill CAPture Managed Services is available on the user's license
     */
    billCAPtureManagedServices;
    /**
     * Whether CarbonHub is available on the user's license
     */
    carbonHub;
    /**
     * Whether Interval Data Managed Services is available on the user's license
     */
    intervalData;
    /**
     * Whether Bill CAPture PrePay is available on the user's license
     */
    billCapturePrePay;
    /**
     * Whether Bill CAPture PostPay is available on the user's license
     */
    billCapturePostPay;
    /**
     * Whether Bill CAPture NonEnglish Bills is available on the user's license
     */
    nonEnglishBills;
    /**
     * Whether Vendor Management Services is available on the user's license
     */
    vendorManagementServices;
    /**
     * Whether UIDI is available on the user's license
     */
    uIdI;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseRequest {
    /**
     * User's license validation key. <span class='property-internal'>Required (defined)</span>
     */
    validationKey;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseResponse {
    /**
     * User's license validation key.
     */
    validationKey;
    /**
     * User's license expiration date.
     */
    expirationDate;
    /**
     * Number of licensed meters for this user.
     */
    licensedMeters;
    /**
     * The user number.
     */
    userNumber;
    /**
     * EnergyCAP version on this license.
     */
    version;
    /**
     * Additional notes related to the license.
     */
    notes;
    meterUsage;
    accountUsage;
    billsCreatedLast30Days;
    billsCreatedLast12Months;
    licenseFeatures;
    /**
     * Application SKU as set in the license code for UtilityManagement.  Possible values are:  SaaS (Express), Professional, Online (Enterprise), ConsultantPlatform, ConsultantPlatformPlus, UtilityCompanyPlatform, and Other.
     */
    utilityManagementSKU;
    emissionSourcesScope1And2Usage;
    emissionSourcesScope3Usage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LicenseUsage {
    /**
     * Purchased allotment of licensed items
     */
    purchased;
    /**
     * Number of active licenses
     */
    active;
    /**
     * Number of inactive licenses
     */
    inactive;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Filter to select accounts to add as sub accounts  If multiple filters are provided, they are combined with AND  Properties with a null value are not included when filtering
 */
class LinkSubAccountsFilters {
    /**
     * Account info contains the specified string <span class='property-internal'>At least one of AccountInfoContains, AccountCodeContains, VendorId, TopmostCostCenterId must not be null</span>
     */
    accountInfoContains;
    /**
     * Account code contains the specified string <span class='property-internal'>At least one of AccountInfoContains, AccountCodeContains, VendorId, TopmostCostCenterId must not be null</span>
     */
    accountCodeContains;
    /**
     * All accounts with the specified vendor id <span class='property-internal'>At least one of AccountInfoContains, AccountCodeContains, VendorId, TopmostCostCenterId must not be null</span>
     */
    vendorId;
    /**
     * All accounts under the specified topmost cost center id <span class='property-internal'>Topmost (CostCenter)</span> <span class='property-internal'>At least one of AccountInfoContains, AccountCodeContains, VendorId, TopmostCostCenterId must not be null</span>
     */
    topmostCostCenterId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Sub accounts to add to a summary account  Either a list of SubAccountIds or use filter to find all accounts to add
 */
class LinkSubAccountsRequest {
    /**
     * List of AccountIds to assign as sub accounts <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Only one of SubAccountIds, LinkSubAccountsFilters can be set</span>
     */
    subAccountIds;
    linkSubAccountsFilters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListActionAccrualExclusion {
    /**
     * Whether or not the bill ids should be excluded from accruals, or included again <span class='property-internal'>Required</span>
     */
    exclude;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListActionApprove {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    approve;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListActionCustom {
    /**
     * The webhook identifier that represents the custom bill action <span class='property-internal'>Required</span>
     */
    webhookId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListActionExportHold {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    exportHold;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListActionReverse {
    batchSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListActionVoid {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    void;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListColumnEdit {
    /**
     * Column/Filter Identifier <span class='property-internal'>Required</span>
     */
    fieldId;
    /**
     * Width of the column <span class='property-internal'>Required</span>
     */
    width;
    /**
     * Order of the column <span class='property-internal'>Required</span>
     */
    displayOrder;
    /**
     * Sort order for the column <span class='property-internal'>Required</span>
     */
    sortOrder;
    /**
     * Sort direction <span class='property-internal'>Required</span> <span class='property-internal'>One of 'asc', 'desc'</span> <span class='property-internal'>Case sensitive</span>
     */
    sortDirection;
    /**
     * Is the column visible? <span class='property-internal'>Required</span>
     */
    visible;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListCopy {
    /**
     * The list name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    listInfo;
    /**
     * The list description <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    listDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListCreate {
    /**
     * The list type (List) id <span class='property-internal'>Required</span>
     */
    listTypeId;
    /**
     * The list name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    listInfo;
    /**
     * The list description <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    listDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListCreateResponse {
    /**
     * The list identifier.
     */
    listId;
    /**
     * The list name.
     */
    listInfo;
    /**
     * The list description.
     */
    listDescription;
    listType;
    user;
    /**
     * Is this a list shared with anyone?
     */
    sharedList;
    /**
     * Is this list visible to me?
     */
    visible;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListEdit {
    /**
     * The list name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    listInfo;
    /**
     * The list description <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    listDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListIds {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    ids;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListResponse {
    /**
     * Specific List Identifier
     */
    listId;
    /**
     * Data for the bill list
     */
    data;
    /**
     * Definition of the bill list - available filters and columns
     */
    field;
    /**
     * Meta data about the list  Can contain:    TotalCount - Total number of items that match the filter  TotalCost - Total Cost of all the items that match the filter  costUnitInfo - The currency unit  ErrorMessage - Indicates data fetch error.
     */
    meta;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListResponseListField {
    /**
     * Column/Filter Identifier
     */
    fieldId;
    /**
     * Width of the column
     */
    width;
    /**
     * Order of the column
     */
    displayOrder;
    /**
     * Is the column sortable?
     */
    sortable;
    /**
     * Caption for the column/filter
     */
    caption;
    /**
     * Sort direction \"asc\" or \"desc\"
     */
    sortDirection;
    /**
     * Sort order for the column
     */
    sortOrder;
    /**
     * Type of Data in this column
     */
    dataTypeCode;
    /**
     * Is this column a required column?
     */
    requiredOutput;
    /**
     * Is this column currently visible?
     */
    visible;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListResponseListItem {
    fieldId;
    name;
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ListTypeChild {
    /**
     *
     */
    listTypeId;
    /**
     *
     */
    listTypeInfo;
    /**
     *
     */
    listTypeDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LoginRequest {
    /**
     * Datasource <span class='property-internal'>Required</span>
     */
    dataSource;
    /**
     * Password <span class='property-internal'>Required</span>
     */
    password;
    /**
     * Username <span class='property-internal'>Required</span>
     */
    username;
    /**
     * OPTIONAL - Partition  Usually this is the environment, Staging, Pro, Web.  An empty or NULL partition will result in all partitions being scanned.
     */
    partition;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class LoginResponse {
    /**
     *
     */
    token;
    user;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ManualAdjustmentRequest {
    /**
     * The manually adjusted Baseline Adjusted to Current Conditions (BATCC) native use <span class='property-internal'>Required when locked is set to True, case sensitive.</span>
     */
    batccNativeUse;
    /**
     * The manually adjusted Baseline Adjusted to Current Conditions (BATCC) cost <span class='property-internal'>Required when locked is set to True, case sensitive.</span>
     */
    batccCost;
    /**
     * The manual adjustment note explaining the reason for the adjustment <span class='property-internal'>Required</span>
     */
    billMtrNote;
    /**
     * Indicates whether or not the values in a savings record are locked (this is not changed by future runs of the savings processor)  Set to true when a manual adjustment is being created.  Set to false when a manual adjustment is being removed.  If locked is set to false, all other values are ignored and will be set by the savings processor. <span class='property-internal'>Required</span>
     */
    locked;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ManuallyAdjustSavings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ManuallyAdjustSavingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class ManufacturerChild {
    /**
     * The identifier for the manufacturer
     */
    manufacturerId;
    /**
     * The manufacturer name
     */
    manufacturerInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MapDashboardSettingsRequest {
    /**
     * The title of the dashboard. <span class='property-internal'>Required</span> <span class='property-internal'>Max length of 255</span>
     */
    title;
    /**
     * The description of the dashboard. <span class='property-internal'>Max length of 255</span> <span class='property-internal'>Required (defined)</span>
     */
    description;
    /**
     * Flag to indicate if Cost data should be shown on the dashboard. <span class='property-internal'>Required (defined)</span>
     */
    showCost;
    /**
     * Flag to indicate if Use data should be shown on the dashboard. <span class='property-internal'>Required (defined)</span>
     */
    showUse;
    /**
     * Flag to indicate if Greenhouse Gas data should be shown on the dashboard. <span class='property-internal'>Required (defined)</span>
     */
    showGHG;
    /**
     * Filters to apply to the map. <span class='property-internal'>Required (defined)</span>
     */
    mapDashboardFilter;
    /**
     * Set how commodities should be ordered for each data type. Applied individually to Cost, Use, and GHG Emissions.  Highest - Order displayed commodities in order of Highest Cost/Use/GHG Emissions  Lowest - Order displayed commodities in order Lowest Cost/Use/GHG Emissions  Fixed - Select up to 5 fixed commodities to display. <span class='property-internal'>One of 'Highest', 'Lowest', 'Fixed'</span> <span class='property-internal'>Required (defined)</span>
     */
    globalCommodityDisplay;
    /**
     * List of Commodities to display for each data type. Required if GlobalCommodityDisplay is Fixed, ignored otherwise. Maximum length of 5 items. <span class='property-internal'>Required when GlobalCommodityDisplay is set to Fixed</span> <span class='property-internal'>List cannot be empty</span>
     */
    fixedCommodityIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MapDashboardSettingsResponse {
    /**
     * The title of the dashboard. Maximum length of 255 characters.
     */
    title;
    /**
     * The description of the dashboard. Maximum length of 255 characters.
     */
    description;
    /**
     * Flag to indicate if Cost data is shown on the dashboard.
     */
    showCost;
    /**
     * Flag to indicate if Use data is shown on the dashboard.
     */
    showUse;
    /**
     * Flag to indicate if Greenhouse Gas data is shown on the dashboard.
     */
    showGHG;
    /**
     * Filters applied to the dashboard.
     */
    mapDashboardFilters;
    /**
     * Display order for commodities. Applied individually to Cost, Use, and GHG Emissions.  Highest - Order displayed commodities in order of Highest Cost/Use/GHG Emissions  Lowest - Order displayed commodities in order Lowest Cost/Use/GHG Emissions  Fixed - Display up to 5 fixed commodities for each data type.
     */
    globalCommodityDisplay;
    /**
     * List of Commodities to display for Cost, Use, and GHG, if applicable. Empty if GlobalCommodityDisplay is set to \"Highest\" or \"Lowest\".
     */
    fixedCommodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MapPlaceChild {
    /**
     * The identifier for place
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place information
     */
    placeInfo;
    address;
    /**
     * The floor area of the place, reported in the global area unit
     */
    floorArea;
    primaryUse;
    /**
     * Energy Use Intensity (EUI) for the past period
     */
    energyUseIntensity;
    /**
     * Energy Cost Intensity (ECI) for the past period
     */
    energyCostIntensity;
    /**
     * Green House Gas (GHG) Intensity for the past period
     */
    ghgIntensity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MapWidgetResponse {
    /**
     * The start period for intensity data on places
     */
    startPeriod;
    /**
     * The end period for intensity data on places
     */
    endPeriod;
    energyUseIntensityUnit;
    energyCostIntensityUnit;
    ghgIntensityUnit;
    floorAreaUnit;
    /**
     * Place data to draw on the map
     */
    places;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Me {
    place;
    costCenter;
    collection;
    space;
    /**
     * User's authentication token
     */
    token;
    /**
     * User's external user ID
     */
    externalUserId;
    /**
     * Username
     */
    systemUserCode;
    /**
     * Unique identifier for the user
     */
    systemUserId;
    /**
     * Owner identifier
     */
    ownerId;
    /**
     * User's full name
     */
    fullName;
    /**
     * User's email address
     */
    email;
    /**
     * Number of accounting periods configured for the user's owner
     */
    numberOfAccountingPeriods;
    /**
     * Calendarization configured for user's owner
     */
    calendarizationMethod;
    /**
     * Fiscal year start month configured for the user's owner
     */
    fiscalYearStartMonth;
    /**
     * Method configured for identification of fiscal year for the user's owner
     */
    fiscalYearMethod;
    /**
     * List of the user's claims
     */
    claim;
    preference;
    /**
     * Available date formats
     */
    dateFormats;
    /**
     * Available time formats
     */
    timeFormats;
    currencyUnit;
    /**
     * Current account period calculated from configuration for the user's owner
     */
    currentAccountingPeriod;
    /**
     * User's user role
     */
    userRoleName;
    permissions;
    /**
     * List of enabled feature flags
     */
    featureFlags;
    /**
     * Upgrade version number (Version 3)
     */
    upgradeVersionV3;
    /**
     * Upgrade version number (Version 7)
     */
    upgradeVersionV7;
    /**
     * Application SKU as set in the license code  Possible values are:  SaaS (Express), Professional, Online (Enterprise), ConsultantPlatform, ConsultantPlatformPlus, UtilityCompanyPlatform, and Other.
     */
    sku;
    /**
     * Current environment
     */
    environment;
    /**
     * Build date for the current application version
     */
    buildDate;
    /**
     * The email address to use as the sender for report distribution
     */
    reportDistributionFromEmailAddress;
    /**
     * The email name to use as the sender for report distribution
     */
    reportDistributionFromEmailName;
    /**
     * The current mode of the application  Values: Online, Offline
     */
    applicationMode;
    /**
     * The current version of the database
     */
    currentDatabaseVersion;
    utilityPlatformSettings;
    /**
     * Node where unplaced meters are assigned
     */
    unplacedMetersParentId;
    /**
     * Node where unplaced accounts are assigned
     */
    unplacedAccountsParentId;
    /**
     * Node where unplaced emmission sources are assigned
     */
    unplacedEmissionSourcesParentId;
    /**
     * Node where unplaced data points are assigned
     */
    unplacedDataPointsParentId;
    floorAreaUnit;
    /**
     * Alternate URL to use as a Support link
     */
    supportUrl;
    ghgSettings;
    targetSettings;
    /**
     * Months to exclude by default in charts
     */
    chartMonthsToExclude;
    energyCapIdSettings;
    energyStarSettings;
    /**
     * Owner’s external Identifier
     */
    externalOwnerId;
    /**
     * Indicates whether the user is in a production environment
     */
    isProduction;
    /**
     * Indicates which approach is used for bill image URL  0 indicates owner is set to use bill image name, 1 indicates use control code of the bill, 2 indicates use batch code.
     */
    webBillImageUseControlCode;
    /**
     * Indicates which extension should be used for bill images.
     */
    webBillImageExt;
    /**
     * Base URL used for bill images.
     */
    webBillImageUrl;
}
(function (Me) {
    let WebBillImageUseControlCodeEnum;
    (function (WebBillImageUseControlCodeEnum) {
        WebBillImageUseControlCodeEnum[WebBillImageUseControlCodeEnum["NUMBER_0"] = 0] = "NUMBER_0";
        WebBillImageUseControlCodeEnum[WebBillImageUseControlCodeEnum["NUMBER_1"] = 1] = "NUMBER_1";
        WebBillImageUseControlCodeEnum[WebBillImageUseControlCodeEnum["NUMBER_2"] = 2] = "NUMBER_2";
    })(WebBillImageUseControlCodeEnum = Me.WebBillImageUseControlCodeEnum || (Me.WebBillImageUseControlCodeEnum = {}));
})(Me || (Me = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeRequest {
    preference;
    /**
     * User's full name <span class='property-internal'>Max length of 32</span> <span class='property-internal'>Required (defined)</span>
     */
    fullName;
    /**
     * User's email address <span class='property-internal'>Max length of 128</span> <span class='property-internal'>Required (defined)</span>
     */
    email;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * This class represents a message from the savings processor
 */
class Message {
    /**
     * Cost Avoidance message type
     */
    messageType;
    /**
     * Cost Avoidance message
     */
    message;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterAccountChild {
    /**
     * The MeterAccount meter identifier
     */
    accountMeterId;
    /**
     * The MeterAccount identifier for this MeterAccount meter
     */
    accountId;
    /**
     * The code of the MeterAccount for this MeterAccount meter
     */
    accountCode;
    /**
     * The info of the MeterAccount for this MeterAccount meter
     */
    accountInfo;
    /**
     * Indicates whether the Account is active or inactive
     */
    active;
    /**
     * Indicates whether the Account has a child calculated meter
     */
    hasCalculatedMeter;
    /**
     * Indicates whether the Account is a recipient of a split
     */
    hasSplitParentMeter;
    /**
     * Indicates whether the Account has a child split meter
     */
    hasSplitChildMeter;
    /**
     * Indicates whether the Account has a sub-account
     */
    hasSubAccount;
    /**
     * Indicates whether the Account is a sub-account
     */
    isSubAccount;
    vendor;
    meterGeneralLedger;
    accountGeneralLedger;
    vendorType;
    /**
     * The beginning date and time for this MeterAccount meter relationship
     */
    startDate;
    /**
     * The ending date and time for this MeterAccount meter relationship
     */
    endDate;
    /**
     * The data access release identifier for this MeterAccount meter relationship, null if there is no release
     */
    dataAccessReleaseId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterActionCreateEmissionSource {
    /**
     *  <span class='property-internal'>Cannot be Empty</span>
     */
    ids;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterBillResponse {
    /**
     * The bill identifier
     */
    billId;
    batch;
    account;
    /**
     * The bill's begin date
     */
    beginDate;
    /**
     * The bill's end date
     */
    endDate;
    /**
     * The bill's billing period
     */
    billingPeriod;
    /**
     * The bill's accounting period
     */
    accountPeriod;
    /**
     * The meter's bill cost
     */
    cost;
    /**
     * The meter's bill cost per date
     */
    costPerDay;
    /**
     * The meter's bill cost per unit
     */
    costPerUnit;
    /**
     * Indicates if the bill is estimated
     */
    estimated;
    /**
     * Indicates if the bill has been approved
     */
    approved;
    /**
     * The date and time the bill was approved
     */
    approveDate;
    approvedBy;
    /**
     * Indicates if the bill has been exported
     */
    exported;
    /**
     * The date and time the bill was exported
     */
    exportDate;
    exportedBy;
    observationMethod;
    /**
     * The date and time of the bill statement
     */
    statementDate;
    /**
     * The date and time the bill is due
     */
    dueDate;
    /**
     * The date and time of the next reading
     */
    nextReading;
    /**
     * The bill's control code
     */
    controlCode;
    /**
     * The bill's invoice number
     */
    invoiceNumber;
    /**
     * The number of pages on the invoice
     */
    invoicePages;
    /**
     * The check number
     */
    checkNumber;
    /**
     * The date and time of the check
     */
    checkDate;
    /**
     * The pay status of the bill
     */
    payStatus;
    /**
     * The cleared date
     */
    clearedDate;
    createdBy;
    /**
     * The date and time the bill was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * Indicates if the bill has been voided
     */
    void;
    /**
     * Indicates if the bill record has been cleaned. Cleaning is an internal EnergyCAP process
     */
    dirty;
    /**
     * Indicates if the import has been verified
     */
    importVerified;
    /**
     * Indicates if the bill is an accrual
     */
    accrual;
    /**
     * Indicates if the bill is a reversed accrual
     */
    accrualReversed;
    /**
     * The date and time the accrual was reversed
     */
    accrualReversedDate;
    /**
     * Indicates if the bill is held for export
     */
    exportHold;
    /**
     * Indicates if the bill has been gl exported
     */
    glExported;
    glExportedBy;
    /**
     * The date and time the bill was exported to gl
     */
    glExportDate;
    /**
     * Indicates if the bill has been bill payment exported
     */
    paymentExported;
    paymentExportedBy;
    /**
     * The date and time the bill was exported to bill payment
     */
    paymentExportDate;
    /**
     * Indicates if the bill is from a vendor
     */
    fromVendor;
    /**
     * Indicates if the bill has been split
     */
    hasBeenSplit;
    /**
     * The date and time the bill was split
     */
    wasSplitDate;
    /**
     * The transaction reference number of the bill
     */
    transRefNum;
    /**
     * The payment type of the bill
     */
    paymentType;
    /**
     * The actual amount paid
     */
    actualAmountPaid;
    assignedTo;
    /**
     * The date and time the bill was assigned to a user
     */
    assignedDate;
    /**
     * The bill's pay source
     */
    paySource;
    /**
     * Indicates whom the bill paid
     */
    payTo;
    /**
     * The balance of the previous bill
     */
    previousBalance;
    /**
     * The amount of balance that was forwarded
     */
    balanceForward;
    /**
     * The current charges
     */
    currentCharges;
    /**
     * The meter's usage
     */
    usage;
    /**
     * The meter's usage per day
     */
    usePerDay;
    useUnit;
    /**
     * The meter's actual demand
     */
    actualDemand;
    actualDemandUnit;
    /**
     * The meter's billed demand
     */
    billedDemand;
    billedDemandUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterCAPResponse {
    /**
     * The meter's baseline start date
     */
    baseStart;
    /**
     * The meter's savings start date
     */
    savingStart;
    /**
     * Indicates if the meter is included or not included in cost avoidance calculations
     */
    includeInCAP;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterCalendarizedUseVsWeatherResponse {
    /**
     * The year
     */
    year;
    /**
     * Is heating weather sensitive?
     */
    isHeatingWeatherSensitive;
    /**
     * Heating needed below this temperature
     */
    winterBalancePoint;
    /**
     * The total base heating use per day
     */
    heatingBaseUsePerDay;
    /**
     * The heating weather factor
     */
    heatingWeatherFactor;
    /**
     * Is cooling weather sensitive?
     */
    isCoolingWeatherSensitive;
    /**
     * Cooling needed above this temperature
     */
    summerBalancePoint;
    /**
     * The total base cooling use per day
     */
    coolingBaseUsePerDay;
    /**
     * The cooling weather factor
     */
    coolingWeatherFactor;
    useUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterCategoryRequest {
    /**
     * The meter category code <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required</span>
     */
    meterGroupCategoryCode;
    /**
     * The meter category info <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required</span>
     */
    meterGroupCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterCategoryResponse {
    /**
     * The meter category identifier
     */
    meterGroupCategoryId;
    /**
     * The meter category code
     */
    meterGroupCategoryCode;
    /**
     * The meter category name
     */
    meterGroupCategoryInfo;
    /**
     * Is this category an automatically maintained one?
     */
    autoGroup;
    /**
     * Number of groups within this category
     */
    numberOfGroups;
    /**
     * Number of groups within this category with members the logged in can see
     */
    numberOfGroupsWithVisibleMembers;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterChild {
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Class derived from MeterChildDTO - has this meter's import id and route information    ///
 */
class MeterChildIncludeMeterImportIdAndRoute {
    /**
     * Meter's import id
     */
    meterImportId;
    route;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Class derived from MeterChildDTO - has this meter's parent place information      ///
 */
class MeterChildIncludePlace {
    parentPlace;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Class derived from MeterChildIncludePlaceDTO - has this meter's serial number     ///
 */
class MeterChildIncludePlaceAndSerialNumber {
    parentPlace;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Class derived from MeterChildIncludePlaceDTO - has this meter's channels with latest reading  ///
 */
class MeterChildIncludePlaceChannelLatestReading {
    /**
     * List of channels with their latest reading
     */
    channels;
    parentPlace;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Class derived from MeterChildDTO - has Meter Address and Serial Number   This class is used by the Bill Entry Account Searcher
 */
class MeterChildSearch {
    meterAddress;
    /**
     * The meter's previous serial number
     */
    previousSerialNumber;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterCost {
    meter;
    place;
    /**
     * Total cost
     */
    totalCost;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterCreate {
    /**
     * The meter code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    meterCode;
    /**
     * The meter info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    meterInfo;
    /**
     * The identifier for the meter's commodity <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The identifier for the place the meter is assigned to <span class='property-internal'>Topmost (Place)</span> <span class='property-internal'>Required</span>
     */
    placeId;
    address;
    /**
     * The bill entry note <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    billEntryNote;
    /**
     * DEPRECATED  To be included in ENERGY STAR a meter needs to be linked to a meter in Portfolio Manager  This can be done with the PUT place/{placeId}/energyStar/link or the ENERGY STAR: Mappings Setup Sheet
     */
    includeInEnergyStar;
    /**
     * An array of meter properties
     */
    properties;
    /**
     * The identifier for the meter's primary use
     */
    primaryUseId;
    /**
     * The identifier for the meter type. Allowed values include: 1 (standard meter) and 6 (chargeback meter) <span class='property-internal'>Required</span>
     */
    meterTypeId;
    /**
     * The identifier for the meter's time zone. If one is not specified, the global default meter time zone will be used.
     */
    meterTimeZoneId;
    /**
     * The use unit ID is the reporting unit for use for this meter.   It is used to determine initial bill format for this meter.  If not provided defaults to the common unit for the meter commodity
     */
    useUnitId;
    /**
     * The demand unit ID is the reporting unit for demand for this meter.   It is used to determine initial bill format for this meter.
     */
    demandUnitId;
    /**
     * A description of the meter <span class='property-internal'>Must be between 0 and 4000 characters</span>
     */
    meterDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestActualAndCalendarizedMonthlyResponse {
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The date and time the data was updated
     */
    updated;
    nativeUseUnit;
    nativeDemandUnit;
    commonUseUnit;
    costUnit;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestActualAndCalendarizedMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * The number of days in the period
     */
    days;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Native Use
     */
    nativeUse;
    /**
     * Native Unit Cost
     */
    nativeUseUnitCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Native Actual Demand
     */
    nativeActualDemand;
    /**
     * Native Actual Demand Unit Cost
     */
    nativeActualDemandUnitCost;
    /**
     * Native Billed Demand
     */
    nativeBilledDemand;
    /**
     * Native Billed Demand Unit Cost
     */
    nativeBilledDemandUnitCost;
    /**
     * Load Factor
     */
    loadFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestActualAndCalendarizedYearlyResponse {
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    /**
     * The meter identifier
     */
    meterId;
    nativeUseUnit;
    nativeDemandUnit;
    commonUseUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestActualAndCalendarizedYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Native Use
     */
    nativeUse;
    /**
     * Native Use Unit Cost
     */
    nativeUseUnitCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Native Demand
     */
    nativeDemand;
    /**
     * Native Demand Unit Cost
     */
    nativeDemandUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestCalendarizedTrendResponse {
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The date and time the data was updated
     */
    updated;
    nativeUseUnit;
    nativeDemandUnit;
    commonUseUnit;
    costUnit;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestCalendarizedTrendResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * The number of days in the period
     */
    days;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Native Use
     */
    nativeUse;
    /**
     * Native Unit Cost
     */
    nativeUseUnitCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Native Actual Demand
     */
    nativeActualDemand;
    /**
     * Native Actual Demand Unit Cost
     */
    nativeActualDemandUnitCost;
    /**
     * Native Billed Demand
     */
    nativeBilledDemand;
    /**
     * Native Billed Demand Unit Cost
     */
    nativeBilledDemandUnitCost;
    /**
     * Load Factor
     */
    loadFactor;
    /**
     * Average Daily Temperature
     */
    averageDailyTemperature;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestNormalizedMonthlyResponse {
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The date and time the data was updated
     */
    updated;
    nativeUseUnit;
    nativeDemandUnit;
    commonUseUnit;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestNormalizedMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * The number of days in the period
     */
    days;
    /**
     * Cumulative Native Use
     */
    cumulativeNativeUse;
    /**
     * Native Use
     */
    nativeUse;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Native Actual Demand
     */
    nativeActualDemand;
    /**
     * Native Billed Demand
     */
    nativeBilledDemand;
    /**
     * Load Factor
     */
    loadFactor;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestNormalizedYearlyResponse {
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    /**
     * The meter identifier
     */
    meterId;
    nativeUseUnit;
    nativeDemandUnit;
    commonUseUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestNormalizedYearlyResponseResults {
    /**
     * year
     */
    year;
    /**
     * Native use
     */
    nativeUse;
    /**
     * Native demand
     */
    nativeDemand;
    /**
     * Common use
     */
    commonUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestSavingsMonthlyResponse {
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterCAP;
    nativeUseUnit;
    commonUseUnit;
    costUnit;
    /**
     * An array of monthly data
     */
    results;
    /**
     * The date and time the data was updated
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestSavingsMonthlyResponseResults {
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * The number of days in the period
     */
    days;
    /**
     * Total Cost
     */
    savingsTotalCost;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Native Use
     */
    batccNativeUse;
    /**
     * Native Use
     */
    nativeUse;
    /**
     * Savings Native Use = BATCCNativeUse - NativeUse
     */
    savingsNativeUse;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Common Use
     */
    batccCommonUse;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Savings Common Use = BATCCCommonUse - CommonUse
     */
    savingsCommonUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestSavingsYearlyResponse {
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterCAP;
    nativeUseUnit;
    commonUseUnit;
    costUnit;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Native Use
     */
    allTimeBATCCNativeUse;
    /**
     * Program to Date Native Use
     */
    allTimeNativeUse;
    /**
     * Program to Date Savings Native Use = allTimeBATCCNativeUse - allTimeNativeUse
     */
    allTimeSavingsNativeUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Common Use
     */
    allTimeBATCCCommonUse;
    /**
     * Program to Date Common Use
     */
    allTimeCommonUse;
    /**
     * Program to Date Savings Common Use = allTimeBATCCCommonUse - allTimeCommonUse
     */
    allTimeSavingsCommonUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    allTimeBATCCTotalCost;
    /**
     * Program to Date Total Cost
     */
    allTimeTotalCost;
    /**
     * Program to Date Savings Total Cost = allTimeBATCCTotalCost - allTimeTotalCost
     */
    allTimeSavingsTotalCost;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * The saving program's start date
     */
    savingsStartDate;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterDigestSavingsYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    batccTotalCost;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Savings Total Cost = BATCCTotalCost - TotalCost
     */
    savingsTotalCost;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Native Use
     */
    batccNativeUse;
    /**
     * Native Use
     */
    nativeUse;
    /**
     * Savings Native Use = BATCCNativeUse - NativeUse
     */
    savingsNativeUse;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Common Use
     */
    batccCommonUse;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Savings Common Use = BATCCCommonUse - CommonUse
     */
    savingsCommonUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterEdit {
    /**
     * The meter code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    meterCode;
    /**
     * The meter info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    meterInfo;
    /**
     * The identifier for the place the meter is assigned to <span class='property-internal'>Topmost (Place)</span> <span class='property-internal'>Required</span>
     */
    placeId;
    /**
     * The commodity identifier that the meter is assigned to.   If different from original commodity id, then a commodity change will be attempted. <span class='property-internal'>Required</span>
     */
    commodityId;
    address;
    /**
     * The bill entry note <span class='property-internal'>Must be between 0 and 64 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    billEntryNote;
    /**
     * DEPRECATED  To be included in ENERGY STAR a meter needs to be linked to a meter in Portfolio Manager  This can be done with the PUT place/{placeId}/energyStar/link or the ENERGY STAR: Mappings Setup Sheet <span class='property-internal'>Required (defined)</span>
     */
    includeInEnergyStar;
    /**
     * The identifier for the meter's primary use <span class='property-internal'>Required (defined)</span>
     */
    primaryUseId;
    /**
     * The identifier for the meter's time zone. <span class='property-internal'>Required</span>
     */
    meterTimeZoneId;
    /**
     * Is this meter active? <span class='property-internal'>Required</span>
     */
    active;
    /**
     * An array of meter properties <span class='property-internal'>Required (defined)</span>
     */
    properties;
    /**
     * The use unit ID is the reporting unit for use for this meter.   If it is null the use unit will be removed (only if the commodity does not have a default use unit, otherwise an exception will be thrown) <span class='property-internal'>Required (defined)</span>
     */
    useUnitId;
    /**
     * The demand unit ID is the reporting unit for demand for this meter.   If it is null the demand unit will be removed <span class='property-internal'>Required (defined)</span>
     */
    demandUnitId;
    /**
     * A description of the meter <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    meterDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupCategoryChild {
    /**
     *
     */
    meterGroupCategoryId;
    /**
     *
     */
    meterGroupCategoryCode;
    /**
     *
     */
    meterGroupCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupChild {
    /**
     * The meter group identifier
     */
    meterGroupId;
    /**
     * The meter group code
     */
    meterGroupCode;
    /**
     * The meter group info
     */
    meterGroupInfo;
    /**
     * Indicates if this meter group is an autogroup
     */
    autoGroup;
    /**
     * Indicates if this meter group is an user defined auto group
     */
    userDefinedAutoGroup;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupDigestChild {
    /**
     *
     */
    meterId;
    /**
     *
     */
    meterCode;
    /**
     *
     */
    meterInfo;
    /**
     *
     */
    meterDisplay;
    commodity;
    /**
     *
     */
    includeInCharts;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split
     */
    isSplitChildMeter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupDigestDemandRankingChild {
    /**
     *
     */
    cost;
    /**
     *
     */
    value;
    /**
     *
     */
    meterId;
    /**
     *
     */
    meterCode;
    /**
     *
     */
    meterInfo;
    /**
     *
     */
    meterDisplay;
    commodity;
    /**
     *
     */
    includeInCharts;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split
     */
    isSplitChildMeter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupDigestDemandRankingResponse {
    /**
     *
     */
    highCost;
    /**
     *
     */
    lowCost;
    /**
     *
     */
    averageCost;
    /**
     *
     */
    medianCost;
    /**
     *
     */
    highValue;
    /**
     *
     */
    lowValue;
    /**
     *
     */
    averageValue;
    /**
     *
     */
    medianValue;
    costUnit;
    /**
     *
     */
    benchmarkUnit;
    /**
     *
     */
    benchmarkValueUnit;
    /**
     *
     */
    benchmarkFactorUnit;
    /**
     *
     */
    results;
    /**
     *
     */
    meterGroupId;
    /**
     *
     */
    meterGroupCode;
    /**
     *
     */
    meterGroupInfo;
    /**
     *
     */
    meterGroupDisplay;
    /**
     * The date and time the data was updated
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupDigestRankingChild {
    /**
     *
     */
    cost;
    /**
     *
     */
    use;
    /**
     *
     */
    unitCost;
    /**
     *
     */
    value;
    /**
     *
     */
    days;
    /**
     *
     */
    savingsOpportunity;
    /**
     *
     */
    meterId;
    /**
     *
     */
    meterCode;
    /**
     *
     */
    meterInfo;
    /**
     *
     */
    meterDisplay;
    commodity;
    /**
     *
     */
    includeInCharts;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split
     */
    isSplitChildMeter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupDigestRankingResponse {
    /**
     *
     */
    highCost;
    /**
     *
     */
    lowCost;
    /**
     *
     */
    averageCost;
    /**
     *
     */
    medianCost;
    /**
     *
     */
    highUse;
    /**
     *
     */
    lowUse;
    /**
     *
     */
    averageUse;
    /**
     *
     */
    medianUse;
    /**
     *
     */
    highUnitCost;
    /**
     *
     */
    lowUnitCost;
    /**
     *
     */
    averageUnitCost;
    /**
     *
     */
    medianUnitCost;
    /**
     *
     */
    highValue;
    /**
     *
     */
    lowValue;
    /**
     *
     */
    averageValue;
    /**
     *
     */
    medianValue;
    costUnit;
    useUnit;
    /**
     *
     */
    benchmarkUnit;
    /**
     *
     */
    benchmarkValueUnit;
    /**
     *
     */
    benchmarkFactorUnit;
    /**
     *
     */
    highSavingsOpportunity;
    /**
     *
     */
    results;
    /**
     *
     */
    meterGroupId;
    /**
     *
     */
    meterGroupCode;
    /**
     *
     */
    meterGroupInfo;
    /**
     *
     */
    meterGroupDisplay;
    /**
     * The date and time the data was updated
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupMember {
    /**
     * The meter group this meter will belong to <span class='property-internal'>Required (defined)</span>
     */
    meterGroupId;
    /**
     * Whether to include this meter in the group's benchmark charts <span class='property-internal'>Required (defined)</span>
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupMemberChild {
    /**
     * The meter identifier <span class='property-internal'>Required (defined)</span>
     */
    meterId;
    /**
     * The meter code <span class='property-internal'>Required (defined)</span>
     */
    meterCode;
    /**
     * The meter info <span class='property-internal'>Required (defined)</span>
     */
    meterInfo;
    meterType;
    commodity;
    place;
    /**
     * The flag determining whether the meter is included in group charts <span class='property-internal'>Required (defined)</span>
     */
    includeInCharts;
    /**
     * Indicates whether the Meter is Active <span class='property-internal'>Required (defined)</span>
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter <span class='property-internal'>Required (defined)</span>
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split <span class='property-internal'>Required (defined)</span>
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split <span class='property-internal'>Required (defined)</span>
     */
    isSplitChildMeter;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupRequest {
    /**
     * The meter group info <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    meterGroupInfo;
    /**
     * The meter group category <span class='property-internal'>Required</span>
     */
    meterGroupCategoryId;
    /**
     * Should this group only return members within the current user's topmost <span class='property-internal'>Required</span>
     */
    limitMembersByTopmost;
    /**
     * List of filters to add members to an automatic meter group  Either AutomaticGroupFilters or ManualGroupMembers, but not both, must be passed in <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Only one of AutomaticGroupFilters, ManualGroupMembers can be set</span>
     */
    automaticGroupFilters;
    /**
     * List of members to add to the group  Either AutomaticGroupFilters or ManualGroupMembers, but not both, must be passed in  Members but be within the current user's topmost  You can create an empty group by passing in an empty array <span class='property-internal'>Only one of AutomaticGroupFilters, ManualGroupMembers can be set</span>
     */
    manualGroupMembers;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterGroupResponse {
    /**
     * The meter group identifier
     */
    meterGroupId;
    /**
     * The meter group code
     */
    meterGroupCode;
    /**
     * The meter group info
     */
    meterGroupInfo;
    /**
     * Indicates if this meter group is an autogroup
     */
    autoGroup;
    meterGroupCategory;
    /**
     * Indicates if this meter group is an user defined auto group
     */
    userDefinedAutoGroup;
    /**
     * The last time a member was inserted, updated, or deleted from the group
     */
    lastUpdated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterLink {
    /**
     * The identifier for a Meter
     */
    meterId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterLinkRequest {
    /**
     * The identifier for a Meter.  Set to null to remove the link. <span class='property-internal'>Topmost (Meter)</span> <span class='property-internal'>Required (defined)</span>
     */
    meterId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterRateResponse {
    /**
     * The meter tariff identifier
     */
    rateId;
    /**
     * The rate name
     */
    name;
    /**
     * The rate code
     */
    rateCode;
    /**
     * The start date for the rate on the account meter
     */
    startDate;
    /**
     * The end date for the rate on the account meter
     */
    endDate;
    account;
    commodity;
    /**
     * The rate's note
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterResponse {
    /**
     * The identifier for the meter
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    /**
     * An array of channels assigned to this meter
     */
    channels;
    /**
     *
     */
    accounts;
    commodity;
    place;
    address;
    /**
     * The bill entry note
     */
    billEntryNote;
    /**
     * Indicates if the building is included in ENERGY STAR submissions
     */
    includeInEnergyStar;
    primaryUse;
    createdBy;
    /**
     * The date and time the meter was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification of the meter
     */
    modifiedDate;
    /**
     * An array of meter properties
     */
    properties;
    /**
     * Indicates if the meter should be included in cost avoidance
     */
    includeInCostAvoidance;
    route;
    meterTimeZone;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the Meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the Meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the Meter is a child of a split
     */
    isSplitChildMeter;
    useUnit;
    demandUnit;
    /**
     * Meter's currently assigned serial number
     */
    serialNumber;
    serialNumberHistory;
    /**
     * A description of the meter
     */
    meterDescription;
    watticsDataPoint;
    emissionSource;
    /**
     * Provides some insight into the current Sentinel enabled status.
     */
    sentinelStatus;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterSavingsSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterSavingsSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Parameters to use for performing a utility platform meter search
 */
class MeterSearchRequest {
    /**
     * Type of input to use for meter search <span class='property-internal'>One of 'Address', 'SerialNumber'</span>
     */
    searchType;
    /**
     * List of premise ids to search for <span class='property-internal'>Required when SearchType is set to Address</span> <span class='property-internal'>List cannot be empty</span> <span class='property-internal'>Only one of Addresses, SerialNumbers can be set</span>
     */
    addresses;
    /**
     * List of serial numbers to search for <span class='property-internal'>Required when SearchType is set to SerialNumber</span> <span class='property-internal'>List cannot be empty</span> <span class='property-internal'>Only one of Addresses, SerialNumbers can be set</span>
     */
    serialNumbers;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterSerialNumberHistoryChild {
    /**
     * Previous serial number of the meter
     */
    previousSerialNumber;
    /**
     * Date that serial number changed
     */
    serialNumberChangeDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterSerialNumberHistoryRequest {
    /**
     * Serial number that will replace the existing one <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    newSerialNumber;
    /**
     * Date that serial number changed <span class='property-internal'>Required (defined)</span>
     */
    serialNumberChangeDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterSerialNumberHistoryResponse {
    /**
     * Meter identifier <span class='property-internal'>Required (defined)</span>
     */
    meterId;
    /**
     * Serial number of the meter <span class='property-internal'>Required (defined)</span>
     */
    serialNumber;
    serialNumberHistory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterTemplateResponse {
    /**
     * The form template identifier
     */
    formTemplateId;
    /**
     * The meter template display order
     */
    displayOrder;
    /**
     * The begin date for the template on the account meter
     */
    beginDate;
    /**
     * The end date for the template on the account meter
     */
    endDate;
    template;
    account;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterTypeChild {
    /**
     *
     */
    meterTypeId;
    /**
     *
     */
    meterTypeCode;
    /**
     *
     */
    meterTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MeterUDFResponse {
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    /**
     * An array of user-defined fields (UDFs)
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Meters {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MetersClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MissingBillWidget {
    /**
     * The begin date of the gap in billing data
     */
    gapBeginDate;
    /**
     * The end date of the gap in billing data
     */
    gapEndDate;
    /**
     * The number of days in the gap in billing data
     */
    gapDays;
    /**
     * The account that is missing billing data
     */
    accountId;
    /**
     * The account that is missing billing data
     */
    accountInfo;
    /**
     * The meter that is missing billing data
     */
    meterInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ModelVoid {
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MonthlyCAPTrend {
    /**
     * The actual cost
     */
    actualCost;
    /**
     * The cap cost
     */
    capCost;
    /**
     * The avoided cost
     */
    avoidedCost;
    /**
     * The percent cost
     */
    percentCost;
    /**
     * The billing period
     */
    billingPeriod;
    /**
     * The fiscal period
     */
    fiscalPeriod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MonthlyTimeSeriesValue {
    /**
     *
     */
    id;
    /**
     *
     */
    formattedValue;
    /**
     *
     */
    month;
    /**
     *
     */
    value;
    /**
     *
     */
    unit;
    /**
     *
     */
    rawValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MostRecentAggregate {
    /**
     * The identifier of the aggregate meter
     */
    aggregateMeterId;
    /**
     * The effective date of the aggregation
     */
    effectiveDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MoveAccountsBetweenVendors {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MoveAccountsBetweenVendorsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MoveBillsDestination {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    commodities;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    accounts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class MoveCreateMeter {
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter display name
     */
    meterDisplay;
    commodity;
    /**
     * The meter serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MoveExistingBills {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class MoveExistingBillsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * This class represents a date period (YYYYMM) which could be an accounting period or a billing/calendar period.
 */
class NamedPeriod {
    /**
     * Name of the period to be displayed  Should be empty if billing period
     */
    periodName;
    /**
     * Value of the period in format (YYYYPP)  PP may be a calendar month (e.g. 01-12) but it could be an accounting period (e.g. 01-13)
     */
    period;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NormalizationSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NormalizationSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationActionButtonResponse {
    /**
     * Url the action will link to
     */
    url;
    /**
     * Label the action will display
     */
    label;
    /**
     * Should clicking the action link open a new window
     */
    openInNewWindow;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationBadgeResponse {
    /**
     * Total of unread and unarchived notifications
     */
    totalNotifications;
    /**
     * Total of unread and unarchived notifications since the last checked date time
     */
    newNotifications;
    /**
     * The date and time in UTC the query to get the badge data was run
     */
    lastCheckDateTimeUtc;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationCategory {
    /**
     * The id of the notification category
     */
    notificationCategoryId;
    /**
     * The notification category name
     */
    notificationCategoryInfo;
    /**
     * A description of the notification category
     */
    notificationCategoryDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationDetailsResponse {
    /**
     * The full notification message
     */
    message;
    createdByUser;
    primaryAction;
    secondaryAction;
    /**
     * The id of the notification
     */
    notificationId;
    /**
     * True if the notification has been read
     */
    read;
    /**
     * True if the notification has been archived
     */
    archived;
    /**
     * Subject of the notification
     */
    subject;
    /**
     * The date and time the notification was generated
     */
    createdDate;
    notificationType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationResponse {
    /**
     * The notification message with any html tags stripped out
     */
    messagePreview;
    /**
     * The id of the notification
     */
    notificationId;
    /**
     * True if the notification has been read
     */
    read;
    /**
     * True if the notification has been archived
     */
    archived;
    /**
     * Subject of the notification
     */
    subject;
    /**
     * The date and time the notification was generated
     */
    createdDate;
    notificationType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationSettingRequest {
    /**
     * The id of the notification type <span class='property-internal'>Required</span>
     */
    notificationTypeId;
    /**
     * Update the configured notification option  To get the list of available options for each setting call the GetNotificationSystemSettings or GetNotificationUserSettings API  If your database is not configured to send emails, passing in ShowInAppAndSendEmail will return an error <span class='property-internal'>One of 'ShowInAppAndSendEmail', 'ShowInAppOnly', 'Off'</span> <span class='property-internal'>Required</span>
     */
    configuredNotificationOption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationSettingResponse {
    notificationType;
    /**
     * The currently configured notification option
     */
    configuredNotificationOption;
    /**
     * All possible notification options for this setting
     */
    availableNotificationOptions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationSettingsResponse {
    /**
     * Are user's allowed to get email notifications
     */
    allowUsersToEmailNotifications;
    /**
     * The list of notification settings available and their configured value
     */
    notificationSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationSystemSettingsRequest {
    /**
     * Are user's allowed to get email notifications <span class='property-internal'>Required</span>
     */
    allowUsersToEmailNotifications;
    /**
     * The list of notification settings and the configured value  If a notification type is not passed the configured value will remain what it was set to <span class='property-internal'>Required (defined)</span>
     */
    notificationSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationType {
    /**
     * The id of the notification type
     */
    notificationTypeId;
    /**
     * The notification type name
     */
    notificationTypeInfo;
    /**
     * A description of the notification type
     */
    notificationTypeDescription;
    notificationCategory;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class NotificationUpdateRequest {
    /**
     * List of notification ids to perform the action on <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    notificationIds;
    /**
     * Action to perform  Unread marks all notifications in the list as unread  Read marks all notifications in the list as read  Archived marks all notifications in the list as archived  Unarchived marks all notifications in the list as unarchived <span class='property-internal'>One of 'Read', 'Unread', 'Archived', 'Unarchived'</span> <span class='property-internal'>Required</span>
     */
    action;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ObservationMethodChild {
    /**
     * Observation method identifier
     */
    observationMethodId;
    /**
     * Observation method code
     */
    observationMethodCode;
    /**
     * Observation method name: Automatic, Manual, Estimated, Simulated, Accrual, or Adjustment
     */
    observationMethodInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ObservationRule {
    /**
     * The observation rule identifier
     */
    observationRuleId;
    /**
     * The observation rule code
     */
    observationRuleCode;
    /**
     * The observation rule info
     */
    observationRuleInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ObservationType {
    /**
     *
     */
    observationTypeId;
    /**
     *
     */
    credit;
    /**
     *
     */
    timeOfUse;
    /**
     *
     */
    creation;
    /**
     *
     */
    noun;
    /**
     *  <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    observationTypeCode;
    /**
     *  <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    observationTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ObservationTypeChild {
    /**
     * The identifier for the observation type's noun
     */
    nounId;
    /**
     * The observation type's noun code
     */
    nounCode;
    /**
     * Indicates the type of credit for the observation type. Possible values include: 1 (Credit), 2 (Debit), 3 (Ignore)
     */
    credit;
    /**
     * The observation type identifier
     */
    observationTypeId;
    /**
     * The observation type code
     */
    observationTypeCode;
    /**
     * The observation type info
     */
    observationTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ObservationTypeChildBase {
    /**
     * The observation type identifier
     */
    observationTypeId;
    /**
     * The observation type code
     */
    observationTypeCode;
    /**
     * The observation type info
     */
    observationTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OkObjectResult {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    formatters;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    contentTypes;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    declaredType;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    statusCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OkResult {
    /**
     *
     */
    statusCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OptionalUpdateNullableDateOnly {
    /**
     * The value to save during update  Should be a date only with no time element  If null is passed as a value and update is true it will be saved to the database <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     * Should the value be saved  This is used to optionally update certain fields during a PUT request <span class='property-internal'>Required (defined)</span>
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OptionalUpdateNullableDecimal {
    /**
     * The value to save during update  If null is passed as a value and update is true it will be saved to the database
     */
    value;
    /**
     * Should the value be saved  This is used to optionally update certain fields during a PUT request
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OptionalUpdateNullableInt32 {
    /**
     * The value to save during update  If null is passed as a value and update is true it will be saved to the database
     */
    value;
    /**
     * Should the value be saved  This is used to optionally update certain fields during a PUT request
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OptionalUpdateString {
    /**
     * The value to save during update  If null is passed as a value and update is true it will be saved to the database
     */
    value;
    /**
     * Should the value be saved  This is used to optionally update certain fields during a PUT request
     */
    update;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OtherSavingsCategory {
    /**
     * Other savings category identifier
     */
    otherSavingsCategoryId;
    /**
     * Other savings category name
     */
    otherSavingsCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OtherSavingsCategoryRequest {
    /**
     * Other savings category name
     */
    otherSavingsCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OtherSavingsRequest {
    /**
     * Other savings type  Possible values are: one-time, continuous and recurring <span class='property-internal'>Required</span>
     */
    frequency;
    /**
     * Other savings category identifier <span class='property-internal'>Required</span>
     */
    otherSavingsCategoryId;
    /**
     * Description <span class='property-internal'>Required</span>
     */
    description;
    /**
     * Other savings start period <span class='property-internal'>Required</span>
     */
    startPeriod;
    /**
     * Other savings end period <span class='property-internal'>Required when frequency is set to continuous, or recurring, case sensitive.</span>
     */
    endPeriod;
    /**
     * Month in which the other savings should begin  This should only be set when the other savings type is recurring <span class='property-internal'>Required when frequency is set to recurring, case sensitive.</span>
     */
    annualCycleStartMonth;
    /**
     * Month in which the other savings should end  This should only be set when the other savings type is recurring <span class='property-internal'>Required when frequency is set to recurring, case sensitive.</span>
     */
    annualCycleEndMonth;
    /**
     * Amount saved <span class='property-internal'>Required</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OtherSavingsResponse {
    /**
     * Other savings identifier
     */
    otherSavingsId;
    /**
     * Other savings frequency  Possible values are: one-time, continuous, and recurring
     */
    frequency;
    otherSavingsCategory;
    /**
     * Description
     */
    description;
    /**
     * Begin period for the other savings
     */
    startPeriod;
    /**
     * End period for the other savings
     */
    endPeriod;
    /**
     * Month the other savings should begin  This is only set when the other savings type is recurring
     */
    annnualCycleStartMonth;
    /**
     * Month the other savings should end  This is only set when the other savings type is recurring
     */
    annualCycleEndMonth;
    /**
     * Amount saved
     */
    value;
    createdBy;
    /**
     * Create date
     */
    createdDate;
    modifiedBy;
    /**
     * Last modified date
     */
    modifiedDate;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class OutlierSeverityChild {
    /**
     * The integer that represents the severity of the outlier  Values: 1, 2, 3, or 4
     */
    outlierSeverity;
    /**
     * The information regarding the current outlier severity  Values: 1 = Severe, 2 = High, 3 = Moderate, 4 = Cannot be determined  Severe - Actual value is 1, standard deviation > 3.0 on the high side or > 5.0 on the low side  High - Actual value is 2, standard deviation > 2.0 high and > 4.0 low  Moderate - Actual value is 3, standard deviation > 1.5 high and > 3.0 low  Not Classified - It is not one of Severe, High, Low or the model could not be determined
     */
    outlierSeverityInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose period comparison DTO
 */
class PeriodComparison {
    /**
     * The date for the current period of data
     */
    currentPeriod;
    /**
     * The date for the previous period of data
     */
    previousPeriod;
    currentValue;
    previousValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose period range DTO
 */
class PeriodRange {
    /**
     * The start period for the range
     */
    startPeriod;
    /**
     * The end period for the range
     */
    endPeriod;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose period range comparison DTO
 */
class PeriodRangeComparison {
    currentPeriodRange;
    previousPeriodRange;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PeriodRangeComparisonDetailed {
    /**
     * The data details
     */
    dataDetails;
    currentPeriodRange;
    previousPeriodRange;
    currentValue;
    previousValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PermissionProduct {
    /**
     *
     */
    productId;
    /**
     *
     */
    productCode;
    /**
     *
     */
    productInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Permissions {
    licenseFeatureAccountingExport;
    licenseFeatureAccrualBills;
    licenseFeatureChargebacks;
    licenseFeatureCostAvoidance;
    licenseFeatureIntervalDataAnalysis;
    licenseFeatureReportDesigner;
    licenseFeatureCustomBenchmarks;
    licenseFeatureReportDistribution;
    licenseFeatureGhg;
    licenseFeatureGhgPremium;
    licenseFeatureLegacyGHG;
    licenseFeatureBudgets;
    licenseFeatureEnergyCAPPayments;
    licenseFeatureBillCAPtureManagedServices;
    licenseFeatureCarbonHub;
    licenseFeatureIntervalData;
    licenseFeatureBillCapturePrePay;
    licenseFeatureBillCapturePostPay;
    licenseFeatureNonEnglishBills;
    licenseFeatureVendorManagementServices;
    licenseFeatureUIdI;
    accountingSettings;
    accounts;
    accountsModule;
    accrualSettings;
    costCenters;
    moveAccountsBetweenVendors;
    applicationSettings;
    approveBills;
    billWorkflowSettings;
    billsAndBatches;
    exportBills;
    exportHold;
    moveExistingBills;
    sharedBillLists;
    unitSystemSettings;
    updateApprovedBills;
    updateUnitsOnExistingBills;
    budgetsAndBudgetVersions;
    chargebacksModule;
    chargebacks;
    chargebackReversals;
    meterSavingsSettings;
    savingsAdjustments;
    manuallyAdjustSavings;
    savingsEngine;
    baselineEngine;
    globalCostAvoidanceSettings;
    dashboardAndMapsModule;
    dashboardAdministrator;
    publicDashboardsOrMaps;
    sharedDashboardsOrMaps;
    buildingsAndMetersModule;
    groupsAndBenchmarksModule;
    buildingAndMeterGroups;
    buildingsAndOrganizations;
    intervalData;
    intervalDataAnalysis;
    energystarSubmissions;
    facilityProjects;
    greenhouseGasAdministrator;
    intervalDataRollup;
    meters;
    normalizationSettings;
    weatherSettings;
    reportsModule;
    distributedReportsSettings;
    reportAdministrator;
    reportGroups;
    sharedReports;
    reports;
    resetUserPasswords;
    usersAndUserGroups;
    vendorsAndRatesModule;
    rateSchedules;
    vendors;
    flaggedItems;
    billListAdministrator;
    allInstalledReports;
    sendNotifications;
    buildingsAndMetersModuleActualData;
    buildingsAndMetersModuleCalendarizedData;
    buildingsAndMetersModuleNormalizedData;
    buildingsAndMetersModuleSavings;
    buildingsAndMetersModuleMeterIntervalData;
    buildingsAndMetersModuleSustainability;
    buildingsAndMetersModuleBudgets;
    accountsModuleActualData;
    billsModule;
    roles;
    usersAndRoles;
    emissionsSourcesModule;
    collections;
    emissionsSources;
    recordsModule;
    records;
    sharedRecordsLists;
    recordsListAdministrator;
    billCAPture;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PermissionsRequest {
    accountingSettings;
    accounts;
    accountsModule;
    accrualSettings;
    costCenters;
    moveAccountsBetweenVendors;
    applicationSettings;
    approveBills;
    billWorkflowSettings;
    billsAndBatches;
    exportBills;
    exportHold;
    moveExistingBills;
    sharedBillLists;
    unitSystemSettings;
    updateApprovedBills;
    updateUnitsOnExistingBills;
    budgetsAndBudgetVersions;
    chargebacksModule;
    chargebacks;
    chargebackReversals;
    meterSavingsSettings;
    savingsAdjustments;
    manuallyAdjustSavings;
    savingsEngine;
    baselineEngine;
    globalCostAvoidanceSettings;
    dashboardAndMapsModule;
    dashboardAdministrator;
    publicDashboardsOrMaps;
    sharedDashboardsOrMaps;
    buildingsAndMetersModule;
    groupsAndBenchmarksModule;
    buildingAndMeterGroups;
    buildingsAndOrganizations;
    intervalData;
    intervalDataAnalysis;
    energystarSubmissions;
    facilityProjects;
    greenhouseGasAdministrator;
    intervalDataRollup;
    meters;
    normalizationSettings;
    weatherSettings;
    reportsModule;
    distributedReportsSettings;
    reportAdministrator;
    reportGroups;
    sharedReports;
    reports;
    resetUserPasswords;
    usersAndUserGroups;
    vendorsAndRatesModule;
    rateSchedules;
    vendors;
    flaggedItems;
    billListAdministrator;
    allInstalledReports;
    sendNotifications;
    buildingsAndMetersModuleActualData;
    buildingsAndMetersModuleCalendarizedData;
    buildingsAndMetersModuleNormalizedData;
    buildingsAndMetersModuleMeterIntervalData;
    buildingsAndMetersModuleSustainability;
    buildingsAndMetersModuleSavings;
    buildingsAndMetersModuleBudgets;
    accountsModuleActualData;
    billsModule;
    roles;
    emissionsSourcesModule;
    collections;
    emissionsSources;
    recordsModule;
    records;
    sharedRecordsLists;
    recordsListAdministrator;
    billCAPture;
    usersAndRoles;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceCategoryRequest {
    /**
     * The place category info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    placeGroupCategoryInfo;
    /**
     * The place category code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    placeGroupCategoryCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceCategoryResponse {
    /**
     * The place category identifier
     */
    placeGroupCategoryId;
    /**
     * The place category code
     */
    placeGroupCategoryCode;
    /**
     * The place category name
     */
    placeGroupCategoryInfo;
    /**
     * Is this category an automatically maintained one?
     */
    autoGroup;
    /**
     * Number of groups within this category
     */
    numberOfGroups;
    /**
     * Number of groups within this category with members the logged in can see
     */
    numberOfGroupsWithVisibleMembers;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceChild {
    placeType;
    /**
     * Tells whether or not the place's data is rolled up to its parents.
     */
    isDataRolledUp;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceChildWithFloorArea {
    currentFloorArea;
    placeType;
    /**
     * Tells whether or not the place's data is rolled up to its parents.
     */
    isDataRolledUp;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceCost {
    place;
    /**
     * Total cost
     */
    totalCost;
    /**
     * Current Area
     */
    currentArea;
    /**
     * Current Area Units
     */
    currentAreaUnit;
    /**
     * Area Units
     */
    areaUnit;
    /**
     * Cost per area
     */
    costPerArea;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceCreate {
    /**
     * The place code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Not ROOT</span>
     */
    placeCode;
    /**
     * The place info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    placeInfo;
    /**
     * The identifier for the parent of the place. The parent is the place directly above the current place on the buildings and meters tree <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Place)</span>
     */
    parentPlaceId;
    /**
     * The identifier for the place type <span class='property-internal'>Required</span>
     */
    placeTypeId;
    /**
     * The identifier for the place's primary use  If this is a building and PrimaryUseId is null this will be set to Unknown (PrimaryUseId 55)
     */
    primaryUseId;
    /**
     * The date and time the place was built
     */
    buildDate;
    address;
    /**
     * The code for the weather station the place is assigned to <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    weatherStationCode;
    /**
     * A description of the place <span class='property-internal'>Must be between 0 and 4000 characters</span>
     */
    placeDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedMonthlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    periodRange;
    targetComparison;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    costUnit;
    /**
     * An array of monthly data per commodity
     */
    commodities;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    /**
     * The commodity category identifier
     */
    commodityCategoryId;
    /**
     * The commodity category name
     */
    commodityCategoryInfo;
    commonUseUnit;
    commonDemandUnit;
    costUnit;
    /**
     * An array of commodity monthly data
     */
    results;
    targetComparison;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Cumulative Total Cost
     */
    cumulativeTotalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Cumulative Common Use
     */
    cumulativeCommonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     *
     */
    cumulativeGlobalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
    /**
     * Common Demand
     */
    commonDemand;
    /**
     * Common Demand Unit Cost
     */
    commonDemandUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Cumulative Total Cost
     */
    cumulativeTotalCost;
    /**
     * Use
     */
    globalUse;
    /**
     * Cumulative Use
     */
    cumulativeGlobalUse;
    /**
     * Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedYearlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    targetComparison;
    /**
     * An array of yearly data
     */
    results;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    costUnit;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    targetComparison;
    costUnit;
    commonUseUnit;
    commonDemandUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
    /**
     * Common Demand
     */
    commonDemand;
    /**
     * Common Demand Unit Cost
     */
    commonDemandUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedYearlyResponseResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Use
     */
    globalUse;
    /**
     * Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison {
    /**
     * Target year
     */
    targetYear;
    /**
     * Target label
     */
    targetLabel;
    /**
     * Total cost for the target year
     */
    totalCost;
    /**
     * Total cost for the target year up to the target period that corresponds to the current period
     */
    totalCostYtd;
    /**
     * Total use for the target year
     */
    globalUse;
    /**
     * Total use for the target year up to the target period that corresponds to the current period
     */
    globalUseYtd;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Comparison data for a place
 */
class PlaceDigestComparisonResponse {
    currentPeriodRange;
    previousPeriodRange;
    intensity;
    total;
    /**
     * Comparison values for each commodity
     */
    commodities;
    floorAreaUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestEnergyUseIntensity {
    /**
     * The calendar period name
     */
    periodName;
    /**
     * The calendar period number
     */
    calendarPeriod;
    /**
     * The calendar year
     */
    calendarYear;
    /**
     * The running average use per area for the prior 12 months
     */
    usePerAreaTrend;
    globalUseUnit;
    /**
     * A list of energy projects for this building. To be listed, a project must end in this period.   Projects are only displayed at the building level, but not at the organization level
     */
    energyProjects;
    /**
     * A breakdown of use per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestEnergyUseIntensityEuiCommodity {
    /**
     * The commodity identifier
     */
    commodityId;
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The use for the commodity
     */
    use;
    /**
     * The percent of the building's energy used by the commodity
     */
    usePercent;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestEnergyUseIntensityEuiEnergyProject {
    /**
     * The energy project identifier
     */
    energyProjectId;
    /**
     * The energy project code
     */
    energyProjectCode;
    /**
     * The energy project info
     */
    energyProjectInfo;
    /**
     * The energy project installation cost
     */
    installationCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestGHGYearlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The date and time the data was updated
     */
    updated;
    equivalentCO2EmissionsUnit;
    /**
     * List of greenhouse gas types with use by year
     */
    ghgTypes;
    /**
     * List of greenhouse gas scopes by type with use by year
     */
    ghgScopes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestGHGYearlyResponseGHGScope {
    /**
     * GHG scope identifier
     */
    ghgScopeId;
    /**
     * GHG scope code
     */
    ghgScopeCode;
    /**
     * GHG scope info
     */
    ghgScopeInfo;
    /**
     * GHG scope type code
     */
    ghgScopeTypeCode;
    /**
     * GHG scope type code
     */
    ghgScopeTypeInfo;
    /**
     * An array of ghg type yearly data
     */
    ghgTypes;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestGHGYearlyResponseGHGType {
    /**
     * GHG type identifier
     */
    ghgTypeId;
    /**
     * GHG type code
     */
    ghgTypeCode;
    /**
     * GHG type info
     */
    ghgTypeInfo;
    targetComparison;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestGHGYearlyResponseResults {
    /**
     * year
     */
    year;
    /**
     * Equivalent CO2 emissions
     */
    equivalentCO2Emissions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestGHGYearlyResponseTargetComparison {
    /**
     * Target year
     */
    targetYear;
    /**
     * Target label
     */
    targetLabel;
    /**
     * Equivalent CO2 emissions for the target year
     */
    equivalentCO2Emissions;
    /**
     * Equivalent CO2 emissions for the target year up to the target period that corresponds to the current period
     */
    equivalentCO2EmissionsYtd;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedCommodityTargetComparisonMonthly {
    /**
     * Target Year
     */
    targetYear;
    /**
     * Target Label
     */
    targetLabel;
    /**
     * Monthly Target Data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedCommodityTargetComparisonMonthlyCommodityResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Cumulative Common Use
     */
    cumulativeCommonUse;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Demand
     */
    commonDemand;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedMonthlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    targetComparison;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    /**
     * An array of monthly data per commodity
     */
    commodities;
    /**
     * An array of monthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedMonthlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    commonDemandUnit;
    /**
     * An array of commodity monthly data
     */
    results;
    targetComparison;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedMonthlyResponseCommodityResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Cumulative Common Use
     */
    cumulativeCommonUse;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Demand
     */
    commonDemand;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Global Use
     */
    globalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedTargetComparisonMonthly {
    /**
     * Target Year
     */
    targetYear;
    /**
     * Target Label
     */
    targetLabel;
    /**
     * Monthly Target Data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedTargetComparisonMonthlyResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Global Use
     */
    globalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedYearlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    targetComparison;
    /**
     * An array of yearly data
     */
    results;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    targetComparison;
    commonUseUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Global Use
     */
    globalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedYearlyResponseResults {
    /**
     * year
     */
    year;
    /**
     * Use
     */
    globalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestNormalizedYearlyResponseTargetComparison {
    /**
     * Target year
     */
    targetYear;
    /**
     * Target label
     */
    targetLabel;
    /**
     * Total use for the target year
     */
    globalUse;
    /**
     * Total use for the target year up to the target period that corresponds to the current period
     */
    globalUseYtd;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsMonthlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    costUnit;
    /**
     * An array of SavingsMonthly data per commodity
     */
    commodities;
    /**
     * An array of SavingsMonthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsMonthlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of SavingsMonthly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsMonthlyResponseCommodityDataCommodityResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Savings Total Cost
     */
    savingsTotalCost;
    /**
     * Savings Global Use
     */
    savingsCommonUse;
    /**
     * Savings Global Use
     */
    savingsGlobalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsMonthlyResponseResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Savings Total Cost
     */
    savingsTotalCost;
    /**
     * Savings Global Use
     */
    savingsGlobalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsYearlyResponse {
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * The place identifier
     */
    placeId;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Global Use
     */
    allTimeBATCCGlobalUse;
    /**
     * Program to Date Global Use
     */
    allTimeGlobalUse;
    /**
     * Program to Date Savings Global Use = allTimeBATCCGlobalUse - allTimeGlobalUse
     */
    allTimeSavingsGlobalUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    allTimeBATCCTotalCost;
    /**
     * Program to Date Savings Total Cost
     */
    allTimeTotalCost;
    /**
     * Program to Date Savings Total Cost = allTimeBATCCTotalCost - allTimeTotalCost
     */
    allTimeSavingsTotalCost;
    /**
     * An array of savings yearly data
     */
    results;
    /**
     * The date and time the data was updated
     */
    updated;
    globalUseUnit;
    costUnit;
    /**
     * An array of savings yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Common Use
     */
    allTimeBATCCCommonUse;
    /**
     * Program to Date Common Use
     */
    allTimeCommonUse;
    /**
     * Program to Date Savings Common Use = allTimeBATCCCommonUse - allTimeCommonUse
     */
    allTimeSavingsCommonUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Global Use
     */
    allTimeBATCCGlobalUse;
    /**
     * Program to Date Global Use
     */
    allTimeGlobalUse;
    /**
     * Program to Date Savings Global Use = allTimeBATCCGlobalUse - allTimeGlobalUse
     */
    allTimeSavingsGlobalUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    allTimeBATCCTotalCost;
    /**
     * Program to Date Total Cost
     */
    allTimeTotalCost;
    /**
     * Program to Date Savings Total Cost = allTimeBATCCTotalCost - allTimeTotalCost
     */
    allTimeSavingsTotalCost;
    costUnit;
    commonUseUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsYearlyResponseCommodityDataCommodityResults {
    /**
     * Year
     */
    year;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    batccTotalCost;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Savings Total Cost = BATCCTotalCost - TotalCost
     */
    savingsTotalCost;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Global Use
     */
    batccGlobalUse;
    /**
     * GlobalUse
     */
    globalUse;
    /**
     * Savings Global Use = BATCCGlobalUse - GlobalUse
     */
    savingsGlobalUse;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Common Use
     */
    batccCommonUse;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Savings Common Use = BATCCCommonUse - CommonUse
     */
    savingsCommonUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestSavingsYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    batccTotalCost;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Savings Total Cost = BATCCTotalCost - TotalCost
     */
    savingsTotalCost;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Global Use
     */
    batccGlobalUse;
    /**
     * GlobalUse
     */
    globalUse;
    /**
     * Savings Global Use = BATCCGlobalUse - GlobalUse
     */
    savingsGlobalUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestTargetComparisonMonthly {
    /**
     * Target Year
     */
    targetYear;
    /**
     * Target Label
     */
    targetLabel;
    /**
     * Monthly Target Data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceDigestTargetComparisonMonthlyResults {
    /**
     * Calendar Period Name
     */
    periodName;
    /**
     * Calendar Period
     */
    calendarPeriod;
    /**
     * Calendar Year
     */
    calendarYear;
    /**
     * Fiscal Period
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Total Cost
     */
    totalCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceEdit {
    /**
     * The place code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Not ROOT</span>
     */
    placeCode;
    /**
     * The place info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    placeInfo;
    /**
     * The identifier for the parent of the place. The parent is the place directly above the current place on the buildings and meters tree <span class='property-internal'>Required</span> <span class='property-internal'>Topmost (Place)</span>
     */
    parentPlaceId;
    /**
     * The identifier for the place type <span class='property-internal'>Required</span>
     */
    placeTypeId;
    /**
     * The identifier for the place's primary use  If this is a building and PrimaryUseId is null this will be set to Unknown (PrimaryUseId 55) <span class='property-internal'>Required (defined)</span>
     */
    primaryUseId;
    /**
     * The date and time the place was built <span class='property-internal'>Required (defined)</span>
     */
    buildDate;
    address;
    /**
     * The code for the weather station the place is assigned to <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    weatherStationCode;
    /**
     * A description of the place <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    placeDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceEntityType {
    /**
     * The place entity type identifier
     */
    placeEntityTypeId;
    /**
     * The place entity type name
     */
    placeEntityTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupCategoryChild {
    /**
     *
     */
    placeGroupCategoryId;
    /**
     *
     */
    placeGroupCategoryCode;
    /**
     *
     */
    placeGroupCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupChild {
    /**
     * The place group identifier
     */
    placeGroupId;
    /**
     * The place group code
     */
    placeGroupCode;
    /**
     * The place group info
     */
    placeGroupInfo;
    /**
     * Indicates if this place group is an autogroup
     */
    autoGroup;
    /**
     * Indicates if this place group is an user defined auto group
     */
    userDefinedAutoGroup;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestAreaDemandRankingResponse {
    /**
     * Highest cost for this group
     */
    highCost;
    /**
     * Lowest cost for this group
     */
    lowCost;
    /**
     * Average cost for this group
     */
    averageCost;
    /**
     * Median cost for this group
     */
    medianCost;
    /**
     * Highest use for this group
     */
    highUse;
    /**
     * Lowest use for this group
     */
    lowUse;
    /**
     * Average use for this group
     */
    averageUse;
    /**
     * Median use for this group
     */
    medianUse;
    /**
     * Highest benchmark value for this group
     */
    highValue;
    /**
     * Lowest benchmark value for this group
     */
    lowValue;
    /**
     * Median benchmark value for this group
     */
    medianValue;
    /**
     * Total area for this group
     */
    totalArea;
    /**
     * Highest area for this group
     */
    highArea;
    /**
     * Lowest area for this group
     */
    lowArea;
    /**
     * Median area for this group
     */
    medianArea;
    /**
     * The highest savings opportunity for this group
     */
    highSavingsOpportunity;
    /**
     *
     */
    results;
    /**
     *
     */
    placeGroupId;
    /**
     *
     */
    placeGroupCode;
    /**
     *
     */
    placeGroupInfo;
    /**
     * This is the user's preferred way of viewing this entity - could be code or info based on the master \"data object view\" setting in DB
     */
    placeGroupDisplay;
    /**
     * This will provide the benchmark unit eg:MMBTU/ft² or $/day
     */
    benchmarkUnit;
    /**
     * This will provide the unit for the benchmarking factor eg:ft² or day
     */
    benchmarkFactorUnit;
    /**
     * This will provide the unit for the benchmark value eg:$ for cost/day, MMBTU for annualized use/area
     */
    benchmarkValueUnit;
    useUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestAreaRankingChild {
    /**
     * The cost for this place
     */
    cost;
    /**
     * The use for this place
     */
    use;
    /**
     * The benchmark value for this place
     */
    value;
    /**
     * The area for this place
     */
    area;
    /**
     * The savings opportunity for this place
     */
    savingsOpportunity;
    /**
     * Does this place have incomplete data?
     */
    incompleteData;
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeCode;
    /**
     *
     */
    placeInfo;
    /**
     *
     */
    placeDisplay;
    /**
     *
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestBenchmarkRankingChild {
    /**
     * The cost for this place
     */
    cost;
    /**
     * The use for this place
     */
    use;
    /**
     * The benchmark value for this place
     */
    value;
    /**
     * Does this place have incomplete data?
     */
    incompleteData;
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeCode;
    /**
     *
     */
    placeInfo;
    /**
     *
     */
    placeDisplay;
    /**
     *
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestBenchmarkRankingResponse {
    /**
     * The highest cost for this group
     */
    highCost;
    /**
     * The lowest cost for this group
     */
    lowCost;
    /**
     * The average cost for this group
     */
    averageCost;
    /**
     * The median cost for this group
     */
    medianCost;
    /**
     * The highest use for this group
     */
    highUse;
    /**
     * The lowest use for this group
     */
    lowUse;
    /**
     * The average use for this group
     */
    averageUse;
    /**
     * The median use for this group
     */
    medianUse;
    /**
     * The highest benchmark value for this group
     */
    highValue;
    /**
     * The lowest benchmark value for this group
     */
    lowValue;
    /**
     * The median benchmark value for this group
     */
    medianValue;
    /**
     *
     */
    results;
    /**
     *
     */
    placeGroupId;
    /**
     *
     */
    placeGroupCode;
    /**
     *
     */
    placeGroupInfo;
    /**
     * This is the user's preferred way of viewing this entity - could be code or info based on the master \"data object view\" setting in DB
     */
    placeGroupDisplay;
    /**
     * This will provide the benchmark unit eg:MMBTU/ft² or $/day
     */
    benchmarkUnit;
    /**
     * This will provide the unit for the benchmarking factor eg:ft² or day
     */
    benchmarkFactorUnit;
    /**
     * This will provide the unit for the benchmark value eg:$ for cost/day, MMBTU for annualized use/area
     */
    benchmarkValueUnit;
    useUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestChild {
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeCode;
    /**
     *
     */
    placeInfo;
    /**
     *
     */
    placeDisplay;
    /**
     *
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestWeatherRankingChild {
    /**
     *
     */
    baseValue;
    /**
     *
     */
    slopeValue;
    /**
     *
     */
    placeId;
    /**
     *
     */
    placeCode;
    /**
     *
     */
    placeInfo;
    /**
     *
     */
    placeDisplay;
    /**
     *
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupDigestWeatherRankingResponse {
    /**
     *
     */
    highWeatherLoad;
    /**
     *
     */
    lowWeatherLoad;
    /**
     *
     */
    averageWeatherLoad;
    /**
     *
     */
    medianWeatherLoad;
    /**
     *
     */
    highNonWeatherLoad;
    /**
     *
     */
    lowNonWeatherLoad;
    /**
     *
     */
    averageNonWeatherLoad;
    /**
     *
     */
    medianNonWeatherLoad;
    /**
     *
     */
    results;
    /**
     *
     */
    placeGroupId;
    /**
     *
     */
    placeGroupCode;
    /**
     *
     */
    placeGroupInfo;
    /**
     * This is the user's preferred way of viewing this entity - could be code or info based on the master \"data object view\" setting in DB
     */
    placeGroupDisplay;
    /**
     * This will provide the benchmark unit eg:MMBTU/ft² or $/day
     */
    benchmarkUnit;
    /**
     * This will provide the unit for the benchmarking factor eg:ft² or day
     */
    benchmarkFactorUnit;
    /**
     * This will provide the unit for the benchmark value eg:$ for cost/day, MMBTU for annualized use/area
     */
    benchmarkValueUnit;
    useUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupMember {
    /**
     * The place group this place will belong to <span class='property-internal'>Required (defined)</span>
     */
    placeGroupId;
    /**
     * Whether to include this place in the group's benchmark charts <span class='property-internal'>Required (defined)</span>
     */
    includeInCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupRequest {
    /**
     * The place group info <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    placeGroupInfo;
    /**
     * The place group category <span class='property-internal'>Required</span>
     */
    placeGroupCategoryId;
    /**
     * Should this group only return members within the current user's topmost <span class='property-internal'>Required</span>
     */
    limitMembersByTopmost;
    /**
     * List of filters to add members to an automatic place group  Either AutomaticGroupFilters or ManualGroupMembers, but not both, must be passed in <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>NULL Valid</span> <span class='property-internal'>Only one of AutomaticGroupFilters, ManualGroupMembers can be set</span>
     */
    automaticGroupFilters;
    /**
     * List of members to add to the group  Either AutomaticGroupFilters or ManualGroupMembers, but not both, must be passed in  Members but be within the current user's topmost  You can create an empty group by passing in an empty array <span class='property-internal'>Only one of AutomaticGroupFilters, ManualGroupMembers can be set</span>
     */
    manualGroupMembers;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceGroupResponse {
    /**
     * The place group identifier
     */
    placeGroupId;
    /**
     * The place group code
     */
    placeGroupCode;
    /**
     * The place group info
     */
    placeGroupInfo;
    /**
     * Indicates if this place group is an autogroup
     */
    autoGroup;
    placeGroupCategory;
    /**
     * Indicates if this place group is an user defined auto group
     */
    userDefinedAutoGroup;
    /**
     * The last time a member was inserted, updated, or deleted from the group
     */
    lastUpdated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceInfo {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceResponse {
    parent;
    placeType;
    /**
     * The date and time the place was created
     */
    createdDate;
    createdBy;
    /**
     * The date and time of the most recent modification to the place
     */
    modifiedDate;
    modifiedBy;
    address;
    /**
     * The date and time the place was built
     */
    buildDate;
    primaryUse;
    weatherStation;
    size;
    benchmark1;
    benchmark2;
    benchmark3;
    /**
     * Tells whether energy star is enabled for the given place
     */
    energyStarEnabled;
    energyStarRating;
    /**
     * An array of child places. A child place is one directly beneath the current place
     */
    places;
    /**
     * An array of child meters. A child meter is one directly beneath the current place
     */
    meters;
    /**
     * An array of child data points. A child data point is one directly beneath the current place
     */
    dataPoints;
    contact;
    /**
     * A description of the place
     */
    placeDescription;
    watticsSite;
    /**
     * Tells whether the place area is calculated from its children (TODO: Use 'Area' instead of 'Size'? Would be inconsistent with Size property in DTO)
     */
    isSizeCalculated;
    /**
     * Tells whether or not the place's data is rolled up to its parents.  Currently only supported by ESA.
     */
    isDataRolledUp;
    sizeInReportingUnit;
    /**
     * The name of the place's image.  Currently only supported by ESA.
     */
    imageFilename;
    timeZone;
    /**
     * The place's schedules
     */
    schedules;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceSizeChild {
    /**
     * The identifier for this PlaceSize record
     */
    placeSizeId;
    /**
     * The effective start date for this place size record
     */
    beginDate;
    /**
     * The effective end date for this place size record
     */
    endDate;
    /**
     * The value of the current place size record
     */
    value;
    /**
     * The identifier for the unit this place size is measured in
     */
    unitId;
    /**
     * The code for the unit this place size is measured in <span class='property-internal'>Must be between 0 and 16 characters</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    unitCode;
    /**
     * The name of the unit this place size is measured in <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    unitInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceSizeCreate {
    /**
     * The begin date for the place size <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    beginDate;
    /**
     * The place size value <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span> <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    value;
    /**
     * <p>The place size's unit code</p>  <p>Options are SQFEET for Square Feet and SQMETER for Square Meters</p> <span class='property-internal'>One of 'SQFEET', 'SQMETER'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Must be between 0 and 16 characters</span> <span class='property-internal'>One of 'SQFEET', 'SQMETER'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Must be between 0 and 16 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    unitCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceSizeResponse {
    /**
     * The identifier for the current place
     */
    placeId;
    /**
     * The code for the current place
     */
    placeCode;
    /**
     * The name of the current place
     */
    placeInfo;
    /**
     * The identifier for this PlaceSize record
     */
    placeSizeId;
    /**
     * The effective start date for this place size record
     */
    beginDate;
    /**
     * The effective end date for this place size record
     */
    endDate;
    /**
     * The value of the current place size record
     */
    value;
    /**
     * The identifier for the unit this place size is measured in
     */
    unitId;
    /**
     * The code for the unit this place size is measured in <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    unitCode;
    /**
     * The name of the unit this place size is measured in <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    unitInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceSubmissionTypeRequest {
    /**
     * The submission type to apply <span class='property-internal'>One of 'Automatic', 'Manual'</span> <span class='property-internal'>Required (defined)</span>
     */
    submissionType;
    /**
     * The list of places whose submission types will be updated <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    placeIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceTypeRequest {
    /**
     * The place type info <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    placeTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceTypeResponse {
    /**
     * The place type identifier
     */
    placeTypeId;
    /**
     * The place type code
     */
    placeTypeCode;
    /**
     * The place type info
     */
    placeTypeInfo;
    /**
     * Indicates if the place is a structure
     */
    structure;
    icon;
    placeEntityType;
    /**
     * Flag to indicate if the place type is a system-level place type
     */
    isSystemPlaceType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PlaceUDFResponse {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    /**
     * An array of user-defined fields (UDFs)
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PmCommodityChild {
    /**
     * Commodity code from Portfolio Manager
     */
    pmCommodityCode;
    /**
     * When true, auto-created Portfolio Manager meters will be of this commodity
     */
    isDefault;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PostalCodeResponse {
    /**
     * The postal code
     */
    postalCode;
    /**
     * The city of the postal code
     */
    city;
    /**
     * The state of the postal code
     */
    state;
    /**
     * The country of the postal code
     */
    country;
    weatherStation;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PostalCodeResponseWeatherStation {
    /**
     * The weather station Id
     */
    weatherStationId;
    /**
     * The web station Id
     */
    webStationId;
    /**
     * The weather station code
     */
    weatherStationCode;
    /**
     * The city of the weather station
     */
    city;
    /**
     * The state of the weather station
     */
    state;
    /**
     * The country of the weather station
     */
    country;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Preferences specific to the logged-in user
 */
class Preference {
    /**
     * Weather degree unit configured for the user's owner
     */
    weatherDegreeUnit;
    /**
     *
     */
    metersShowInactive;
    /**
     * Indicates whether or not to show inactive data points in the Data Points tree
     */
    dataPointsShowInactive;
    /**
     * Indicates whether or not to show the datasource name
     */
    showDataSource;
    /**
     *  <span class='property-internal'>One of 'name', 'code', 'namefirst', 'codefirst'</span> <span class='property-internal'>Case sensitive</span>
     */
    buildingTreeDisplaySetting;
    /**
     * Indicates whether or not to show inactive accounts in the Accounts tree
     */
    accountsShowInactive;
    /**
     * Indicates whether or not to show inactive emission sources in the Emission Sources tree
     */
    emissionSourcesShowInactive;
    /**
     * Name/Code display settings for the Accounts tree <span class='property-internal'>One of 'name', 'code', 'namefirst', 'codefirst'</span> <span class='property-internal'>Case sensitive</span>
     */
    costCenterTreeDisplaySetting;
    /**
     *
     */
    buildingTreeGroupToDisplay;
    /**
     *  <span class='property-internal'>One of 'name', 'code', 'namefirst', 'codefirst'</span> <span class='property-internal'>Case sensitive</span>
     */
    vendorTreeDisplaySetting;
    /**
     *
     */
    viewVendorsTreeByCommodity;
    groupDisplaySetting;
    /**
     * Number of rows to display in bill lists
     */
    billListRowsPerPage;
    /**
     * Date format for the user
     */
    dateFormat;
    /**
     * Time format for the user
     */
    timeFormat;
    /**
     * Code of the default time zone configured for the user's owner
     */
    timeZoneCode;
    /**
     * Number of years to display in trend charts when the user views them
     */
    trendChartNumberOfYears;
    /**
     * User's language preference
     */
    language;
    /**
     * Value to use when displaying a single building or organization (name or code)
     */
    buildingAndOrganizationIdentifier;
    /**
     * Value to use when displaying a single meter (name or code)
     */
    meterIdentifier;
    /**
     * Value to use when displaying a single account (name or code)
     */
    accountIdentifier;
    /**
     * Value to use when displaying generic items (name or code)
     */
    otherIdentifier;
    /**
     * Value to use when displaying a single collection (name or code)
     */
    collectionIdentifier;
    /**
     * Value to use when displaying a single emission source (name or code)
     */
    emissionSourceIdentifier;
    /**
     * Value to use when displaying a single Space (name or code)
     */
    spaceIdentifier;
    /**
     * Value to use when displaying a single Data Point (name or code)
     */
    dataPointIdentifier;
    /**
     * Indicates whether or not in-app help is open
     */
    helpOpen;
    workflowDisplaySetting;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Preferences specific to the logged-in user
 */
class PreferenceRequest {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    metersShowInactive;
    /**
     * Indicates whether or not to show inactive data points in the Data Points tree <span class='property-internal'>Required (defined)</span>
     */
    dataPointsShowInactive;
    /**
     * Indicates whether or not to show the datasource name <span class='property-internal'>Required (defined)</span>
     */
    showDataSource;
    /**
     *  <span class='property-internal'>One of 'name', 'code', 'namefirst', 'codefirst'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    buildingTreeDisplaySetting;
    /**
     * Indicates whether or not to show inactive accounts in the Accounts tree <span class='property-internal'>Required (defined)</span>
     */
    accountsShowInactive;
    /**
     * Indicates whether or not to show inactive emission sources in the Emission Sources tree <span class='property-internal'>Required (defined)</span>
     */
    emissionSourcesShowInactive;
    /**
     * Name/Code display settings for the Accounts tree <span class='property-internal'>One of 'name', 'code', 'namefirst', 'codefirst'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    costCenterTreeDisplaySetting;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    buildingTreeGroupToDisplay;
    /**
     *  <span class='property-internal'>One of 'name', 'code', 'namefirst', 'codefirst'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    vendorTreeDisplaySetting;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    viewVendorsTreeByCommodity;
    groupDisplaySetting;
    /**
     * Number of rows to display in bill lists <span class='property-internal'>Required (defined)</span>
     */
    billListRowsPerPage;
    /**
     * Date format for the user <span class='property-internal'>Required (defined)</span>
     */
    dateFormat;
    /**
     * Time format for the user <span class='property-internal'>Required (defined)</span>
     */
    timeFormat;
    /**
     * Code of the default time zone configured for the user's owner <span class='property-internal'>Required (defined)</span>
     */
    timeZoneCode;
    /**
     * Number of years to display in trend charts when the user views them <span class='property-internal'>Required (defined)</span>
     */
    trendChartNumberOfYears;
    /**
     * User's language preference <span class='property-internal'>Required (defined)</span>
     */
    language;
    /**
     * Value to use when displaying a single building or organization (name or code) <span class='property-internal'>Required (defined)</span>
     */
    buildingAndOrganizationIdentifier;
    /**
     * Value to use when displaying a single meter (name or code) <span class='property-internal'>Required (defined)</span>
     */
    meterIdentifier;
    /**
     * Value to use when displaying a single account (name or code) <span class='property-internal'>Required (defined)</span>
     */
    accountIdentifier;
    /**
     * Value to use when displaying generic items (name or code) <span class='property-internal'>Required (defined)</span>
     */
    otherIdentifier;
    /**
     * Value to use when displaying a single collection (name or code) <span class='property-internal'>Required (defined)</span>
     */
    collectionIdentifier;
    /**
     * Value to use when displaying a single emission source (name or code) <span class='property-internal'>Required (defined)</span>
     */
    emissionSourceIdentifier;
    /**
     * Value to use when displaying a single Space (name or code) <span class='property-internal'>Required (defined)</span>
     */
    spaceIdentifier;
    /**
     * Value to use when displaying a single Data Point (name or code) <span class='property-internal'>Required (defined)</span>
     */
    dataPointIdentifier;
    /**
     * Indicates whether or not in-app help is open <span class='property-internal'>Required (defined)</span>
     */
    helpOpen;
    workflowDisplaySetting;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PrimaryUseChild {
    /**
     *
     */
    primaryUseId;
    /**
     *
     */
    primaryUseCode;
    /**
     *
     */
    primaryUseInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PrimaryUseCreate {
    /**
     * The Primary Use Code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    primaryUseCode;
    /**
     * The Primary Use Info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    primaryUseInfo;
    /**
     * The Primary Use Type. Possible value include: \"place\" and \"meter\" <span class='property-internal'>Required</span> <span class='property-internal'>One of 'place', 'meter'</span>
     */
    primaryUseType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PrimaryUseResponse {
    /**
     *
     */
    primaryUseId;
    /**
     *
     */
    primaryUseCode;
    /**
     *
     */
    primaryUseInfo;
    /**
     *
     */
    primaryUseType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ProblemDetails {
    /**
     *
     */
    type;
    /**
     *
     */
    title;
    /**
     *
     */
    status;
    /**
     *
     */
    detail;
    /**
     *
     */
    instance;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Product {
    /**
     * The product identifier
     */
    productId;
    /**
     * The product code
     */
    productCode;
    /**
     * The product info
     */
    productInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ProjectManagerResponse {
    /**
     * The full name of project manager
     */
    projectManagerFullName;
    /**
     * The code for project manager
     */
    projectManagerCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PublicDashboardsOrMaps {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class PublicDashboardsOrMapsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class QuickFilter {
    /**
     *  <span class='property-internal'>Required</span>
     */
    caption;
    /**
     *  <span class='property-internal'>Required</span>
     */
    operator;
    /**
     *  <span class='property-internal'>Required</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class QuickReport {
    /**
     * Report code of the report to execute
     */
    reportCode;
    /**
     * File name that the report file will receive
     */
    fileName;
    /**
     * Desired format for the resulting report.  Available options are PDF, Excel, Excel formatted, Excel data only, Word, and CSV. Support for each format varies by report.
     */
    format;
    /**
     * The filters to apply to this execution of the report. They will not be saved, and stored filters will not be honored.
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateChild {
    /**
     *
     */
    rateId;
    /**
     *
     */
    name;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateChildResponse {
    /**
     *
     */
    rateId;
    /**
     *
     */
    name;
    commodity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateCreate {
    /**
     *  <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    name;
    /**
     *  <span class='property-internal'>Required</span>
     */
    vendorId;
    /**
     *  <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     *  <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateDigestActualYearlyResponse {
    /**
     * The rate name
     */
    name;
    /**
     * The rate identifier
     */
    rateId;
    globalUseUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateDigestActualYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateDigestActualYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateDigestActualYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateEdit {
    /**
     *  <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    name;
    /**
     *  <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateResponse {
    /**
     *
     */
    rateId;
    /**
     *
     */
    name;
    /**
     *
     */
    note;
    vendor;
    commodity;
    /**
     *
     */
    versions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateSchedules {
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateSchedulesClassPermission {
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateVersionRequest {
    /**
     * Effective date for the version <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
     */
    effectiveDate;
    /**
     * Note for the version <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
    /**
     * Unit cost for the use <span class='property-internal'>Required when UseUnitID is set</span> <span class='property-info'>Max scale of 8</span> <span class='property-internal'>NULL Valid</span>
     */
    useUnitCost;
    /**
     * Use unit ID <span class='property-internal'>Required when UseUnitCost is set</span>
     */
    useUnitId;
    /**
     * Unit cost for the demand <span class='property-internal'>Required when DemandUnitID is set</span> <span class='property-info'>Max scale of 8</span> <span class='property-internal'>NULL Valid</span>
     */
    demandUnitCost;
    /**
     * Demand unit ID <span class='property-internal'>Required when DemandUnitCost is set</span>
     */
    demandUnitId;
    /**
     * Cost bodylines for the account <span class='property-internal'>Required (defined)</span>
     */
    accountLineItems;
    /**
     * Cost bodylines for the meter <span class='property-internal'>Required (defined)</span>
     */
    meterLineItems;
    /**
     * List of user defined/custom fields and values for this version  If the Udfs list is null or empty no values are assigned  If a udf is omitted no value is assigned to that udf  To remove a value from an existing Udf, pass in the UdfId and set the Value to null <span class='property-internal'>Required (defined)</span>
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RateVersionResponse {
    /**
     * ID of the rate schedule version
     */
    versionId;
    /**
     * Begin date for the version
     */
    beginDate;
    /**
     * End date for the version
     */
    endDate;
    /**
     * Created date
     */
    createdDate;
    /**
     * Last modified date
     */
    modifiedDate;
    /**
     * Note
     */
    note;
    createdBy;
    modifiedBy;
    /**
     * Unit cost for the use
     */
    useUnitCost;
    useUnit;
    /**
     * Unit cost for the demand
     */
    demandUnitCost;
    demandUnit;
    costUnit;
    /**
     * Cost bodylines for the account
     */
    accountLineItems;
    /**
     * Cost bodylines for the meter
     */
    meterLineItems;
    /**
     * List of user defined/custom fields and values for this version
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Reading {
    /**
     * The date and time of the reading <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    time;
    /**
     * The reading's value <span class='property-internal'>Required</span> <span class='property-internal'>Required</span>
     */
    value;
    /**
     * Indicates if the reading is estimated <span class='property-internal'>Required (defined)</span>
     */
    estimated;
    /**
     * A note pertaining to the reading <span class='property-internal'>Required (defined)</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingChildBase {
    /**
     * The unique ID of the reading
     */
    observationId;
    /**
     * The date and time of the reading
     */
    time;
    /**
     * The value of the reading
     */
    value;
    /**
     * Indicates if the reading is estimated
     */
    estimated;
    /**
     * A note pertaining to the reading
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingCreate {
    /**
     *  Channel Identification         The channel that receives the reading is determined by the following rules:        Direct pointers to a channel      If the channelId is supplied, then import to that channel.      If the channelId is not supplied look at the channelImportId property, which indicates a specific channel.  Inferred pointers to a channel      If the channelId and channelImportId are not supplied, look at the meterImportId property, which indicates a meter.If that meter has one channel, import to that channel.      If that meter has more than one channel, find the channel with the same observation type as the observationTypeCode property.If only one is found, import to that channel.      If more than one channel is found based on observation type, find the channel with the same output unit as the unitCode property.If only one is found, import to that channel.      If more than one channel is found based on unit, find the channel with the same channelIntervalInSeconds property. If only one is found, import to that channel. <span class='property-internal'>Topmost (Channel)</span>
     */
    channelId;
    /**
     * The import identifier for the channel on which to create the reading. See the channelId property for more information <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    channelImportId;
    /**
     * The import identifier for the meter on which to create the reading. See the channelId property for more information <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    meterImportId;
    /**
     *
     */
    channelIntervalInSeconds;
    /**
     * The observationType code of the reading. See the channelId property for more information <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    observationTypeCode;
    /**
     * The unit code of the reading. See the channelId property for more information <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    unitCode;
    /**
     * array of readings <span class='property-internal'>Required</span>
     */
    readings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingDelete {
    /**
     * The identifier for the channel of the reading <span class='property-internal'>Required</span>
     */
    channelId;
    /**
     * The begin date and time of the set of readings to be deleted.   If provided, readings after but NOT including the provided begin date and time will be deleted.
     */
    timeBegin;
    /**
     * The end date and time of the set of readings to be deleted.   If provided, readings up to and including the provided end date and time will be deleted.
     */
    timeEnd;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingImportProfile {
    /**
     * The interval of the readings in seconds
     */
    channelIntervalInSeconds;
    /**
     * The string that represents how the file contents are delimited.  Valid options are \"\\t\" for tab, \" \" for space and \",\" for comma. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2 characters</span> <span class='property-internal'>One of ' ', ' ', ','</span> <span class='property-internal'>Case sensitive</span>
     */
    delimiter;
    /**
     * Number of header rows before the data begins <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    numberOfHeaderRows;
    /**
     * The number of the column that holds the timestamp <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    timestampColumnNumber;
    /**
     * The format for the timestamp of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz
     */
    timestampFormat;
    /**
     * The number of the column that holds the date <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    dateColumnNumber;
    /**
     * The number of the column that holds the time <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    timeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy
     */
    dateFormat;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz
     */
    timeFormat;
    /**
     * The time zone for the readings
     */
    timeZoneId;
    /**
     * The number of the column that holds the meter import identifier <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    meterImportIdColumnNumber;
    /**
     * The number of the column that holds the channel import identifier <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    channelImportIdColumnNumber;
    /**
     * The minimum number of columns in the import sheet <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    numberOfColumns;
    /**
     * A list of columns from the import sheet with their observation type and unit
     */
    dataMapping;
    estimated;
    /**
     * Column number that holds a note to be stored with the reading <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    noteColumnNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingImportProfileColumn {
    /**
     * The number of the column <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    columnNumber;
    /**
     * The observation type code of the reading <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    observationTypeCode;
    /**
     * The unit code of the reading <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    unitCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingImportProfileRequest {
    /**
     * The profile code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    profileCode;
    /**
     * The interval of the readings in seconds
     */
    channelIntervalInSeconds;
    /**
     * The string that represents how the file contents are delimited.  Valid options are \"\\t\" for tab, \" \" for space and \",\" for comma. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2 characters</span> <span class='property-internal'>One of ' ', ' ', ','</span> <span class='property-internal'>Case sensitive</span>
     */
    delimiter;
    /**
     * Number of header rows before the data begins <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 2147483647</span>
     */
    numberOfHeaderRows;
    /**
     * The number of the column that holds the timestamp <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    timestampColumnNumber;
    /**
     * The format for the timestamp of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz
     */
    timestampFormat;
    /**
     * The number of the column that holds the date <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    dateColumnNumber;
    /**
     * The number of the column that holds the time <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    timeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy
     */
    dateFormat;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz
     */
    timeFormat;
    /**
     * The time zone for the readings
     */
    timeZoneId;
    /**
     * The number of the column that holds the meter import identifier <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    meterImportIdColumnNumber;
    /**
     * The number of the column that holds the channel import identifier <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    channelImportIdColumnNumber;
    /**
     * The minimum number of columns in the import sheet <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    numberOfColumns;
    /**
     * A list of columns from the import sheet with their observation type and unit
     */
    dataMapping;
    estimated;
    /**
     * Column number that holds a note to be stored with the reading <span class='property-internal'>Must be between 1 and 2147483647</span>
     */
    noteColumnNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingImportProfileResponse {
    /**
     * The profile Identifier
     */
    profileId;
    /**
     * The profile code
     */
    profileCode;
    createdBy;
    /**
     * The number of the column that holds the Meter import identifier
     */
    meterImportIdColumnNumber;
    /**
     * The number of the column that holds the Channel import identifier
     */
    channelImportIdColumnNumber;
    /**
     * The total number of columns in the import sheet
     */
    numberOfColumns;
    /**
     * The interval of the readings
     */
    channelIntervalInSeconds;
    /**
     * The string that represents how the file contents are delimited.  Valid options are \"\\t\" for tab, \" \" for space and \",\" for comma.
     */
    delimiter;
    /**
     * Number of header rows before the data begins
     */
    numberOfHeaderRows;
    /**
     * The number of the column that holds the timestamp
     */
    timestampColumnNumber;
    /**
     * The format for the timestamp of the readings. An example is MM/dd/yyyy mm:hh:ss:zzz
     */
    timestampFormat;
    /**
     * The number of the column that holds the date
     */
    dateColumnNumber;
    /**
     * The number of the column that holds the time
     */
    timeColumnNumber;
    /**
     * The format for the date of the readings. An example is MM/dd/yyyy
     */
    dateFormat;
    /**
     * The format for the time of the readings. An example is mm:hh:ss:zzz
     */
    timeFormat;
    timeZone;
    /**
     * A list of columns from the import sheet with their observation type and unit
     */
    dataMapping;
    estimated;
    /**
     * Column number that holds a note to be stored with the reading
     */
    noteColumnNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingImportRequest {
    /**
     * A reading import data profile code.
     */
    profileCode;
    inlineProfile;
    /**
     * The base64 encoded file. <span class='property-internal'>Required</span>
     */
    data;
    /**
     * Create new channels if they don't exist?
     */
    autoCreateChannels;
    /**
     * Optional note/comment.
     */
    importNote;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingResponse {
    /**
     * The number of successfully imported readings
     */
    importedReadingsCount;
    /**
     * The number of failed reading imports
     */
    failedReadingsCount;
    /**
     * Data representing the failed reading imports
     */
    failedReadings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Readings {
    /**
     * The Id of the Channel
     */
    channelId;
    /**
     * 1 = odometer, 2 = trip (to calculate delta)
     */
    rule;
    unit;
    /**
     *
     */
    readings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReadingsObservation {
    /**
     * The unique ID for the reading <span class='property-internal'>Required (defined)</span>
     */
    observationId;
    /**
     * The date and time of the reading <span class='property-internal'>Required (defined)</span>
     */
    time;
    /**
     * The raw or computed value of the reading <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     * The raw value of the reading (before multiplier or delta are applied) <span class='property-internal'>Required (defined)</span>
     */
    rawValue;
    /**
     * Indicates if the reading is estimated <span class='property-internal'>Required (defined)</span>
     */
    estimated;
    /**
     * A note pertaining to the reading <span class='property-internal'>Required (defined)</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordImportProfile {
    /**
     * The format for the record start/end dates.  It represents the regional convention for the order of day, month, and year. It is not a date format itself. <span class='property-internal'>Required</span> <span class='property-internal'>One of 'MM/dd/yyyy', 'dd/MM/yyyy', 'yyyy/MM/dd'</span> <span class='property-internal'>Case sensitive</span>
     */
    dateFormat;
    /**
     * The number of header rows before the data begins <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 9</span>
     */
    numberOfHeaderRows;
    /**
     * Flag to indicate if new emission sources or suppliers should be created if they do not already exist <span class='property-internal'>Required</span>
     */
    createNewEntities;
    /**
     * Optional notes field <span class='property-internal'>Max length of 255</span>
     */
    notes;
    /**
     * The index of the column that holds the emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    emissionSourceCodeColumnIndex;
    /**
     * The index of the column that holds the emission source name <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when CreateNewEntities is set to True, case sensitive.</span> <span class='property-internal'>Must be null when CreateNewEntities  is  set to False, case sensitive</span>
     */
    emissionSourceNameColumnIndex;
    /**
     * The index of the column that holds the emission source type <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when CreateNewEntities is set to True, case sensitive.</span> <span class='property-internal'>Must be null when CreateNewEntities  is  set to False, case sensitive</span>
     */
    emissionSourceTypeColumnIndex;
    /**
     * The index of the column that holds the emission record start date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    startDateColumnIndex;
    /**
     * The index of the column that holds the emission record end date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    endDateColumnIndex;
    /**
     * The index of the column that holds the supplier name. This field is optional <span class='property-internal'>Must be between 1 and 104</span>
     */
    supplierColumnIndex;
    /**
     * The index of the column that holds the notes for a record. This field is optional <span class='property-internal'>Must be between 1 and 104</span>
     */
    notesColumnIndex;
    /**
     * The index of the column that holds the use for a record.   Required if no value is set for either the Cost Or Direct/Offset column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    useColumnIndex;
    /**
     * The identifier for the use unit to use.  Required if UseColumnIndex is set <span class='property-internal'>Required when UseColumnIndex is set</span>
     */
    useUnitId;
    /**
     * The index of the column that holds the cost for a record.   Required if no value is set for either the Use Or Direct/Offset column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    costColumnIndex;
    /**
     * The identifier for the cost unit to use.  Required if CostColumnIndex is set <span class='property-internal'>Required when CostColumnIndex is set</span>
     */
    costUnitId;
    /**
     * The index of the column that holds direct emissions/emission offsets for a record.   Required if no value is set for either the Use Or Cost column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    directOffsetColumnIndex;
    /**
     * The identifier for the direct emissions/emission offset unit to use.  Required if DirectOffsetColumnIndex is set <span class='property-internal'>Required when DirectOffsetColumnIndex is set</span>
     */
    directOffsetUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordImportProfileEdit {
    /**
     * Name of the import profile <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    profileCode;
    /**
     * The format for the record start/end dates.  It represents the regional convention for the order of day, month, and year. It is not a date format itself. <span class='property-internal'>Required</span> <span class='property-internal'>One of 'MM/dd/yyyy', 'dd/MM/yyyy', 'yyyy/MM/dd'</span> <span class='property-internal'>Case sensitive</span>
     */
    dateFormat;
    /**
     * The number of header rows before the data begins <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 9</span>
     */
    numberOfHeaderRows;
    /**
     * Flag to indicate if new emission sources or suppliers should be created if they do not already exist <span class='property-internal'>Required</span>
     */
    createNewEntities;
    /**
     * Optional notes field <span class='property-internal'>Max length of 255</span> <span class='property-internal'>Required (defined)</span>
     */
    notes;
    /**
     * The index of the column that holds the emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    emissionSourceCodeColumnIndex;
    /**
     * The index of the column that holds the emission source name <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when CreateNewEntities is set to True, case sensitive.</span> <span class='property-internal'>Must be null when CreateNewEntities  is  set to False, case sensitive</span>
     */
    emissionSourceNameColumnIndex;
    /**
     * The index of the column that holds the emission source type <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when CreateNewEntities is set to True, case sensitive.</span> <span class='property-internal'>Must be null when CreateNewEntities  is  set to False, case sensitive</span>
     */
    emissionSourceTypeColumnIndex;
    /**
     * The index of the column that holds the emission record start date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    startDateColumnIndex;
    /**
     * The index of the column that holds the emission record end date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    endDateColumnIndex;
    /**
     * The index of the column that holds the supplier name. This field is optional <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required (defined)</span>
     */
    supplierColumnIndex;
    /**
     * The index of the column that holds the notes for a record. This field is optional <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required (defined)</span>
     */
    notesColumnIndex;
    /**
     * The index of the column that holds the use for a record.   Required if no value is set for either the Cost Or Direct/Offset column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    useColumnIndex;
    /**
     * The identifier for the use unit to use.  Required if UseColumnIndex is set <span class='property-internal'>Required when UseColumnIndex is set</span>
     */
    useUnitId;
    /**
     * The index of the column that holds the cost for a record.   Required if no value is set for either the Use Or Direct/Offset column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    costColumnIndex;
    /**
     * The identifier for the cost unit to use.  Required if CostColumnIndex is set <span class='property-internal'>Required when CostColumnIndex is set</span>
     */
    costUnitId;
    /**
     * The index of the column that holds direct emissions/emission offsets for a record.   Required if no value is set for either the Use Or Cost column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    directOffsetColumnIndex;
    /**
     * The identifier for the direct emissions/emission offset unit to use.  Required if DirectOffsetColumnIndex is set <span class='property-internal'>Required when DirectOffsetColumnIndex is set</span>
     */
    directOffsetUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordImportProfileRequest {
    /**
     * Name of the import profile <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    profileCode;
    /**
     * The format for the record start/end dates.  It represents the regional convention for the order of day, month, and year. It is not a date format itself. <span class='property-internal'>Required</span> <span class='property-internal'>One of 'MM/dd/yyyy', 'dd/MM/yyyy', 'yyyy/MM/dd'</span> <span class='property-internal'>Case sensitive</span>
     */
    dateFormat;
    /**
     * The number of header rows before the data begins <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 9</span>
     */
    numberOfHeaderRows;
    /**
     * Flag to indicate if new emission sources or suppliers should be created if they do not already exist <span class='property-internal'>Required</span>
     */
    createNewEntities;
    /**
     * Optional notes field <span class='property-internal'>Max length of 255</span>
     */
    notes;
    /**
     * The index of the column that holds the emission source code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    emissionSourceCodeColumnIndex;
    /**
     * The index of the column that holds the emission source name <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when CreateNewEntities is set to True, case sensitive.</span> <span class='property-internal'>Must be null when CreateNewEntities  is  set to False, case sensitive</span>
     */
    emissionSourceNameColumnIndex;
    /**
     * The index of the column that holds the emission source type <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>Required when CreateNewEntities is set to True, case sensitive.</span> <span class='property-internal'>Must be null when CreateNewEntities  is  set to False, case sensitive</span>
     */
    emissionSourceTypeColumnIndex;
    /**
     * The index of the column that holds the emission record start date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    startDateColumnIndex;
    /**
     * The index of the column that holds the emission record end date <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 1 and 104</span>
     */
    endDateColumnIndex;
    /**
     * The index of the column that holds the supplier name. This field is optional <span class='property-internal'>Must be between 1 and 104</span>
     */
    supplierColumnIndex;
    /**
     * The index of the column that holds the notes for a record. This field is optional <span class='property-internal'>Must be between 1 and 104</span>
     */
    notesColumnIndex;
    /**
     * The index of the column that holds the use for a record.   Required if no value is set for either the Cost Or Direct/Offset column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    useColumnIndex;
    /**
     * The identifier for the use unit to use.  Required if UseColumnIndex is set <span class='property-internal'>Required when UseColumnIndex is set</span>
     */
    useUnitId;
    /**
     * The index of the column that holds the cost for a record.   Required if no value is set for either the Use Or Direct/Offset column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    costColumnIndex;
    /**
     * The identifier for the cost unit to use.  Required if CostColumnIndex is set <span class='property-internal'>Required when CostColumnIndex is set</span>
     */
    costUnitId;
    /**
     * The index of the column that holds direct emissions/emission offsets for a record.   Required if no value is set for either the Use Or Cost column numbers <span class='property-internal'>Must be between 1 and 104</span> <span class='property-internal'>At least one of UseColumnIndex, CostColumnIndex, DirectOffsetColumnIndex must not be null</span>
     */
    directOffsetColumnIndex;
    /**
     * The identifier for the direct emissions/emission offset unit to use.  Required if DirectOffsetColumnIndex is set <span class='property-internal'>Required when DirectOffsetColumnIndex is set</span>
     */
    directOffsetUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordImportProfileResponse {
    /**
     * Identifier of the record import profile
     */
    profileId;
    /**
     * Name of the import profile
     */
    profileCode;
    createdBy;
    /**
     * The date and time the import profile was modified
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time the import profile was modified
     */
    modifiedDate;
    /**
     * The format for the record start/end dates
     */
    dateFormat;
    /**
     * The number of header rows before the data begins
     */
    numberOfHeaderRows;
    /**
     * Flag to indicate if new emission sources or suppliers should be created if they do not already exist
     */
    createNewEntities;
    /**
     * Optional notes field
     */
    notes;
    /**
     * The index of the column that holds the emission source code
     */
    emissionSourceCodeColumnIndex;
    /**
     * The index of the column that holds the emission source name
     */
    emissionSourceNameColumnIndex;
    /**
     * The index of the column that holds the emission source type
     */
    emissionSourceTypeColumnIndex;
    /**
     * The index of the column that holds the emission record start date
     */
    startDateColumnIndex;
    /**
     * The index of the column that holds the emission record end date
     */
    endDateColumnIndex;
    /**
     * The index of the column that holds the supplier name
     */
    supplierColumnIndex;
    /**
     * The index of the column that holds the notes for a record
     */
    notesColumnIndex;
    /**
     * The index of the column that holds the use for a record
     */
    useColumnIndex;
    useUnit;
    /**
     * The index of the column that holds the cost for a record
     */
    costColumnIndex;
    costUnit;
    /**
     * The index of the column that holds direct emissions/emission offsets for a record
     */
    directOffsetColumnIndex;
    directOffsetUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordImportRequest {
    /**
     * Name of the import profile <span class='property-internal'>Must be between 0 and 64 characters</span> <span class='property-internal'>Only one of ProfileCode, InlineProfile can be set</span>
     */
    profileCode;
    inlineProfile;
    /**
     * FileName for the import file. Should include extension.  The extension allows the importer to read the data in the proper format (csv, xlsx) <span class='property-internal'>Required</span>
     */
    fileName;
    /**
     * The base64 encoded file <span class='property-internal'>Required</span>
     */
    fileContent;
    /**
     * Optional note/comment.
     */
    importNote;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Records {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordsListAdministrator {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordsListAdministratorClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordsModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RecordsModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RelatedReportResponse {
    /**
     * Specific report id of the related report
     */
    specificReportId;
    /**
     * Name of the related report
     */
    name;
    /**
     * Description of the related report
     */
    description;
    /**
     * The rendering engine used for the report (EnergyCAP currently uses SSRS and Crystal)
     */
    reportSource;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportAdministrator {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportAdministratorClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportCategoryChild {
    /**
     *
     */
    reportCategoryId;
    /**
     *
     */
    reportCategoryCode;
    /**
     *
     */
    reportCategoryInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportChild {
    /**
     * The version of the report
     */
    version;
    /**
     * The identifier of the report
     */
    reportId;
    /**
     * The report code
     */
    reportCode;
    /**
     * The report name
     */
    reportInfo;
    reportType;
    /**
     * The report description
     */
    description;
    /**
     * Indicates whether or not the report is rendered in landscape
     */
    isLandscape;
    /**
     * The last time this report was updated
     */
    lastUpdated;
    /**
     * Tags describing features of the report
     */
    tags;
    /**
     * Supported export formats (EnergyCAP currently supports PDF, Word, Excel, Excel data only, Excel formatted, and CSV)
     */
    exportFormats;
    /**
     * The rendering engine used for the report (EnergyCAP currently uses SSRS and Crystal)
     */
    reportSource;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportCreate {
    /**
     * New specific report code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    reportCode;
    /**
     * New specific report name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    reportInfo;
    /**
     * New specific report description <span class='property-internal'>Required</span>
     */
    reportDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionChild {
    /**
     * The id of the report distribution
     */
    reportDistributionId;
    /**
     * The name of the report distribution
     */
    reportDistributionName;
    /**
     * The report code to run as part of the report distribution
     */
    reportCode;
    createdByUser;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionCreateRequest {
    /**
     * The id of the report to distribute  A new copy of the report will be created for the distribution with the filters specified in this request  Any changes to the existing report will not effect the distribution copy  Only SSRS reports are supported <span class='property-internal'>Required</span>
     */
    specificReportId;
    /**
     * The name of the report distribution <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    reportDistributionName;
    /**
     * List of filters to apply to the report <span class='property-internal'>Required</span>
     */
    reportFilters;
    /**
     * The email address the receiver should reply to <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    replyToEmail;
    /**
     * The id of each user group that should receive the report <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required</span>
     */
    recipientUserGroupIds;
    /**
     * The subject line of the email <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    emailSubject;
    /**
     * The body of the email <span class='property-internal'>Required</span>
     */
    emailMessage;
    /**
     * The schedule type of the report  Values may be:  Daily: 1  Weekly: 2  Monthly: 3  Quarterly: 4 <span class='property-internal'>Required</span> <span class='property-internal'>One of '1', '2', '3', '4'</span> <span class='property-internal'>Case sensitive</span>
     */
    reportSubscriptionScheduleTypeId;
    /**
     * Indicates when to send the report for the given schedule type  Values may be:   Daily: 0  Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)  Monthly: Day of Month - 1 to 28  Quarterly: Month in Quarter - 1, 2, or 3 <span class='property-internal'>Must be between 0 and 28</span> <span class='property-internal'>Required</span>
     */
    dayIndicatorValue;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, the subscribed report will not be emailed, if the report does not contain data.  When set to false, if the requested report has no data, it will still be sent. <span class='property-internal'>Required</span>
     */
    onlySendIfData;
    /**
     * The format in which the generated report should be downloaded <span class='property-internal'>Required</span> <span class='property-internal'>One of 'Excel', 'Excel data only', 'Csv', 'PDF', 'Word'</span>
     */
    reportFormat;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionDetailsResponse {
    /**
     * The id of the report distribution
     */
    reportDistributionId;
    /**
     * The name of the report distribution
     */
    reportDistributionName;
    createdByUser;
    /**
     * The date and time the report distribution was created
     */
    createdDate;
    modifiedByUser;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * Last time the report distribution was run
     */
    lastRunDate;
    /**
     * Next time the report distribution will run
     */
    nextRunDate;
    /**
     * Indicates if the report distribution is currently enabled
     */
    enabled;
    /**
     * The id of the report being distributed
     */
    specificReportId;
    baseReport;
    emailSettings;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionEditRequest {
    /**
     * Indicates if the report distribution is currently enabled <span class='property-internal'>Required</span>
     */
    enabled;
    /**
     * The name of the report distribution <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    reportDistributionName;
    /**
     * List of filters to apply to the report <span class='property-internal'>Required</span>
     */
    reportFilters;
    /**
     * The email address the receiver should reply to <span class='property-internal'>Must be between 0 and 128 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    replyToEmail;
    /**
     * The id of each user group that should receive the report <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required</span>
     */
    recipientUserGroupIds;
    /**
     * The subject line of the email <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    emailSubject;
    /**
     * The body of the email <span class='property-internal'>Required</span>
     */
    emailMessage;
    /**
     * The schedule type of the report  Values may be:  Daily: 1  Weekly: 2  Monthly: 3  Quarterly: 4 <span class='property-internal'>Required</span> <span class='property-internal'>One of '1', '2', '3', '4'</span> <span class='property-internal'>Case sensitive</span>
     */
    reportSubscriptionScheduleTypeId;
    /**
     * Indicates when to send the report for the given schedule type  Values may be:   Daily: 0  Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)  Monthly: Day of Month - 1 to 28  Quarterly: Month in Quarter - 1, 2, or 3 <span class='property-internal'>Must be between 0 and 28</span> <span class='property-internal'>Required</span>
     */
    dayIndicatorValue;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, the subscribed report will not be emailed, if the report does not contain data.  When set to false, if the requested report has no data, it will still be sent. <span class='property-internal'>Required</span>
     */
    onlySendIfData;
    /**
     * The format in which the generated report should be downloaded <span class='property-internal'>Required</span> <span class='property-internal'>One of 'Excel', 'Excel data only', 'Csv', 'PDF', 'Word'</span>
     */
    reportFormat;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionEmailSettings {
    /**
     * The email address the receiver should reply to
     */
    replyToEmail;
    /**
     * The list of user groups that should receive the report
     */
    recipientUserGroups;
    /**
     * The subject line of the email
     */
    emailSubject;
    /**
     * The body of the email
     */
    emailMessage;
    /**
     * Format of the report (EnergyCAP currently supports PDF, Word, Excel, and CSV)
     */
    reportFormat;
    scheduleType;
    dayIndicator;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, the subscribed report will not be emailed, if the report does not contain data.  When set to false, if the requested report has no data, it will still be sent.
     */
    onlySendIfData;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionLogDetailsResponse {
    emailSettings;
    reportSettings;
    /**
     * Detailed errors that may have occurred during report distribution run
     */
    errors;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionLogEmailSettings {
    /**
     * The email address the the email was sent from
     */
    sentFromEmail;
    /**
     * The list of user groups with members that should receive the report
     */
    recipientUserGroups;
    /**
     * The email address the receiver should reply to
     */
    replyToEmail;
    /**
     * The subject line of the email
     */
    emailSubject;
    /**
     * The body of the email
     */
    emailMessage;
    /**
     * Format of the report (EnergyCAP currently supports PDF, Word, Excel, and CSV)
     */
    reportFormat;
    scheduleType;
    dayIndicator;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, the subscribed report will not be emailed, if the report does not contain data.  When set to false, if the requested report has no data, it will still be sent.
     */
    onlySendIfData;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionLogReportSettings {
    baseReport;
    /**
     * List of filters to apply to the report
     */
    reportFilters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportDistributionLogResponse {
    /**
     * The report distribution log identifier
     */
    reportDistributionLogId;
    reportDistribution;
    /**
     * The date and time the report distribution was started
     */
    beginDate;
    /**
     * The date and time the report distribution was completed
     */
    endDate;
    /**
     * The status of the report distribution  Possible values - In Progress, Complete, Not sent, Some reports not sent
     */
    status;
    /**
     * The number of unique recipients for the report  If a user is a member of multiple groups assigned to the report distribution they will only be counted once
     */
    numberOfRecipients;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportEdit {
    /**
     * New specific report code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    reportCode;
    /**
     * New specific report name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    reportInfo;
    /**
     * New specific report description <span class='property-internal'>Required</span>
     */
    reportDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportGroupChildResponse {
    /**
     *
     */
    reportGroupId;
    /**
     *
     */
    reportGroupCode;
    /**
     *
     */
    reportGroupInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportGroupRequest {
    /**
     *
     */
    reportGroupCode;
    /**
     *
     */
    reportGroupInfo;
    /**
     *
     */
    reportIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportGroupResponse {
    /**
     *
     */
    reportGroupId;
    /**
     *
     */
    reportGroupCode;
    /**
     *
     */
    reportGroupInfo;
    /**
     *
     */
    reports;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportGroups {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportGroupsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportSubscriptionChild {
    /**
     * The identifier of the report subscription
     */
    reportSubscriptionId;
    user;
    /**
     * The email address to send the report to
     */
    emailRecipient;
    /**
     * The subject line of the email
     */
    emailSubject;
    /**
     * The body of the email
     */
    emailMessage;
    /**
     * Format of the report (EnergyCAP currently supports PDF, Word, Excel, and CSV)
     */
    reportFormat;
    scheduleType;
    dayIndicator;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, the subscribed report will not be emailed, if the report does not contain data.  When set to false, if the requested report has no data, it will still be sent.
     */
    onlySendIfData;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportSubscriptionDayIndicatorChild {
    /**
     * Indicates when to send the report for the given schedule type  Values may be:   Daily: 0  Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)  Monthly: Day of Month - 1 to 28  Quarterly: Month in Quarter - 1, 2, or 3
     */
    dayIndicatorValue;
    /**
     * Name of the day indicator  Daily: None  Weekly: One of Sunday to Saturday  Monthly: One of 1 to 28  Quarterly: 1st day of month 1 of calendar quarter, 1st day of month 2 of calendar quarter, 1st day of month 3 of calendar quarter
     */
    dayIndicatorInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportSubscriptionRequest {
    /**
     * The subject line of the email <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required</span>
     */
    emailSubject;
    /**
     * The body of the email <span class='property-internal'>Required</span>
     */
    emailMessage;
    /**
     * The schedule type of the report  Values may be:  Daily: 1  Weekly: 2  Monthly: 3  Quarterly: 4 <span class='property-internal'>Required</span> <span class='property-internal'>One of '1', '2', '3', '4'</span> <span class='property-internal'>Case sensitive</span>
     */
    reportSubscriptionScheduleTypeId;
    /**
     * Indicates when to send the report for the given schedule type  Values may be:   Daily: 0  Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)  Monthly: Day of Month - 1 to 28  Quarterly: Month in Quarter - 1, 2, or 3 <span class='property-internal'>Must be between 0 and 28</span> <span class='property-internal'>Required</span>
     */
    dayIndicatorValue;
    /**
     * Indicates whether or not to email a report if it contains no data.  When set to true, the subscribed report will not be emailed, if the report does not contain data.  When set to false, if the requested report has no data, it will still be sent. <span class='property-internal'>Required</span>
     */
    onlySendIfData;
    /**
     * The format in which the generated report should be downloaded <span class='property-internal'>Required</span> <span class='property-internal'>One of 'Excel', 'Excel data only', 'Csv', 'PDF', 'Word'</span>
     */
    reportFormat;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportSubscriptionScheduleTypeChild {
    /**
     * The identifier of the subscription schedule type
     */
    reportSubscriptionScheduleTypeId;
    /**
     * The name of the subscription schedule type
     */
    reportSubscriptionScheduleTypeName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportSubscriptionScheduleTypeResponse {
    /**
     * The identifier of the schedule type
     */
    reportSubscriptionScheduleTypeId;
    /**
     * The name of the schedule type
     */
    reportSubscriptionScheduleTypeName;
    /**
     * Available day indicators for this schedule type
     */
    dayIndicators;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportType {
    /**
     * The identifier of the report type
     */
    reportTypeId;
    /**
     * The report type code
     */
    reportTypeCode;
    /**
     * The report type name
     */
    reportTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportingSettingRequest {
    /**
     * The energy unit identifier <span class='property-internal'>Required (defined)</span>
     */
    energyUnitId;
    /**
     * The cost unit identifier <span class='property-internal'>Required (defined)</span>
     */
    costUnitId;
    /**
     * The floor area unit identifier <span class='property-internal'>Required (defined)</span>
     */
    floorAreaUnitId;
    /**
     * Months to exclude from charts, including the current month.  Ex. If the current month is October,   A value of 0 will not exclude any months,   A value of 1 will exclude the month of October,   A value of 2 will exclude October and September,   A value of 3 will exclude October, September, and August,   A value of 13 will exclude October and the last full year of data. <span class='property-internal'>Must be between 0 and 13</span> <span class='property-internal'>Required (defined)</span>
     */
    monthsToExcludeFromCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportingSettingResponse {
    energyUnit;
    costUnit;
    floorAreaUnit;
    /**
     * Months to exclude from charts, including the current month.  Ex. If the current month is October,   A value of 0 will not exclude any months,   A value of 1 will exclude the month of October,   A value of 2 will exclude October and September,   A value of 3 will exclude October, September, and August,   A value of 13 will exclude October and the last full year of data.
     */
    monthsToExcludeFromCharts;
    /**
     * For internal use only. The task GUID of cost reporting unit post processing, only set when the cost reporting unit is changed in the Edit Reporting Settings API.
     */
    costReportingUnitTaskGUId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Reports {
    /**
     *
     */
    run;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportsClassPermission {
    /**
     *
     */
    run;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportsModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ReportsModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RequiredAddressChild {
    /**
     * The address country <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    country;
    /**
     * The postal code for the address  Required when the country is United States or Canada <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    postalCode;
    /**
     * The address type identifier
     */
    addressTypeId;
    /**
     * The line 1 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line1;
    /**
     * The line 2 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line2;
    /**
     * The line 3 of the address <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    line3;
    /**
     * The city of the place <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    city;
    /**
     * The state of the place <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    state;
    /**
     * The latitude of the place  Required when the country is not United States or Canada <span class='property-internal'>Must be between -90 and 90</span> <span class='property-internal'>Required when Longitude is set</span>
     */
    latitude;
    /**
     * The longitude of the place  Required when the country is not United States or Canada <span class='property-internal'>Must be between -180 and 180</span> <span class='property-internal'>Required when Latitude is set</span>
     */
    longitude;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ResetUserPasswords {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ResetUserPasswordsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Reviewed {
    /**
     * Indicates whether or not the savings has been reviewed
     */
    reviewed;
    reviewedBy;
    /**
     * Reviewed date
     */
    reviewedDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Roles {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RolesClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RollingComparisonDetail {
    yearRange;
    /**
     * The monthly values within the year range
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RollingComparisonPeriodValue {
    /**
     * The grouped values within the period
     */
    groupByValues;
    /**
     * The period
     */
    period;
    /**
     * The value within the period
     */
    value;
    /**
     * The formatted value within the period
     */
    formattedValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RollingComparisonResponse {
    /**
     * Indicates the type of the data displayed. Eg: Actual, Calendarized or Normalized.
     */
    dataDisplayed;
    /**
     * The values unit
     */
    unit;
    periodRange;
    /**
     * The entities for the groups
     */
    groupByEntities;
    /**
     * The data details
     */
    dataDetails;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RollupUnitUpdate {
    /**
     * List of commodities and their rollup units to update <span class='property-internal'>Required (defined)</span>
     */
    commonRollups;
    /**
     * The global rollup unit. Automatically assigned to ENERGY commodity. Pass in null to leave alone. <span class='property-internal'>Required (defined)</span>
     */
    globalRollupUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RollupUnitUpdateCommonUnit {
    /**
     * The commodity identifier <span class='property-internal'>Required (defined)</span>
     */
    commodityId;
    /**
     * The unit identifier that this commodity will roll up to <span class='property-internal'>Required (defined)</span>
     */
    commonRollupUnitId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RouteChild {
    /**
     * The route identifier
     */
    routeId;
    /**
     * The route info
     */
    routeInfo;
    /**
     * The route code
     */
    routeCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RouteDetailsResponse {
    /**
     * The meters assigned to this route
     */
    meters;
    /**
     * The number of meters assigned to this route
     */
    numberOfMeters;
    /**
     * The route identifier
     */
    routeId;
    /**
     * The route info
     */
    routeInfo;
    /**
     * The route code
     */
    routeCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RouteMeter {
    /**
     * The identifier for the meter <span class='property-internal'>Required</span>
     */
    meterId;
    /**
     * The display order for this route meter
     */
    displayOrder;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RouteMeterChannelLatestReadingResponse {
    /**
     * List of meters with channels and their latest reading
     */
    meters;
    /**
     * The route identifier
     */
    routeId;
    /**
     * The route info
     */
    routeInfo;
    /**
     * The route code
     */
    routeCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RouteRequest {
    /**
     * The route info <span class='property-internal'>Must be between 0 and 32 characters</span> <span class='property-internal'>Required</span>
     */
    routeInfo;
    /**
     * The route code  This property has been deprecated. Route code will be generated from the value in route info <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    routeCode;
    /**
     * The list of IDs for meters to be assigned to the route. The order in which the meter IDs appear will determine their order on the route.  NOTE: if the same meter ID is passed in multiple times, the first occurrence of the meter ID will be used to determine the order on the route <span class='property-internal'>Required</span>
     */
    meterIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class RouteResponse {
    /**
     * The number of meters assigned to this route
     */
    numberOfMeters;
    /**
     * The route identifier
     */
    routeId;
    /**
     * The route info
     */
    routeInfo;
    /**
     * The route code
     */
    routeCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SavingsAdjustments {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SavingsAdjustmentsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * SavingsDaily Data - a class that represents CA Savings for a given day per meter/bill
 */
class SavingsDailyData {
    /**
     * Baseline Adjusted to Current Conditions (BATCC) non-weather use in native units
     */
    batccNonWeatherNativeUse;
    /**
     * Baseline Adjusted to Current Conditions (BATCC) weather use in native units
     */
    batccWeatherNativeUse;
    /**
     * Baseline non-weather Use in native units
     */
    baselineNonWeatherNativeUse;
    /**
     * Baseline weather use in native units
     */
    baselineWeatherNativeUse;
    /**
     * Baseline Adjusted to Current Conditions (BATCC) cost
     */
    batccCost;
    /**
     * Average unit cost
     */
    averageUnitCost;
    /**
     * Number of cooling degrees used on this day in the baseline
     */
    baselineCoolingDegreeDays;
    /**
     * Number of cooling degrees used on this day
     */
    currentCoolingDegreeDays;
    /**
     * Number of heating degrees used on this day in the baseline
     */
    baselineHeatingDegreeDays;
    /**
     * Number of heating degrees used on this day
     */
    currentHeatingDegreeDays;
    /**
     * Indicates whether or not a Special Adjustment was in effect on this day
     */
    specialAdjustment;
    /**
     * Indicates whether or not an Area Adjustment was in effect on this day
     */
    areaAdjustment;
    /**
     * Indicates whether or not Weather Adjustment was in effect on this day
     */
    weatherAdjustment;
    /**
     * Indicates whether or not Other Adjustment was in effect on this day
     */
    otherAdjustment;
    /**
     * Daily savings date
     */
    date;
    /**
     * List of Processor Messages for this day
     */
    messages;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SavingsEngine {
    /**
     *
     */
    run;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SavingsEngineClassPermission {
    /**
     *
     */
    run;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SavingsLog {
    /**
     * The status of savings processing
     */
    status;
    /**
     * Number of meters successfully processed
     */
    successCount;
    /**
     * Number of bills processed that have warnings across all meters processed  A bill has a \"warning\" if it had 1) incomplete weather data or 2) exceeded the average unit cost range set for its commodity
     */
    warningCount;
    /**
     * Number of meters processed with errors
     */
    errorCount;
    /**
     * Number of meters to process
     */
    numberOfMeters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * SavingsMeterBillDailyResponseDTO - This class is the DTO for a meter's bill's Cost Avoidance savings in daily format  It provides the meter, bill, use unit, and then an array of daily savings values  Each daily value contains date that represents this day, non-weather use, weather use, BATCC Cost, average daily unit cost,   whether any of the four adjustments (special, area, weather, other) were performed  and a list of messages generated by the Savings Processor for this day
 */
class SavingsMeterBillDailyResponse {
    /**
     * Unique meter identifier
     */
    meterId;
    /**
     * Meter Code
     */
    meterCode;
    /**
     * Meter Name
     */
    meterInfo;
    /**
     * Unique bill identifier
     */
    billId;
    /**
     * Calendar Period Name (e.g. Jan)
     */
    periodName;
    /**
     * Calendar period Number (e.g. 1)
     */
    calendarPeriod;
    /**
     * Calendar year (e.g. 2019)
     */
    calendarYear;
    /**
     * Fiscal period number
     */
    fiscalPeriod;
    /**
     * Fiscal year
     */
    fiscalYear;
    nativeUseUnit;
    /**
     * Cost avoidance savings for this meter, day by day
     */
    daily;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SavingsMeterBillResponse {
    /**
     * Unique ID for this savings record (Bill Meter CAP)
     */
    billMtrCapId;
    /**
     * Unique ID of the bill processed for this savings record
     */
    billId;
    /**
     * Calendar Period Name (e.g. Jan)
     */
    periodName;
    /**
     * Calendar Period Number (e.g. 4)
     */
    calendarPeriod;
    /**
     * Calendar Year (e.g. 2019)
     */
    calendarYear;
    /**
     * Fiscal Period Number
     */
    fiscalPeriod;
    /**
     * Fiscal Year
     */
    fiscalYear;
    /**
     * Baseline Cost
     */
    baselineCost;
    /**
     * Baseline Native Use
     */
    baselineNativeUse;
    /**
     * Baseline Weather Native Use
     */
    baselineWeatherNativeUse;
    /**
     * Baseline Nonweather Native Use
     */
    baselineNonweatherNativeUse;
    /**
     * Baseline Adjusted to Current Conditions (BATCC) Cost
     */
    batccCost;
    /**
     * Baseline Adjusted to Current Conditions (BATCC) Native Use
     */
    batccNativeUse;
    /**
     * Baseline Adjusted to Current Conditions (BATCC) Weather Native Use
     */
    batccWeatherNativeUse;
    /**
     * Baseline Adjusted to Current Conditions (BATCC) Nonweather Native Use
     */
    batccNonweatherNativeUse;
    /**
     * Actual Cost
     */
    actualCost;
    /**
     * Actual Native Use
     */
    actualNativeUse;
    /**
     * Savings Cost
     */
    savingsCost;
    /**
     * Savings Native Use
     */
    savingsNativeUse;
    /**
     * Savings Cost Percent
     */
    savingsCostPercent;
    /**
     * Savings Native Use Percent
     */
    savingsNativeUsePercent;
    /**
     * Heating Degree Days
     */
    hdd;
    /**
     * Cooling Degree Days
     */
    cdd;
    /**
     * Heating Degree Days Adjusted
     */
    hddAdjusted;
    /**
     * Cooling Degree Days Adjusted
     */
    cddAdjusted;
    /**
     * Heating Use Per Degree Day
     */
    heatingUsePerDegreeDay;
    /**
     * Heating R2
     */
    heatR2;
    /**
     * Cooling Use Per Degree Day
     */
    coolingUsePerDegreeDay;
    /**
     * Cooling R2
     */
    coolR2;
    /**
     * Cost Avoidance Status
     */
    capStatus;
    /**
     * Indicates whether or not the bill's cost avoidance data is locked
     */
    locked;
    /**
     *
     */
    billMtrNotes;
    nativeUseUnit;
    review;
    account;
    meter;
    place;
    costUnit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ScheduleChild {
    /**
     * The ID of this Schedule record.
     */
    scheduleId;
    /**
     * Information about this schedule. This can be thought of as a name.  For example, \"24/7\".
     */
    scheduleInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ScheduleCreate {
    /**
     * Unique name of the schedule <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    scheduleInfo;
    /**
     * Optional description of the schedule <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    scheduleDescription;
    /**
     * List of schedule day definition for each day of the week  All 7 days must be informed <span class='property-internal'>Cannot be Empty</span>
     */
    scheduleDays;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ScheduleDay {
    /**
     * The ID of this ScheduleDay record.
     */
    scheduleDayId;
    dayOfWeek;
    /**
     * The time of day that this schedule begins.  It is serialized as a \"HH:MM:SS\" string.  For example, \"09:00:00\".
     */
    beginTime;
    /**
     * The time of day that this schedule ends.  It is serialized as a \"HH:MM:SS\" string.  For example, \"17:29:59\".
     */
    endTime;
    /**
     * Indicates whether the record represents an opening period of 24 hours.  - i.e. starting at \"00:00:00\" and finishing at \"23:59:59\"
     */
    is24Hours;
    /**
     * Indicates whether the record represents being closed for the entire day.  If this is `true` then BeginTime and EndTime will both be null.
     */
    isClosed;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ScheduleDayCreate {
    /**
     * The day of week that this record refers to. <span class='property-internal'>Required</span> <span class='property-internal'>Must be a valid value for DayOfWeek: Sunday = 0, Monday = 1, Tuesday = 2, Wednesday = 3, Thursday = 4, Friday = 5, Saturday = 6</span>
     */
    dayOfWeek;
    /**
     * The time of day that this schedule begins.   It is serialized as a \"HH:MM:SS\" string.  For example, \"17:29:59\".  Should only be informed when Is24Hours = false AND IsClosed = false, otherwise it should be null. <span class='property-internal'>Must be null when IsClosed, or Is24Hours are set to True, case sensitive</span>
     */
    beginTime;
    /**
     * The time of day that this schedule ends.  It is serialized as a \"HH:MM:SS\" string.  For example, \"17:29:59\".  Should only be informed when Is24Hours = false AND IsClosed = false, otherwise it should be null. <span class='property-internal'>Must be greater than BeginTime</span> <span class='property-internal'>Must be null when IsClosed, or Is24Hours are set to True, case sensitive</span>
     */
    endTime;
    /**
     * Indicates whether the record represents an opening period of 24 hours.  When Is24Hours = true, BeginTime and EndTime should be null because it will automatically be set to begin at \"00:00:00\" and finish at \"23:59:59\"
     */
    is24Hours;
    /**
     * Indicates whether the record represents being closed for the entire day.  When IsClosed = true, BeginTime and EndTime should be null because it does not apply for a closed day.
     */
    isClosed;
}
(function (ScheduleDayCreate) {
    let DayOfWeekEnum;
    (function (DayOfWeekEnum) {
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_0"] = 0] = "NUMBER_0";
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_1"] = 1] = "NUMBER_1";
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_2"] = 2] = "NUMBER_2";
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_3"] = 3] = "NUMBER_3";
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_4"] = 4] = "NUMBER_4";
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_5"] = 5] = "NUMBER_5";
        DayOfWeekEnum[DayOfWeekEnum["NUMBER_6"] = 6] = "NUMBER_6";
    })(DayOfWeekEnum = ScheduleDayCreate.DayOfWeekEnum || (ScheduleDayCreate.DayOfWeekEnum = {}));
})(ScheduleDayCreate || (ScheduleDayCreate = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ScheduleEdit {
    /**
     * Unique name of the schedule <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    scheduleInfo;
    /**
     * Optional description of the schedule <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    scheduleDescription;
    /**
     * List of schedule day definition for each day of the week  All 7 days must be informed <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    scheduleDays;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ScheduleResponse {
    /**
     * A longer description of this schedule.  For example, \"9-5, Mon-Fri\".
     */
    scheduleDescription;
    /**
     * A list of 7 ScheduleDay records, each of which defines  the open hours for a single day of the week.  They are returned in order, beginning with Sunday and  ending with Saturday.
     */
    scheduleDays;
    createdBy;
    /**
     * The date when the schedule was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date when the version was schedule
     */
    modifiedDate;
    /**
     * The ID of this Schedule record.
     */
    scheduleId;
    /**
     * Information about this schedule. This can be thought of as a name.  For example, \"24/7\".
     */
    scheduleInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Represents a Schedule in the context of an interval data response. An interval data  response contain results for zero, one, or more \"Entities\" (for example, Data Points,  Places, or Commodities).  For each Entity, this DTO includes a summary containing its associated \"in-schedule\" and  \"out-schedule\" use (or demand).
 */
class ScheduleWithEntitySummaries {
    /**
     *
     */
    entityScheduleSummaries;
    /**
     * A longer description of this schedule.  For example, \"9-5, Mon-Fri\".
     */
    scheduleDescription;
    /**
     * A list of 7 ScheduleDay records, each of which defines  the open hours for a single day of the week.  They are returned in order, beginning with Sunday and  ending with Saturday.
     */
    scheduleDays;
    createdBy;
    /**
     * The date when the schedule was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date when the version was schedule
     */
    modifiedDate;
    /**
     * The ID of this Schedule record.
     */
    scheduleId;
    /**
     * Information about this schedule. This can be thought of as a name.  For example, \"24/7\".
     */
    scheduleInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchAccountChild {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchAccountChildSearchAccountChild {
    /**
     * The Account identifier
     */
    accountId;
    /**
     * The Account code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    accountCode;
    /**
     * The Account info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    accountInfo;
    /**
     * Indicates whether the Account is active or inactive
     */
    active;
    accountType;
    vendor;
    address;
    /**
     * The collection of cost centers representing the path to its parent
     */
    parentPath;
    /**
     * Indicates whether the Account has a child calculated meter
     */
    hasCalculatedMeter;
    /**
     * Indicates whether the Account is a recipient of a split
     */
    hasSplitParentMeter;
    /**
     * Indicates whether the Account has a child split meter
     */
    hasSplitChildMeter;
    /**
     * Indicates whether the Account is a sub-account
     */
    isSubAccount;
    /**
     * Indicates whether the Account has a sub-account
     */
    hasSubAccount;
    /**
     * The previous Account code
     */
    previousAccountCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchAccountMeterBillEntry {
    /**
     * The MatchType  values -  Account - we found a match on account code, account info or previous account code  Meter - we found a match on meter code, meter info or serial number  AccountAddress - we found a match on account's address - line1, line2, city or state  MeterAddress - we found a match on meter's address - line1, line2, city or state
     */
    matchType;
    /**
     * The Account identifier
     */
    accountId;
    /**
     * The Account code
     */
    accountCode;
    /**
     * The Account info
     */
    accountInfo;
    /**
     * The Previous Account code
     */
    previousAccountCode;
    /**
     * Indicates whether the Account is active or inactive
     */
    active;
    accountType;
    /**
     * Indicates whether the Account has a child calculated meter
     */
    hasCalculatedMeter;
    /**
     * Indicates whether the Account is a recipient of a split
     */
    hasSplitParentMeter;
    /**
     * Indicates whether the Account has a child split meter
     */
    hasSplitChildMeter;
    /**
     * Indicates whether the Account is a sub-account
     */
    isSubAccount;
    /**
     * Indicates whether the Account has a sub-account
     */
    hasSubAccount;
    vendor;
    accountAddress;
    /**
     * The Account's vendor
     */
    meters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchCollectionChild {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchCollectionChildSearchCollection {
    /**
     * The collection identifier
     */
    collectionId;
    /**
     * The collection code
     */
    collectionCode;
    /**
     * The collection info
     */
    collectionInfo;
    collectionIcon;
    /**
     * The collection of CarbonHub collections representing the path to its parent
     */
    parentPath;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchCostCenterChild {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchCostCenterChildSearchCostCenter {
    /**
     * The cost center identifier
     */
    costCenterId;
    /**
     * The cost center code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    costCenterCode;
    /**
     * The cost center info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    costCenterInfo;
    /**
     * The collection of cost centers representing the path to its parent
     */
    parentPath;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchEmissionSourceChild {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchEmissionSourceChildSearchEmissionSource {
    /**
     * The emissions source identifier
     */
    emissionSourceId;
    /**
     * The emissions source code
     */
    emissionSourceCode;
    /**
     * The emissions source info
     */
    emissionSourceInfo;
    commodity;
    /**
     * The collection of CarbonHub collections representing the path to its parent
     */
    parentPath;
    /**
     * Indicates whether or not the emissions source is active
     */
    active;
    /**
     * The address postal code
     */
    postalCode;
    /**
     * The address city
     */
    city;
    /**
     * The address state
     */
    state;
    /**
     * The address country
     */
    country;
    /**
     * The address first line
     */
    line1;
    /**
     * The address second line
     */
    line2;
    /**
     * The address third line
     */
    line3;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchMeterChild {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchMeterChildSearchMeterChild {
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    meterCode;
    /**
     * The meter info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    meterInfo;
    /**
     * The collection of accounts
     */
    accounts;
    commodity;
    meterType;
    /**
     * The address postal code
     */
    postalCode;
    /**
     * The address city
     */
    city;
    /**
     * The address state
     */
    state;
    /**
     * The address country
     */
    country;
    /**
     * The address first line
     */
    line1;
    /**
     * The address second line
     */
    line2;
    /**
     * The address third line
     */
    line3;
    /**
     * The bill entry note
     */
    billEntryNote;
    /**
     * Indicates if the building is included in ENERGY STAR submissions
     */
    includeInEnergyStar;
    /**
     * An array of meter properties
     */
    properties;
    /**
     * The collection of places representing the path to its parent
     */
    parentPath;
    /**
     * Indicates whether the meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The previous serial number of the meter
     */
    previousSerialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchParentPlaceChild {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
    placeType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchPlaceChild {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchPlaceChildSearchPlaceChild {
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    placeCode;
    /**
     * The place info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    placeInfo;
    placeType;
    address;
    /**
     * The collection of places representing the path to its parent
     */
    parentPath;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchPlaceGroup {
    result;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SearchResponse {
    /**
     * The collection of cost centers
     */
    costCenters;
    /**
     * The collection of accounts
     */
    accounts;
    /**
     * The collection of places
     */
    places;
    /**
     * The collection of meters
     */
    meters;
    /**
     * The collection of place groups
     */
    placeGroups;
    /**
     * The collection of CarbonHub collections
     */
    collections;
    /**
     * The collection of CarbonHub emissions sources
     */
    emissionSources;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SendDataAccessReleaseRequest {
    /**
     * Sets the reply-to email address <span class='property-internal'>Must be between 0 and 128 characters</span> <span class='property-internal'>Required</span>
     */
    replyTo;
    /**
     * The list of recipient email addresses <span class='property-internal'>Cannot be Empty</span>
     */
    recipients;
    /**
     * The subject of the data access release request email <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    subject;
    /**
     * The body of the data access release request email <span class='property-internal'>Required</span>
     */
    message;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SendNotifications {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SendNotificationsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Setup {
    /**
     * Type of importer
     */
    type;
    /**
     * Type of sheet that was imported
     */
    sheetType;
    /**
     * Action that was performed - create, update, convert
     */
    action;
    /**
     * Count of rows that succeeded
     */
    success;
    /**
     * Count of rows that failed
     */
    failure;
    /**
     * Count of rows that were skipped
     */
    skip;
    /**
     * A stream that represents the kickout file
     */
    kickout;
    /**
     * Time at which the import started
     */
    start;
    /**
     * Time at which the import finished
     */
    finish;
    /**
     * Unique identifier for this import
     */
    taskId;
}
(function (Setup) {
    let TypeEnum;
    (function (TypeEnum) {
        TypeEnum[TypeEnum["UNKNOWNTYPE"] = 'UNKNOWNTYPE'] = "UNKNOWNTYPE";
        TypeEnum[TypeEnum["CREATEAccountsAndMeters"] = 'CREATE_AccountsAndMeters'] = "CREATEAccountsAndMeters";
        TypeEnum[TypeEnum["CREATEBuildingsAndOrganizations"] = 'CREATE_BuildingsAndOrganizations'] = "CREATEBuildingsAndOrganizations";
        TypeEnum[TypeEnum["CREATECostAvoidanceOtherSavings"] = 'CREATE_CostAvoidanceOtherSavings'] = "CREATECostAvoidanceOtherSavings";
        TypeEnum[TypeEnum["CREATECostAvoidanceSpecialAdjustments"] = 'CREATE_CostAvoidanceSpecialAdjustments'] = "CREATECostAvoidanceSpecialAdjustments";
        TypeEnum[TypeEnum["CREATECostCenters"] = 'CREATE_CostCenters'] = "CREATECostCenters";
        TypeEnum[TypeEnum["CREATECustomers"] = 'CREATE_Customers'] = "CREATECustomers";
        TypeEnum[TypeEnum["CREATEChargebackDistributionsVersions"] = 'CREATE_ChargebackDistributionsVersions'] = "CREATEChargebackDistributionsVersions";
        TypeEnum[TypeEnum["CREATERateSchedules"] = 'CREATE_RateSchedules'] = "CREATERateSchedules";
        TypeEnum[TypeEnum["CREATEVendors"] = 'CREATE_Vendors'] = "CREATEVendors";
        TypeEnum[TypeEnum["CREATEChannels"] = 'CREATE_Channels'] = "CREATEChannels";
        TypeEnum[TypeEnum["UPDATECostCenters"] = 'UPDATE_CostCenters'] = "UPDATECostCenters";
        TypeEnum[TypeEnum["UPDATEBuildingsAndOrganizations"] = 'UPDATE_BuildingsAndOrganizations'] = "UPDATEBuildingsAndOrganizations";
        TypeEnum[TypeEnum["UPDATEAccountingCalendar"] = 'UPDATE_AccountingCalendar'] = "UPDATEAccountingCalendar";
        TypeEnum[TypeEnum["UPDATEAccounts"] = 'UPDATE_Accounts'] = "UPDATEAccounts";
        TypeEnum[TypeEnum["UPDATECustomFieldsAccount"] = 'UPDATE_CustomFieldsAccount'] = "UPDATECustomFieldsAccount";
        TypeEnum[TypeEnum["UPDATECostAvoidanceOtherSavings"] = 'UPDATE_CostAvoidanceOtherSavings'] = "UPDATECostAvoidanceOtherSavings";
        TypeEnum[TypeEnum["UPDATECostAvoidanceSpecialAdjustments"] = 'UPDATE_CostAvoidanceSpecialAdjustments'] = "UPDATECostAvoidanceSpecialAdjustments";
        TypeEnum[TypeEnum["UPDATECustomers"] = 'UPDATE_Customers'] = "UPDATECustomers";
        TypeEnum[TypeEnum["CREATEGLCodesAndSubcodes"] = 'CREATE_GLCodesAndSubcodes'] = "CREATEGLCodesAndSubcodes";
        TypeEnum[TypeEnum["UPDATEGLCodesAndSubcodes"] = 'UPDATE_GLCodesAndSubcodes'] = "UPDATEGLCodesAndSubcodes";
        TypeEnum[TypeEnum["UPDATEMeters"] = 'UPDATE_Meters'] = "UPDATEMeters";
        TypeEnum[TypeEnum["UPDATECustomFieldsMeter"] = 'UPDATE_CustomFieldsMeter'] = "UPDATECustomFieldsMeter";
        TypeEnum[TypeEnum["UPDATECustomFieldsPlace"] = 'UPDATE_CustomFieldsPlace'] = "UPDATECustomFieldsPlace";
        TypeEnum[TypeEnum["UPDATEUsers"] = 'UPDATE_Users'] = "UPDATEUsers";
        TypeEnum[TypeEnum["UPDATEVendors"] = 'UPDATE_Vendors'] = "UPDATEVendors";
        TypeEnum[TypeEnum["UPDATECustomFieldsVendor"] = 'UPDATE_CustomFieldsVendor'] = "UPDATECustomFieldsVendor";
        TypeEnum[TypeEnum["CREATEUsers"] = 'CREATE_Users'] = "CREATEUsers";
        TypeEnum[TypeEnum["UPDATEChannels"] = 'UPDATE_Channels'] = "UPDATEChannels";
        TypeEnum[TypeEnum["UPDATEBillCalculations"] = 'UPDATE_BillCalculations'] = "UPDATEBillCalculations";
        TypeEnum[TypeEnum["CREATEBillCalculations"] = 'CREATE_BillCalculations'] = "CREATEBillCalculations";
        TypeEnum[TypeEnum["UPDATEBillSplits"] = 'UPDATE_BillSplits'] = "UPDATEBillSplits";
        TypeEnum[TypeEnum["CREATEBillSplits"] = 'CREATE_BillSplits'] = "CREATEBillSplits";
        TypeEnum[TypeEnum["UPDATEMeterGroups"] = 'UPDATE_MeterGroups'] = "UPDATEMeterGroups";
        TypeEnum[TypeEnum["UPDATEBuildingGroups"] = 'UPDATE_BuildingGroups'] = "UPDATEBuildingGroups";
        TypeEnum[TypeEnum["CREATEReadings"] = 'CREATE_Readings'] = "CREATEReadings";
        TypeEnum[TypeEnum["UPDATEReadings"] = 'UPDATE_Readings'] = "UPDATEReadings";
        TypeEnum[TypeEnum["CREATEMonthlyReadings"] = 'CREATE_MonthlyReadings'] = "CREATEMonthlyReadings";
        TypeEnum[TypeEnum["CREATEPlaceBenchmarks"] = 'CREATE_PlaceBenchmarks'] = "CREATEPlaceBenchmarks";
        TypeEnum[TypeEnum["UPDATEPlaceBenchmarks"] = 'UPDATE_PlaceBenchmarks'] = "UPDATEPlaceBenchmarks";
        TypeEnum[TypeEnum["CREATEUserGroups"] = 'CREATE_UserGroups'] = "CREATEUserGroups";
        TypeEnum[TypeEnum["UPDATEUserGroups"] = 'UPDATE_UserGroups'] = "UPDATEUserGroups";
        TypeEnum[TypeEnum["UPDATEUserGroupMembers"] = 'UPDATE_UserGroupMembers'] = "UPDATEUserGroupMembers";
        TypeEnum[TypeEnum["UPDATEPlaceEnergyStarLink"] = 'UPDATE_PlaceEnergyStarLink'] = "UPDATEPlaceEnergyStarLink";
        TypeEnum[TypeEnum["CREATEBuildingForecastWorksheet"] = 'CREATE_BuildingForecastWorksheet'] = "CREATEBuildingForecastWorksheet";
        TypeEnum[TypeEnum["UPDATEMeterEmissionSourceLink"] = 'UPDATE_MeterEmissionSourceLink'] = "UPDATEMeterEmissionSourceLink";
        TypeEnum[TypeEnum["UPDATECustomGhgFactors"] = 'UPDATE_CustomGhgFactors'] = "UPDATECustomGhgFactors";
        TypeEnum[TypeEnum["CREATEEmissionRecords"] = 'CREATE_EmissionRecords'] = "CREATEEmissionRecords";
        TypeEnum[TypeEnum["UPDATEEmissionRecords"] = 'UPDATE_EmissionRecords'] = "UPDATEEmissionRecords";
        TypeEnum[TypeEnum["UPDATEBasicUnitConversions"] = 'UPDATE_BasicUnitConversions'] = "UPDATEBasicUnitConversions";
        TypeEnum[TypeEnum["CREATECollections"] = 'CREATE_Collections'] = "CREATECollections";
        TypeEnum[TypeEnum["UPDATECollections"] = 'UPDATE_Collections'] = "UPDATECollections";
        TypeEnum[TypeEnum["UPDATEAdvancedUnitConversions"] = 'UPDATE_AdvancedUnitConversions'] = "UPDATEAdvancedUnitConversions";
        TypeEnum[TypeEnum["CREATEEmissionSources"] = 'CREATE_EmissionSources'] = "CREATEEmissionSources";
        TypeEnum[TypeEnum["UPDATEEmissionSources"] = 'UPDATE_EmissionSources'] = "UPDATEEmissionSources";
        TypeEnum[TypeEnum["UPDATEBudgetMonthlyMeter"] = 'UPDATE_BudgetMonthlyMeter'] = "UPDATEBudgetMonthlyMeter";
        TypeEnum[TypeEnum["UPDATEBudgetMonthlyBuilding"] = 'UPDATE_BudgetMonthlyBuilding'] = "UPDATEBudgetMonthlyBuilding";
        TypeEnum[TypeEnum["UPDATEBillPaymentDetails"] = 'UPDATE_BillPaymentDetails'] = "UPDATEBillPaymentDetails";
        TypeEnum[TypeEnum["UPDATEBillLineTypeMapping"] = 'UPDATE_BillLineTypeMapping'] = "UPDATEBillLineTypeMapping";
        TypeEnum[TypeEnum["UPDATECostCategoryMapping"] = 'UPDATE_CostCategoryMapping'] = "UPDATECostCategoryMapping";
        TypeEnum[TypeEnum["CREATESpaces"] = 'CREATE_Spaces'] = "CREATESpaces";
        TypeEnum[TypeEnum["UPDATESpaces"] = 'UPDATE_Spaces'] = "UPDATESpaces";
        TypeEnum[TypeEnum["CREATEDataPoints"] = 'CREATE_DataPoints'] = "CREATEDataPoints";
        TypeEnum[TypeEnum["UPDATEDataPoints"] = 'UPDATE_DataPoints'] = "UPDATEDataPoints";
        TypeEnum[TypeEnum["CREATEEsaReadings"] = 'CREATE_EsaReadings'] = "CREATEEsaReadings";
        TypeEnum[TypeEnum["UPDATEEsaReadings"] = 'UPDATE_EsaReadings'] = "UPDATEEsaReadings";
        TypeEnum[TypeEnum["CREATESitesAndSpaces"] = 'CREATE_SitesAndSpaces'] = "CREATESitesAndSpaces";
        TypeEnum[TypeEnum["UPDATESitesAndSpaces"] = 'UPDATE_SitesAndSpaces'] = "UPDATESitesAndSpaces";
        TypeEnum[TypeEnum["CREATEEsaChannels"] = 'CREATE_EsaChannels'] = "CREATEEsaChannels";
        TypeEnum[TypeEnum["UPDATEEsaChannels"] = 'UPDATE_EsaChannels'] = "UPDATEEsaChannels";
    })(TypeEnum = Setup.TypeEnum || (Setup.TypeEnum = {}));
})(Setup || (Setup = {}));

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ShareRequest {
    /**
     * Set to True to share the item everyone  When true, SharedUsers and SharedUserGroups should be set to empty lists [] <span class='property-internal'>Required</span>
     */
    sharedWithEveryone;
    /**
     * The list of individual user ids an item should be shared with  Should be an empty list [], when SharedWithEveryone is true <span class='property-internal'>Required</span>
     */
    sharedUserIds;
    /**
     * The list of user group ids an item should be shared with  Should be an empty list [], when SharedWithEveryone is true <span class='property-internal'>Required</span>
     */
    sharedUserGroupIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ShareResponse {
    /**
     * True if the item is shared with everyone
     */
    sharedWithEveryone;
    /**
     * The list of individual users an item has been assigned to be shared with  This does NOT take into account users that are in a shared user group
     */
    sharedUsers;
    /**
     * The list of user groups an item has been assigned to be shared with
     */
    sharedUserGroups;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedBillLists {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedBillListsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedDashboardsOrMaps {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedDashboardsOrMapsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedRecordsLists {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedRecordsListsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedReports {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SharedReportsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SingleBoolean {
    /**
     *
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SingleValue {
    /**
     *
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecialAdjustmentCreate {
    /**
     * Special adjustment method identifier <span class='property-internal'>Required</span>
     */
    specialAdjustmentMethodId;
    /**
     * Reason for making the special adjustment <span class='property-internal'>Required</span>
     */
    comments;
    /**
     * Amount  See special adjustment method list for acceptable precision  Precision of -1 means the value should not be passed in
     */
    value;
    /**
     * Special adjustment type identifier <span class='property-internal'>Required</span>
     */
    specialAdjustmentTypeId;
    /**
     * Frequency type <span class='property-internal'>One of 'Recurring', 'Continuous'</span> <span class='property-internal'>Required</span>
     */
    frequency;
    /**
     * Start date <span class='property-internal'>Required</span>
     */
    startDate;
    /**
     * End date <span class='property-internal'>Required</span> <span class='property-internal'>Must be greater than StartDate</span>
     */
    endDate;
    /**
     * Frequency start period  Should only be passed when Frequency type is Recurring <span class='property-internal'>Required when frequency is set to recurring</span>
     */
    annualCycleStartMMDD;
    /**
     * Frequency end period  Should only be passed when Frequency type is Recurring <span class='property-internal'>Required when frequency is set to recurring</span>
     */
    annualCycleEndMMDD;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecialAdjustmentEdit {
    /**
     * The special adjustment method identifier <span class='property-internal'>Required</span>
     */
    specialAdjustmentMethodId;
    /**
     * Reason for making the special adjustment <span class='property-internal'>Required</span>
     */
    comments;
    /**
     * The amount  See special adjustment method list for acceptable precision  Precision of -1 means the value should not be passed in <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     * The special adjustment type identifier <span class='property-internal'>Required</span>
     */
    specialAdjustmentTypeId;
    /**
     * The start date <span class='property-internal'>Required</span>
     */
    startDate;
    /**
     * The end date <span class='property-internal'>Required</span> <span class='property-internal'>Must be greater than StartDate</span>
     */
    endDate;
    /**
     * The frequency start period  Should only be passed when frequency type is Recurring <span class='property-internal'>Required (defined)</span>
     */
    annualCycleStartMMDD;
    /**
     * The frequency end period   Should only be passed when frequency type is Recurring <span class='property-internal'>Required (defined)</span>
     */
    annualCycleEndMMDD;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecialAdjustmentMethod {
    /**
     * Description of Special Adjustment method
     */
    label;
    /**
     * Special Adjustment Method ID
     */
    specialAdjustmentMethodId;
    /**
     * Indicates whether or not this method is for Electric meters only
     */
    electricOnly;
    /**
     * The symbol for the Special Adjustment's input value
     */
    symbol;
    /**
     * The precision on the Special Adjustment's input value
     */
    precision;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecialAdjustmentResponse {
    /**
     * Special adjustment identifier
     */
    specialAdjustmentId;
    /**
     * Sequence number; this controls the order in which special adjustments will be processed for this meter
     */
    indexNumber;
    /**
     * Amount
     */
    value;
    specialAdjustmentMethod;
    frequency;
    /**
     * Special adjustment comments
     */
    comments;
    createdByUser;
    /**
     * Created date
     */
    createdDate;
    modifiedByUser;
    /**
     * Last modified date
     */
    modifiedDate;
    specialAdjustmentType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecialAdjustmentType {
    /**
     * Special Adjustment type identifier
     */
    specialAdjustmentTypeId;
    /**
     * Special Adjustment type code
     */
    specialAdjustmentTypeCode;
    /**
     * Special Adjustment type name
     */
    specialAdjustmentTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecificReportResponse {
    /**
     * Unique identifier for the report
     */
    specificReportId;
    baseReport;
    /**
     * Report code
     */
    specificReportCode;
    /**
     * Report name
     */
    specificReportInfo;
    /**
     * Last time this report was run
     */
    lastViewed;
    /**
     * Indicates if this is a recommended report
     */
    recommended;
    reportCategory;
    /**
     * The report description
     */
    description;
    /**
     * Indicates if this report is visible to the current user
     */
    visible;
    /**
     * Indicates if this report is shared
     */
    shared;
    user;
    subscription;
    /**
     * List of reports related to this report
     */
    relatedReports;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SpecificWidgetResponse {
    /**
     * Specific widget identifier
     */
    specificWidgetId;
    /**
     * User Widget title
     */
    title;
    /**
     * Widget title
     */
    widgetInfo;
    /**
     * Widget description
     */
    description;
    /**
     * User Widget description
     */
    userWidgetDescription;
    /**
     * Dashboard row
     */
    row;
    /**
     * Dashboard column
     */
    col;
    /**
     * Widget height
     */
    height;
    /**
     * Widget width
     */
    width;
    /**
     * Widget filters
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class StatementDateTooLongAfterBillEndSettingRequest {
    /**
     * Threshold for how long the statement date can be after the end date  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Must be between 0 and 2147483647</span> <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span>
     */
    days;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class StatementDateTooLongAfterBillEndSettingResponse {
    /**
     * Threshold for how long the statement date can be after the end date  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    days;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class StatisticsResponse {
    /**
     * The model value
     */
    model;
    /**
     * The difference between the model and the actual value
     */
    difference;
    /**
     * Statistical measure of how spread out numbers are from the average
     */
    standardDeviation;
    /**
     * Statistical measure of how far each value in the data set is from the mean
     */
    variance;
    /**
     * Statistical measure of how close the data is to the fitted regression line
     */
    rSquared;
    unit;
    severity;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SubmissionTypeResponse {
    /**
     * The identifier for the submission type
     */
    submissionTypeId;
    /**
     * The name of the submission type
     */
    submissionTypeName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SubtractRequest {
    /**
     * Meters in this list will have their use or cost subtracted during bill calculation <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of SubtractMeterIds, SubtractMeterGroupIds can be set</span>
     */
    subtractMeterIds;
    /**
     * Distinct meters from these meter groups will have their use or cost subtracted together during the bill calculation  System auto groups cannot be used <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of SubtractMeterIds, SubtractMeterGroupIds can be set</span>
     */
    subtractMeterGroupIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SubtractResponse {
    /**
     * Meters in this list will have their use or cost subtracted during bill calculation
     */
    subtractMeters;
    /**
     * Distinct meters from these meter groups will have their use or cost subtracted together during the bill calculation
     */
    subtractMeterGroups;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SumRequest {
    /**
     * Meters in this list will have their use or cost added together during the bill calculation <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of SumMeterIds, SumMeterGroupIds can be set</span>
     */
    sumMeterIds;
    /**
     * Distinct meters from these meter groups will have their use or cost added together during the bill calculation  System auto groups cannot be used <span class='property-internal'>Required (defined)</span> <span class='property-internal'>Only one of SumMeterIds, SumMeterGroupIds can be set</span>
     */
    sumMeterGroupIds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SumResponse {
    /**
     * Meters in this list will have their use or cost added together during the bill calculation
     */
    sumMeters;
    /**
     * Distinct meters from these meter groups will have their use or cost added together during the bill calculation
     */
    sumMeterGroups;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SummarizationMethod {
    /**
     * The summarization method identifier
     */
    summarizationMethodId;
    /**
     * The name of the summarization method
     */
    summarizationMethodInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SystemSettingsRequest {
    /**
     * Default topmost space ID for new users <span class='property-internal'>Required (defined)</span>
     */
    defaultTopmostSpaceId;
    /**
     * Default topmost collection ID for new users <span class='property-internal'>Required (defined)</span>
     */
    defaultTopmostCollectionId;
    /**
     * The organization name <span class='property-internal'>Required (defined)</span>
     */
    organizationName;
    /**
     * Indicates whether or not organization name should be displayed in the application header <span class='property-internal'>Required</span>
     */
    displayOrganizationNameInHeader;
    /**
     * The organization logo  May be a base64-encoded PNG, JPG, or SVG image or a URI for an image hosted online  A null value will clear the saved image <span class='property-internal'>Min length of 5</span> <span class='property-internal'>Required (defined)</span>
     */
    organizationLogo;
    /**
     * Number of minutes after which users will be automatically logged out <span class='property-internal'>Must be between 10 and 780</span> <span class='property-internal'>Required (defined)</span>
     */
    automaticLogoutMinutes;
    /**
     * Default country for new users <span class='property-internal'>Required (defined)</span>
     */
    defaultCountry;
    /**
     * ID of the default time zone for new meters <span class='property-internal'>Required</span>
     */
    defaultMeterTimeZoneId;
    /**
     * Default date format for new users <span class='property-internal'>One of 'MM/dd/yyyy', 'dd/MM/yyyy'</span> <span class='property-internal'>Case sensitive</span> <span class='property-internal'>Required (defined)</span>
     */
    defaultDateFormat;
    /**
     * Default topmost cost center ID for new users <span class='property-internal'>Required (defined)</span>
     */
    defaultTopmostCostCenterId;
    /**
     * Default topmost place ID for new users <span class='property-internal'>Required (defined)</span>
     */
    defaultTopmostPlaceId;
    /**
     * Default user role ID for new users <span class='property-internal'>Required (defined)</span>
     */
    defaultUserRoleId;
    /**
     * Months to exclude from charts, including the current month. Set to 2 months by default.  Ex. If the current month is October,   A value of 0 will not exclude any months,   A value of 1 will exclude the month of October,   A value of 2 will exclude October and September,   A value of 3 will exclude October, September, and August,   A value of 13 will exclude October and the last full year of data.   A null value will preserve the existing setting. <span class='property-internal'>Must be between 0 and 13</span> <span class='property-internal'>Required (defined)</span>
     */
    monthsToExcludeFromCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SystemSettingsResponse {
    /**
     * The organization name
     */
    organizationName;
    /**
     * Indicates whether or not organization name should be displayed in the application header
     */
    displayOrganizationNameInHeader;
    /**
     * The organization logo  May be a base64-encoded PNG, JPG, or SVG image or a URI for an image hosted online  A null value will clear the saved image
     */
    organizationLogo;
    /**
     * Number of minutes after which users will be automatically logged out
     */
    automaticLogoutMinutes;
    /**
     * Default country for new users
     */
    defaultCountry;
    defaultMeterTimeZone;
    /**
     * Default date format for new users
     */
    defaultDateFormat;
    defaultTopmostPlace;
    defaultCostCenter;
    defaultCollection;
    defaultTopmostSpace;
    defaultUserRole;
    /**
     * Number of months to exclude from powerview charts
     */
    monthsToExcludeFromCharts;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SystemUserRoleChild {
    /**
     * The user role identifier
     */
    userRoleId;
    /**
     * The user role name
     */
    userRoleInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SystemUserRoleResponse {
    /**
     * Identifier for the system user role
     */
    systemUserRoleId;
    /**
     * Name of the system user role
     */
    systemUserRoleName;
    /**
     * Description of the system user role
     */
    description;
    /**
     * Number of users currently assigned to the system user role
     */
    usersAssignedCount;
    permissions;
    /**
     * Indicates the system user role that cannot be modified  These roles can be hidden using the SetUserRoleHidden API
     */
    readOnly;
    /**
     * Hidden status of the system user role  Roles Manage permission is required to access hidden roles
     */
    hidden;
    /**
     * List of products this system user role applies to
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class SystemUserRoleWithHiddenRequest {
    /**
     * Set a system user role to be hidden or shown  Roles Manage permission is required to access hidden roles
     */
    hidden;
    /**
     * Name of the system user role <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    systemUserRoleName;
    /**
     * Description of the system user role <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 1000 characters</span>
     */
    description;
    permissions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TagChild {
    /**
     *
     */
    tagTypeId;
    /**
     *
     */
    tagTypeInfo;
    /**
     *
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TagResponse {
    /**
     *
     */
    tagTypeId;
    /**
     *
     */
    tagTypeInfo;
    /**
     *
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Target {
    /**
     * Is the target setting enabled
     */
    enable;
    /**
     * What multiplier to use for the target
     */
    multiplier;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TargetSettings {
    /**
     * Target line label
     */
    label;
    /**
     * Target line base year
     */
    baseYear;
    costTarget;
    useTarget;
    ghgTarget;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TaskChild {
    /**
     * Identifier for the Task
     */
    taskId;
    /**
     * GUID for the Task
     */
    taskGUId;
    /**
     * Status of the task
     */
    status;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TaskEdit {
    /**
     *  <span class='property-internal'>Required</span>
     */
    taskNote;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TaskResponse {
    /**
     * Deprecated property - HasAttachments always returns true
     */
    hasAttachments;
    /**
     *
     */
    taskId;
    /**
     * The task guid
     */
    taskGUId;
    taskType;
    /**
     * The date and time the task began
     */
    beginDate;
    /**
     * The date and time the task finished. If the task is not finished, endDate will have no value
     */
    endDate;
    user;
    /**
     * The task's message
     */
    message;
    /**
     * The task's output. For certain task types, this field could be sizable
     */
    output;
    /**
     * The task's settings
     */
    settings;
    /**
     * The task's status
     */
    status;
    /**
     * User provided note/comment for this Task
     */
    taskNote;
    /**
     * Count of bills that are in the analyzing state, used by bill import tasks only
     */
    analyzingCount;
    /**
     * The count of bills with unresolved flags on this task, used by bill import tasks only
     */
    unresolvedFlagCount;
    /**
     * The count of successful bills that still exist (i.e. have not been deleted), used by bill import tasks only
     */
    currentSuccessCount;
    batch;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TaskType {
    /**
     * The task type identifier
     */
    taskTypeId;
    /**
     * The code for task type
     */
    taskTypeCode;
    /**
     * The task type information
     */
    taskTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TemplateChild {
    /**
     *
     */
    templateId;
    /**
     *
     */
    templateCode;
    /**
     *
     */
    templateInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TemplateLine {
    /**
     * The template line identifier
     */
    templateLineId;
    /**
     * The begin day
     */
    beginDay;
    /**
     * The end day
     */
    endDay;
    /**
     * The display order
     */
    displayOrder;
    /**
     * The caption
     */
    caption;
    /**
     * The help tag
     */
    helpTag;
    /**
     * Indicates whether a template line value is required or not required
     */
    isRequired;
    /**
     * The from previous template line identifier
     */
    fromPrevTemplateLineId;
    unit;
    costUnit;
    commodity;
    observationType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TemplateResponse {
    /**
     *
     */
    templateId;
    /**
     *
     */
    templateCode;
    /**
     *
     */
    templateInfo;
    /**
     *
     */
    note;
    commodity;
    demandUnit;
    useUnit;
    /**
     *
     */
    versions;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TemplateVendorLineRequest {
    /**
     * Specifies the type of line to create  Only cost observation types are allowed  To get the valid list of observation type ids call the GetObservationTypes API with ?filter=nounId one of '4'|'6'|'23' <span class='property-internal'>Required</span>
     */
    observationTypeId;
    /**
     * The label for this line, that will be shown on the bill <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 100 characters</span>
     */
    caption;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TemplateVersion {
    /**
     * The identifier for the template
     */
    templateId;
    /**
     * The identifier for the template version
     */
    versionId;
    /**
     * The begin date of the template version
     */
    beginDate;
    /**
     * The end date of the template version
     */
    endDate;
    /**
     * An array of template lines belonging to the template version
     */
    templateLines;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TimeFormatResponse {
    /**
     * Display name for time format
     */
    displayName;
    /**
     * Format mask for time format
     */
    formatMask;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TimeSeriesDataResponse {
    /**
     *
     */
    entities;
    /**
     *
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TimeSeriesEntity {
    /**
     *
     */
    type;
    /**
     *
     */
    id;
    /**
     *
     */
    display;
    /**
     *
     */
    secondaryDisplay;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * A collection of \"min\", \"max\", \"sum\", \"average\" Values, associated with an Entity.
 */
class TimeSeriesEntitySummary {
    /**
     *
     */
    entityId;
    min;
    max;
    sum;
    average;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TimeSeriesValue {
    /**
     *
     */
    id;
    /**
     *
     */
    date;
    /**
     * Value, as a decimal. Note that this could be very large, and/or to a high degree of  precision. In particular, in Javascript, it might not be able to be precisely  represented in a 64-bit float. See: `formattedValue`.
     */
    value;
    /**
     * Value, serialized as a String. This is the value that should be displayed to the  User. If Value is very large or to a high degree of precision its Number value  in Javascript cannot be relied upon. Other client languages might have similar  limitations. In order to guarantee that Value is displayed to the User to the  same degree of precision as is stored in the readings database, this  `formattedValue` property must be used.
     */
    formattedValue;
    /**
     * The Unit that `Value` is expressed in. E.g. \"kWh\".
     */
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TimeZoneChild {
    /**
     *
     */
    timeZoneId;
    /**
     *
     */
    timeZoneCode;
    /**
     *
     */
    timeZoneInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TimeZoneResponse {
    /**
     * The time zone id
     */
    timeZoneId;
    /**
     * The time zone code
     */
    timeZoneCode;
    /**
     * The time zone info
     */
    timeZoneInfo;
    /**
     * The time zone gmt offset
     */
    gmtOffset;
    /**
     * Indicates if the time zone observes daylight savings time or not
     */
    daylightSavingsObserved;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class ToggleVisible {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    visible;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TooManyConsecutiveEstimatedBillsSettingRequest {
    /**
     * Threshold for how many bills can be estimated in a row  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Must be between 1 and 2147483647</span> <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span>
     */
    bills;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TooManyConsecutiveEstimatedBillsSettingResponse {
    /**
     * Threshold for how many bills can be estimated in a row  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    bills;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TopmostCollection {
    /**
     * User's topmost combines multiple collections
     */
    isMultiTopmostCollection;
    /**
     *
     */
    multiTopmostCollections;
    /**
     * The collection identifier
     */
    collectionId;
    /**
     * The collection code
     */
    collectionCode;
    /**
     * The collection info
     */
    collectionInfo;
    collectionIcon;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TopmostCostCenter {
    /**
     * User's topmost combines multiple cost centers
     */
    isMultiTopmostCostCenter;
    /**
     *
     */
    multiTopmostCostCenters;
    /**
     * The cost center identifier
     */
    costCenterId;
    /**
     * The cost center code
     */
    costCenterCode;
    /**
     * The cost center info
     */
    costCenterInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TopmostPlace {
    /**
     * User's topmost combines multiple places
     */
    isMultiTopmostPlace;
    /**
     *
     */
    multiTopmostPlaces;
    placeType;
    /**
     * Tells whether or not the place's data is rolled up to its parents.
     */
    isDataRolledUp;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TopmostSpace {
    /**
     * User's topmost combines multiple places
     */
    isMultiTopmostPlace;
    /**
     *
     */
    multiTopmostPlaces;
    placeType;
    /**
     * Tells whether or not the place's data is rolled up to its parents.
     */
    isDataRolledUp;
    /**
     * The place identifier
     */
    placeId;
    /**
     * The place code
     */
    placeCode;
    /**
     * The place info
     */
    placeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TotalBillCostDoesNotMatchLineItemTypesSettingRequest {
    /**
     * List of observation type codes  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set <span class='property-internal'>Required when SettingStatus is set to Check, or Hold</span> <span class='property-internal'>List cannot be empty</span>
     */
    lineItemTypes;
    /**
     * The status of the audit setting <span class='property-internal'>One of 'Check', 'Hold', 'Skip'</span> <span class='property-internal'>Required (defined)</span>
     */
    settingStatus;
    /**
     * Minimum Bill/Meter Cost.   This audit will run only when the cost meets the specified minimum cost <span class='property-internal'>Required (defined)</span>
     */
    minimumCost;
    /**
     * List of Assignees.   Ids of the users the flag should get assigned to when the audit fails. <span class='property-internal'>Required (defined)</span>
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class TotalBillCostDoesNotMatchLineItemTypesSettingResponse {
    /**
     * List of observation type codes  If SettingStatus is set to Skip and no value is provided, EnergyCAP default will be set
     */
    lineItemTypes;
    /**
     * The status of the audit setting - Possible values Check, Hold, Skip
     */
    settingStatus;
    /**
     * The setting code
     */
    settingCode;
    /**
     * A description of the setting
     */
    settingDescription;
    /**
     * Minimum Bill/Meter Cost.   This audit wwill run only when the cost meets the specified minimum cost
     */
    minimumCost;
    /**
     * List of Assignees.   UserChildDTO representing the users the flag should get assigned to when the audit fails.
     */
    assignees;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * This DTO is used for the Trend Widget
 */
class TrendDataResponse {
    target;
    periodRange;
    /**
     * The latest calendar or fiscal year, denotes the YTD year
     */
    currentYear;
    /**
     * The type of calendar periods being returned, either \"Calendar\" or \"Fiscal\".  This applies to CurrentYear, PeriodRange, and dates in the Values array
     */
    calendarType;
    /**
     *
     */
    entities;
    /**
     *
     */
    values;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Target data for use / cost / target emissions data
 */
class TrendTarget {
    /**
     * Target year
     */
    targetYear;
    /**
     * Target label
     */
    targetLabel;
    /**
     * Target YTD label
     */
    targetYTDLabel;
    /**
     * Total value (use or cost) for the target year in the unit of the value being reported on
     */
    targetValue;
    /**
     * Year to date value (use or cost) for the target year in the unit of the value being reported on
     */
    targetYTDValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFCreate {
    /**
     * The UDF type. Possible value include: \"Vendor\", \"Place\", \"Account\", \"Meter\", \"ChannelVersion\", \"Rate\", \"Bill\", \"EnergyProject\", \"Collection\", and \"EmissionSource\". <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    udfType;
    /**
     * The UDF's name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    name;
    /**
     * Description for the UDF. Displayed next to the field name during data entry. <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    description;
    /**
     * The UDF's data type identifier.   Possible value include:  1 (boolean), 2 (integer), 3 (string),   4 (double), 6 (date), 12 (select list),  13 (url), 15 (formatted text), 16 (image),  17 (pdf), 18 (document file), 19 (JSON text) <span class='property-internal'>Required</span>
     */
    dataTypeId;
    /**
     * <p>The UDF's display order</p>  <p>A value of 1 or less will put this record the beginning of the list</p>  <p>If the display order exists it will put this record at that spot. Display orders greater than or equal to this will be incremented by 1</p>  <p>A value greater than the stored max will put this record at the end of the list</p> <span class='property-internal'>Required</span>
     */
    displayOrder;
    /**
     * <p>An array of options to populate a UDF select list.</p>  <p>Required when dataTypeId is 12 otherwise this will be ignored.</p> <span class='property-internal'>Required when dataTypeId is set to 12, case sensitive.</span>
     */
    udfSelectValues;
    /**
     * Marks a UDF as important. Important fields are highlighted during data entry.
     */
    important;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFEdit {
    /**
     * The UDF's name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    name;
    /**
     * The description for the UDF.   Not required, if left blank the description will not be updated. <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    description;
    /**
     * <p>The UDF's display order</p>  <p>A value of 1 or less will put this record the beginning of the list</p>  <p>A value greater than the stored max will put this record at the end of the list</p>  <p>When the old display order of the UDF being updated is less than the new specified display order, decrement the display order of all other UDFs falling between the old and new display order</p>  <p>When the old display order of the UDF being updated is greater than the new specified display order, increment the display order of all other UDFs falling between the old and new display order</p>  <p>All UDF lying outside the range of display orders being updated retain their original values</p> <span class='property-internal'>Required</span>
     */
    displayOrder;
    /**
     * <p>An array of options to populate a UDF select list.</p>  <p>Required when the UDF being edited has a dataTypeId of 12 otherwise this will be ignored.</p>  <p>To remove an option from the select list, omit it from this array. Options that are in use may not be deleted. To add a new option, pass in null as the udfSelectValueId</p>
     */
    udfSelectValues;
    /**
     * Important flag for the UDF. UDFs marked as important will be highlighted during data entry.   Not required, if left blank the flag's value will not be changed.
     */
    important;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFFieldChild {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    udfId;
    dataType;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    name;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    description;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    displayOrder;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    udfSelectValues;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    important;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFResponse {
    /**
     * The identifier of the custom field. <span class='property-internal'>Required (defined)</span>
     */
    udfId;
    /**
     * The name of the custom field. <span class='property-internal'>Required (defined)</span>
     */
    name;
    /**
     * The description for the custom field. <span class='property-internal'>Required (defined)</span>
     */
    description;
    /**
     * The type of the udf. Values include: Account, Meter, Vendor, Place, ChannelVersion, Rate, Bill, \"EnergyProject\", \"Collection\", and \"EmissionSource\". <span class='property-internal'>Required (defined)</span>
     */
    udfType;
    dataType;
    /**
     * The display order of the custom field. <span class='property-internal'>Required (defined)</span>
     */
    displayOrder;
    /**
     * Select values of the custom field, if it is a select list (DataType = 12). <span class='property-internal'>Required (defined)</span>
     */
    udfSelectValues;
    /**
     * The number of times this custom field has been used. <span class='property-internal'>Required (defined)</span>
     */
    count;
    /**
     * If true, then this udf is a system custom field <span class='property-internal'>Required (defined)</span>
     */
    locked;
    /**
     * If true, this custom field is important. <span class='property-internal'>Required (defined)</span>
     */
    important;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFSelectValueCreate {
    /**
     * The UDF select option's value <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    value;
    /**
     * The UDF select option's display order <span class='property-internal'>Required</span>
     */
    displayOrder;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFSelectValueEdit {
    /**
     * The UDF select value identifier. When creating a new option, assign null to this property. <span class='property-internal'>Required (defined)</span>
     */
    udfSelectValueId;
    /**
     * The UDF select option's value <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    value;
    /**
     * The UDF select option's display order <span class='property-internal'>Required</span>
     */
    displayOrder;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFSelectValueEntityResponse {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    udfSelectValueId;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    value;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    displayOrder;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFSelectValueResponse {
    /**
     *
     */
    udfSelectValueId;
    /**
     *
     */
    value;
    /**
     *
     */
    displayOrder;
    /**
     *
     */
    count;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFSelectValueUpdate {
    /**
     * The UDF select value identifier. When creating a new option, assign null to this property. <span class='property-internal'>Required (defined)</span>
     */
    udfSelectValueId;
    /**
     * The UDF select option's value <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFUpdate {
    /**
     * The Udf's ID. When creating a new UDF, assign null to this property. <span class='property-internal'>Required (defined)</span>
     */
    udfId;
    /**
     * The UDF's name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    name;
    /**
     * The UDF's description <span class='property-internal'>Must be between 0 and 128 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    description;
    /**
     * The UDF's data type identifier. Possible value include 1 (boolean), 2 (integer), 3 (string), 4 (double), 6 (date), 12 (select list) and 13 (url) <span class='property-internal'>Required</span>
     */
    dataTypeId;
    /**
     * <p>An array of options to populate a UDF select list.</p>  <p>Required when the UDF being edited has a dataTypeId of 12 otherwise this will be ignored.</p>  <p>To remove an option from the select list, omit it from this array. Options that are in use may not be deleted. To add a new option, pass in null as the udfSelectValueId</p> <span class='property-internal'>Required when dataTypeId is set to 12, case sensitive.</span>
     */
    udfSelectValues;
    /**
     * Used to mark a UDF as important. Important UDFs are highlighted during data entry. <span class='property-internal'>Required (defined)</span>
     */
    important;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UDFValue {
    /**
     * udfId of the UDF being edited <span class='property-internal'>Required (defined)</span>
     */
    udfId;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    value;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Unit {
    /**
     *
     */
    unitId;
    /**
     *  <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    unitCode;
    /**
     *  <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    unitInfo;
    /**
     *  <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    unitDisplayName;
    unitType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UnitChild {
    /**
     * The unit identifier
     */
    unitId;
    /**
     * The unit code
     */
    unitCode;
    /**
     * The unit info
     */
    unitInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UnitResponse {
    /**
     *
     */
    unitId;
    /**
     *
     */
    unitCode;
    /**
     *
     */
    unitInfo;
    unitType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UnitSystemSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UnitSystemSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UnitType {
    /**
     *
     */
    unitTypeId;
    /**
     *
     */
    unitTypeCode;
    /**
     *
     */
    unitTypeInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdateApprovedBills {
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdateApprovedBillsClassPermission {
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 *
 */
class UpdateBatchStatusRequest {
    /**
     * The status to set on the batch <span class='property-internal'>Required</span> <span class='property-internal'>One of 'Open', 'Pending', 'Closed'</span> <span class='property-internal'>Case sensitive</span>
     */
    batchStatus;
    /**
     * The batch note, referred to as a comment in the application when setting state to pending.  If opening another user's batch, the note will only be applied to the requesting user's open batch that is being set to pending (if any).  If null, the note will not be updated. Set to an empty string to remove the current note. <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    note;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdateResult {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    selected;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdateSkippedResult {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    skipped;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    skippedEntityIds;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    selected;
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdateUnitsOnExistingBills {
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdateUnitsOnExistingBillsClassPermission {
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpdatedOnlyResult {
    /**
     *  <span class='property-internal'>Required (defined)</span>
     */
    updated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UpsertAggregateMeterRequest {
    /**
     * Aggregation Meter Identifier  If AggregateMeterId is null: a new aggregate meter and version is always created  If AggregateMeterId is not null: it must exist and only associated with 1 account otherwise error  If AggregateMeterId exists: we will always update the Aggregate's MeterInfo and AccountInfo  If AggregateMeterId exists and no version exists on the same account and meter with the specified billing period: a new version is created  If AggregateMeterId exists and a version exists on the same account and meter with the specified billing period: the version is updated <span class='property-internal'>Required (defined)</span>
     */
    aggregateMeterId;
    /**
     * Begin period for the version in the format YYYYMM <span class='property-internal'>Required</span> <span class='property-internal'>Valid billing period between 190001 and 300001</span>
     */
    beginPeriod;
    /**
     * Meters to aggregate  All meters must match the commodity of the aggregate meter  All meters must be on the place the aggregate is created  All meters should be hidden <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    sourceMeterIds;
    /**
     * The identifier for the aggregate meter's commodity <span class='property-internal'>Required</span>
     */
    commodityId;
    /**
     * The aggregate meter info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    aggregateMeterInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserChild {
    /**
     * The user identifier
     */
    userId;
    /**
     * The user code
     */
    userCode;
    /**
     * The user's full name
     */
    fullName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserChildWithEmail {
    /**
     * Email ID of the user
     */
    email;
    /**
     * The user identifier
     */
    userId;
    /**
     * The user code
     */
    userCode;
    /**
     * The user's full name
     */
    fullName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserCreateRequest {
    /**
     * The user code. This is the user name that is used on sign-in <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 65 characters</span>
     */
    userCode;
    /**
     * The user's full name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    fullName;
    /**
     * The user's password. Password is not changed if this field is empty.  Not available for users whose identity is managed externally. <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    password;
    /**
     * The user's email address <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    email;
    /**
     * Create User with one or multiple topmost cost center ids  The CostCenterIds must be in the creating user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostCostCenterIds;
    /**
     * Create User with one or multiple topmost place ids  The PlaceIds must be in the creating user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostPlaceIds;
    /**
     * Update a user to one or multiple topmost EsaSpace ids  The EsaSpaceIds must be in the editing user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostSpaceIds;
    /**
     * Create User with one or multiple topmost collection ids  The CollectionIds must be in the creating user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostCollectionIds;
    /**
     * Whether or not the user signs in using active directory. This is used for install client only
     */
    activeDirectory;
    /**
     * Whether or not the user is active
     */
    active;
    /**
     * Days until the user's password expires  Must be set to 0 for users whose identity is managed externally. <span class='property-internal'>Required</span>
     */
    passwordExpirationInterval;
    /**
     * Force the user's password to have a minimum of 8 characters,   containing at least 1 uppercase, 1 lowercase, 1 number, and 1 symbol.  Must be set to false for users whose identity is managed externally. <span class='property-internal'>Required</span>
     */
    strongPassword;
    /**
     * Force the user to change their password on next login.   Must be set to false for users whose identity is managed externally. <span class='property-internal'>Required</span>
     */
    forcePasswordChange;
    /**
     * User role id of the user being created  User role id is required <span class='property-internal'>Required</span>
     */
    userRoleId;
    /**
     * The maximum bill amount (in dollars) the user can approve  If not included, the user has no max limit
     */
    maxApprovalAmount;
    /**
     * The user's report group. If not included, set to the default report group
     */
    reportGroupId;
    /**
     * List of user group ids  If null or not passed the groups a user assigned to will NOT be modified  If an empty list the user will be removed from all groups
     */
    userGroups;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserEditRequest {
    /**
     * The user code. This is the user name that is used on sign-in <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 65 characters</span>
     */
    userCode;
    /**
     * The user's full name <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 32 characters</span>
     */
    fullName;
    /**
     * The user's password. Password is not changed if this field is empty.  Not available for users whose identity is managed externally. <span class='property-internal'>Must be between 0 and 128 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    password;
    /**
     * The user's email address <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 128 characters</span>
     */
    email;
    /**
     * Update a user to one multiple topmost cost center ids  The CostCenterIds must be in the editing user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostCostCenterIds;
    /**
     * Update a user to one or multiple topmost place ids  The PlaceIds must be in the editing user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostPlaceIds;
    /**
     * Update a user to one or multiple topmost EsaSpace ids  The EsaSpaceIds must be in the editing user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostSpaceIds;
    /**
     * Update a user to one or multiple topmost collection ids  The CollectionIds must be in the editing user's topmost <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    topmostCollectionIds;
    /**
     * Whether or not the user signs in using active directory. This is used for install client only <span class='property-internal'>Required</span>
     */
    activeDirectory;
    /**
     * Whether or not the user is active <span class='property-internal'>Required</span>
     */
    active;
    /**
     * Days until the user's password expires  Must be set to 0 for users whose identity is managed externally. <span class='property-internal'>Required</span>
     */
    passwordExpirationInterval;
    /**
     * Force the user's password to have a minimum of 8 characters,   containing at least 1 uppercase, 1 lowercase, 1 number, and 1 symbol.  Must be set to false for users whose identity is managed externally. <span class='property-internal'>Required</span>
     */
    strongPassword;
    /**
     * Force the user to change their password on next login.   Must be set to false for users whose identity is managed externally. <span class='property-internal'>Required</span>
     */
    forcePasswordChange;
    /**
     * The user's role <span class='property-internal'>Required</span>
     */
    userRoleId;
    /**
     * The maximum bill amount (in dollars) the user can approve  If not included, the user has no max limit <span class='property-internal'>Required (defined)</span>
     */
    maxApprovalAmount;
    /**
     * The user's report group. If not included, set to the default report group <span class='property-internal'>Required</span>
     */
    reportGroupId;
    /**
     * List of user group ids  If null or not passed the groups a user assigned to will NOT be modified  If an empty list the user will be removed from all groups <span class='property-internal'>Required (defined)</span>
     */
    userGroups;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserGroupChild {
    /**
     * The user group identifier
     */
    userGroupId;
    /**
     * The user group name
     */
    userGroupName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserGroupRequest {
    /**
     * The user group name <span class='property-internal'>Must be between 0 and 64 characters</span> <span class='property-internal'>Required</span>
     */
    userGroupName;
    /**
     * A description of the user group <span class='property-internal'>Must be between 0 and 255 characters</span>
     */
    description;
    /**
     * List of system user ids in the group  Hidden users cannot be added to groups  On PUT request, if this property is null or not passed the group membership will not change  To remove all members pass an empty list
     */
    members;
    /**
     * List of new users to create and add to the group  The email cannot be currently used by another user  Users are created as limited users with the Contact role and default topmost
     */
    newUserEmail;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserGroupResponse {
    /**
     * The user group identifier
     */
    userGroupId;
    /**
     * The user group name
     */
    userGroupName;
    /**
     * The user group description
     */
    description;
    /**
     * The number of users in this group
     */
    memberCount;
    /**
     * The last time a member was inserted, updated, or deleted from the group
     */
    lastUpdated;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserGroupWithMembers {
    /**
     * List of user group members
     */
    members;
    /**
     * The user group identifier
     */
    userGroupId;
    /**
     * The user group name
     */
    userGroupName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserResponse {
    /**
     * User Identifier
     */
    userId;
    /**
     * User Code
     */
    userCode;
    /**
     * Full name of the user
     */
    fullName;
    userRole;
    costCenter;
    place;
    collection;
    /**
     * Is this a active directory user?
     */
    activeDirectory;
    /**
     * User is active or inactive
     */
    active;
    /**
     * Email ID of the user
     */
    email;
    /**
     * Days until password expires
     */
    passwordExpirationInterval;
    /**
     * Does user need a strong password - at least 8 character long, one upper case, one number, one special char
     */
    strongPassword;
    /**
     * Should the user be forced to change password on next login
     */
    forcePasswordChange;
    /**
     * Max Total cost of bill this user is allowed to approve
     */
    maxApprovalAmount;
    /**
     * last time the user logged in
     */
    lastLogin;
    reportGroup;
    /**
     * The external identifier for the user. This is only used for federated login.
     */
    externalUserId;
    /**
     * List of groups a user is a part of
     */
    userGroups;
    space;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UserRoleRequest {
    /**
     * The user role id to set for the user <span class='property-internal'>Required (defined)</span>
     */
    userRoleId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UsersAndRoles {
    /**
     *
     */
    permissionName;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    licenseIndex;
    /**
     *
     */
    products;
    /**
     *
     */
    permissionId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UsersAndRolesClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UsersAndUserGroups {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UsersAndUserGroupsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UtilityPlatform {
    /**
     * Date Release file Url used to record Data access release
     */
    dataReleaseFileUrl;
    /**
     * Identifier for the Utility Platform Provider Organization
     */
    utilityPlatformProviderKey;
    /**
     * Name of the Utility Platform Provider Organization
     */
    utilityPlatformProviderInfo;
    /**
     * Flag to indicate if Data Release requests from this Utility Provider can be declined
     */
    canDeclineDataRelease;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class UtilityPlatformMeter {
    meterAddress;
    dataAccessReleaseStatus;
    mostRecentAggregate;
    /**
     * The meter identifier
     */
    meterId;
    /**
     * The meter code
     */
    meterCode;
    /**
     * The meter info
     */
    meterInfo;
    meterType;
    commodity;
    /**
     * Indicates whether the Meter is Active
     */
    active;
    /**
     * Indicates whether the meter is a calculated meter
     */
    isCalculatedMeter;
    /**
     * Indicates whether the meter is a parent of a split
     */
    isSplitParentMeter;
    /**
     * Indicates whether the meter is a child of a split
     */
    isSplitChildMeter;
    /**
     * The meter's current serial number
     */
    serialNumber;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose value comparison DTO
 */
class ValueComparison {
    currentValue;
    previousValue;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose value DTO
 */
class ValueWithUnit {
    /**
     * Value
     */
    value;
    unit;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorAuditEnable {
    /**
     * True to allow all vendor accounts' bills to be audited  False to exclude all vendor accounts' bills from being audited <span class='property-internal'>Required (defined)</span>
     */
    auditEnabled;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorBillAccountChargeSplitSettingsResponse {
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code that the caption maps to
     */
    vendorCode;
    /**
     * The vendor info that the caption maps to
     */
    vendorInfo;
    /**
     * Split account charges with a bill line type assigned the cost categories
     */
    costCategories;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorChild {
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorContractResponse {
    /**
     * The contract identifier
     */
    contractId;
    /**
     * The contract code
     */
    contractCode;
    /**
     * The contract info
     */
    contractInfo;
    /**
     * The start date of the contract
     */
    startDate;
    /**
     * The expiration date of the contract
     */
    expirationDate;
    /**
     * Contract notes
     */
    notes;
    vendor;
    commodity;
    /**
     * The date a reminder will be sent for the contract expiration
     */
    renewalReminderDate;
    /**
     * Is this a Green Energy contract
     */
    isGreenEnergy;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorDigestActualYearlyResponse {
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
    /**
     * The vendor identifier
     */
    vendorId;
    globalUseUnit;
    costUnit;
    /**
     * The date and time the data was updated
     */
    updated;
    /**
     * An array of yearly data
     */
    results;
    /**
     * An array of yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorDigestActualYearlyResponseCommodityData {
    /**
     * The commodity code
     */
    commodityCode;
    /**
     * The commodity info
     */
    commodityInfo;
    /**
     * The commodity identifier
     */
    commodityId;
    commonUseUnit;
    costUnit;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorDigestActualYearlyResponseCommodityResults {
    /**
     * year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Common Use
     */
    commonUse;
    /**
     * Common Use Unit Cost
     */
    commonUseUnitCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorDigestActualYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Global Use
     */
    globalUse;
    /**
     * Global Use Unit Cost
     */
    globalUseUnitCost;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorRequest {
    /**
     * The vendor code <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 16 characters</span>
     */
    vendorCode;
    /**
     * The vendor info <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 50 characters</span>
     */
    vendorInfo;
    /**
     * The vendor's website <span class='property-internal'>Must be between 0 and 255 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    website;
    /**
     * The vendor's email address <span class='property-internal'>Must be between 0 and 128 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    email;
    /**
     * The vendor's phone number <span class='property-internal'>Must be between 0 and 50 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    phoneNumber;
    address;
    /**
     * A description of the vendor <span class='property-internal'>Must be between 0 and 4000 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    vendorDescription;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorResponse {
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
    address;
    /**
     * The vendor's edi code
     */
    ediCode;
    /**
     * The pay days
     */
    payDays;
    createdBy;
    /**
     * The date and time the vendor was created
     */
    createdDate;
    modifiedBy;
    /**
     * The date and time of the most recent modification
     */
    modifiedDate;
    /**
     * The vendor's website
     */
    website;
    /**
     * The vendor's email address
     */
    email;
    /**
     * The vendor's phone number
     */
    phoneNumber;
    /**
     * The vendor's rates
     */
    rates;
    /**
     * A description of the vendor
     */
    vendorDescription;
    /**
     * If there are settings configured to split account charges for this vendor  This will only be true when the setting applies to all accounts for this vendor
     */
    splitAccountChargesConfigured;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorTypeChild {
    /**
     * The vendor type identifier
     */
    vendorTypeId;
    /**
     * The vendor type code
     */
    vendorTypeCode;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorUDFResponse {
    /**
     * The vendor identifier
     */
    vendorId;
    /**
     * The vendor code
     */
    vendorCode;
    /**
     * The vendor info
     */
    vendorInfo;
    /**
     * An array of user-defined fields (UDFs)
     */
    udfs;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class Vendors {
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorsAndRatesModule {
    /**
     *
     */
    view;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorsAndRatesModuleClassPermission {
    /**
     *
     */
    view;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VendorsClassPermission {
    /**
     *
     */
    create;
    /**
     *
     */
    edit;
    /**
     *
     */
    delete;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VersionChild {
    /**
     *
     */
    versionId;
    /**
     *
     */
    beginDate;
    /**
     *
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class VersionResponse {
    /**
     *
     */
    versionId;
    /**
     *
     */
    beginDate;
    /**
     *
     */
    endDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WatticsDataPoint {
    /**
     * The identifier for a SmartAnalytics (Wattics) meter
     */
    watticsDataPointId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WatticsDataPointChild {
    /**
     * The identifier for a SmartAnalytics (Wattics) meter
     */
    watticsDataPointId;
    /**
     * The name for a SmartAnalytics (Wattics) meter
     */
    watticsDataPointInfo;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WatticsDataPointRequest {
    /**
     * The identifier for a SmartAnalytics (Wattics) meter  Set to null to remove the link <span class='property-internal'>Required (defined)</span>
     */
    watticsDataPointId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WatticsSite {
    /**
     * The identifier for a SmartAnalytics (Wattics) site
     */
    watticsSiteId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WatticsSiteRequest {
    /**
     * The identifier for a SmartAnalytics (Wattics) site  Set to null to remove the link <span class='property-internal'>Required (defined)</span>
     */
    watticsSiteId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherImportResult {
    /**
     * The begin date of the weather data that was imported
     */
    beginDate;
    /**
     * The end date of the weather data that was imported
     */
    endDate;
    /**
     * List of weather stations and the number of readings that were imported for each
     */
    weatherStationSummaries;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherImportSettings {
    /**
     * List of weather station codes for which to import data  If omitted or empty, weather data will be imported for all weather stations which are assigned to buildings
     */
    weatherStationCodes;
    /**
     * The begin date for the weather data  Readings will be imported from this date through the current date  If omitted or empty, weather data will be imported for the past 31 days
     */
    beginDate;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherSettings {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
    /**
     *
     */
    permissionId;
    /**
     *
     */
    permissionCode;
    /**
     *
     */
    permissionName;
    /**
     *
     */
    description;
    /**
     *
     */
    permissionCategoryName;
    /**
     *
     */
    isLicensed;
    /**
     *
     */
    products;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherSettingsClassPermission {
    /**
     *
     */
    view;
    /**
     *
     */
    manage;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherStationChild {
    /**
     * Weather Station Id
     */
    stationId;
    /**
     * Weather Station Code
     */
    stationCode;
    /**
     * Weather Station Name
     */
    stationInfo;
    /**
     * City the weather station is located
     */
    city;
    /**
     * State the weather station is located
     */
    state;
    /**
     * Country the weather station is located
     */
    country;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherStationResponse {
    /**
     * ID of the weather station
     */
    stationId;
    /**
     * Weather station code
     */
    stationCode;
    /**
     * Weather station info
     */
    stationInfo;
    /**
     * Code of the base weather station  Will be null if not linked
     */
    baseStationCode;
    channel;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WeatherStationSummary {
    /**
     * Begin date for this weather station  May differ from the begin date provided by the user if the most recent weather reading for this station was earlier.
     */
    beginDate;
    /**
     * Earliest reading date imported for this weather station  May differ from the begin date provided by the user if the most recent weather reading available for this station was later.
     */
    earliestReadingDate;
    /**
     * Weather station ID
     */
    weatherStationId;
    /**
     * Weather station code
     */
    weatherStationCode;
    /**
     * Weather station name
     */
    weatherStationName;
    /**
     * Source weather station code (if any)
     */
    baseWeatherStationCode;
    /**
     * Number of readings imported
     */
    numberOfReadingsImported;
    /**
     * Number of readings failed to import
     */
    numberOfFailedReadings;
    /**
     * Channel ID
     */
    channelId;
    /**
     * Channel code
     */
    channelCode;
    /**
     * Channel interval in seconds
     */
    channelIntervalInSeconds;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WebhookCreateRequest {
    /**
     * The name of the webhook <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    webhookName;
    /**
     * The description for the webhook
     */
    webhookDescription;
    /**
     * The type of event that will trigger the webhook <span class='property-internal'>Required</span>
     */
    webhookEventTypeId;
    /**
     * List of email addresses. Each recipient in this list will receive an email when a webhook fails or gets disabled <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    mailingList;
    /**
     * The URL to be invoked by the webhook <span class='property-internal'>Required</span>
     */
    url;
    /**
     * The encryption secret. <span class='property-internal'>Required</span>
     */
    secret;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * DTO for Custom Actions
 */
class WebhookCustomAction {
    /**
     * The list of ids on which to perform the custom action <span class='property-internal'>Cannot be Empty</span> <span class='property-internal'>Required (defined)</span>
     */
    ids;
    /**
     * The webhook identifier that represents the custom action <span class='property-internal'>Required</span>
     */
    webhookId;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WebhookEditRequest {
    /**
     * The webhook activation status (true=Active, false=Inactive) <span class='property-internal'>Required</span>
     */
    active;
    /**
     * The name of the webhook <span class='property-internal'>Required</span> <span class='property-internal'>Must be between 0 and 64 characters</span>
     */
    webhookName;
    /**
     * The description for the webhook <span class='property-internal'>Required (defined)</span>
     */
    webhookDescription;
    /**
     * The type of event that will trigger the webhook <span class='property-internal'>Required</span>
     */
    webhookEventTypeId;
    /**
     * List of email addresses. Each recipient in this list will receive an email when a webhook fails or gets disabled <span class='property-internal'>Required</span> <span class='property-internal'>Cannot be Empty</span>
     */
    mailingList;
    /**
     * The URL to be invoked by the webhook <span class='property-internal'>Required</span>
     */
    url;
    /**
     * The encryption secret. <span class='property-internal'>Required</span>
     */
    secret;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WebhookEventTypeChild {
    /**
     * The identifier for the webhook event type
     */
    webhookEventTypeId;
    /**
     * The name of the webhook event type
     */
    webhookEventTypeName;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WebhookLogDetailsResponse {
    /**
     * The URL that the webhook is configured for <span class='property-internal'>Required (defined)</span>
     */
    url;
    /**
     * The request that was sent from the webhook (headers and body) <span class='property-internal'>Required (defined)</span>
     */
    request;
    /**
     * The response that was received from the configured url (headers and body) <span class='property-internal'>Required (defined)</span>
     */
    response;
    /**
     * The HTTP status code that was received from the configured url  0 indicates no response was received from the configured url <span class='property-internal'>Required (defined)</span>
     */
    result;
    user;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WebhookLogResponse {
    /**
     * The identifier of the webhook log
     */
    webhookLogId;
    /**
     * The date and time that the webhook was fired
     */
    requestTimestamp;
    /**
     * The HTTP status code that was received from the configured url  0 indicates no response was received from the configured url
     */
    result;
    user;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WebhookResponse {
    /**
     * The identifier of the webhook
     */
    webhookId;
    /**
     * The name of the webhook
     */
    webhookName;
    /**
     * The description of the webhook
     */
    webhookDescription;
    createdBy;
    /**
     * The date and time the webhook was created
     */
    createdDate;
    /**
     * List of email addresses. Each recipient in this list will receive an email when a webhook fails or gets disabled
     */
    mailingList;
    /**
     * The percentage of success for the webhook
     */
    successRate;
    /**
     * The activation status of the webhook
     */
    webhookStatus;
    /**
     * Locked webhooks cannot be edited.  Locked webhooks will also NOT be automatically disabled on 10 consecutive failures
     */
    locked;
    /**
     * The URL to be invoked by the webhook
     */
    url;
    /**
     * The encryption secret
     */
    secret;
    eventType;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WidgetCreate {
    /**
     * Widget identifier <span class='property-internal'>Required</span>
     */
    widgetId;
    /**
     * Dashboard row <span class='property-internal'>Required</span>
     */
    row;
    /**
     * Dashboard column <span class='property-internal'>Required</span>
     */
    col;
    /**
     * Widget height <span class='property-internal'>Required</span>
     */
    height;
    /**
     * Widget width <span class='property-internal'>Required</span>
     */
    width;
    /**
     * Personal Widget title <span class='property-internal'>Must be between 0 and 600 characters</span> <span class='property-internal'>Required</span>
     */
    title;
    /**
     * Personal Widget description <span class='property-internal'>Must be between 0 and 600 characters</span>
     */
    userWidgetDescription;
    /**
     * Widget filters
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WidgetEdit {
    /**
     * Specific Widget identifier <span class='property-internal'>Required</span>
     */
    specificWidgetId;
    /**
     * Personal Widget title <span class='property-internal'>Must be between 0 and 600 characters</span> <span class='property-internal'>Required</span>
     */
    title;
    /**
     * Dashboard row <span class='property-internal'>Required (defined)</span>
     */
    row;
    /**
     * Dashboard column <span class='property-internal'>Required (defined)</span>
     */
    col;
    /**
     * Widget height <span class='property-internal'>Required (defined)</span>
     */
    height;
    /**
     * Widget width <span class='property-internal'>Required (defined)</span>
     */
    width;
    /**
     * Personal Widget description <span class='property-internal'>Must be between 0 and 600 characters</span> <span class='property-internal'>Required (defined)</span>
     */
    userWidgetDescription;
    /**
     * Widget filters <span class='property-internal'>Required (defined)</span>
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WidgetResponse {
    /**
     * Widget identifier
     */
    widgetId;
    /**
     * Widget info
     */
    widgetInfo;
    /**
     * Widget description
     */
    description;
    /**
     * Widget tags
     */
    tags;
    /**
     * Widget filters
     */
    filters;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WidgetSavingsYearlyResponse {
    billingPeriodRange;
    fiscalPeriodRange;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Use
     */
    allTimeBATCCUse;
    /**
     * Program to Date Use
     */
    allTimeUse;
    /**
     * Program to Date Savings Use = allTimeBATCCUse - allTimeUse
     */
    allTimeSavingsUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    allTimeBATCCTotalCost;
    /**
     * Program to Date Savings Total Cost
     */
    allTimeTotalCost;
    /**
     * Program to Date Savings Total Cost = allTimeBATCCTotalCost - allTimeTotalCost
     */
    allTimeSavingsTotalCost;
    /**
     * An array of savings yearly data
     */
    results;
    /**
     * The date and time the data was updated
     */
    updated;
    useUnit;
    costUnit;
    /**
     * An array of savings yearly data per commodity
     */
    commodities;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WidgetSavingsYearlyResponseCommodityData {
    commodity;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Use
     */
    allTimeBATCCUse;
    /**
     * Program to Date Native Use
     */
    allTimeUse;
    /**
     * Program to Date Savings Use = allTimeBATCCUse - allTimeUse
     */
    allTimeSavingsUse;
    /**
     * Program to Date BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    allTimeBATCCTotalCost;
    /**
     * Program to Date Total Cost
     */
    allTimeTotalCost;
    /**
     * Program to Date Savings Total Cost = allTimeBATCCTotalCost - allTimeTotalCost
     */
    allTimeSavingsTotalCost;
    /**
     * An array of yearly data
     */
    results;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WidgetSavingsYearlyResponseResults {
    /**
     * Year
     */
    year;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Total Cost
     */
    batccTotalCost;
    /**
     * Total Cost
     */
    totalCost;
    /**
     * Savings Total Cost = BATCCTotalCost - TotalCost
     */
    savingsTotalCost;
    /**
     * BATCC (Baseline Adjusted to Current Conditions) Use
     */
    batccUse;
    /**
     * Use
     */
    use;
    /**
     * Savings Use = BATCCUse - Use
     */
    savingsUse;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WorkflowDisplaySetting {
    /**
     * Indicates whether or not to show the Unapproved bill list in Bill Processing
     */
    showUnapprovedList;
    /**
     * Indicates whether or not to show the Waiting for Export to AP bill list in Bill Processing
     */
    showAPExportList;
    /**
     * Indicates whether or not to show the Waiting for Export to GL bill list in Bill Processing
     */
    showGLExportList;
    /**
     * Indicates whether or not to show the Held from Export bill list in Bill Processing
     */
    showExportHoldList;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
class WorkflowSettingsRequest {
    apExport;
    glExport;
    paymentExport;
    batch;
    approval;
    chargeback;
    billImport;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * Workflow settings response
 */
class WorkflowSettingsResponse {
    batch;
    approval;
    apExport;
    glExport;
    paymentExport;
    chargeback;
    billImport;
}

/**
 * EnergyCAP SDK
 * Document used to generate the EnergyCAP SDK
 *
 * OpenAPI spec version: 8.2506
 * Contact: support@energycap.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/**
 * General purpose year range DTO
 */
class YearRange {
    /**
     * The start year for the range
     */
    startYear;
    /**
     * The end year for the range
     */
    endYear;
}

class EnergyCapSdkModule {
    static forConfig(configurationFactory) {
        return {
            ngModule: EnergyCapSdkModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyCapSdkModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: EnergyCapSdkModule, imports: [CommonModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyCapSdkModule, providers: [provideHttpClient(withInterceptorsFromDi()), AccountService, AccountDigestService, AccountMeterService, AccrualService, ActivityService, AdminService, ApiService, ApiKeyService, AuditService, AuthenticationService, BatchService, BillService, BillAccountChargeSplitService, BillSplitService, BillViewService, BudgetService, CalculatedBillService, ChannelService, ChargebackEngineService, ChargebackTaskService, ChargebackWorkflowService, CollectionService, CommodityService, CommodityCategoryService, CommodityDigestService, CostCategoryService, CostCenterService, CostCenterDigestService, CountryService, CustomerService, DashboardService, DataPointService, EmissionRecordService, EmissionSourceService, EnergyManagerService, EnergyProjectService, EnergyStarService, EnvironmentService, EsaChannelService, EsaPlaceService, EsaReadingService, ExportService, FileStoreService, FilterService, FlagService, FormulaService, GHGService, GeneralLedgerService, HierarchyService, ImportService, ListService, MeService, MeterService, MeterDigestService, MeterGroupService, MeterGroupDigestService, NotificationService, ObservationService, ObservationTypeService, PlaceService, PlaceBenchmarkService, PlaceDigestService, PlaceGroupService, PlaceGroupDigestService, PostalCodeService, PrimaryUseService, RateService, RateDigestService, ReportService, ReportBuilderService, ReportDistributionService, RouteService, SavingsService, ScheduleService, SearchService, SentinelService, SetupService, SparkService, SummaryAccountService, SystemUserService, TagService, TaskService, TemplateService, TimeZoneService, UDFService, UnitService, UserGroupService, UserRoleService, UtilityPlatformService, VendorService, VendorDigestService, WeatherStationService, WebhookService, WidgetService, WorkflowService, SpanClasspropertyinfoPaginatedPaginatedspanService, SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService, SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService, SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService, SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService, SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService, SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService, SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService, SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService, SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, SpanClasspropertyinfoPermissionPermissionsRolesManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService, SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService, SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService, SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService], imports: [CommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnergyCapSdkModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [],
                    exports: [],
                    providers: [provideHttpClient(withInterceptorsFromDi()), AccountService, AccountDigestService, AccountMeterService, AccrualService, ActivityService, AdminService, ApiService, ApiKeyService, AuditService, AuthenticationService, BatchService, BillService, BillAccountChargeSplitService, BillSplitService, BillViewService, BudgetService, CalculatedBillService, ChannelService, ChargebackEngineService, ChargebackTaskService, ChargebackWorkflowService, CollectionService, CommodityService, CommodityCategoryService, CommodityDigestService, CostCategoryService, CostCenterService, CostCenterDigestService, CountryService, CustomerService, DashboardService, DataPointService, EmissionRecordService, EmissionSourceService, EnergyManagerService, EnergyProjectService, EnergyStarService, EnvironmentService, EsaChannelService, EsaPlaceService, EsaReadingService, ExportService, FileStoreService, FilterService, FlagService, FormulaService, GHGService, GeneralLedgerService, HierarchyService, ImportService, ListService, MeService, MeterService, MeterDigestService, MeterGroupService, MeterGroupDigestService, NotificationService, ObservationService, ObservationTypeService, PlaceService, PlaceBenchmarkService, PlaceDigestService, PlaceGroupService, PlaceGroupDigestService, PostalCodeService, PrimaryUseService, RateService, RateDigestService, ReportService, ReportBuilderService, ReportDistributionService, RouteService, SavingsService, ScheduleService, SearchService, SentinelService, SetupService, SparkService, SummaryAccountService, SystemUserService, TagService, TaskService, TemplateService, TimeZoneService, UDFService, UnitService, UserGroupService, UserRoleService, UtilityPlatformService, VendorService, VendorDigestService, WeatherStationService, WebhookService, WidgetService, WorkflowService, SpanClasspropertyinfoPaginatedPaginatedspanService, SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService, SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService, SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService, SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService, SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService, SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService, SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService, SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService, SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, SpanClasspropertyinfoPermissionPermissionsRolesManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService, SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService, SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService, SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { APIS, AbnormalBillCostWithOutlierAnalysisSettingRequest, AbnormalBillCostWithOutlierAnalysisSettingResponse, AbnormalBillDemandWithOutlierAnalysisSettingRequest, AbnormalBillDemandWithOutlierAnalysisSettingResponse, AbnormalBillUseWithOutlierAnalysisSettingRequest, AbnormalBillUseWithOutlierAnalysisSettingResponse, AccountAlertRequest, AccountAlertResponse, AccountAuditEnable, AccountAuditSettingsRequest, AccountAuditSettingsResponse, AccountBillAccountChargeSplitSettingsResponse, AccountChild, AccountChildWithType, AccountCodeHistoryChild, AccountCodeHistoryRequest, AccountCodeHistoryResponse, AccountConnectionStatusResponse, AccountCreate, AccountDigestActualMonthlyResponse, AccountDigestActualMonthlyResponseCommodityData, AccountDigestActualMonthlyResponseCommodityResults, AccountDigestActualMonthlyResponseResults, AccountDigestActualYearlyResponse, AccountDigestActualYearlyResponseCommodityData, AccountDigestActualYearlyResponseCommodityResults, AccountDigestActualYearlyResponseResults, AccountDigestService, AccountEdit, AccountMeterChild, AccountMeterChildWithSerialNumber, AccountMeterEdit, AccountMeterRateResponse, AccountMeterRequest, AccountMeterResponse, AccountMeterService, AccountOrMeterUsage, AccountPeriodRequest, AccountPeriodResponse, AccountRateChild, AccountRateRequest, AccountRateResponse, AccountResponse, AccountService, AccountTemplateResponse, AccountTypeChild, AccountUDFResponse, AccountingSettings, AccountingSettingsClassPermission, AccountingSettingsRequest, AccountingSettingsResponse, Accounts, AccountsClassPermission, AccountsModule, AccountsModuleActualData, AccountsModuleActualDataClassPermission, AccountsModuleClassPermission, AccrualProcessorRequest, AccrualService, AccrualSettings, AccrualSettingsClassPermission, AccrualSettingsResponse, ActionableBillCounts, Activity, ActivityService, ActualVsBudgetResponse, AddressChild, AddressChildBase, AddressLookup, AdjustedCostTypeResponse, AdjustmentBaseMethodChild, AdminService, AdminSettingsRequest, AdminSettingsResponse, AggregatedComparisonResponseGHGPerformanceComparison, AggregatedItemRankResponse, AggregatedMonthlyCAPTrendResponse, AggregatedResponseGHGBuildingRank, AggregatedResponseItemRankWithUnitResponse, AllInstalledReports, AllInstalledReportsClassPermission, ApiKeyCreateRequest, ApiKeyCreateResponse, ApiKeyEditRequest, ApiKeyResponse, ApiKeyService, ApiService, ApiUser, ApplicationSettings, ApplicationSettingsClassPermission, ApprovalWorkflowChild, ApprovalWorkflowRequestChild, ApprovalWorkflowSettings, ApproveBills, ApproveBillsClassPermission, AssignVersionsToStep, AucRangeRequest, AucRangeResponse, AuditService, AuditSettingRequest, AuditSettingResponse, AuditSettingsRequest, AuditSettingsResponse, AuthenticationService, BASE_PATH, BaselineEngine, BaselineEngineClassPermission, BaselineLog, BaselineProcessorRequest, BaselineProcessorRequestBaselineBill, BaselineProcessorResponse, BaselineProcessorResponseBaselineBill, BatchChild, BatchCreate, BatchEdit, BatchResponse, BatchService, BatchSettings, BatchWorkflowChild, BatchWorkflowSettings, BenchmarkCategoryResponse, BenchmarkEdit, BenchmarkSettingsEdit, BenchmarkSettingsResponse, BenchmarkValue, BenchmarkValueRequest, BenchmarkValuesResponse, BenchmarkWithUsedCountResponse, BillAccountBodyLineCreate, BillAccountBodyLineEdit, BillAccountChargeSplitMethodRequest, BillAccountChargeSplitMethodResponse, BillAccountChargeSplitService, BillAccountChargeSplitSettingResponse, BillAccountChargeSplitSettingsResponse, BillAccountMeterChild, BillAccountMeterResponse, BillAccountMeterStatisticsResponse, BillAccrualExclusionRequest, BillActionApprove, BillActionCustom, BillActionDelete, BillActionExportHold, BillActionHeaderUpdate, BillActionHistoricalExport, BillActionMove, BillActionMoveList, BillActionSplit, BillActionVoid, BillCAPture, BillCAPtureClassPermission, BillCalendarizedHistory, BillContainsLineItemDescriptionsSettingRequest, BillContainsLineItemDescriptionsSettingResponse, BillContainsLineItemTypesSettingRequest, BillContainsLineItemTypesSettingResponse, BillCreate, BillDeleteActionResult, BillEdit, BillEntryBodyLine, BillEntryBodyLineChild, BillEntryBodyLineWithNounChild, BillEntryMeterChild, BillEntryObservationTypeChild, BillEntryResponse, BillExport, BillExportOptions, BillHeaderChild, BillHeaderUpdate, BillHeaderUpdateAccountPeriodChild, BillHeaderUpdateBeginDateChild, BillHeaderUpdateBillingPeriodChild, BillHeaderUpdateControlCodeChild, BillHeaderUpdateDueDateChild, BillHeaderUpdateEndDateChild, BillHeaderUpdateEstimatedChild, BillHeaderUpdateInvoiceNumberChild, BillHeaderUpdateStatementDateChild, BillHeaderWorkflowChild, BillHistoryResponse, BillIdResponse, BillImportKickoutDetailsResponse, BillImportProfileColumnMapping, BillImportProfileObservation, BillImportProfileRequest, BillImportProfileResponse, BillImportRequest, BillImportTaskKickoutSummaryResponse, BillImportWorkflowSettings, BillKickoutImportRequest, BillLineTypeMappingResponse, BillListAdministrator, BillListAdministratorClassPermission, BillMeterBodyLineCreate, BillMeterBodyLineEdit, BillMeterCreate, BillMeterEdit, BillPaymentDetailsFileResponse, BillPaymentDetailsOptionalItem, BillPaymentDetailsOptionalItemWithErrors, BillPaymentDetailsOptionalResponse, BillPaymentEventCreate, BillPaymentEventResponse, BillResponse, BillReversal, BillReversalRequest, BillService, BillSignificantlyShorterOrLongerThanPreviousSettingRequest, BillSignificantlyShorterOrLongerThanPreviousSettingResponse, BillSplitDetailsRequest, BillSplitDetailsResponse, BillSplitParentDetailsResponse, BillSplitPlaceSizeChild, BillSplitService, BillUnexport, BillUnexportOptions, BillUsage, BillViewAccountChild, BillViewAddressChild, BillViewMeterChild, BillViewResponse, BillViewService, BillViewVendorChild, BillWorkflowSettings, BillWorkflowSettingsClassPermission, BillingPeriodCostUnitChild, BillingPeriodCostUnitDeltaChild, BillingPeriodUseCostChild, BillingPeriodUseCostDeltaChild, BillingPeriodUseUnitChild, BillingPeriodUseUnitDeltaChild, BillsAndBatches, BillsAndBatchesClassPermission, BillsModule, BillsModuleClassPermission, BillsOverdueFromVendorResponse, BodylineChild, BodylineResponse, BudgetCreate, BudgetDataType, BudgetEdit, BudgetPeriodType, BudgetResponse, BudgetService, BudgetUsageMethod, BudgetVersionCreate, BudgetVersionEdit, BudgetVersionResponse, BudgetVersionSummary, BudgetVersionSummaryResponse, BudgetsAndBudgetVersions, BudgetsAndBudgetVersionsClassPermission, BuildingAndMeterGroups, BuildingAndMeterGroupsClassPermission, BuildingsAndMetersModule, BuildingsAndMetersModuleActualData, BuildingsAndMetersModuleActualDataClassPermission, BuildingsAndMetersModuleBudgets, BuildingsAndMetersModuleBudgetsClassPermission, BuildingsAndMetersModuleCalendarizedData, BuildingsAndMetersModuleCalendarizedDataClassPermission, BuildingsAndMetersModuleClassPermission, BuildingsAndMetersModuleMeterIntervalData, BuildingsAndMetersModuleMeterIntervalDataClassPermission, BuildingsAndMetersModuleNormalizedData, BuildingsAndMetersModuleNormalizedDataClassPermission, BuildingsAndMetersModuleSavings, BuildingsAndMetersModuleSavingsClassPermission, BuildingsAndMetersModuleSustainability, BuildingsAndMetersModuleSustainabilityClassPermission, BuildingsAndOrganizations, BuildingsAndOrganizationsClassPermission, BulkBaselineProcessorRequest, BulkMeterCostAvoidanceSettings, COLLECTION_FORMATS, CalculateSavingsRequest, CalculatedBillCostRequest, CalculatedBillCostResponse, CalculatedBillDemandRequest, CalculatedBillDemandResponse, CalculatedBillDetailsResponse, CalculatedBillService, CalculatedBillUseRequest, CalculatedBillUseResponse, CalculationRequest, CalculationResponse, CalendarizedCalculationRequest, CalendarizedCalculationResponse, CalendarizedSumRequest, ChannelChild, ChannelChildWithObservationType, ChannelCreate, ChannelEdit, ChannelLatestReading, ChannelResponse, ChannelService, ChannelVersionRequest, ChannelVersionResponse, ChannelVersionWithBeginDateRequest, ChargebackEngineService, ChargebackProcessorSettings, ChargebackProcessorSettingsForAggregations, ChargebackProcessorSettingsForSplits, ChargebackProcessorSettingsWithoutFilters, ChargebackReversals, ChargebackReversalsClassPermission, ChargebackTaskRequest, ChargebackTaskResponse, ChargebackTaskService, ChargebackTaskVersionResponse, ChargebackWorkflowBase, ChargebackWorkflowCreate, ChargebackWorkflowDigestChild, ChargebackWorkflowDigestResponse, ChargebackWorkflowDigestSplitChild, ChargebackWorkflowEdit, ChargebackWorkflowResponse, ChargebackWorkflowService, ChargebackWorkflowSettings, ChargebackWorkflowStep, ChargebackWorkflowStepChild, ChargebackWorkflowStepCreate, ChargebackWorkflowStepEdit, Chargebacks, ChargebacksClassPermission, ChargebacksModule, ChargebacksModuleClassPermission, Claim, CollectionChild, CollectionEmissionSourceChild, CollectionRequest, CollectionResponse, CollectionService, Collections, CollectionsClassPermission, ColumnNumberOrOverrideValueNullableInt32, ColumnNumberOrOverrideValueString, CommodityCategory, CommodityCategoryChild, CommodityCategoryRequest, CommodityCategoryResponse, CommodityCategoryService, CommodityChild, CommodityChildWithCategory, CommodityDigestActualYearlyResponse, CommodityDigestActualYearlyResponseCommodityData, CommodityDigestActualYearlyResponseCommodityResults, CommodityDigestActualYearlyResponseResults, CommodityDigestService, CommodityEditRequest, CommodityRequest, CommodityResponse, CommodityService, CommodityValueComparison, Configuration, ContactChild, CopyFromMeterResponse, CopyMeterRequest, CostAvoidanceSettings, CostAvoidanceTask, CostCategoryEdit, CostCategoryResponse, CostCategoryService, CostCenterAccountChild, CostCenterChild, CostCenterCreate, CostCenterDigestActualMonthlyResponse, CostCenterDigestActualMonthlyResponseCommodityData, CostCenterDigestActualMonthlyResponseCommodityResults, CostCenterDigestActualMonthlyResponseResults, CostCenterDigestActualYearlyResponse, CostCenterDigestActualYearlyResponseCommodityData, CostCenterDigestActualYearlyResponseCommodityResults, CostCenterDigestActualYearlyResponseResults, CostCenterDigestService, CostCenterResponse, CostCenterService, CostCenters, CostCentersClassPermission, CostConversion, CostConversionBase, CostSavingsChild, CostSavingsUnit, Country, CountryService, CreateTemplateFromBill, CreateUtilityPlatformMeter, CustomerChild, CustomerResponse, CustomerService, DashboardAdministrator, DashboardAdministratorClassPermission, DashboardAndMapsModule, DashboardAndMapsModuleClassPermission, DashboardCopy, DashboardCreate, DashboardEdit, DashboardGlobalSettings, DashboardGlobalSettingsEdit, DashboardResponse, DashboardService, DataAccessRelease, DataAccessReleaseMetaData, DataAccessReleaseNoFileRequest, DataAccessReleaseRequest, DataAccessReleaseState, DataAccessReleaseStatus, DataPointChild, DataPointChildWithParentAndImportId, DataPointCreate, DataPointEdit, DataPointResponse, DataPointSentinel, DataPointService, DataTypeResponse, DateRange, DayOfWeek, DeleteReadingResponse, DestinationAccountMeterChild, DestinationAccountResponse, DetailedGuidResponse, DistributeAccountChargesBase, DistributeAccountChargesToBillsRequest, DistributedReportsConfiguration, DistributedReportsSettings, DistributedReportsSettingsClassPermission, DistributionVersionManage, DistributionVersionResponse, DueDateTooLongAfterBillEndSettingRequest, DueDateTooLongAfterBillEndSettingResponse, DynamicListRequest, DynamicPercentageBillSplit, DynamicPercentageBillSplitResponse, ENERGYSTARSubmissions, ENERGYSTARSubmissionsClassPermission, EditEsaPlaceSizesRequest, EmailProperties, EmissionRecordRequest, EmissionRecordResponse, EmissionRecordService, EmissionRecordType, EmissionSourceChild, EmissionSourceCreate, EmissionSourceEdit, EmissionSourceFactorCategoryBulkUpdate, EmissionSourceLink, EmissionSourceLinkRequest, EmissionSourceMultiFactorCreate, EmissionSourceMultiFactorEdit, EmissionSourceMultiFactorResponse, EmissionSourceResponse, EmissionSourceService, EmissionsSources, EmissionsSourcesClassPermission, EmissionsSourcesModule, EmissionsSourcesModuleClassPermission, EnergyCapOptionsEnergyCapIDOptions, EnergyCapSdkModule, EnergyManagerService, EnergyProjectCreate, EnergyProjectEdit, EnergyProjectPlaceChild, EnergyProjectResponse, EnergyProjectService, EnergyProjectType, EnergyProjectTypeCreate, EnergySavingsChild, EnergySavingsUnit, EnergyStarCommodityLinkChild, EnergyStarCommodityLinkRequest, EnergyStarCommodityMeterTypeMapping, EnergyStarCommodityMeterTypeMappingChild, EnergyStarMeterLinkChild, EnergyStarMeterLinkRequest, EnergyStarPlaceHierarchyResponse, EnergyStarPlaceLinkRequest, EnergyStarPlaceLinkResponse, EnergyStarPlaceMetricsRequest, EnergyStarPlaceMetricsResponse, EnergyStarPlaceSubmissionStatusChild, EnergyStarPlaceSubmissionStatusResponse, EnergyStarPmMeter, EnergyStarPmProperty, EnergyStarRatingChild, EnergyStarService, EnergyStarSettings, EnergyStarSettingsRequest, EnergyStarSettingsResponse, EnergyStarSubmissionPlaceChild, EnergyStarSubmissionRequest, EnergyStarTaskPlaceChild, EnergyStarTaskResponse, EntityScheduleSummary, Environment, EnvironmentService, EsaChannelChild, EsaChannelChildWithObservationType, EsaChannelCreate, EsaChannelEdit, EsaChannelResponse, EsaChannelService, EsaChannelVersionCreate, EsaChannelVersionCreateWithBeginDate, EsaChannelVersionEdit, EsaChannelVersionResponse, EsaDeleteReadingResponse, EsaDeleteReadingSummarizedResponse, EsaIntervalDataResponse, EsaPlaceCreate, EsaPlaceDataRollupRequest, EsaPlaceEdit, EsaPlaceResponse, EsaPlaceService, EsaPlaceSizeCreate, EsaReadingCreate, EsaReadingCreateError, EsaReadingCreateResponse, EsaReadingDelete, EsaReadingImportProfile, EsaReadingImportProfileColumn, EsaReadingImportProfileCreate, EsaReadingImportProfileEdit, EsaReadingImportProfileResponse, EsaReadingImportRequest, EsaReadingResponse, EsaReadingService, EsaReadingSummarizedDelete, EsaReadingSummarizedResponse, EsaReadingValue, EsaReadingValueError, EsaSentinelPrediction, EsaSentinelPredictionRequest, EsaSentinelPredictionResponse, EsaSentinelPredictionsResponse, Estimated, ExportBills, ExportBillsClassPermission, ExportFormatChild, ExportHold, ExportHoldClassPermission, ExportService, ExportWorkflowChild, ExportWorkflowSettings, FacilityProjects, FacilityProjectsClassPermission, FailedReadingResponse, FailedReadings, FileDataTypeResponse, FileStoreService, FilterDataResponse, FilterEdit, FilterResponse, FilterService, FixedAmountResponse, FixedDemandRequest, FixedPercentage, FixedPercentageResponse, FixedUnitCostRequest, FixedUseRequest, FlagActionChild, FlagEdit, FlagEventChild, FlagIssueActionChild, FlagIssueEdit, FlagIssueEditAction, FlagIssueEventChild, FlagIssueListAction, FlagIssueResponse, FlagIssueStatusChild, FlagIssueTypeChild, FlagListAction, FlagResponse, FlagService, FlagStatusChild, FlagTypeChild, FlagTypeCreate, FlagWidget, FlagWidgetChild, FlaggedItems, FlaggedItemsClassPermission, FloorAreaSplit, FloorAreaSplitResponse, FormTemplateChild, FormTemplateRequest, FormTemplateResponse, FormulaService, FormulaValidationRequest, FormulaValidationResponse, Frequency, GHGBuildingRank, GHGCarbonFootprintResponse, GHGDefaultFactor, GHGFactor, GHGFactorCategory, GHGFactorChild, GHGFactorRegion, GHGFactorResponse, GHGFactorVersionHistoryResponse, GHGFactorsResponse, GHGGas, GHGGroupEmissions, GHGPerformanceComparison, GHGScope, GHGScopeCategory, GHGScopeCategoryChild, GHGScopeResponse, GHGService, GHGSettingResponse, GHGSettings, GHGTargetEmissions, GHGTypeChild, GHGVersion, GHGYearlyEmissions, GHGasDefaultSettingRequest, GHGasDefaultSettingRequestCommodityChild, GHGasDefaultSettingRequestScopeCategoryAndFactorChild, GHGasDefaultSettingResponse, GHGasDefaultSettingResponseCommodityChild, GHGasFactorAndScopeCategoryPair, GHGasFactorAndScopeCategoryPairCreate, GHGasFactorChild, GHGasScopeCategoryChild, GLSubCodeChild, GLSubCodeChildRequest, GLSubcodeRequest, GLSubcodeResponse, GeneralLedgerChild, GeneralLedgerRequest, GeneralLedgerResponse, GeneralLedgerService, GenericBodylineRequest, GenericBodylineResponse, GenericCount, GlobalCostAvoidanceSettings, GlobalCostAvoidanceSettingsClassPermission, GreenhouseGasAdministrator, GreenhouseGasAdministratorClassPermission, GroupDisplaySetting, GroupMemberRequest, GroupMeterGroupResponse, GroupPlaceGroupMember, GroupPlaceGroupResponse, GroupsAndBenchmarksModule, GroupsAndBenchmarksModuleClassPermission, GuidResponse, HiddenRequest, HierarchicalCollections, HierarchicalCollections2, HierarchicalCostCenters, HierarchicalCostCenters2, HierarchicalDataPoint, HierarchicalEmissionSource, HierarchicalMeter, HierarchicalPlaces, HierarchicalPlaces2, HierarchicalSpaces, HierarchicalSpaces2, HierarchyService, HighPrecisionTimeSeriesValue, HighPrecisionValue, IActionResult, IGHGDefaultScopeCategoryAndFactor, IOutputFormatter, Icon, ImportService, IntervalData, IntervalDataAnalysis, IntervalDataAnalysisClassPermission, IntervalDataClassPermission, IntervalDataRollup, IntervalDataRollupClassPermission, ItemRankResponse, ItemRankWithUnitResponse, JsonBillExportAccount, JsonBillExportGeneralLedger, JsonBillExportLine, JsonBillExportMeter, JsonBillExportPlace, JsonBillExportResponse, JsonBillExportVendor, KickoutField, KickoutValue, LatestBenchmarkValue, LicenseFeatureAccountingExport, LicenseFeatureAccrualBills, LicenseFeatureBillCAPtureManagedServices, LicenseFeatureBillCapturePostPay, LicenseFeatureBillCapturePrePay, LicenseFeatureBudgets, LicenseFeatureCarbonHub, LicenseFeatureChargebacks, LicenseFeatureCostAvoidance, LicenseFeatureCustomBenchmarks, LicenseFeatureEnergyCAPPayments, LicenseFeatureGhg, LicenseFeatureGhgPremium, LicenseFeatureIntervalData, LicenseFeatureIntervalDataAnalysis, LicenseFeatureLegacyGHG, LicenseFeatureNonEnglishBills, LicenseFeatureReportDesigner, LicenseFeatureReportDistribution, LicenseFeatureUIDI, LicenseFeatureVendorManagementServices, LicenseFeatures, LicenseRequest, LicenseResponse, LicenseUsage, LinkSubAccountsFilters, LinkSubAccountsRequest, ListActionAccrualExclusion, ListActionApprove, ListActionCustom, ListActionExportHold, ListActionReverse, ListActionVoid, ListColumnEdit, ListCopy, ListCreate, ListCreateResponse, ListEdit, ListIds, ListResponse, ListResponseListField, ListResponseListItem, ListService, ListTypeChild, LoginRequest, LoginResponse, ManualAdjustmentRequest, ManuallyAdjustSavings, ManuallyAdjustSavingsClassPermission, ManufacturerChild, MapDashboardSettingsRequest, MapDashboardSettingsResponse, MapPlaceChild, MapWidgetResponse, Me, MeRequest, MeService, Message, MeterAccountChild, MeterActionCreateEmissionSource, MeterBillResponse, MeterCAPResponse, MeterCalendarizedUseVsWeatherResponse, MeterCategoryRequest, MeterCategoryResponse, MeterChild, MeterChildIncludeMeterImportIdAndRoute, MeterChildIncludePlace, MeterChildIncludePlaceAndSerialNumber, MeterChildIncludePlaceChannelLatestReading, MeterChildSearch, MeterCost, MeterCreate, MeterDigestActualAndCalendarizedMonthlyResponse, MeterDigestActualAndCalendarizedMonthlyResponseResults, MeterDigestActualAndCalendarizedYearlyResponse, MeterDigestActualAndCalendarizedYearlyResponseResults, MeterDigestCalendarizedTrendResponse, MeterDigestCalendarizedTrendResponseResults, MeterDigestNormalizedMonthlyResponse, MeterDigestNormalizedMonthlyResponseResults, MeterDigestNormalizedYearlyResponse, MeterDigestNormalizedYearlyResponseResults, MeterDigestSavingsMonthlyResponse, MeterDigestSavingsMonthlyResponseResults, MeterDigestSavingsYearlyResponse, MeterDigestSavingsYearlyResponseResults, MeterDigestService, MeterEdit, MeterGroupCategoryChild, MeterGroupChild, MeterGroupDigestChild, MeterGroupDigestDemandRankingChild, MeterGroupDigestDemandRankingResponse, MeterGroupDigestRankingChild, MeterGroupDigestRankingResponse, MeterGroupDigestService, MeterGroupMember, MeterGroupMemberChild, MeterGroupRequest, MeterGroupResponse, MeterGroupService, MeterLink, MeterLinkRequest, MeterRateResponse, MeterResponse, MeterSavingsSettings, MeterSavingsSettingsClassPermission, MeterSearchRequest, MeterSerialNumberHistoryChild, MeterSerialNumberHistoryRequest, MeterSerialNumberHistoryResponse, MeterService, MeterTemplateResponse, MeterTypeChild, MeterUDFResponse, Meters, MetersClassPermission, MissingBillWidget, ModelVoid, MonthlyCAPTrend, MonthlyTimeSeriesValue, MostRecentAggregate, MoveAccountsBetweenVendors, MoveAccountsBetweenVendorsClassPermission, MoveBillsDestination, MoveCreateMeter, MoveExistingBills, MoveExistingBillsClassPermission, NamedPeriod, NormalizationSettings, NormalizationSettingsClassPermission, NotificationActionButtonResponse, NotificationBadgeResponse, NotificationCategory, NotificationDetailsResponse, NotificationResponse, NotificationService, NotificationSettingRequest, NotificationSettingResponse, NotificationSettingsResponse, NotificationSystemSettingsRequest, NotificationType, NotificationUpdateRequest, ObservationMethodChild, ObservationRule, ObservationService, ObservationType, ObservationTypeChild, ObservationTypeChildBase, ObservationTypeService, OkObjectResult, OkResult, OptionalUpdateNullableDateOnly, OptionalUpdateNullableDecimal, OptionalUpdateNullableInt32, OptionalUpdateString, OtherSavingsCategory, OtherSavingsCategoryRequest, OtherSavingsRequest, OtherSavingsResponse, OutlierSeverityChild, PeriodComparison, PeriodRange, PeriodRangeComparison, PeriodRangeComparisonDetailed, PermissionProduct, Permissions, PermissionsRequest, PlaceBenchmarkService, PlaceCategoryRequest, PlaceCategoryResponse, PlaceChild, PlaceChildWithFloorArea, PlaceCost, PlaceCreate, PlaceDigestActualAndCalendarizedMonthlyResponse, PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData, PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults, PlaceDigestActualAndCalendarizedMonthlyResponseResults, PlaceDigestActualAndCalendarizedYearlyResponse, PlaceDigestActualAndCalendarizedYearlyResponseCommodityData, PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults, PlaceDigestActualAndCalendarizedYearlyResponseResults, PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison, PlaceDigestComparisonResponse, PlaceDigestEnergyUseIntensity, PlaceDigestEnergyUseIntensityEuiCommodity, PlaceDigestEnergyUseIntensityEuiEnergyProject, PlaceDigestGHGYearlyResponse, PlaceDigestGHGYearlyResponseGHGScope, PlaceDigestGHGYearlyResponseGHGType, PlaceDigestGHGYearlyResponseResults, PlaceDigestGHGYearlyResponseTargetComparison, PlaceDigestNormalizedCommodityTargetComparisonMonthly, PlaceDigestNormalizedCommodityTargetComparisonMonthlyCommodityResults, PlaceDigestNormalizedMonthlyResponse, PlaceDigestNormalizedMonthlyResponseCommodityData, PlaceDigestNormalizedMonthlyResponseCommodityResults, PlaceDigestNormalizedMonthlyResponseResults, PlaceDigestNormalizedTargetComparisonMonthly, PlaceDigestNormalizedTargetComparisonMonthlyResults, PlaceDigestNormalizedYearlyResponse, PlaceDigestNormalizedYearlyResponseCommodityData, PlaceDigestNormalizedYearlyResponseCommodityResults, PlaceDigestNormalizedYearlyResponseResults, PlaceDigestNormalizedYearlyResponseTargetComparison, PlaceDigestSavingsMonthlyResponse, PlaceDigestSavingsMonthlyResponseCommodityData, PlaceDigestSavingsMonthlyResponseCommodityDataCommodityResults, PlaceDigestSavingsMonthlyResponseResults, PlaceDigestSavingsYearlyResponse, PlaceDigestSavingsYearlyResponseCommodityData, PlaceDigestSavingsYearlyResponseCommodityDataCommodityResults, PlaceDigestSavingsYearlyResponseResults, PlaceDigestService, PlaceDigestTargetComparisonMonthly, PlaceDigestTargetComparisonMonthlyResults, PlaceEdit, PlaceEntityType, PlaceGroupCategoryChild, PlaceGroupChild, PlaceGroupDigestAreaDemandRankingResponse, PlaceGroupDigestAreaRankingChild, PlaceGroupDigestBenchmarkRankingChild, PlaceGroupDigestBenchmarkRankingResponse, PlaceGroupDigestChild, PlaceGroupDigestService, PlaceGroupDigestWeatherRankingChild, PlaceGroupDigestWeatherRankingResponse, PlaceGroupMember, PlaceGroupRequest, PlaceGroupResponse, PlaceGroupService, PlaceInfo, PlaceResponse, PlaceService, PlaceSizeChild, PlaceSizeCreate, PlaceSizeResponse, PlaceSubmissionTypeRequest, PlaceTypeRequest, PlaceTypeResponse, PlaceUDFResponse, PmCommodityChild, PostalCodeResponse, PostalCodeResponseWeatherStation, PostalCodeService, Preference, PreferenceRequest, PrimaryUseChild, PrimaryUseCreate, PrimaryUseResponse, PrimaryUseService, ProblemDetails, Product, ProjectManagerResponse, PublicDashboardsOrMaps, PublicDashboardsOrMapsClassPermission, QuickFilter, QuickReport, RateChild, RateChildResponse, RateCreate, RateDigestActualYearlyResponse, RateDigestActualYearlyResponseCommodityData, RateDigestActualYearlyResponseCommodityResults, RateDigestActualYearlyResponseResults, RateDigestService, RateEdit, RateResponse, RateSchedules, RateSchedulesClassPermission, RateService, RateVersionRequest, RateVersionResponse, Reading, ReadingChildBase, ReadingCreate, ReadingDelete, ReadingImportProfile, ReadingImportProfileColumn, ReadingImportProfileRequest, ReadingImportProfileResponse, ReadingImportRequest, ReadingResponse, Readings, ReadingsObservation, RecordImportProfile, RecordImportProfileEdit, RecordImportProfileRequest, RecordImportProfileResponse, RecordImportRequest, Records, RecordsClassPermission, RecordsListAdministrator, RecordsListAdministratorClassPermission, RecordsModule, RecordsModuleClassPermission, RelatedReportResponse, ReportAdministrator, ReportAdministratorClassPermission, ReportBuilderService, ReportCategoryChild, ReportChild, ReportCreate, ReportDistributionChild, ReportDistributionCreateRequest, ReportDistributionDetailsResponse, ReportDistributionEditRequest, ReportDistributionEmailSettings, ReportDistributionLogDetailsResponse, ReportDistributionLogEmailSettings, ReportDistributionLogReportSettings, ReportDistributionLogResponse, ReportDistributionService, ReportEdit, ReportGroupChildResponse, ReportGroupRequest, ReportGroupResponse, ReportGroups, ReportGroupsClassPermission, ReportService, ReportSubscriptionChild, ReportSubscriptionDayIndicatorChild, ReportSubscriptionRequest, ReportSubscriptionScheduleTypeChild, ReportSubscriptionScheduleTypeResponse, ReportType, ReportingSettingRequest, ReportingSettingResponse, Reports, ReportsClassPermission, ReportsModule, ReportsModuleClassPermission, RequiredAddressChild, ResetUserPasswords, ResetUserPasswordsClassPermission, Reviewed, Roles, RolesClassPermission, RollingComparisonDetail, RollingComparisonPeriodValue, RollingComparisonResponse, RollupUnitUpdate, RollupUnitUpdateCommonUnit, RouteChild, RouteDetailsResponse, RouteMeter, RouteMeterChannelLatestReadingResponse, RouteRequest, RouteResponse, RouteService, SavingsAdjustments, SavingsAdjustmentsClassPermission, SavingsDailyData, SavingsEngine, SavingsEngineClassPermission, SavingsLog, SavingsMeterBillDailyResponse, SavingsMeterBillResponse, SavingsService, ScheduleChild, ScheduleCreate, ScheduleDay, ScheduleDayCreate, ScheduleEdit, ScheduleResponse, ScheduleService, ScheduleWithEntitySummaries, SearchAccountChild, SearchAccountChildSearchAccountChild, SearchAccountMeterBillEntry, SearchCollectionChild, SearchCollectionChildSearchCollection, SearchCostCenterChild, SearchCostCenterChildSearchCostCenter, SearchEmissionSourceChild, SearchEmissionSourceChildSearchEmissionSource, SearchMeterChild, SearchMeterChildSearchMeterChild, SearchParentPlaceChild, SearchPlaceChild, SearchPlaceChildSearchPlaceChild, SearchPlaceGroup, SearchResponse, SearchService, SendDataAccessReleaseRequest, SendNotifications, SendNotificationsClassPermission, SentinelService, Setup, SetupService, ShareRequest, ShareResponse, SharedBillLists, SharedBillListsClassPermission, SharedDashboardsOrMaps, SharedDashboardsOrMapsClassPermission, SharedRecordsLists, SharedRecordsListsClassPermission, SharedReports, SharedReportsClassPermission, SingleBoolean, SingleValue, SpanClasspropertyinfoPaginatedPaginatedspanService, SpanClasspropertyinfoPermissionPermissionsAccountingSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccountsCreatespanService, SpanClasspropertyinfoPermissionPermissionsAccountsDeletespanService, SpanClasspropertyinfoPermissionPermissionsAccountsEditspanService, SpanClasspropertyinfoPermissionPermissionsAccountsViewspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsRunspanService, SpanClasspropertyinfoPermissionPermissionsAccrualSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsApplicationSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsApproveBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsBaselineEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsBillCAPtureViewspanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsBillWorkflowSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesCreatespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesDeletespanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesEditspanService, SpanClasspropertyinfoPermissionPermissionsBillsAndBatchesViewspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsEditspanService, SpanClasspropertyinfoPermissionPermissionsBudgetsAndBudgetVersionsViewspanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingAndMeterGroupsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsCreatespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsDeletespanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsEditspanService, SpanClasspropertyinfoPermissionPermissionsBuildingsAndOrganizationsViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebackReversalsManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksManagespanService, SpanClasspropertyinfoPermissionPermissionsChargebacksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsChargebacksRunspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsCreatespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsDeletespanService, SpanClasspropertyinfoPermissionPermissionsCollectionsEditspanService, SpanClasspropertyinfoPermissionPermissionsCollectionsViewspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersCreatespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersDeletespanService, SpanClasspropertyinfoPermissionPermissionsCostCentersEditspanService, SpanClasspropertyinfoPermissionPermissionsCostCentersViewspanService, SpanClasspropertyinfoPermissionPermissionsDashboardAndMapsModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsDistributedReportsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsManagespanService, SpanClasspropertyinfoPermissionPermissionsENERGYSTARSubmissionsRunspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesCreatespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesDeletespanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesEditspanService, SpanClasspropertyinfoPermissionPermissionsEmissionsSourcesViewspanService, SpanClasspropertyinfoPermissionPermissionsExportBillsRunspanService, SpanClasspropertyinfoPermissionPermissionsExportHoldManagespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsCreatespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsDeletespanService, SpanClasspropertyinfoPermissionPermissionsFacilityProjectsEditspanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsManagespanService, SpanClasspropertyinfoPermissionPermissionsFlaggedItemsViewspanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsGlobalCostAvoidanceSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsGroupsAndBenchmarksModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsIntervalDataManagespanService, SpanClasspropertyinfoPermissionPermissionsLicenseFeatureIntervalDataAnalysisViewspanService, SpanClasspropertyinfoPermissionPermissionsManuallyAdjustSavingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsMeterSavingsSettingsViewspanService, SpanClasspropertyinfoPermissionPermissionsMetersCreatespanService, SpanClasspropertyinfoPermissionPermissionsMetersDeletespanService, SpanClasspropertyinfoPermissionPermissionsMetersEditspanService, SpanClasspropertyinfoPermissionPermissionsMetersViewspanService, SpanClasspropertyinfoPermissionPermissionsMoveAccountsBetweenVendorsManagespanService, SpanClasspropertyinfoPermissionPermissionsMoveExistingBillsManagespanService, SpanClasspropertyinfoPermissionPermissionsPublicDashboardsOrMapsManagespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesCreatespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesDeletespanService, SpanClasspropertyinfoPermissionPermissionsRateSchedulesEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsCreatespanService, SpanClasspropertyinfoPermissionPermissionsRecordsDeletespanService, SpanClasspropertyinfoPermissionPermissionsRecordsEditspanService, SpanClasspropertyinfoPermissionPermissionsRecordsViewspanService, SpanClasspropertyinfoPermissionPermissionsReportAdministratorManagespanService, SpanClasspropertyinfoPermissionPermissionsReportGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsReportsRunspanService, SpanClasspropertyinfoPermissionPermissionsRolesManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsManagespanService, SpanClasspropertyinfoPermissionPermissionsSavingsAdjustmentsViewspanService, SpanClasspropertyinfoPermissionPermissionsSavingsEngineRunspanService, SpanClasspropertyinfoPermissionPermissionsUnitSystemSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsManagespanService, SpanClasspropertyinfoPermissionPermissionsUsersAndUserGroupsViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsAndRatesModuleViewspanService, SpanClasspropertyinfoPermissionPermissionsVendorsCreatespanService, SpanClasspropertyinfoPermissionPermissionsVendorsDeletespanService, SpanClasspropertyinfoPermissionPermissionsVendorsEditspanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsManagespanService, SpanClasspropertyinfoPermissionPermissionsWeatherSettingsViewspanService, SparkService, SpecialAdjustmentCreate, SpecialAdjustmentEdit, SpecialAdjustmentMethod, SpecialAdjustmentResponse, SpecialAdjustmentType, SpecificReportResponse, SpecificWidgetResponse, StatementDateTooLongAfterBillEndSettingRequest, StatementDateTooLongAfterBillEndSettingResponse, StatisticsResponse, SubmissionTypeResponse, SubtractRequest, SubtractResponse, SumRequest, SumResponse, SummarizationMethod, SummaryAccountService, SystemSettingsRequest, SystemSettingsResponse, SystemUserRoleChild, SystemUserRoleResponse, SystemUserRoleWithHiddenRequest, SystemUserService, TagChild, TagResponse, TagService, Target, TargetSettings, TaskChild, TaskEdit, TaskResponse, TaskService, TaskType, TemplateChild, TemplateLine, TemplateResponse, TemplateService, TemplateVendorLineRequest, TemplateVersion, TimeFormatResponse, TimeSeriesDataResponse, TimeSeriesEntity, TimeSeriesEntitySummary, TimeSeriesValue, TimeZoneChild, TimeZoneResponse, TimeZoneService, ToggleVisible, TooManyConsecutiveEstimatedBillsSettingRequest, TooManyConsecutiveEstimatedBillsSettingResponse, TopmostCollection, TopmostCostCenter, TopmostPlace, TopmostSpace, TotalBillCostDoesNotMatchLineItemTypesSettingRequest, TotalBillCostDoesNotMatchLineItemTypesSettingResponse, TrendDataResponse, TrendTarget, UDFCreate, UDFEdit, UDFFieldChild, UDFResponse, UDFSelectValueCreate, UDFSelectValueEdit, UDFSelectValueEntityResponse, UDFSelectValueResponse, UDFSelectValueUpdate, UDFService, UDFUpdate, UDFValue, Unit, UnitChild, UnitResponse, UnitService, UnitSystemSettings, UnitSystemSettingsClassPermission, UnitType, UpdateApprovedBills, UpdateApprovedBillsClassPermission, UpdateBatchStatusRequest, UpdateResult, UpdateSkippedResult, UpdateUnitsOnExistingBills, UpdateUnitsOnExistingBillsClassPermission, UpdatedOnlyResult, UpsertAggregateMeterRequest, UserChild, UserChildWithEmail, UserCreateRequest, UserEditRequest, UserGroupChild, UserGroupRequest, UserGroupResponse, UserGroupService, UserGroupWithMembers, UserResponse, UserRoleRequest, UserRoleService, UsersAndRoles, UsersAndRolesClassPermission, UsersAndUserGroups, UsersAndUserGroupsClassPermission, UtilityPlatform, UtilityPlatformMeter, UtilityPlatformService, ValueComparison, ValueWithUnit, VendorAuditEnable, VendorBillAccountChargeSplitSettingsResponse, VendorChild, VendorContractResponse, VendorDigestActualYearlyResponse, VendorDigestActualYearlyResponseCommodityData, VendorDigestActualYearlyResponseCommodityResults, VendorDigestActualYearlyResponseResults, VendorDigestService, VendorRequest, VendorResponse, VendorService, VendorTypeChild, VendorUDFResponse, Vendors, VendorsAndRatesModule, VendorsAndRatesModuleClassPermission, VendorsClassPermission, VersionChild, VersionResponse, WatticsDataPoint, WatticsDataPointChild, WatticsDataPointRequest, WatticsSite, WatticsSiteRequest, WeatherImportResult, WeatherImportSettings, WeatherSettings, WeatherSettingsClassPermission, WeatherStationChild, WeatherStationResponse, WeatherStationService, WeatherStationSummary, WebhookCreateRequest, WebhookCustomAction, WebhookEditRequest, WebhookEventTypeChild, WebhookLogDetailsResponse, WebhookLogResponse, WebhookResponse, WebhookService, WidgetCreate, WidgetEdit, WidgetResponse, WidgetSavingsYearlyResponse, WidgetSavingsYearlyResponseCommodityData, WidgetSavingsYearlyResponseResults, WidgetService, WorkflowDisplaySetting, WorkflowService, WorkflowSettingsRequest, WorkflowSettingsResponse, YearRange };
//# sourceMappingURL=energycap-energycap-sdk-angular.mjs.map
